
SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
SET time_zone = "+00:00";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

--
-- Database: `drupal1101`
--
-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]batch`
--

CREATE TABLE `[[dbprefix]]batch` (
  `bid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique batch ID.',
  `token` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'A string token generated against the current user''s session id and the batch id, used to ensure that only the user who submitted the batch can effectively access it.',
  `timestamp` int NOT NULL COMMENT 'A Unix timestamp indicating when this batch was submitted for processing. Stale batches are purged at cron time.',
  `batch` longblob COMMENT 'A serialized array containing the processing data for the batch.',
  PRIMARY KEY (`bid`),
  KEY `token` (`token`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COMMENT='Stores details about batches (processes that run in…' AUTO_INCREMENT=2 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]block_content`
--

CREATE TABLE `[[dbprefix]]block_content` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `block_content_field__uuid__value` (`uuid`),
  UNIQUE KEY `block_content__revision_id` (`revision_id`),
  KEY `block_content_field__type__target_id` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The base table for block_content entities.' AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]block_content_field_data`
--

CREATE TABLE `[[dbprefix]]block_content_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `info` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `reusable` tinyint DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `block_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `block_content__revision_id` (`revision_id`),
  KEY `block_content_field__type__target_id` (`type`),
  KEY `block_content_field__reusable` (`reusable`),
  KEY `block_content__status_type` (`status`,`type`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The data table for block_content entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]block_content_field_revision`
--

CREATE TABLE `[[dbprefix]]block_content_field_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `info` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `block_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The revision data table for block_content entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]block_content_revision`
--

CREATE TABLE `[[dbprefix]]block_content_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `block_content__id` (`id`),
  KEY `block_content_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The revision table for block_content entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]block_content_revision__body`
--

CREATE TABLE `[[dbprefix]]block_content_revision__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Revision archive storage for block_content field body.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]block_content__body`
--

CREATE TABLE `[[dbprefix]]block_content__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Data storage for block_content field body.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cachetags`
--

CREATE TABLE `[[dbprefix]]cachetags` (
  `tag` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Namespace-prefixed tag string.',
  `invalidations` int NOT NULL DEFAULT '0' COMMENT 'Number incremented when the tag is invalidated.',
  PRIMARY KEY (`tag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Cache table for tracking cache tag invalidations.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_access_policy`
--

CREATE TABLE `[[dbprefix]]cache_access_policy` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_access_policy`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_bootstrap`
--

CREATE TABLE `[[dbprefix]]cache_bootstrap` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_bootstrap`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_config`
--

CREATE TABLE `[[dbprefix]]cache_config` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_config`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_container`
--

CREATE TABLE `[[dbprefix]]cache_container` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_container`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_data`
--

CREATE TABLE `[[dbprefix]]cache_data` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_data`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_default`
--

CREATE TABLE `[[dbprefix]]cache_default` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_default`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_discovery`
--

CREATE TABLE `[[dbprefix]]cache_discovery` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_discovery`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_dynamic_page_cache`
--

CREATE TABLE `[[dbprefix]]cache_dynamic_page_cache` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_dynamic_page_cache`
--

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_entity`
--

CREATE TABLE `[[dbprefix]]cache_entity` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_entity`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_menu`
--

CREATE TABLE `[[dbprefix]]cache_menu` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_menu`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_render`
--

CREATE TABLE `[[dbprefix]]cache_render` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Storage for the cache API.';

--
-- Dumping data for table `[[dbprefix]]cache_render`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]comment`
--

CREATE TABLE `[[dbprefix]]comment` (
  `cid` int unsigned NOT NULL AUTO_INCREMENT,
  `comment_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`cid`),
  UNIQUE KEY `comment_field__uuid__value` (`uuid`),
  KEY `comment_field__comment_type__target_id` (`comment_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The base table for comment entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]comment_entity_statistics`
--

CREATE TABLE `[[dbprefix]]comment_entity_statistics` (
  `entity_id` int unsigned NOT NULL DEFAULT '0' COMMENT 'The entity_id of the entity for which the statistics are compiled.',
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'node' COMMENT 'The entity_type of the entity to which this comment is a reply.',
  `field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field_name of the field that was used to add this comment.',
  `cid` int NOT NULL DEFAULT '0' COMMENT 'The "[[dbprefix]]comment".cid of the last comment.',
  `last_comment_timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp of the last comment that was posted within this node, from "[[dbprefix]]comment".changed.',
  `last_comment_name` varchar(60) DEFAULT NULL COMMENT 'The name of the latest author to post a comment on this node, from "[[dbprefix]]comment".name.',
  `last_comment_uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The user ID of the latest author to post a comment on this node, from "[[dbprefix]]comment".uid.',
  `comment_count` int unsigned NOT NULL DEFAULT '0' COMMENT 'The total number of comments on this entity.',
  PRIMARY KEY (`entity_id`,`entity_type`,`field_name`),
  KEY `last_comment_timestamp` (`last_comment_timestamp`),
  KEY `comment_count` (`comment_count`),
  KEY `last_comment_uid` (`last_comment_uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Maintains statistics of entity and comments posts to show …';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]comment_field_data`
--

CREATE TABLE `[[dbprefix]]comment_field_data` (
  `cid` int unsigned NOT NULL,
  `comment_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `pid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `entity_id` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `subject` varchar(64) DEFAULT NULL,
  `name` varchar(60) DEFAULT NULL,
  `mail` varchar(254) DEFAULT NULL,
  `homepage` varchar(255) DEFAULT NULL,
  `hostname` varchar(128) DEFAULT NULL,
  `created` int NOT NULL,
  `changed` int DEFAULT NULL,
  `thread` varchar(255) NOT NULL,
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`cid`,`langcode`),
  KEY `comment__id__default_langcode__langcode` (`cid`,`default_langcode`,`langcode`),
  KEY `comment_field__comment_type__target_id` (`comment_type`),
  KEY `comment_field__uid__target_id` (`uid`),
  KEY `comment_field__created` (`created`),
  KEY `comment__status_comment_type` (`status`,`comment_type`,`cid`),
  KEY `comment__status_pid` (`pid`,`status`),
  KEY `comment__num_new` (`entity_id`,`entity_type`,`comment_type`,`status`,`created`,`cid`,`thread`(191)),
  KEY `comment__entity_langcode` (`entity_id`,`entity_type`,`comment_type`,`default_langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The data table for comment entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]comment__comment_body`
--

CREATE TABLE `[[dbprefix]]comment__comment_body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `comment_body_value` longtext NOT NULL,
  `comment_body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `comment_body_format` (`comment_body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Data storage for comment field comment_body.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]config`
--

CREATE TABLE `[[dbprefix]]config` (
  `collection` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object collection.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object name.',
  `data` longblob COMMENT 'A serialized configuration object data.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The base table for configuration data.';

--
-- Dumping data for table `[[dbprefix]]config`
--

INSERT INTO `[[dbprefix]]config` VALUES
('', 'announcements_feed.settings', 'a:4:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"0G5pZBcxbg8ONYzNLd1RJIsvuFFewm9htnS4I-ABKJ8";}s:7:"max_age";i:86400;s:13:"cron_interval";i:21600;s:5:"limit";i:10;}'),
('', 'automated_cron.settings', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"fUksROt4FfkAU9BV4hV2XvhTBSS2nTNrZS4U7S-tKrs";}s:8:"interval";i:10800;}'),
('', 'block.block.claro_breadcrumbs', 'a:13:{s:4:"uuid";s:36:"303d9913-97fc-402d-a3dc-88b1fcd6dde9";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:6:"system";}s:5:"theme";a:1:{i:0;s:5:"claro";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"NjcxOBrPOiK5-38t56DwFBDVY4yer7YSlbRWXFuHe7A";}s:2:"id";s:17:"claro_breadcrumbs";s:5:"theme";s:5:"claro";s:6:"region";s:10:"breadcrumb";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:23:"system_breadcrumb_block";s:8:"settings";a:4:{s:2:"id";s:23:"system_breadcrumb_block";s:5:"label";s:11:"Breadcrumbs";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"system";}s:10:"visibility";a:0:{}}'),
('', 'block.block.claro_content', 'a:13:{s:4:"uuid";s:36:"d3769e61-82ac-48ed-a7b7-82667768846a";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:6:"system";}s:5:"theme";a:1:{i:0;s:5:"claro";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"a0Yyx1GeyKarZ4T_yXQBR_ZFKnXiFLtxAb6gWLd8nr0";}s:2:"id";s:13:"claro_content";s:5:"theme";s:5:"claro";s:6:"region";s:7:"content";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:17:"system_main_block";s:8:"settings";a:4:{s:2:"id";s:17:"system_main_block";s:5:"label";s:17:"Main page content";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"system";}s:10:"visibility";a:0:{}}'),
('', 'block.block.claro_help', 'a:13:{s:4:"uuid";s:36:"2f3d3006-55c0-41bd-8d90-50b965d32756";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:4:"help";}s:5:"theme";a:1:{i:0;s:5:"claro";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"jccFSSVqV0WCDb6NtML1VWAWTtDbZ-zn5YgTRMgMrIM";}s:2:"id";s:10:"claro_help";s:5:"theme";s:5:"claro";s:6:"region";s:4:"help";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:10:"help_block";s:8:"settings";a:4:{s:2:"id";s:10:"help_block";s:5:"label";s:4:"Help";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"help";}s:10:"visibility";a:0:{}}'),
('', 'block.block.claro_help_search', 'a:13:{s:4:"uuid";s:36:"6bef9a54-1d94-4340-a3d1-cb5f35b3e061";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:3:{s:6:"module";a:2:{i:0;s:6:"search";i:1;s:6:"system";}s:5:"theme";a:1:{i:0;s:5:"claro";}s:8:"enforced";a:1:{s:6:"config";a:1:{i:0;s:23:"search.page.help_search";}}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"2ToeZLvlHKTeFY74gpgu1PejLoFyCECLO_gw6rAZwqw";}s:2:"id";s:17:"claro_help_search";s:5:"theme";s:5:"claro";s:6:"region";s:4:"help";s:6:"weight";i:-4;s:8:"provider";N;s:6:"plugin";s:17:"search_form_block";s:8:"settings";a:5:{s:2:"id";s:17:"search_form_block";s:5:"label";s:11:"Search help";s:13:"label_display";s:7:"visible";s:8:"provider";s:6:"search";s:7:"page_id";s:11:"help_search";}s:10:"visibility";a:1:{s:12:"request_path";a:4:{s:2:"id";s:12:"request_path";s:6:"negate";b:0;s:15:"context_mapping";a:0:{}s:5:"pages";s:11:"/admin/help";}}}'),
('', 'block.block.claro_local_actions', 'a:13:{s:4:"uuid";s:36:"b4ae1d15-1adb-4ec4-9b07-f0c33294df85";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:5:"theme";a:1:{i:0;s:5:"claro";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"CdXfDmRgAvms7EQovxxWPdYi0GitxeRbVtScYK16ZH0";}s:2:"id";s:19:"claro_local_actions";s:5:"theme";s:5:"claro";s:6:"region";s:7:"content";s:6:"weight";i:-10;s:8:"provider";N;s:6:"plugin";s:19:"local_actions_block";s:8:"settings";a:4:{s:2:"id";s:19:"local_actions_block";s:5:"label";s:21:"Primary admin actions";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"core";}s:10:"visibility";a:0:{}}'),
('', 'block.block.claro_messages', 'a:13:{s:4:"uuid";s:36:"05dad6b8-2007-4914-9f28-09f909d4c797";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:6:"system";}s:5:"theme";a:1:{i:0;s:5:"claro";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"-Ac3ISpIT0PQ-whzD7_dw0SdKi6dAbRFNWdSjOiVDqg";}s:2:"id";s:14:"claro_messages";s:5:"theme";s:5:"claro";s:6:"region";s:11:"highlighted";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:21:"system_messages_block";s:8:"settings";a:4:{s:2:"id";s:21:"system_messages_block";s:5:"label";s:15:"Status messages";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"system";}s:10:"visibility";a:0:{}}'),
('', 'block.block.claro_page_title', 'a:13:{s:4:"uuid";s:36:"6466c4e0-5d42-4bc4-9671-569dbf4b60d8";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:5:"theme";a:1:{i:0;s:5:"claro";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"fNwDdW063tk_ktzSWzZVeQS9wzvLooVO280BQ9WrsIs";}s:2:"id";s:16:"claro_page_title";s:5:"theme";s:5:"claro";s:6:"region";s:6:"header";s:6:"weight";i:-30;s:8:"provider";N;s:6:"plugin";s:16:"page_title_block";s:8:"settings";a:4:{s:2:"id";s:16:"page_title_block";s:5:"label";s:10:"Page title";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"core";}s:10:"visibility";a:0:{}}'),
('', 'block.block.claro_primary_local_tasks', 'a:13:{s:4:"uuid";s:36:"46636a48-9c80-4e79-9036-e0097a006aed";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:5:"theme";a:1:{i:0;s:5:"claro";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"ACjBZI5shAMiiUpsz-inLYVXDqNNXRnSzAWV3kV_8Hw";}s:2:"id";s:25:"claro_primary_local_tasks";s:5:"theme";s:5:"claro";s:6:"region";s:6:"header";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:17:"local_tasks_block";s:8:"settings";a:6:{s:2:"id";s:17:"local_tasks_block";s:5:"label";s:12:"Primary tabs";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"core";s:7:"primary";b:1;s:9:"secondary";b:0;}s:10:"visibility";a:0:{}}'),
('', 'block.block.claro_secondary_local_tasks', 'a:13:{s:4:"uuid";s:36:"e257b9fc-cd97-428e-aa25-db965faf5f51";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:5:"theme";a:1:{i:0;s:5:"claro";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"2L0geP-ixCbCkEpW6BVF6H7vDUZN4ea07_Y9CociQm4";}s:2:"id";s:27:"claro_secondary_local_tasks";s:5:"theme";s:5:"claro";s:6:"region";s:11:"pre_content";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:17:"local_tasks_block";s:8:"settings";a:6:{s:2:"id";s:17:"local_tasks_block";s:5:"label";s:14:"Secondary tabs";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"core";s:7:"primary";b:0;s:9:"secondary";b:1;}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_account_menu', 'a:13:{s:4:"uuid";s:36:"36af0246-a6f8-4b6f-91e8-fa9e05fd69ac";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:3:{s:6:"config";a:1:{i:0;s:19:"system.menu.account";}s:6:"module";a:1:{i:0;s:6:"system";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU";}s:2:"id";s:20:"olivero_account_menu";s:5:"theme";s:7:"olivero";s:6:"region";s:14:"secondary_menu";s:6:"weight";i:-4;s:8:"provider";N;s:6:"plugin";s:25:"system_menu_block:account";s:8:"settings";a:7:{s:2:"id";s:25:"system_menu_block:account";s:5:"label";s:17:"User account menu";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"system";s:5:"level";i:1;s:5:"depth";i:1;s:16:"expand_all_items";b:0;}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_breadcrumbs', 'a:13:{s:4:"uuid";s:36:"06cef69f-00dc-4a06-a6eb-5f79ae63c06e";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:6:"system";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE";}s:2:"id";s:19:"olivero_breadcrumbs";s:5:"theme";s:7:"olivero";s:6:"region";s:10:"breadcrumb";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:23:"system_breadcrumb_block";s:8:"settings";a:4:{s:2:"id";s:23:"system_breadcrumb_block";s:5:"label";s:11:"Breadcrumbs";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"system";}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_content', 'a:13:{s:4:"uuid";s:36:"14923216-919d-4ec9-ab04-fffb90b233e9";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:6:"system";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk";}s:2:"id";s:15:"olivero_content";s:5:"theme";s:7:"olivero";s:6:"region";s:7:"content";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:17:"system_main_block";s:8:"settings";a:4:{s:2:"id";s:17:"system_main_block";s:5:"label";s:17:"Main page content";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"system";}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_help', 'a:13:{s:4:"uuid";s:36:"63bdc52f-5e57-42a7-8f92-7d760792086c";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:4:"help";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg";}s:2:"id";s:12:"olivero_help";s:5:"theme";s:7:"olivero";s:6:"region";s:13:"content_above";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:10:"help_block";s:8:"settings";a:4:{s:2:"id";s:10:"help_block";s:5:"label";s:4:"Help";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"help";}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_main_menu', 'a:13:{s:4:"uuid";s:36:"2c9e0d19-49d2-4b4e-a179-c386470bda58";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:3:{s:6:"config";a:1:{i:0;s:16:"system.menu.main";}s:6:"module";a:1:{i:0;s:6:"system";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE";}s:2:"id";s:17:"olivero_main_menu";s:5:"theme";s:7:"olivero";s:6:"region";s:12:"primary_menu";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:22:"system_menu_block:main";s:8:"settings";a:7:{s:2:"id";s:22:"system_menu_block:main";s:5:"label";s:15:"Main navigation";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"system";s:5:"level";i:1;s:5:"depth";i:2;s:16:"expand_all_items";b:1;}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_messages', 'a:13:{s:4:"uuid";s:36:"f6d3456b-668d-4f76-a737-c0d40d47b7d4";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:6:"system";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0";}s:2:"id";s:16:"olivero_messages";s:5:"theme";s:7:"olivero";s:6:"region";s:11:"highlighted";s:6:"weight";i:-5;s:8:"provider";N;s:6:"plugin";s:21:"system_messages_block";s:8:"settings";a:4:{s:2:"id";s:21:"system_messages_block";s:5:"label";s:15:"Status messages";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"system";}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_page_title', 'a:13:{s:4:"uuid";s:36:"929a4472-d1e7-4dde-bec0-8738e80e2ad6";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y";}s:2:"id";s:18:"olivero_page_title";s:5:"theme";s:7:"olivero";s:6:"region";s:13:"content_above";s:6:"weight";i:-5;s:8:"provider";N;s:6:"plugin";s:16:"page_title_block";s:8:"settings";a:4:{s:2:"id";s:16:"page_title_block";s:5:"label";s:10:"Page title";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"core";}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_powered', 'a:13:{s:4:"uuid";s:36:"247f58ed-7454-425c-9dbb-6d7bc53b7b68";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:6:"system";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"eYL19CLDyinGTWYQfBD1DswWzglEotE_kHnHx3AxTXM";}s:2:"id";s:15:"olivero_powered";s:5:"theme";s:7:"olivero";s:6:"region";s:13:"footer_bottom";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:23:"system_powered_by_block";s:8:"settings";a:4:{s:2:"id";s:23:"system_powered_by_block";s:5:"label";s:17:"Powered by Drupal";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"system";}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_primary_admin_actions', 'a:13:{s:4:"uuid";s:36:"7843ce95-19a0-41bd-80f4-2cca6dc7f5b6";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U";}s:2:"id";s:29:"olivero_primary_admin_actions";s:5:"theme";s:7:"olivero";s:6:"region";s:11:"highlighted";s:6:"weight";i:-5;s:8:"provider";N;s:6:"plugin";s:19:"local_actions_block";s:8:"settings";a:4:{s:2:"id";s:19:"local_actions_block";s:5:"label";s:21:"Primary admin actions";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"core";}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_primary_local_tasks', 'a:13:{s:4:"uuid";s:36:"7f713f72-12ea-4661-bfc3-cdcb88686ef4";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4";}s:2:"id";s:27:"olivero_primary_local_tasks";s:5:"theme";s:7:"olivero";s:6:"region";s:11:"highlighted";s:6:"weight";i:-4;s:8:"provider";N;s:6:"plugin";s:17:"local_tasks_block";s:8:"settings";a:6:{s:2:"id";s:17:"local_tasks_block";s:5:"label";s:12:"Primary tabs";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"core";s:7:"primary";b:1;s:9:"secondary";b:0;}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_search_form_narrow', 'a:13:{s:4:"uuid";s:36:"c8c70524-3fc0-41eb-8f1c-cd6baee9e745";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:6:"search";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"yEBET0cqDbk8dkWzaJw-8CKft0961VBflsISoSR6Lj8";}s:2:"id";s:26:"olivero_search_form_narrow";s:5:"theme";s:7:"olivero";s:6:"region";s:12:"primary_menu";s:6:"weight";i:-4;s:8:"provider";N;s:6:"plugin";s:17:"search_form_block";s:8:"settings";a:5:{s:2:"id";s:17:"search_form_block";s:5:"label";s:20:"Search form (narrow)";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"search";s:7:"page_id";s:0:"";}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_search_form_wide', 'a:13:{s:4:"uuid";s:36:"ac40eed0-a7f4-45d8-90b4-485c237ec255";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:6:"search";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"imMyHD6LYci0gtXq56qr9ZKGHzbEG9uFydrN5EhKtSU";}s:2:"id";s:24:"olivero_search_form_wide";s:5:"theme";s:7:"olivero";s:6:"region";s:14:"secondary_menu";s:6:"weight";i:-5;s:8:"provider";N;s:6:"plugin";s:17:"search_form_block";s:8:"settings";a:5:{s:2:"id";s:17:"search_form_block";s:5:"label";s:18:"Search form (wide)";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"search";s:7:"page_id";s:0:"";}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_secondary_local_tasks', 'a:13:{s:4:"uuid";s:36:"4608a49e-d742-43b3-bdf0-19564706be05";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI";}s:2:"id";s:29:"olivero_secondary_local_tasks";s:5:"theme";s:7:"olivero";s:6:"region";s:11:"highlighted";s:6:"weight";i:-2;s:8:"provider";N;s:6:"plugin";s:17:"local_tasks_block";s:8:"settings";a:6:{s:2:"id";s:17:"local_tasks_block";s:5:"label";s:14:"Secondary tabs";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"core";s:7:"primary";b:0;s:9:"secondary";b:1;}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_site_branding', 'a:13:{s:4:"uuid";s:36:"5cb78c6b-d165-4e4f-8a5f-90070bb1359e";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:6:"system";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM";}s:2:"id";s:21:"olivero_site_branding";s:5:"theme";s:7:"olivero";s:6:"region";s:6:"header";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:21:"system_branding_block";s:8:"settings";a:7:{s:2:"id";s:21:"system_branding_block";s:5:"label";s:13:"Site branding";s:13:"label_display";s:1:"0";s:8:"provider";s:6:"system";s:13:"use_site_logo";b:1;s:13:"use_site_name";b:1;s:15:"use_site_slogan";b:0;}s:10:"visibility";a:0:{}}'),
('', 'block.block.olivero_syndicate', 'a:13:{s:4:"uuid";s:36:"d3efc778-f391-4111-b150-4e5f8f4405bf";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"module";a:1:{i:0;s:4:"node";}s:5:"theme";a:1:{i:0;s:7:"olivero";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"0gq3VPg-_UM69FCCWurLFIrrnIjC2HLKhwo9iQNtcUo";}s:2:"id";s:17:"olivero_syndicate";s:5:"theme";s:7:"olivero";s:6:"region";s:6:"social";s:6:"weight";i:0;s:8:"provider";N;s:6:"plugin";s:20:"node_syndicate_block";s:8:"settings";a:5:{s:2:"id";s:20:"node_syndicate_block";s:5:"label";s:8:"RSS feed";s:13:"label_display";s:1:"0";s:8:"provider";s:4:"node";s:11:"block_count";i:10;}s:10:"visibility";a:0:{}}'),
('', 'block_content.type.basic', 'a:9:{s:4:"uuid";s:36:"7a717b00-8ba3-4dd8-881c-747a8a230a50";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"pQP5iQy4SdhAMVcjDUncCfkJmTofnHVtXrsMzx4k6Yk";}s:2:"id";s:5:"basic";s:5:"label";s:11:"Basic block";s:8:"revision";b:0;s:11:"description";s:42:"A basic block contains a title and a body.";}'),
('', 'claro.settings', 'a:1:{s:20:"third_party_settings";a:1:{s:8:"shortcut";a:1:{s:11:"module_link";b:1;}}}'),
('', 'comment.settings', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"YNUW2Ij5uE7a4oaXp3i_2lvaFdYM1zNKPPfnEjB0jEc";}s:16:"log_ip_addresses";b:0;}'),
('', 'comment.type.comment', 'a:9:{s:4:"uuid";s:36:"0c9a00bd-c8de-4cd5-93fe-7d5809edfb5c";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"bqZsN31T2n0UjcbyCpOPi9D2iO0sAOHR7FnEs9qMvaA";}s:2:"id";s:7:"comment";s:5:"label";s:16:"Default comments";s:21:"target_entity_type_id";s:4:"node";s:11:"description";s:28:"Allows commenting on content";}'),
('', 'contact.form.feedback', 'a:12:{s:4:"uuid";s:36:"8894f18a-a90f-41a7-806f-e4cf3038e7e0";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"vymHlgJy26BuI5GGj9-IXjwR3dRC5C0tij4BpWJnoqw";}s:2:"id";s:8:"feedback";s:5:"label";s:16:"Website feedback";s:10:"recipients";a:1:{i:0;[[site_mail]]}s:5:"reply";s:0:"";s:6:"weight";i:0;s:7:"message";s:27:"Your message has been sent.";s:8:"redirect";s:0:"";}'),
('', 'contact.form.personal', 'a:12:{s:4:"uuid";s:36:"fb580b41-ff44-4496-943a-f2858cfb9708";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"jonvgt3CkUM2eMLTFwWfHileWWDC4YtXCuIlCahTk_I";}s:2:"id";s:8:"personal";s:5:"label";s:21:"Personal contact form";s:10:"recipients";a:0:{}s:5:"reply";s:0:"";s:6:"weight";i:0;s:7:"message";s:27:"Your message has been sent.";s:8:"redirect";s:0:"";}'),
('', 'contact.settings', 'a:4:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"U69DBeuvXuNVOC15rVNaBjDPK2fWFbo9v4takdYSSO8";}s:12:"default_form";s:8:"feedback";s:5:"flood";a:2:{s:5:"limit";i:5;s:8:"interval";i:3600;}s:20:"user_default_enabled";b:1;}'),
('', 'core.base_field_override.node.page.promote', 'a:17:{s:4:"uuid";s:36:"9a0a8f27-e940-43fe-a940-ed0f985924cf";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"config";a:1:{i:0;s:14:"node.type.page";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"fPUEnm4T5zfZRr3ttDUqq7yCDd2uW3clWD-pvos4tlQ";}s:2:"id";s:17:"node.page.promote";s:10:"field_name";s:7:"promote";s:11:"entity_type";s:4:"node";s:6:"bundle";s:4:"page";s:5:"label";s:22:"Promoted to front page";s:11:"description";s:0:"";s:8:"required";b:0;s:12:"translatable";b:0;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";i:0;}}s:22:"default_value_callback";s:0:"";s:8:"settings";a:2:{s:8:"on_label";s:2:"On";s:9:"off_label";s:3:"Off";}s:10:"field_type";s:7:"boolean";}'),
('', 'core.date_format.fallback', 'a:9:{s:4:"uuid";s:36:"69881563-98cb-4f9d-baad-50f645b81d18";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"7klS5IWXrwzVaPpYZFAs6wcx8U2FF1X73OfrtTsvuvE";}s:2:"id";s:8:"fallback";s:5:"label";s:20:"Fallback date format";s:6:"locked";b:1;s:7:"pattern";s:14:"D, m/d/Y - H:i";}'),
('', 'core.date_format.html_date', 'a:9:{s:4:"uuid";s:36:"14b69244-ffec-4dbb-a37a-650eb8fef1c0";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"EOQltUQPmgc6UQ2rcJ4Xi_leCEJj5ui0TR-12duS-Tk";}s:2:"id";s:9:"html_date";s:5:"label";s:9:"HTML Date";s:6:"locked";b:1;s:7:"pattern";s:5:"Y-m-d";}'),
('', 'core.date_format.html_datetime', 'a:9:{s:4:"uuid";s:36:"cc1b05ca-6d1f-4ed2-a51e-3b644676fad0";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"jxfClwZIRXIdcvMrE--WkcZxDGUVoOIE3Sm2NRZlFuE";}s:2:"id";s:13:"html_datetime";s:5:"label";s:13:"HTML Datetime";s:6:"locked";b:1;s:7:"pattern";s:13:"Y-m-d\\TH:i:sO";}'),
('', 'core.date_format.html_month', 'a:9:{s:4:"uuid";s:36:"1a1d6ac2-3239-4f41-ba13-d502c64c6cbc";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"Z7KuCUwM_WdTNvLcoltuX3_8d-s-8FZkTN6KgNwF0eM";}s:2:"id";s:10:"html_month";s:5:"label";s:10:"HTML Month";s:6:"locked";b:1;s:7:"pattern";s:3:"Y-m";}'),
('', 'core.date_format.html_time', 'a:9:{s:4:"uuid";s:36:"3d404085-7c28-42b0-8cd2-bad13eadeb94";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"M7yqicYkU36hRy5p9drAaGBBihhUD1OyujFrAaQ93ZE";}s:2:"id";s:9:"html_time";s:5:"label";s:9:"HTML Time";s:6:"locked";b:1;s:7:"pattern";s:5:"H:i:s";}'),
('', 'core.date_format.html_week', 'a:9:{s:4:"uuid";s:36:"b65a0c7a-bda0-4dc4-b329-8d78d46fddf8";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"wKD4WsoV_wFgv2vgI4mcAAFSIzrye17ykzdwrnApkfY";}s:2:"id";s:9:"html_week";s:5:"label";s:9:"HTML Week";s:6:"locked";b:1;s:7:"pattern";s:5:"Y-\\WW";}'),
('', 'core.date_format.html_year', 'a:9:{s:4:"uuid";s:36:"d2c8ba26-18bc-4d59-8bae-e17abe4fc226";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"OjekiQuX9RbVQ2_8jOHBL94RgYLePqX7wpfNGgcQzrk";}s:2:"id";s:9:"html_year";s:5:"label";s:9:"HTML Year";s:6:"locked";b:1;s:7:"pattern";s:1:"Y";}'),
('', 'core.date_format.html_yearless_date', 'a:9:{s:4:"uuid";s:36:"cbbca4c4-74d0-41b9-8835-a3ebed5199c8";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"5VpawMrKPEPCkoO4YpPa0TDFO2dgiIHfTziJtwlmUxc";}s:2:"id";s:18:"html_yearless_date";s:5:"label";s:18:"HTML Yearless date";s:6:"locked";b:1;s:7:"pattern";s:3:"m-d";}'),
('', 'core.date_format.long', 'a:9:{s:4:"uuid";s:36:"d0292129-252a-453c-b925-e331e6c742a8";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"og8sWXhBuHbLMw3CoiBEZjgqSyhFBFmcbUW_wLcfNbo";}s:2:"id";s:4:"long";s:5:"label";s:17:"Default long date";s:6:"locked";b:0;s:7:"pattern";s:15:"l, F j, Y - H:i";}'),
('', 'core.date_format.medium', 'a:9:{s:4:"uuid";s:36:"c8dc50e2-9daf-4ee7-8f00-b489c001583b";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"nzL5d024NjXIX_8TlT6uFAu973lmfkmHklJC-2i9rAE";}s:2:"id";s:6:"medium";s:5:"label";s:19:"Default medium date";s:6:"locked";b:0;s:7:"pattern";s:14:"D, m/d/Y - H:i";}'),
('', 'core.date_format.olivero_medium', 'a:9:{s:4:"uuid";s:36:"976ef5de-de0f-4a83-861e-4441b90732c5";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:8:"enforced";a:1:{s:5:"theme";a:1:{i:0;s:7:"olivero";}}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"Mt6cmxUbDZ9XxD6p25WQ8tj3_JcX8ylfcddwZc8gcAE";}s:2:"id";s:14:"olivero_medium";s:5:"label";s:14:"Olivero Medium";s:6:"locked";b:0;s:7:"pattern";s:8:"j  F,  Y";}'),
('', 'core.date_format.short', 'a:9:{s:4:"uuid";s:36:"08dfa482-4a6e-4f85-a9ce-a1f2e69fcf98";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"AlzeyytA8InBgxIG9H2UDJYs3CG98Zj6yRsDKmlbZwA";}s:2:"id";s:5:"short";s:5:"label";s:18:"Default short date";s:6:"locked";b:0;s:7:"pattern";s:11:"m/d/Y - H:i";}'),
('', 'core.entity_form_display.block_content.basic.default', 'a:11:{s:4:"uuid";s:36:"dcb997d7-8084-47b2-90ea-c8a684d9a98d";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:24:"block_content.type.basic";i:1;s:36:"field.field.block_content.basic.body";}s:6:"module";a:1:{i:0;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"jAps3FCxvKecABS_tgExbhCZrBLQB3bNPWw18WjE3ss";}s:2:"id";s:27:"block_content.basic.default";s:16:"targetEntityType";s:13:"block_content";s:6:"bundle";s:5:"basic";s:4:"mode";s:7:"default";s:7:"content";a:2:{s:4:"body";a:5:{s:4:"type";s:26:"text_textarea_with_summary";s:6:"weight";i:-4;s:6:"region";s:7:"content";s:8:"settings";a:4:{s:4:"rows";i:9;s:12:"summary_rows";i:3;s:11:"placeholder";s:0:"";s:12:"show_summary";b:0;}s:20:"third_party_settings";a:0:{}}s:4:"info";a:5:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:-5;s:6:"region";s:7:"content";s:8:"settings";a:2:{s:4:"size";i:60;s:11:"placeholder";s:0:"";}s:20:"third_party_settings";a:0:{}}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_form_display.comment.comment.default', 'a:11:{s:4:"uuid";s:36:"82a67875-24fb-437a-8d8f-6b0f40f699b6";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:20:"comment.type.comment";i:1;s:40:"field.field.comment.comment.comment_body";}s:6:"module";a:1:{i:0;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"I0Pa0aQvT_jawlPo9oz4FE3h_ickc55dYKTPl6gILes";}s:2:"id";s:23:"comment.comment.default";s:16:"targetEntityType";s:7:"comment";s:6:"bundle";s:7:"comment";s:4:"mode";s:7:"default";s:7:"content";a:3:{s:6:"author";a:2:{s:6:"weight";i:-2;s:6:"region";s:7:"content";}s:12:"comment_body";a:5:{s:4:"type";s:13:"text_textarea";s:6:"weight";i:11;s:6:"region";s:7:"content";s:8:"settings";a:2:{s:4:"rows";i:5;s:11:"placeholder";s:0:"";}s:20:"third_party_settings";a:0:{}}s:7:"subject";a:5:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:10;s:6:"region";s:7:"content";s:8:"settings";a:2:{s:4:"size";i:60;s:11:"placeholder";s:0:"";}s:20:"third_party_settings";a:0:{}}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_form_display.node.article.default', 'a:11:{s:4:"uuid";s:36:"1797bfec-e120-4911-b079-026c9a764a1e";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:6:{i:0;s:29:"field.field.node.article.body";i:1;s:32:"field.field.node.article.comment";i:2;s:36:"field.field.node.article.field_image";i:3;s:35:"field.field.node.article.field_tags";i:4;s:21:"image.style.thumbnail";i:5;s:17:"node.type.article";}s:6:"module";a:4:{i:0;s:7:"comment";i:1;s:5:"image";i:2;s:4:"path";i:3;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"ewbd6G2uX456-bgwseM2Q-KQG3RkASoyHmTh-XR3oLU";}s:2:"id";s:20:"node.article.default";s:16:"targetEntityType";s:4:"node";s:6:"bundle";s:7:"article";s:4:"mode";s:7:"default";s:7:"content";a:11:{s:4:"body";a:5:{s:4:"type";s:26:"text_textarea_with_summary";s:6:"weight";i:2;s:6:"region";s:7:"content";s:8:"settings";a:4:{s:4:"rows";i:9;s:12:"summary_rows";i:3;s:11:"placeholder";s:0:"";s:12:"show_summary";b:0;}s:20:"third_party_settings";a:0:{}}s:7:"comment";a:5:{s:4:"type";s:15:"comment_default";s:6:"weight";i:20;s:6:"region";s:7:"content";s:8:"settings";a:0:{}s:20:"third_party_settings";a:0:{}}s:7:"created";a:5:{s:4:"type";s:18:"datetime_timestamp";s:6:"weight";i:10;s:6:"region";s:7:"content";s:8:"settings";a:0:{}s:20:"third_party_settings";a:0:{}}s:11:"field_image";a:5:{s:4:"type";s:11:"image_image";s:6:"weight";i:1;s:6:"region";s:7:"content";s:8:"settings";a:2:{s:18:"progress_indicator";s:8:"throbber";s:19:"preview_image_style";s:9:"thumbnail";}s:20:"third_party_settings";a:0:{}}s:10:"field_tags";a:5:{s:4:"type";s:34:"entity_reference_autocomplete_tags";s:6:"weight";i:3;s:6:"region";s:7:"content";s:8:"settings";a:4:{s:14:"match_operator";s:8:"CONTAINS";s:11:"match_limit";i:10;s:4:"size";i:60;s:11:"placeholder";s:0:"";}s:20:"third_party_settings";a:0:{}}s:4:"path";a:5:{s:4:"type";s:4:"path";s:6:"weight";i:30;s:6:"region";s:7:"content";s:8:"settings";a:0:{}s:20:"third_party_settings";a:0:{}}s:7:"promote";a:5:{s:4:"type";s:16:"boolean_checkbox";s:6:"weight";i:15;s:6:"region";s:7:"content";s:8:"settings";a:1:{s:13:"display_label";b:1;}s:20:"third_party_settings";a:0:{}}s:6:"status";a:5:{s:4:"type";s:16:"boolean_checkbox";s:6:"weight";i:120;s:6:"region";s:7:"content";s:8:"settings";a:1:{s:13:"display_label";b:1;}s:20:"third_party_settings";a:0:{}}s:6:"sticky";a:5:{s:4:"type";s:16:"boolean_checkbox";s:6:"weight";i:16;s:6:"region";s:7:"content";s:8:"settings";a:1:{s:13:"display_label";b:1;}s:20:"third_party_settings";a:0:{}}s:5:"title";a:5:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:0;s:6:"region";s:7:"content";s:8:"settings";a:2:{s:4:"size";i:60;s:11:"placeholder";s:0:"";}s:20:"third_party_settings";a:0:{}}s:3:"uid";a:5:{s:4:"type";s:29:"entity_reference_autocomplete";s:6:"weight";i:5;s:6:"region";s:7:"content";s:8:"settings";a:4:{s:14:"match_operator";s:8:"CONTAINS";s:11:"match_limit";i:10;s:4:"size";i:60;s:11:"placeholder";s:0:"";}s:20:"third_party_settings";a:0:{}}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_form_display.node.page.default', 'a:11:{s:4:"uuid";s:36:"ffc56d8a-983b-4c39-a402-9be9dd3e29a5";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:26:"field.field.node.page.body";i:1;s:14:"node.type.page";}s:6:"module";a:2:{i:0;s:4:"path";i:1;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0";}s:2:"id";s:17:"node.page.default";s:16:"targetEntityType";s:4:"node";s:6:"bundle";s:4:"page";s:4:"mode";s:7:"default";s:7:"content";a:8:{s:4:"body";a:5:{s:4:"type";s:26:"text_textarea_with_summary";s:6:"weight";i:31;s:6:"region";s:7:"content";s:8:"settings";a:4:{s:4:"rows";i:9;s:12:"summary_rows";i:3;s:11:"placeholder";s:0:"";s:12:"show_summary";b:0;}s:20:"third_party_settings";a:0:{}}s:7:"created";a:5:{s:4:"type";s:18:"datetime_timestamp";s:6:"weight";i:10;s:6:"region";s:7:"content";s:8:"settings";a:0:{}s:20:"third_party_settings";a:0:{}}s:4:"path";a:5:{s:4:"type";s:4:"path";s:6:"weight";i:30;s:6:"region";s:7:"content";s:8:"settings";a:0:{}s:20:"third_party_settings";a:0:{}}s:7:"promote";a:5:{s:4:"type";s:16:"boolean_checkbox";s:6:"weight";i:15;s:6:"region";s:7:"content";s:8:"settings";a:1:{s:13:"display_label";b:1;}s:20:"third_party_settings";a:0:{}}s:6:"status";a:5:{s:4:"type";s:16:"boolean_checkbox";s:6:"weight";i:120;s:6:"region";s:7:"content";s:8:"settings";a:1:{s:13:"display_label";b:1;}s:20:"third_party_settings";a:0:{}}s:6:"sticky";a:5:{s:4:"type";s:16:"boolean_checkbox";s:6:"weight";i:16;s:6:"region";s:7:"content";s:8:"settings";a:1:{s:13:"display_label";b:1;}s:20:"third_party_settings";a:0:{}}s:5:"title";a:5:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:-5;s:6:"region";s:7:"content";s:8:"settings";a:2:{s:4:"size";i:60;s:11:"placeholder";s:0:"";}s:20:"third_party_settings";a:0:{}}s:3:"uid";a:5:{s:4:"type";s:29:"entity_reference_autocomplete";s:6:"weight";i:5;s:6:"region";s:7:"content";s:8:"settings";a:4:{s:14:"match_operator";s:8:"CONTAINS";s:11:"match_limit";i:10;s:4:"size";i:60;s:11:"placeholder";s:0:"";}s:20:"third_party_settings";a:0:{}}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_form_display.user.user.default', 'a:11:{s:4:"uuid";s:36:"ec3461fd-45fb-4c9a-b85d-757e33f73ede";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:34:"field.field.user.user.user_picture";i:1;s:21:"image.style.thumbnail";}s:6:"module";a:2:{i:0;s:5:"image";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"FaQ9Ptcpxpg30AtiqRDtl_8zbJArHP1LPfug_s59TOA";}s:2:"id";s:17:"user.user.default";s:16:"targetEntityType";s:4:"user";s:6:"bundle";s:4:"user";s:4:"mode";s:7:"default";s:7:"content";a:5:{s:7:"account";a:2:{s:6:"weight";i:-10;s:6:"region";s:7:"content";}s:7:"contact";a:2:{s:6:"weight";i:5;s:6:"region";s:7:"content";}s:8:"language";a:2:{s:6:"weight";i:0;s:6:"region";s:7:"content";}s:8:"timezone";a:2:{s:6:"weight";i:6;s:6:"region";s:7:"content";}s:12:"user_picture";a:5:{s:4:"type";s:11:"image_image";s:6:"weight";i:-1;s:6:"region";s:7:"content";s:8:"settings";a:2:{s:18:"progress_indicator";s:8:"throbber";s:19:"preview_image_style";s:9:"thumbnail";}s:20:"third_party_settings";a:0:{}}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_form_mode.user.register', 'a:10:{s:4:"uuid";s:36:"9cb89199-0eb6-42fb-9fc2-6d6b3320610a";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"5pE_4hurqtIlZN3XDi7eTo5RG13BMG0Rh9HYlRI3h8U";}s:2:"id";s:13:"user.register";s:5:"label";s:8:"Register";s:11:"description";s:0:"";s:16:"targetEntityType";s:4:"user";s:5:"cache";b:1;}'),
('', 'core.entity_view_display.block_content.basic.default', 'a:11:{s:4:"uuid";s:36:"eaccd6e8-0b9f-415f-ab39-2470fdbabb15";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:24:"block_content.type.basic";i:1;s:36:"field.field.block_content.basic.body";}s:6:"module";a:1:{i:0;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"hBNNDTFwakREOTa6GGMqN899Iyrii0hInwSJtQ7Kj30";}s:2:"id";s:27:"block_content.basic.default";s:16:"targetEntityType";s:13:"block_content";s:6:"bundle";s:5:"basic";s:4:"mode";s:7:"default";s:7:"content";a:1:{s:4:"body";a:6:{s:4:"type";s:12:"text_default";s:5:"label";s:6:"hidden";s:8:"settings";a:0:{}s:20:"third_party_settings";a:0:{}s:6:"weight";i:0;s:6:"region";s:7:"content";}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_view_display.comment.comment.default', 'a:11:{s:4:"uuid";s:36:"da2af7c6-e616-4175-9760-2ea5e31b959b";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:20:"comment.type.comment";i:1;s:40:"field.field.comment.comment.comment_body";}s:6:"module";a:1:{i:0;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"aBQUGsQ46M4048fIlFuTXwl2zV0j2cJX89CTUobh9hA";}s:2:"id";s:23:"comment.comment.default";s:16:"targetEntityType";s:7:"comment";s:6:"bundle";s:7:"comment";s:4:"mode";s:7:"default";s:7:"content";a:2:{s:12:"comment_body";a:6:{s:4:"type";s:12:"text_default";s:5:"label";s:6:"hidden";s:8:"settings";a:0:{}s:20:"third_party_settings";a:0:{}s:6:"weight";i:0;s:6:"region";s:7:"content";}s:5:"links";a:2:{s:6:"weight";i:100;s:6:"region";s:7:"content";}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_view_display.node.article.default', 'a:11:{s:4:"uuid";s:36:"3a2f70f6-695e-4b69-9f32-19422a28951c";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:7:{i:0;s:48:"core.entity_view_display.comment.comment.default";i:1;s:29:"field.field.node.article.body";i:2;s:32:"field.field.node.article.comment";i:3;s:36:"field.field.node.article.field_image";i:4;s:35:"field.field.node.article.field_tags";i:5;s:16:"image.style.wide";i:6;s:17:"node.type.article";}s:6:"module";a:4:{i:0;s:7:"comment";i:1;s:5:"image";i:2;s:4:"text";i:3;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"br6izr-iGEu--JvNbCJNtOBpRnxpFLXfoV5y61U9Nqc";}s:2:"id";s:20:"node.article.default";s:16:"targetEntityType";s:4:"node";s:6:"bundle";s:7:"article";s:4:"mode";s:7:"default";s:7:"content";a:5:{s:4:"body";a:6:{s:4:"type";s:12:"text_default";s:5:"label";s:6:"hidden";s:8:"settings";a:0:{}s:20:"third_party_settings";a:0:{}s:6:"weight";i:0;s:6:"region";s:7:"content";}s:7:"comment";a:6:{s:4:"type";s:15:"comment_default";s:5:"label";s:5:"above";s:8:"settings";a:2:{s:9:"view_mode";s:7:"default";s:8:"pager_id";i:0;}s:20:"third_party_settings";a:0:{}s:6:"weight";i:110;s:6:"region";s:7:"content";}s:11:"field_image";a:6:{s:4:"type";s:5:"image";s:5:"label";s:6:"hidden";s:8:"settings";a:3:{s:10:"image_link";s:0:"";s:11:"image_style";s:4:"wide";s:13:"image_loading";a:1:{s:9:"attribute";s:5:"eager";}}s:20:"third_party_settings";a:0:{}s:6:"weight";i:-1;s:6:"region";s:7:"content";}s:10:"field_tags";a:6:{s:4:"type";s:22:"entity_reference_label";s:5:"label";s:5:"above";s:8:"settings";a:1:{s:4:"link";b:1;}s:20:"third_party_settings";a:0:{}s:6:"weight";i:10;s:6:"region";s:7:"content";}s:5:"links";a:4:{s:8:"settings";a:0:{}s:20:"third_party_settings";a:0:{}s:6:"weight";i:100;s:6:"region";s:7:"content";}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_view_display.node.article.rss', 'a:11:{s:4:"uuid";s:36:"9fb143d8-b81d-4e70-aea9-25049f54cea7";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:6:{i:0;s:30:"core.entity_view_mode.node.rss";i:1;s:29:"field.field.node.article.body";i:2;s:32:"field.field.node.article.comment";i:3;s:36:"field.field.node.article.field_image";i:4;s:35:"field.field.node.article.field_tags";i:5;s:17:"node.type.article";}s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"2rIr6K5Q0UQ9khg0zE_CK-PtJH76UL-BDDZcZnZzwCc";}s:2:"id";s:16:"node.article.rss";s:16:"targetEntityType";s:4:"node";s:6:"bundle";s:7:"article";s:4:"mode";s:3:"rss";s:7:"content";a:1:{s:5:"links";a:2:{s:6:"weight";i:100;s:6:"region";s:7:"content";}}s:6:"hidden";a:4:{s:4:"body";b:1;s:7:"comment";b:1;s:11:"field_image";b:1;s:10:"field_tags";b:1;}}'),
('', 'core.entity_view_display.node.article.teaser', 'a:11:{s:4:"uuid";s:36:"e5897eaf-2da1-48b3-813e-98b2dbdb06c9";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:7:{i:0;s:33:"core.entity_view_mode.node.teaser";i:1;s:29:"field.field.node.article.body";i:2;s:32:"field.field.node.article.comment";i:3;s:36:"field.field.node.article.field_image";i:4;s:35:"field.field.node.article.field_tags";i:5;s:18:"image.style.medium";i:6;s:17:"node.type.article";}s:6:"module";a:3:{i:0;s:5:"image";i:1;s:4:"text";i:2;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"O8PxzfG8DOHHRu6M23kwR6TDPq_MNfYQ10Mp367ICUQ";}s:2:"id";s:19:"node.article.teaser";s:16:"targetEntityType";s:4:"node";s:6:"bundle";s:7:"article";s:4:"mode";s:6:"teaser";s:7:"content";a:4:{s:4:"body";a:6:{s:4:"type";s:23:"text_summary_or_trimmed";s:5:"label";s:6:"hidden";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:20:"third_party_settings";a:0:{}s:6:"weight";i:0;s:6:"region";s:7:"content";}s:11:"field_image";a:6:{s:4:"type";s:5:"image";s:5:"label";s:6:"hidden";s:8:"settings";a:3:{s:10:"image_link";s:7:"content";s:11:"image_style";s:6:"medium";s:13:"image_loading";a:1:{s:9:"attribute";s:4:"lazy";}}s:20:"third_party_settings";a:0:{}s:6:"weight";i:-1;s:6:"region";s:7:"content";}s:10:"field_tags";a:6:{s:4:"type";s:22:"entity_reference_label";s:5:"label";s:5:"above";s:8:"settings";a:1:{s:4:"link";b:1;}s:20:"third_party_settings";a:0:{}s:6:"weight";i:10;s:6:"region";s:7:"content";}s:5:"links";a:2:{s:6:"weight";i:100;s:6:"region";s:7:"content";}}s:6:"hidden";a:1:{s:7:"comment";b:1;}}'),
('', 'core.entity_view_display.node.page.default', 'a:11:{s:4:"uuid";s:36:"8b6e095a-16df-4934-a17a-db7eb1d28867";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:26:"field.field.node.page.body";i:1;s:14:"node.type.page";}s:6:"module";a:2:{i:0;s:4:"text";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"M_Y8L5tfmhx7DR143E05YyZSpvgil6VFvqcfBWykalg";}s:2:"id";s:17:"node.page.default";s:16:"targetEntityType";s:4:"node";s:6:"bundle";s:4:"page";s:4:"mode";s:7:"default";s:7:"content";a:2:{s:4:"body";a:6:{s:4:"type";s:12:"text_default";s:5:"label";s:6:"hidden";s:8:"settings";a:0:{}s:20:"third_party_settings";a:0:{}s:6:"weight";i:100;s:6:"region";s:7:"content";}s:5:"links";a:2:{s:6:"weight";i:101;s:6:"region";s:7:"content";}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_view_display.node.page.teaser', 'a:11:{s:4:"uuid";s:36:"ec4a784c-74c3-41e2-a937-6888f3512a35";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:3:{i:0;s:33:"core.entity_view_mode.node.teaser";i:1;s:26:"field.field.node.page.body";i:2;s:14:"node.type.page";}s:6:"module";a:2:{i:0;s:4:"text";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"8BgdRtLbtQ0F__o0FHSH0Mx5fvXOra9tfT1GmNKbRYw";}s:2:"id";s:16:"node.page.teaser";s:16:"targetEntityType";s:4:"node";s:6:"bundle";s:4:"page";s:4:"mode";s:6:"teaser";s:7:"content";a:2:{s:4:"body";a:6:{s:4:"type";s:23:"text_summary_or_trimmed";s:5:"label";s:6:"hidden";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:20:"third_party_settings";a:0:{}s:6:"weight";i:100;s:6:"region";s:7:"content";}s:5:"links";a:2:{s:6:"weight";i:101;s:6:"region";s:7:"content";}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_view_display.user.user.compact', 'a:11:{s:4:"uuid";s:36:"fdda2e97-d213-4a8d-b380-ced42df80ba4";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:3:{i:0;s:34:"core.entity_view_mode.user.compact";i:1;s:34:"field.field.user.user.user_picture";i:2;s:21:"image.style.thumbnail";}s:6:"module";a:2:{i:0;s:5:"image";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"00zr_RBdTjPjBGITD3h4c1ESQZimjdVCcHGt1trLqIY";}s:2:"id";s:17:"user.user.compact";s:16:"targetEntityType";s:4:"user";s:6:"bundle";s:4:"user";s:4:"mode";s:7:"compact";s:7:"content";a:1:{s:12:"user_picture";a:6:{s:4:"type";s:5:"image";s:5:"label";s:6:"hidden";s:8:"settings";a:3:{s:11:"image_style";s:9:"thumbnail";s:10:"image_link";s:7:"content";s:13:"image_loading";a:1:{s:9:"attribute";s:4:"lazy";}}s:20:"third_party_settings";a:0:{}s:6:"weight";i:0;s:6:"region";s:7:"content";}}s:6:"hidden";a:1:{s:10:"member_for";b:1;}}'),
('', 'core.entity_view_display.user.user.default', 'a:11:{s:4:"uuid";s:36:"970b5c1c-ae15-4a2a-a6ed-efbc270b7fdc";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:34:"field.field.user.user.user_picture";i:1;s:21:"image.style.thumbnail";}s:6:"module";a:2:{i:0;s:5:"image";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"mZLyuWM9CQx2ZJVqFGSbzgFnHzudVbHBYmdU256A5Wk";}s:2:"id";s:17:"user.user.default";s:16:"targetEntityType";s:4:"user";s:6:"bundle";s:4:"user";s:4:"mode";s:7:"default";s:7:"content";a:2:{s:10:"member_for";a:2:{s:6:"weight";i:5;s:6:"region";s:7:"content";}s:12:"user_picture";a:6:{s:4:"type";s:5:"image";s:5:"label";s:6:"hidden";s:8:"settings";a:3:{s:11:"image_style";s:9:"thumbnail";s:10:"image_link";s:7:"content";s:13:"image_loading";a:1:{s:9:"attribute";s:4:"lazy";}}s:20:"third_party_settings";a:0:{}s:6:"weight";i:0;s:6:"region";s:7:"content";}}s:6:"hidden";a:0:{}}'),
('', 'core.entity_view_mode.block_content.full', 'a:10:{s:4:"uuid";s:36:"60d5f0c0-5347-400c-a767-0befdaf74db3";s:8:"langcode";s:2:"en";s:6:"status";b:0;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:13:"block_content";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"Q7yUUYeRLByl-MCGveKKF_KhAtNICLCMJuKWfugCvso";}s:2:"id";s:18:"block_content.full";s:5:"label";s:4:"Full";s:11:"description";s:0:"";s:16:"targetEntityType";s:13:"block_content";s:5:"cache";b:1;}'),
('', 'core.entity_view_mode.comment.full', 'a:10:{s:4:"uuid";s:36:"669b65ea-e626-4a86-acef-aacb5d947b59";s:8:"langcode";s:2:"en";s:6:"status";b:0;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:7:"comment";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"N4mUjXpPckUkVRY1PbKw4GGoL1i2ECU7PL3EreiKStk";}s:2:"id";s:12:"comment.full";s:5:"label";s:12:"Full comment";s:11:"description";s:0:"";s:16:"targetEntityType";s:7:"comment";s:5:"cache";b:1;}'),
('', 'core.entity_view_mode.node.full', 'a:10:{s:4:"uuid";s:36:"76728183-3321-4875-988e-b69488fc0bc6";s:8:"langcode";s:2:"en";s:6:"status";b:0;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"QJ2aZ1xfVf59aq6Pz5X7fyUOa2HxuCoTwQ_RQjoulAU";}s:2:"id";s:9:"node.full";s:5:"label";s:12:"Full content";s:11:"description";s:0:"";s:16:"targetEntityType";s:4:"node";s:5:"cache";b:1;}'),
('', 'core.entity_view_mode.node.rss', 'a:10:{s:4:"uuid";s:36:"a0ab9a4b-b6ae-4cf6-8fd1-6fa61bb9d929";s:8:"langcode";s:2:"en";s:6:"status";b:0;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"l8fiAFE3Kng_6bhLlUDnVTkTDzXWxzYFrCWTrngVXEA";}s:2:"id";s:8:"node.rss";s:5:"label";s:3:"RSS";s:11:"description";s:0:"";s:16:"targetEntityType";s:4:"node";s:5:"cache";b:1;}'),
('', 'core.entity_view_mode.node.search_index', 'a:10:{s:4:"uuid";s:36:"9ccca42e-72b9-4b63-9367-cc677075973d";s:8:"langcode";s:2:"en";s:6:"status";b:0;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"r_A0T3aTqGDwLyvoH7wLps-0PM--RHlS8UsiJe_Ac64";}s:2:"id";s:17:"node.search_index";s:5:"label";s:12:"Search index";s:11:"description";s:0:"";s:16:"targetEntityType";s:4:"node";s:5:"cache";b:1;}'),
('', 'core.entity_view_mode.node.search_result', 'a:10:{s:4:"uuid";s:36:"326c1f72-87f3-40cb-9a0c-3811aba557c6";s:8:"langcode";s:2:"en";s:6:"status";b:0;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"d8wBEm7XvJ6H3S0IneDD9PfTBklPIH7GMpxElVemPf8";}s:2:"id";s:18:"node.search_result";s:5:"label";s:32:"Search result highlighting input";s:11:"description";s:0:"";s:16:"targetEntityType";s:4:"node";s:5:"cache";b:1;}'),
('', 'core.entity_view_mode.node.teaser', 'a:10:{s:4:"uuid";s:36:"19cfcd88-2c67-433b-a179-10fd6337c176";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"KgGJDZFpMaz_8bTv6fN1bXS3Qi5LWmRJI9R53kEGsNQ";}s:2:"id";s:11:"node.teaser";s:5:"label";s:6:"Teaser";s:11:"description";s:0:"";s:16:"targetEntityType";s:4:"node";s:5:"cache";b:1;}'),
('', 'core.entity_view_mode.taxonomy_term.full', 'a:10:{s:4:"uuid";s:36:"bbbcd2dd-4ae1-41fa-a3fb-6e87c20e3a6b";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:8:"taxonomy";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"iukUENpf8CFvjZbGGacKX_Ges0-lU9z6zvsd32P6kbo";}s:2:"id";s:18:"taxonomy_term.full";s:5:"label";s:18:"Taxonomy term page";s:11:"description";s:0:"";s:16:"targetEntityType";s:13:"taxonomy_term";s:5:"cache";b:1;}'),
('', 'core.entity_view_mode.user.compact', 'a:10:{s:4:"uuid";s:36:"ba9b1777-193d-45b3-9fb3-2be0a3c5154b";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"TtD7OuGskOsQfoGyxXkrdtllBpR37J19d5BMQDZWJgA";}s:2:"id";s:12:"user.compact";s:5:"label";s:7:"Compact";s:11:"description";s:0:"";s:16:"targetEntityType";s:4:"user";s:5:"cache";b:1;}'),
('', 'core.entity_view_mode.user.full', 'a:10:{s:4:"uuid";s:36:"4f2b3a08-517f-49ca-8ceb-3be1027509c6";s:8:"langcode";s:2:"en";s:6:"status";b:0;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"ZbXunWS_xAvMZXFfinyvClDAb_RCVLt7gAzE3v16E-Q";}s:2:"id";s:9:"user.full";s:5:"label";s:12:"User account";s:11:"description";s:0:"";s:16:"targetEntityType";s:4:"user";s:5:"cache";b:1;}'),
('', 'core.extension', 'a:4:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"4GIX5Esnc_umpXUBj4IIocRX7Mt5fPhm4AgXfE3E56E";}s:6:"module";a:42:{s:18:"announcements_feed";i:0;s:14:"automated_cron";i:0;s:8:"big_pipe";i:0;s:5:"block";i:0;s:13:"block_content";i:0;s:10:"breakpoint";i:0;s:9:"ckeditor5";i:0;s:7:"comment";i:0;s:6:"config";i:0;s:7:"contact";i:0;s:10:"contextual";i:0;s:8:"datetime";i:0;s:5:"dblog";i:0;s:18:"dynamic_page_cache";i:0;s:6:"editor";i:0;s:5:"field";i:0;s:8:"field_ui";i:0;s:4:"file";i:0;s:6:"filter";i:0;s:4:"help";i:0;s:7:"history";i:0;s:5:"image";i:0;s:4:"link";i:0;s:17:"menu_link_content";i:0;s:7:"menu_ui";i:0;s:5:"mysql";i:0;s:4:"node";i:0;s:7:"options";i:0;s:10:"page_cache";i:0;s:4:"path";i:0;s:10:"path_alias";i:0;s:6:"search";i:0;s:8:"shortcut";i:0;s:6:"system";i:0;s:8:"taxonomy";i:0;s:4:"text";i:0;s:7:"toolbar";i:0;s:6:"update";i:0;s:4:"user";i:0;s:8:"views_ui";i:0;s:5:"views";i:10;s:8:"standard";i:1000;}s:5:"theme";a:2:{s:7:"olivero";i:0;s:5:"claro";i:0;}s:7:"profile";s:8:"standard";}'),
('', 'core.menu.static_menu_link_overrides', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"CXhei_vpaZk-3f_Mj2cH0YmpK-ZpKHoSzVA3yZrDq0g";}s:11:"definitions";a:1:{s:18:"contact__site_page";a:5:{s:9:"menu_name";s:6:"footer";s:6:"parent";s:0:"";s:6:"weight";i:0;s:8:"expanded";b:0;s:7:"enabled";b:1;}}}'),
('', 'dblog.settings', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"e883aGsrt1wFrsydlYU584PZONCSfRy0DtkZ9KzHb58";}s:9:"row_limit";i:1000;}');
INSERT INTO `[[dbprefix]]config` VALUES
('', 'editor.editor.basic_html', 'a:9:{s:4:"uuid";s:36:"2067e04f-0094-4ea7-94f0-11056c835b43";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:24:"filter.format.basic_html";}s:6:"module";a:1:{i:0;s:9:"ckeditor5";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"Qi2tIe-L97EutlMmhEvhsNxZOpOoA-RH82c4BQb5n4A";}s:6:"format";s:10:"basic_html";s:6:"editor";s:9:"ckeditor5";s:8:"settings";a:2:{s:7:"toolbar";a:1:{s:5:"items";a:15:{i:0;s:4:"bold";i:1;s:6:"italic";i:2;s:1:"|";i:3;s:4:"link";i:4;s:1:"|";i:5;s:12:"bulletedList";i:6;s:12:"numberedList";i:7;s:1:"|";i:8;s:10:"blockQuote";i:9;s:17:"drupalInsertImage";i:10;s:1:"|";i:11;s:7:"heading";i:12;s:4:"code";i:13;s:1:"|";i:14;s:13:"sourceEditing";}}s:7:"plugins";a:4:{s:17:"ckeditor5_heading";a:1:{s:16:"enabled_headings";a:5:{i:0;s:8:"heading2";i:1;s:8:"heading3";i:2;s:8:"heading4";i:3;s:8:"heading5";i:4;s:8:"heading6";}}s:21:"ckeditor5_imageResize";a:1:{s:12:"allow_resize";b:1;}s:14:"ckeditor5_list";a:2:{s:10:"properties";a:2:{s:8:"reversed";b:0;s:10:"startIndex";b:1;}s:10:"multiBlock";b:1;}s:23:"ckeditor5_sourceEditing";a:1:{s:12:"allowed_tags";a:13:{i:0;s:6:"<cite>";i:1;s:4:"<dl>";i:2;s:4:"<dt>";i:3;s:4:"<dd>";i:4;s:12:"<a hreflang>";i:5;s:17:"<blockquote cite>";i:6;s:9:"<ul type>";i:7;s:9:"<ol type>";i:8;s:7:"<h2 id>";i:9;s:7:"<h3 id>";i:10;s:7:"<h4 id>";i:11;s:7:"<h5 id>";i:12;s:7:"<h6 id>";}}}}s:12:"image_upload";a:5:{s:6:"status";b:1;s:6:"scheme";s:6:"public";s:9:"directory";s:13:"inline-images";s:8:"max_size";N;s:14:"max_dimensions";a:2:{s:5:"width";N;s:6:"height";N;}}}'),
('', 'editor.editor.full_html', 'a:9:{s:4:"uuid";s:36:"baf2a3c0-0038-45f8-917c-7f737e630c96";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:23:"filter.format.full_html";}s:6:"module";a:1:{i:0;s:9:"ckeditor5";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"lurcn8yf33g3Dkzdc55cTfJa9salGp9ytSYyG1s7QMI";}s:6:"format";s:9:"full_html";s:6:"editor";s:9:"ckeditor5";s:8:"settings";a:2:{s:7:"toolbar";a:1:{s:5:"items";a:21:{i:0;s:4:"bold";i:1;s:6:"italic";i:2;s:13:"strikethrough";i:3;s:11:"superscript";i:4;s:9:"subscript";i:5;s:12:"removeFormat";i:6;s:1:"|";i:7;s:4:"link";i:8;s:1:"|";i:9;s:12:"bulletedList";i:10;s:12:"numberedList";i:11;s:1:"|";i:12;s:10:"blockQuote";i:13;s:17:"drupalInsertImage";i:14;s:11:"insertTable";i:15;s:14:"horizontalLine";i:16;s:1:"|";i:17;s:7:"heading";i:18;s:9:"codeBlock";i:19;s:1:"|";i:20;s:13:"sourceEditing";}}s:7:"plugins";a:5:{s:19:"ckeditor5_codeBlock";a:1:{s:9:"languages";a:14:{i:0;a:2:{s:5:"label";s:10:"Plain text";s:8:"language";s:9:"plaintext";}i:1;a:2:{s:5:"label";s:1:"C";s:8:"language";s:1:"c";}i:2;a:2:{s:5:"label";s:2:"C#";s:8:"language";s:2:"cs";}i:3;a:2:{s:5:"label";s:3:"C++";s:8:"language";s:3:"cpp";}i:4;a:2:{s:5:"label";s:3:"CSS";s:8:"language";s:3:"css";}i:5;a:2:{s:5:"label";s:4:"Diff";s:8:"language";s:4:"diff";}i:6;a:2:{s:5:"label";s:4:"HTML";s:8:"language";s:4:"html";}i:7;a:2:{s:5:"label";s:4:"Java";s:8:"language";s:4:"java";}i:8;a:2:{s:5:"label";s:10:"JavaScript";s:8:"language";s:10:"javascript";}i:9;a:2:{s:5:"label";s:3:"PHP";s:8:"language";s:3:"php";}i:10;a:2:{s:5:"label";s:6:"Python";s:8:"language";s:6:"python";}i:11;a:2:{s:5:"label";s:4:"Ruby";s:8:"language";s:4:"ruby";}i:12;a:2:{s:5:"label";s:10:"TypeScript";s:8:"language";s:10:"typescript";}i:13;a:2:{s:5:"label";s:3:"XML";s:8:"language";s:3:"xml";}}}s:17:"ckeditor5_heading";a:1:{s:16:"enabled_headings";a:5:{i:0;s:8:"heading2";i:1;s:8:"heading3";i:2;s:8:"heading4";i:3;s:8:"heading5";i:4;s:8:"heading6";}}s:21:"ckeditor5_imageResize";a:1:{s:12:"allow_resize";b:1;}s:14:"ckeditor5_list";a:2:{s:10:"properties";a:2:{s:8:"reversed";b:1;s:10:"startIndex";b:1;}s:10:"multiBlock";b:1;}s:23:"ckeditor5_sourceEditing";a:1:{s:12:"allowed_tags";a:0:{}}}}s:12:"image_upload";a:5:{s:6:"status";b:1;s:6:"scheme";s:6:"public";s:9:"directory";s:13:"inline-images";s:8:"max_size";N;s:14:"max_dimensions";a:2:{s:5:"width";N;s:6:"height";N;}}}'),
('', 'field.field.block_content.basic.body', 'a:17:{s:4:"uuid";s:36:"b20166b5-ed72-45b0-8551-7219b8ae98c5";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:24:"block_content.type.basic";i:1;s:32:"field.storage.block_content.body";}s:6:"module";a:1:{i:0;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"j00Gfs9AFqwK4x9RIsISLbPO7vA12psPR4s60wOIwQo";}s:2:"id";s:24:"block_content.basic.body";s:10:"field_name";s:4:"body";s:11:"entity_type";s:13:"block_content";s:6:"bundle";s:5:"basic";s:5:"label";s:4:"Body";s:11:"description";s:0:"";s:8:"required";b:0;s:12:"translatable";b:1;s:13:"default_value";a:0:{}s:22:"default_value_callback";s:0:"";s:8:"settings";a:3:{s:15:"display_summary";b:0;s:16:"required_summary";b:0;s:15:"allowed_formats";a:0:{}}s:10:"field_type";s:17:"text_with_summary";}'),
('', 'field.field.comment.comment.comment_body', 'a:17:{s:4:"uuid";s:36:"a1a3e111-c95e-4500-ba43-64c27f84f863";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:20:"comment.type.comment";i:1;s:34:"field.storage.comment.comment_body";}s:6:"module";a:1:{i:0;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"62rlTOx3sPVrYhBnSBHZStXwiO02v1UpHSMrhWDsuG8";}s:2:"id";s:28:"comment.comment.comment_body";s:10:"field_name";s:12:"comment_body";s:11:"entity_type";s:7:"comment";s:6:"bundle";s:7:"comment";s:5:"label";s:7:"Comment";s:11:"description";s:0:"";s:8:"required";b:1;s:12:"translatable";b:1;s:13:"default_value";a:0:{}s:22:"default_value_callback";s:0:"";s:8:"settings";a:1:{s:15:"allowed_formats";a:0:{}}s:10:"field_type";s:9:"text_long";}'),
('', 'field.field.node.article.body', 'a:17:{s:4:"uuid";s:36:"05ad2534-241a-4ed6-871e-799464d991a4";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:23:"field.storage.node.body";i:1;s:17:"node.type.article";}s:6:"module";a:1:{i:0;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"4Wxs1LseZ8JsNwD9uJVIbzZqG35yQXN8Eo1Hub6NMuI";}s:2:"id";s:17:"node.article.body";s:10:"field_name";s:4:"body";s:11:"entity_type";s:4:"node";s:6:"bundle";s:7:"article";s:5:"label";s:4:"Body";s:11:"description";s:0:"";s:8:"required";b:0;s:12:"translatable";b:1;s:13:"default_value";a:0:{}s:22:"default_value_callback";s:0:"";s:8:"settings";a:3:{s:15:"display_summary";b:1;s:16:"required_summary";b:0;s:15:"allowed_formats";a:0:{}}s:10:"field_type";s:17:"text_with_summary";}'),
('', 'field.field.node.article.comment', 'a:17:{s:4:"uuid";s:36:"83b38220-7cae-4156-b1ab-f26c109f7c53";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:26:"field.storage.node.comment";i:1;s:17:"node.type.article";}s:6:"module";a:1:{i:0;s:7:"comment";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"UqXlkKC4v2-bDfWx4zcXQrD5YIi3d5byENEmWv-G_Uc";}s:2:"id";s:20:"node.article.comment";s:10:"field_name";s:7:"comment";s:11:"entity_type";s:4:"node";s:6:"bundle";s:7:"article";s:5:"label";s:8:"Comments";s:11:"description";s:0:"";s:8:"required";b:0;s:12:"translatable";b:1;s:13:"default_value";a:1:{i:0;a:6:{s:6:"status";i:2;s:3:"cid";i:0;s:22:"last_comment_timestamp";i:0;s:17:"last_comment_name";N;s:16:"last_comment_uid";i:0;s:13:"comment_count";i:0;}}s:22:"default_value_callback";s:0:"";s:8:"settings";a:5:{s:12:"default_mode";i:1;s:8:"per_page";i:50;s:9:"anonymous";i:0;s:13:"form_location";b:1;s:7:"preview";i:1;}s:10:"field_type";s:7:"comment";}'),
('', 'field.field.node.article.field_image', 'a:17:{s:4:"uuid";s:36:"c3539d99-630b-4b4d-b07a-61515727a187";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:30:"field.storage.node.field_image";i:1;s:17:"node.type.article";}s:6:"module";a:1:{i:0;s:5:"image";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"j0riO_-77ZFWNLtj0iJ31HnohiNjdn8HUL86RueCF-M";}s:2:"id";s:24:"node.article.field_image";s:10:"field_name";s:11:"field_image";s:11:"entity_type";s:4:"node";s:6:"bundle";s:7:"article";s:5:"label";s:5:"Image";s:11:"description";s:0:"";s:8:"required";b:0;s:12:"translatable";b:1;s:13:"default_value";a:0:{}s:22:"default_value_callback";s:0:"";s:8:"settings";a:12:{s:7:"handler";s:12:"default:file";s:16:"handler_settings";a:0:{}s:14:"file_directory";s:31:"[date:custom:Y]-[date:custom:m]";s:15:"file_extensions";s:21:"png gif jpg jpeg webp";s:12:"max_filesize";s:0:"";s:14:"max_resolution";s:0:"";s:14:"min_resolution";s:0:"";s:9:"alt_field";b:1;s:18:"alt_field_required";b:1;s:11:"title_field";b:0;s:20:"title_field_required";b:0;s:13:"default_image";a:5:{s:4:"uuid";N;s:3:"alt";s:0:"";s:5:"title";s:0:"";s:5:"width";N;s:6:"height";N;}}s:10:"field_type";s:5:"image";}'),
('', 'field.field.node.article.field_tags', 'a:17:{s:4:"uuid";s:36:"98d032c0-0cac-41e6-8d55-48d1dfcb4909";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"config";a:3:{i:0;s:29:"field.storage.node.field_tags";i:1;s:17:"node.type.article";i:2;s:24:"taxonomy.vocabulary.tags";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"QdUgf_beeoaPiyKorFv0q1fcJpWH_uZTqe_xoVJacrw";}s:2:"id";s:23:"node.article.field_tags";s:10:"field_name";s:10:"field_tags";s:11:"entity_type";s:4:"node";s:6:"bundle";s:7:"article";s:5:"label";s:4:"Tags";s:11:"description";s:84:"Enter a comma-separated list. For example: Amsterdam, Mexico City, "Cleveland, Ohio"";s:8:"required";b:0;s:12:"translatable";b:1;s:13:"default_value";a:0:{}s:22:"default_value_callback";s:0:"";s:8:"settings";a:2:{s:7:"handler";s:21:"default:taxonomy_term";s:16:"handler_settings";a:3:{s:14:"target_bundles";a:1:{s:4:"tags";s:4:"tags";}s:4:"sort";a:1:{s:5:"field";s:5:"_none";}s:11:"auto_create";b:1;}}s:10:"field_type";s:16:"entity_reference";}'),
('', 'field.field.node.page.body', 'a:17:{s:4:"uuid";s:36:"314bb960-496c-42a5-99f3-2c20e83fc553";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:23:"field.storage.node.body";i:1;s:14:"node.type.page";}s:6:"module";a:1:{i:0;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"KHu9I-pR4FnP79crRJ5gVD_1mKGSZcJsdIm9bn64iFg";}s:2:"id";s:14:"node.page.body";s:10:"field_name";s:4:"body";s:11:"entity_type";s:4:"node";s:6:"bundle";s:4:"page";s:5:"label";s:4:"Body";s:11:"description";s:0:"";s:8:"required";b:0;s:12:"translatable";b:1;s:13:"default_value";a:0:{}s:22:"default_value_callback";s:0:"";s:8:"settings";a:3:{s:15:"display_summary";b:1;s:16:"required_summary";b:0;s:15:"allowed_formats";a:0:{}}s:10:"field_type";s:17:"text_with_summary";}'),
('', 'field.field.user.user.user_picture', 'a:17:{s:4:"uuid";s:36:"2f5a24cf-d040-4a30-8225-7c2e0c09080d";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:31:"field.storage.user.user_picture";}s:6:"module";a:2:{i:0;s:5:"image";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"TE3gYVzd6g0deXqUl8SEu2azHwVG-SdXm3kwbrz0kHw";}s:2:"id";s:22:"user.user.user_picture";s:10:"field_name";s:12:"user_picture";s:11:"entity_type";s:4:"user";s:6:"bundle";s:4:"user";s:5:"label";s:7:"Picture";s:11:"description";s:29:"Your virtual face or picture.";s:8:"required";b:0;s:12:"translatable";b:1;s:13:"default_value";a:0:{}s:22:"default_value_callback";s:0:"";s:8:"settings";a:12:{s:7:"handler";s:12:"default:file";s:16:"handler_settings";a:0:{}s:14:"file_directory";s:40:"pictures/[date:custom:Y]-[date:custom:m]";s:15:"file_extensions";s:21:"png gif jpg jpeg webp";s:12:"max_filesize";s:0:"";s:14:"max_resolution";s:0:"";s:14:"min_resolution";s:0:"";s:9:"alt_field";b:0;s:18:"alt_field_required";b:0;s:11:"title_field";b:0;s:20:"title_field_required";b:0;s:13:"default_image";a:5:{s:4:"uuid";N;s:3:"alt";s:0:"";s:5:"title";s:0:"";s:5:"width";N;s:6:"height";N;}}s:10:"field_type";s:5:"image";}'),
('', 'field.settings', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"nJk0TAQBzlNo52ehiHI7bIEPLGi0BYqZvPdEn7Chfu0";}s:16:"purge_batch_size";i:50;}'),
('', 'field.storage.block_content.body', 'a:17:{s:4:"uuid";s:36:"71f98988-aa58-42f6-b766-9d7a71cb01d9";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:13:"block_content";i:1;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc";}s:2:"id";s:18:"block_content.body";s:10:"field_name";s:4:"body";s:11:"entity_type";s:13:"block_content";s:4:"type";s:17:"text_with_summary";s:8:"settings";a:0:{}s:6:"module";s:4:"text";s:6:"locked";b:0;s:11:"cardinality";i:1;s:12:"translatable";b:1;s:7:"indexes";a:0:{}s:22:"persist_with_no_fields";b:1;s:14:"custom_storage";b:0;}'),
('', 'field.storage.comment.comment_body', 'a:17:{s:4:"uuid";s:36:"aa3202fe-45b4-46af-99eb-a871cb54985b";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:7:"comment";i:1;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw";}s:2:"id";s:20:"comment.comment_body";s:10:"field_name";s:12:"comment_body";s:11:"entity_type";s:7:"comment";s:4:"type";s:9:"text_long";s:8:"settings";a:0:{}s:6:"module";s:4:"text";s:6:"locked";b:0;s:11:"cardinality";i:1;s:12:"translatable";b:1;s:7:"indexes";a:0:{}s:22:"persist_with_no_fields";b:1;s:14:"custom_storage";b:0;}'),
('', 'field.storage.node.body', 'a:17:{s:4:"uuid";s:36:"d8f860c7-f93a-446c-bdce-18ff53e81cc9";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:4:"node";i:1;s:4:"text";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY";}s:2:"id";s:9:"node.body";s:10:"field_name";s:4:"body";s:11:"entity_type";s:4:"node";s:4:"type";s:17:"text_with_summary";s:8:"settings";a:0:{}s:6:"module";s:4:"text";s:6:"locked";b:0;s:11:"cardinality";i:1;s:12:"translatable";b:1;s:7:"indexes";a:0:{}s:22:"persist_with_no_fields";b:1;s:14:"custom_storage";b:0;}'),
('', 'field.storage.node.comment', 'a:17:{s:4:"uuid";s:36:"a16c5662-b6e3-442f-b490-f840f6c7f095";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:7:"comment";i:1;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"ktCna9xmWvYZIUfOCUyDQvedn5RtnS4CRmEIwNmvYjc";}s:2:"id";s:12:"node.comment";s:10:"field_name";s:7:"comment";s:11:"entity_type";s:4:"node";s:4:"type";s:7:"comment";s:8:"settings";a:1:{s:12:"comment_type";s:7:"comment";}s:6:"module";s:7:"comment";s:6:"locked";b:0;s:11:"cardinality";i:1;s:12:"translatable";b:1;s:7:"indexes";a:0:{}s:22:"persist_with_no_fields";b:0;s:14:"custom_storage";b:0;}'),
('', 'field.storage.node.field_image', 'a:17:{s:4:"uuid";s:36:"4197b587-d8c1-48a4-832c-ffa48b177a67";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:3:{i:0;s:4:"file";i:1;s:5:"image";i:2;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE";}s:2:"id";s:16:"node.field_image";s:10:"field_name";s:11:"field_image";s:11:"entity_type";s:4:"node";s:4:"type";s:5:"image";s:8:"settings";a:5:{s:11:"target_type";s:4:"file";s:13:"display_field";b:0;s:15:"display_default";b:0;s:10:"uri_scheme";s:6:"public";s:13:"default_image";a:5:{s:4:"uuid";N;s:3:"alt";s:0:"";s:5:"title";s:0:"";s:5:"width";N;s:6:"height";N;}}s:6:"module";s:5:"image";s:6:"locked";b:0;s:11:"cardinality";i:1;s:12:"translatable";b:1;s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:22:"persist_with_no_fields";b:0;s:14:"custom_storage";b:0;}'),
('', 'field.storage.node.field_tags', 'a:17:{s:4:"uuid";s:36:"2b96be3b-b152-45c3-b641-eb7aa053b6aa";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:4:"node";i:1;s:8:"taxonomy";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs";}s:2:"id";s:15:"node.field_tags";s:10:"field_name";s:10:"field_tags";s:11:"entity_type";s:4:"node";s:4:"type";s:16:"entity_reference";s:8:"settings";a:1:{s:11:"target_type";s:13:"taxonomy_term";}s:6:"module";s:4:"core";s:6:"locked";b:0;s:11:"cardinality";i:-1;s:12:"translatable";b:1;s:7:"indexes";a:0:{}s:22:"persist_with_no_fields";b:0;s:14:"custom_storage";b:0;}'),
('', 'field.storage.user.user_picture', 'a:17:{s:4:"uuid";s:36:"ba3d61d8-4eb7-46de-ba22-28dcaaa22262";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:3:{i:0;s:4:"file";i:1;s:5:"image";i:2;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E";}s:2:"id";s:17:"user.user_picture";s:10:"field_name";s:12:"user_picture";s:11:"entity_type";s:4:"user";s:4:"type";s:5:"image";s:8:"settings";a:5:{s:11:"target_type";s:4:"file";s:13:"display_field";b:0;s:15:"display_default";b:0;s:10:"uri_scheme";s:6:"public";s:13:"default_image";a:5:{s:4:"uuid";N;s:3:"alt";s:0:"";s:5:"title";s:0:"";s:5:"width";N;s:6:"height";N;}}s:6:"module";s:5:"image";s:6:"locked";b:0;s:11:"cardinality";i:1;s:12:"translatable";b:1;s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:22:"persist_with_no_fields";b:0;s:14:"custom_storage";b:0;}'),
('', 'field_ui.settings', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"Q1nMi90W6YQxKzZAgJQw7Ag9U4JrsEUwkomF0lhvbIM";}s:12:"field_prefix";s:6:"field_";}'),
('', 'file.settings', 'a:5:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"2bwjZB1IjEYbppgZT3g7YW_5h_LDZYNa3DaDEfWX82U";}s:11:"description";a:2:{s:4:"type";s:9:"textfield";s:6:"length";i:128;}s:4:"icon";a:1:{s:9:"directory";s:23:"core/modules/file/icons";}s:35:"make_unused_managed_files_temporary";b:0;s:21:"filename_sanitization";a:6:{s:13:"transliterate";b:0;s:18:"replace_whitespace";b:0;s:24:"replace_non_alphanumeric";b:0;s:22:"deduplicate_separators";b:0;s:9:"lowercase";b:0;s:21:"replacement_character";s:1:"-";}}'),
('', 'filter.format.basic_html', 'a:9:{s:4:"uuid";s:36:"efbbd834-71f0-410e-a7c1-16e22df1b8fb";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:6:"editor";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"mclCbTlJwWJORez4Y1eX2MqA0aGjSMAoJb3TaBABcK8";}s:4:"name";s:10:"Basic HTML";s:6:"format";s:10:"basic_html";s:6:"weight";i:0;s:7:"filters";a:6:{s:21:"editor_file_reference";a:5:{s:2:"id";s:21:"editor_file_reference";s:8:"provider";s:6:"editor";s:6:"status";b:1;s:6:"weight";i:11;s:8:"settings";a:0:{}}s:12:"filter_align";a:5:{s:2:"id";s:12:"filter_align";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:7;s:8:"settings";a:0:{}}s:14:"filter_caption";a:5:{s:2:"id";s:14:"filter_caption";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:8;s:8:"settings";a:0:{}}s:11:"filter_html";a:5:{s:2:"id";s:11:"filter_html";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:-10;s:8:"settings";a:3:{s:12:"allowed_html";s:243:"<br> <p> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id> <cite> <dl> <dt> <dd> <a hreflang href> <blockquote cite> <ul type> <ol start type> <strong> <em> <code> <li> <img src alt data-entity-uuid data-entity-type height width data-caption data-align>";s:16:"filter_html_help";b:0;s:20:"filter_html_nofollow";b:0;}}s:24:"filter_html_image_secure";a:5:{s:2:"id";s:24:"filter_html_image_secure";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:9;s:8:"settings";a:0:{}}s:22:"filter_image_lazy_load";a:5:{s:2:"id";s:22:"filter_image_lazy_load";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:15;s:8:"settings";a:0:{}}}}'),
('', 'filter.format.full_html', 'a:9:{s:4:"uuid";s:36:"3fb39974-c855-4bd7-8483-2fd31beedc6f";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:6:"editor";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"vpZysv3RHJjhYzq7O_q5q8mVlHdrSzKELmXyiX6RtV0";}s:4:"name";s:9:"Full HTML";s:6:"format";s:9:"full_html";s:6:"weight";i:2;s:7:"filters";a:5:{s:21:"editor_file_reference";a:5:{s:2:"id";s:21:"editor_file_reference";s:8:"provider";s:6:"editor";s:6:"status";b:1;s:6:"weight";i:11;s:8:"settings";a:0:{}}s:12:"filter_align";a:5:{s:2:"id";s:12:"filter_align";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:8;s:8:"settings";a:0:{}}s:14:"filter_caption";a:5:{s:2:"id";s:14:"filter_caption";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:9;s:8:"settings";a:0:{}}s:20:"filter_htmlcorrector";a:5:{s:2:"id";s:20:"filter_htmlcorrector";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:10;s:8:"settings";a:0:{}}s:22:"filter_image_lazy_load";a:5:{s:2:"id";s:22:"filter_image_lazy_load";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:15;s:8:"settings";a:0:{}}}}'),
('', 'filter.format.plain_text', 'a:9:{s:4:"uuid";s:36:"af4426ab-3b1f-4061-ac02-13abf9672aab";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"JLMwODO0epnA_H-jFlH9ezVfa5YBJniRv3MmLqYNl_Q";}s:4:"name";s:10:"Plain text";s:6:"format";s:10:"plain_text";s:6:"weight";i:10;s:7:"filters";a:3:{s:12:"filter_autop";a:5:{s:2:"id";s:12:"filter_autop";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:0;s:8:"settings";a:0:{}}s:18:"filter_html_escape";a:5:{s:2:"id";s:18:"filter_html_escape";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:-10;s:8:"settings";a:0:{}}s:10:"filter_url";a:5:{s:2:"id";s:10:"filter_url";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:0;s:8:"settings";a:1:{s:17:"filter_url_length";i:72;}}}}'),
('', 'filter.format.restricted_html', 'a:9:{s:4:"uuid";s:36:"aebc09f6-c5b1-47a2-ba77-3057d5a5e38f";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"QiKqQS_YGAT3Qr4vaAgZICJknm-MGCzt_xBAMqg-tRM";}s:4:"name";s:15:"Restricted HTML";s:6:"format";s:15:"restricted_html";s:6:"weight";i:1;s:7:"filters";a:3:{s:12:"filter_autop";a:5:{s:2:"id";s:12:"filter_autop";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:0;s:8:"settings";a:0:{}}s:11:"filter_html";a:5:{s:2:"id";s:11:"filter_html";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:-10;s:8:"settings";a:3:{s:12:"allowed_html";s:149:"<a href hreflang> <em> <strong> <cite> <blockquote cite> <code> <ul type> <ol start type> <li> <dl> <dt> <dd> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id>";s:16:"filter_html_help";b:1;s:20:"filter_html_nofollow";b:0;}}s:10:"filter_url";a:5:{s:2:"id";s:10:"filter_url";s:8:"provider";s:6:"filter";s:6:"status";b:1;s:6:"weight";i:0;s:8:"settings";a:1:{s:17:"filter_url_length";i:72;}}}}'),
('', 'filter.settings', 'a:3:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"FiPjM3WdB__ruFA7B6TLwni_UcZbmek5G4b2dxQItxA";}s:15:"fallback_format";s:10:"plain_text";s:27:"always_show_fallback_choice";b:0;}'),
('', 'image.settings', 'a:4:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"k-yDFHbqNfpe-Srg4sdCSqaosCl2D8uwyEY5esF8gEw";}s:13:"preview_image";s:29:"core/modules/image/sample.png";s:26:"allow_insecure_derivatives";b:0;s:20:"suppress_itok_output";b:0;}'),
('', 'image.style.large', 'a:8:{s:4:"uuid";s:36:"9dd42401-666c-44a4-b7bb-30fba679cf4d";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"rDR2BOewa2UFH9yG4tVvrGxEVv8U7LQo-RLkJhFpERs";}s:4:"name";s:5:"large";s:5:"label";s:16:"Large (480×480)";s:7:"effects";a:2:{s:36:"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d";a:4:{s:4:"uuid";s:36:"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d";s:2:"id";s:11:"image_scale";s:6:"weight";i:0;s:4:"data";a:3:{s:5:"width";i:480;s:6:"height";i:480;s:7:"upscale";b:0;}}s:36:"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8";a:4:{s:4:"uuid";s:36:"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8";s:2:"id";s:13:"image_convert";s:6:"weight";i:2;s:4:"data";a:1:{s:9:"extension";s:4:"webp";}}}}'),
('', 'image.style.medium', 'a:8:{s:4:"uuid";s:36:"1845b698-fff3-4a4f-8dd2-9928c638e925";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"dlar76VBuGj5iMGTruB_uMZX8VbivXt9_QLemaG2q4E";}s:4:"name";s:6:"medium";s:5:"label";s:17:"Medium (220×220)";s:7:"effects";a:2:{s:36:"bddf0d06-42f9-4c75-a700-a33cafa25ea0";a:4:{s:4:"uuid";s:36:"bddf0d06-42f9-4c75-a700-a33cafa25ea0";s:2:"id";s:11:"image_scale";s:6:"weight";i:0;s:4:"data";a:3:{s:5:"width";i:220;s:6:"height";i:220;s:7:"upscale";b:0;}}s:36:"c410ed2f-aa30-4d9c-a224-d2865d9188cd";a:4:{s:4:"uuid";s:36:"c410ed2f-aa30-4d9c-a224-d2865d9188cd";s:2:"id";s:13:"image_convert";s:6:"weight";i:2;s:4:"data";a:1:{s:9:"extension";s:4:"webp";}}}}'),
('', 'image.style.thumbnail', 'a:8:{s:4:"uuid";s:36:"8c9d250b-f29b-4112-9ec0-2921ae917d3d";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"BgeBV-xOFINMsz-y2thm45EGesj6bRM6DTLZ6ce3V9I";}s:4:"name";s:9:"thumbnail";s:5:"label";s:20:"Thumbnail (100×100)";s:7:"effects";a:2:{s:36:"1cfec298-8620-4749-b100-ccb6c4500779";a:4:{s:4:"uuid";s:36:"1cfec298-8620-4749-b100-ccb6c4500779";s:2:"id";s:11:"image_scale";s:6:"weight";i:0;s:4:"data";a:3:{s:5:"width";i:100;s:6:"height";i:100;s:7:"upscale";b:0;}}s:36:"c4eb9942-2c9e-4a81-949f-6161a44b6559";a:4:{s:4:"uuid";s:36:"c4eb9942-2c9e-4a81-949f-6161a44b6559";s:2:"id";s:13:"image_convert";s:6:"weight";i:2;s:4:"data";a:1:{s:9:"extension";s:4:"webp";}}}}'),
('', 'image.style.wide', 'a:8:{s:4:"uuid";s:36:"d3f45111-f962-462a-b272-e1fe0d5c0a98";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"XHh3ATMH7z4ljwmzdndM47qNMkgLnoYsP98rGxVgCOw";}s:4:"name";s:4:"wide";s:5:"label";s:11:"Wide (1090)";s:7:"effects";a:2:{s:36:"09959c15-59ce-4f6d-90df-e2d7cf32bce5";a:4:{s:4:"uuid";s:36:"09959c15-59ce-4f6d-90df-e2d7cf32bce5";s:2:"id";s:11:"image_scale";s:6:"weight";i:1;s:4:"data";a:3:{s:5:"width";i:1090;s:6:"height";N;s:7:"upscale";b:0;}}s:36:"294c5f76-42a4-43ce-82c2-81c2f4723da0";a:4:{s:4:"uuid";s:36:"294c5f76-42a4-43ce-82c2-81c2f4723da0";s:2:"id";s:13:"image_convert";s:6:"weight";i:2;s:4:"data";a:1:{s:9:"extension";s:4:"webp";}}}}'),
('', 'menu_ui.settings', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"SqMarzIjxC3F8dZo9FEOxfqDKD_sdW1tbcFTV1BA2zU";}s:24:"override_parent_selector";b:0;}'),
('', 'node.settings', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"W0cgFPhPJ3gAdqm06-az48BLf5MVcoZVS0HdByoofi0";}s:15:"use_admin_theme";b:1;}'),
('', 'node.type.article', 'a:12:{s:4:"uuid";s:36:"3ee06044-7dde-40ec-b915-d970a4686cab";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"Fe3N1uqaAyyKJbVkqT-btXy3t98puW8GCRD822xjl10";}s:4:"name";s:7:"Article";s:4:"type";s:7:"article";s:11:"description";s:89:"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.";s:4:"help";N;s:12:"new_revision";b:1;s:12:"preview_mode";i:1;s:17:"display_submitted";b:1;}'),
('', 'node.type.page', 'a:12:{s:4:"uuid";s:36:"39c96fb8-f8a0-4092-943f-fc3b72331c9f";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"i0snV8Wj--OkRW12UdachUiYiz3FbeMwHu_pZYfzKLc";}s:4:"name";s:10:"Basic page";s:4:"type";s:4:"page";s:11:"description";s:77:"Use <em>basic pages</em> for your static content, such as an ''About us'' page.";s:4:"help";N;s:12:"new_revision";b:1;s:12:"preview_mode";i:1;s:17:"display_submitted";b:0;}'),
('', 'olivero.settings', 'a:8:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"1TswGK46jyu77aIM7Z-0JVQs5bxHmo-gtgrvrQGMXxc";}s:7:"favicon";a:1:{s:11:"use_default";b:1;}s:8:"features";a:4:{s:20:"comment_user_picture";b:1;s:25:"comment_user_verification";b:1;s:7:"favicon";b:1;s:17:"node_user_picture";b:0;}s:4:"logo";a:1:{s:11:"use_default";b:0;}s:20:"third_party_settings";a:1:{s:8:"shortcut";a:1:{s:11:"module_link";b:1;}}s:22:"mobile_menu_all_widths";i:0;s:22:"site_branding_bg_color";s:7:"default";s:18:"base_primary_color";s:7:"#1b9ae4";}'),
('', 'search.page.help_search', 'a:11:{s:4:"uuid";s:36:"28698998-9349-41ff-aa07-85677d583124";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"help";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"RZ-bcSekNSsAbIPLW7Gmyd3uUjIOSrPvnb8RCCZYJm8";}s:2:"id";s:11:"help_search";s:5:"label";s:4:"Help";s:4:"path";s:4:"help";s:6:"weight";i:0;s:6:"plugin";s:11:"help_search";s:13:"configuration";a:0:{}}'),
('', 'search.page.node_search', 'a:11:{s:4:"uuid";s:36:"82a27bc3-9284-4a81-974f-71ad5b5ce51c";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"97tvtzGOa8_flb22CzSjgtm_YkiGMHvEBO-6q2K9V_U";}s:2:"id";s:11:"node_search";s:5:"label";s:7:"Content";s:4:"path";s:4:"node";s:6:"weight";i:-10;s:6:"plugin";s:11:"node_search";s:13:"configuration";a:1:{s:8:"rankings";a:0:{}}}'),
('', 'search.page.user_search', 'a:11:{s:4:"uuid";s:36:"72d55c92-3be9-4368-bf45-d3ff7ee01051";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"k3aUaZXGDuhkek2TZIee0PApOPTvYZLadziekdyHA5A";}s:2:"id";s:11:"user_search";s:5:"label";s:5:"Users";s:4:"path";s:4:"user";s:6:"weight";i:0;s:6:"plugin";s:11:"user_search";s:13:"configuration";a:0:{}}'),
('', 'search.settings', 'a:5:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"hvVxL1G-ZCxaq32IZws0YsfuhvaDiQE_np-0g35KjUk";}s:12:"and_or_limit";i:7;s:12:"default_page";s:11:"node_search";s:5:"index";a:4:{s:10:"cron_limit";i:100;s:11:"overlap_cjk";b:1;s:17:"minimum_word_size";i:3;s:11:"tag_weights";a:12:{s:2:"h1";i:25;s:2:"h2";i:18;s:2:"h3";i:15;s:2:"h4";i:14;s:2:"h5";i:9;s:2:"h6";i:6;s:1:"u";i:3;s:1:"b";i:3;s:1:"i";i:3;s:6:"strong";i:3;s:2:"em";i:3;s:1:"a";i:10;}}s:7:"logging";b:0;}'),
('', 'shortcut.set.default', 'a:7:{s:4:"uuid";s:36:"55b875ef-d9ad-4f74-bbf9-2f3803cda8bb";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"U5VlGjd_SfV0Qm_EfnaynOfc549cNscFAx48JfYoMRI";}s:2:"id";s:7:"default";s:5:"label";s:7:"Default";}'),
('', 'system.action.comment_delete_action', 'a:10:{s:4:"uuid";s:36:"f4e9fbbc-4215-46b3-a9f8-4a1ab1e6259e";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:7:"comment";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"vpBH8OmL4sdesCdeZLsW8KOutB5gkbreWJbfjhfFKaQ";}s:2:"id";s:21:"comment_delete_action";s:5:"label";s:14:"Delete comment";s:4:"type";s:7:"comment";s:6:"plugin";s:28:"entity:delete_action:comment";s:13:"configuration";a:0:{}}'),
('', 'system.action.comment_publish_action', 'a:10:{s:4:"uuid";s:36:"ee170ca8-05e4-4c9e-acce-fb79e6655f9c";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:7:"comment";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"C00dyL_W_5M0nFlgUB3lWUTUs96jn51Jw1MLHVEHZD0";}s:2:"id";s:22:"comment_publish_action";s:5:"label";s:15:"Publish comment";s:4:"type";s:7:"comment";s:6:"plugin";s:29:"entity:publish_action:comment";s:13:"configuration";a:0:{}}'),
('', 'system.action.comment_save_action', 'a:10:{s:4:"uuid";s:36:"c866e7f5-fdd4-453a-9d4e-10b8f07604d7";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:7:"comment";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"lfyE_snmvfg_EQ3VDyhUtGAXgmqtEiqa46I3bTMg8DU";}s:2:"id";s:19:"comment_save_action";s:5:"label";s:12:"Save comment";s:4:"type";s:7:"comment";s:6:"plugin";s:26:"entity:save_action:comment";s:13:"configuration";a:0:{}}'),
('', 'system.action.comment_unpublish_action', 'a:10:{s:4:"uuid";s:36:"891ae484-6a65-41d3-a061-c1de60d2ca51";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:7:"comment";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"tWOIjSMobEWOFZddMkNqb9JySbOVwE1diC6NRqcfLTk";}s:2:"id";s:24:"comment_unpublish_action";s:5:"label";s:17:"Unpublish comment";s:4:"type";s:7:"comment";s:6:"plugin";s:31:"entity:unpublish_action:comment";s:13:"configuration";a:0:{}}'),
('', 'system.action.node_delete_action', 'a:10:{s:4:"uuid";s:36:"6796d819-0b36-46f0-a1a6-25ca87ac42f5";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"t43OqwzP3CTbcAagSsWKNy6KwMm_zShXo3c4-So6rQg";}s:2:"id";s:18:"node_delete_action";s:5:"label";s:14:"Delete content";s:4:"type";s:4:"node";s:6:"plugin";s:25:"entity:delete_action:node";s:13:"configuration";a:0:{}}'),
('', 'system.action.node_make_sticky_action', 'a:10:{s:4:"uuid";s:36:"44fd7ebc-0c6c-4403-b2c9-5198940c80f2";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"sOb26JSy3fGpWkvR0WYN6_hMqj_6d1rvbvrkzp1yya0";}s:2:"id";s:23:"node_make_sticky_action";s:5:"label";s:19:"Make content sticky";s:4:"type";s:4:"node";s:6:"plugin";s:23:"node_make_sticky_action";s:13:"configuration";a:0:{}}'),
('', 'system.action.node_make_unsticky_action', 'a:10:{s:4:"uuid";s:36:"947b8d1c-b1d7-41b6-9926-b6d3f3fffba1";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"lDM9mvIGAu8Sw8rt-uCO4Sr7yX5VPrDPxYcawkbKd6k";}s:2:"id";s:25:"node_make_unsticky_action";s:5:"label";s:21:"Make content unsticky";s:4:"type";s:4:"node";s:6:"plugin";s:25:"node_make_unsticky_action";s:13:"configuration";a:0:{}}'),
('', 'system.action.node_promote_action', 'a:10:{s:4:"uuid";s:36:"a3072b0e-5e7b-4939-acd7-6ea93d4c6343";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"N0RDBTqiK4dKoN4p4oW2j0SGWycdHyALUe9M-Ofp89U";}s:2:"id";s:19:"node_promote_action";s:5:"label";s:29:"Promote content to front page";s:4:"type";s:4:"node";s:6:"plugin";s:19:"node_promote_action";s:13:"configuration";a:0:{}}'),
('', 'system.action.node_publish_action', 'a:10:{s:4:"uuid";s:36:"c0884e7c-2f3b-4c1e-afcc-340ddc314022";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"2B9uF8NL5gutNKSdPRAhhAsDWFZZG1PJOBmx0aBGd_0";}s:2:"id";s:19:"node_publish_action";s:5:"label";s:15:"Publish content";s:4:"type";s:4:"node";s:6:"plugin";s:26:"entity:publish_action:node";s:13:"configuration";a:0:{}}'),
('', 'system.action.node_save_action', 'a:10:{s:4:"uuid";s:36:"a15f3224-f521-4f70-85b7-7bd74477a229";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"LhdsoZPL_pFas2fjaAWue4zvrQ_tEVofLYtcNec-JGM";}s:2:"id";s:16:"node_save_action";s:5:"label";s:12:"Save content";s:4:"type";s:4:"node";s:6:"plugin";s:23:"entity:save_action:node";s:13:"configuration";a:0:{}}'),
('', 'system.action.node_unpromote_action', 'a:10:{s:4:"uuid";s:36:"c34ff704-ae20-4fd1-95dd-7cd9814400bf";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"JBptjnfuOMtsdKygklXxoOgeOCTMtQxlkymjnnj-cC0";}s:2:"id";s:21:"node_unpromote_action";s:5:"label";s:30:"Remove content from front page";s:4:"type";s:4:"node";s:6:"plugin";s:21:"node_unpromote_action";s:13:"configuration";a:0:{}}'),
('', 'system.action.node_unpublish_action', 'a:10:{s:4:"uuid";s:36:"9576c5af-0977-46e0-9278-2130c407aa5e";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"node";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"C7X8h9FWlwkQ9y5mnU2JzgaZICAdc6HFbPVbhvjlAYE";}s:2:"id";s:21:"node_unpublish_action";s:5:"label";s:17:"Unpublish content";s:4:"type";s:4:"node";s:6:"plugin";s:28:"entity:unpublish_action:node";s:13:"configuration";a:0:{}}'),
('', 'system.action.taxonomy_term_publish_action', 'a:10:{s:4:"uuid";s:36:"185dac4e-65cc-4ebc-9b72-fecea81b7447";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:8:"taxonomy";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"DoVt_VGgVLcDD4XmVbSFzr0K17SJy9imFiYusKkJBgY";}s:2:"id";s:28:"taxonomy_term_publish_action";s:5:"label";s:21:"Publish taxonomy term";s:4:"type";s:13:"taxonomy_term";s:6:"plugin";s:35:"entity:publish_action:taxonomy_term";s:13:"configuration";a:0:{}}'),
('', 'system.action.taxonomy_term_unpublish_action', 'a:10:{s:4:"uuid";s:36:"7611458e-aaff-4499-911d-c951fbf6c97d";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:8:"taxonomy";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"z2sNRM3ECa7FPCGnSNje_9SmZJQgwhD_6fG_L4Mr8zI";}s:2:"id";s:30:"taxonomy_term_unpublish_action";s:5:"label";s:23:"Unpublish taxonomy term";s:4:"type";s:13:"taxonomy_term";s:6:"plugin";s:37:"entity:unpublish_action:taxonomy_term";s:13:"configuration";a:0:{}}'),
('', 'system.action.user_add_role_action.administrator', 'a:9:{s:4:"uuid";s:36:"763fa5d1-021b-42ca-8166-6754bcae6d68";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:23:"user.role.administrator";}s:6:"module";a:1:{i:0;s:4:"user";}}s:2:"id";s:34:"user_add_role_action.administrator";s:5:"label";s:50:"Add the Administrator role to the selected user(s)";s:4:"type";s:4:"user";s:6:"plugin";s:20:"user_add_role_action";s:13:"configuration";a:1:{s:3:"rid";s:13:"administrator";}}'),
('', 'system.action.user_add_role_action.content_editor', 'a:9:{s:4:"uuid";s:36:"252809a9-7844-4a72-bb02-8766aa53e8f0";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:24:"user.role.content_editor";}s:6:"module";a:1:{i:0;s:4:"user";}}s:2:"id";s:35:"user_add_role_action.content_editor";s:5:"label";s:51:"Add the Content editor role to the selected user(s)";s:4:"type";s:4:"user";s:6:"plugin";s:20:"user_add_role_action";s:13:"configuration";a:1:{s:3:"rid";s:14:"content_editor";}}'),
('', 'system.action.user_block_user_action', 'a:10:{s:4:"uuid";s:36:"604609d8-ec4c-4e56-96b0-7c588d0fd294";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"DyypzTfThX10FFQw-399qPfEbLLyrhXgQrKPVsmAoJ4";}s:2:"id";s:22:"user_block_user_action";s:5:"label";s:26:"Block the selected user(s)";s:4:"type";s:4:"user";s:6:"plugin";s:22:"user_block_user_action";s:13:"configuration";a:0:{}}'),
('', 'system.action.user_cancel_user_action', 'a:10:{s:4:"uuid";s:36:"72abe7b6-a935-4bf6-a823-2f9e63657a9b";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"nvrL9bFilzBvm2bjO9rQnFDpBA7dBBUjShSSt6NS-DU";}s:2:"id";s:23:"user_cancel_user_action";s:5:"label";s:35:"Cancel the selected user account(s)";s:4:"type";s:4:"user";s:6:"plugin";s:23:"user_cancel_user_action";s:13:"configuration";a:0:{}}'),
('', 'system.action.user_remove_role_action.administrator', 'a:9:{s:4:"uuid";s:36:"6921cc0b-5cdb-4f4e-bc3c-0e92be8e7e4d";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:23:"user.role.administrator";}s:6:"module";a:1:{i:0;s:4:"user";}}s:2:"id";s:37:"user_remove_role_action.administrator";s:5:"label";s:55:"Remove the Administrator role from the selected user(s)";s:4:"type";s:4:"user";s:6:"plugin";s:23:"user_remove_role_action";s:13:"configuration";a:1:{s:3:"rid";s:13:"administrator";}}'),
('', 'system.action.user_remove_role_action.content_editor', 'a:9:{s:4:"uuid";s:36:"d4a82d44-3643-4e78-82dd-9fdc6c117f5d";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:24:"user.role.content_editor";}s:6:"module";a:1:{i:0;s:4:"user";}}s:2:"id";s:38:"user_remove_role_action.content_editor";s:5:"label";s:56:"Remove the Content editor role from the selected user(s)";s:4:"type";s:4:"user";s:6:"plugin";s:23:"user_remove_role_action";s:13:"configuration";a:1:{s:3:"rid";s:14:"content_editor";}}'),
('', 'system.action.user_unblock_user_action', 'a:10:{s:4:"uuid";s:36:"ea263e3e-9392-4d9c-b5d6-020de34b7b44";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"SPsUXsR3Rc8d1y3gewzaAKWa1ncea_ywXX3f7LTn7k0";}s:2:"id";s:24:"user_unblock_user_action";s:5:"label";s:28:"Unblock the selected user(s)";s:4:"type";s:4:"user";s:6:"plugin";s:24:"user_unblock_user_action";s:13:"configuration";a:0:{}}'),
('', 'system.advisories', 'a:3:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"x0FuQ_7Cg81mSDQwG028_Z0CjH3R9ib5IDlHeV2BbAo";}s:7:"enabled";b:1;s:14:"interval_hours";i:6;}'),
('', 'system.cron', 'a:3:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"f3yToH8v8EaBZU0NFFw2qR8ogSCuWVmQaN0hpYR1BD8";}s:9:"threshold";a:2:{s:20:"requirements_warning";i:172800;s:18:"requirements_error";i:1209600;}s:7:"logging";b:1;}'),
('', 'system.date', 'a:4:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"IVsFTD1mvR2NGBP_1myt9kFIFmGepH4PyaN5aQBYpno";}s:9:"first_day";i:0;s:7:"country";a:1:{s:7:"default";N;}s:8:"timezone";a:2:{s:7:"default";s:3:"UTC";s:4:"user";a:3:{s:12:"configurable";b:1;s:7:"default";i:0;s:4:"warn";b:0;}}}'),
('', 'system.diff', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"1WanmaEhxW_vM8_5Ktsdntj8MaO9UBHXg0lN603PsWM";}s:7:"context";a:2:{s:13:"lines_leading";i:2;s:14:"lines_trailing";i:2;}}'),
('', 'system.feature_flags', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"ZYyVj1FtPGV40Cf65YDVTUIc7YgLH6trXlotuevfs2I";}s:16:"linkset_endpoint";b:0;}'),
('', 'system.file', 'a:4:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"mguGHCYb9Dw5EcpfjwoShGV1Vjkbz3QuPRCLfxiye-g";}s:22:"allow_insecure_uploads";b:0;s:14:"default_scheme";s:6:"public";s:21:"temporary_maximum_age";i:21600;}'),
('', 'system.image', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"durWHaKeBaq4d9Wpi4RqwADj1OufDepcnJuhVLmKN24";}s:7:"toolkit";s:2:"gd";}'),
('', 'system.image.gd', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"eNXaHfkJJUThHeF0nvkoXyPLRrKYGxgHRjORvT4F5rQ";}s:12:"jpeg_quality";i:75;}'),
('', 'system.logging', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"u3-njszl92FaxjrCMiq0yDcjAfcdx72w1zT1O9dx6aA";}s:11:"error_level";s:4:"hide";}'),
('', 'system.mail', 'a:3:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"5PvD9swkqWUeHkabdvbJ2SQqdhrzjkCT21wtD4BLfk4";}s:9:"interface";a:1:{s:7:"default";s:8:"php_mail";}s:10:"mailer_dsn";a:6:{s:6:"scheme";s:8:"sendmail";s:4:"host";s:7:"default";s:4:"user";N;s:8:"password";N;s:4:"port";N;s:7:"options";a:0:{}}}'),
('', 'system.maintenance', 'a:3:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"1SNdA25INsV5YjlgAJtfC-6AM8VcWe_00xneMLb2yFg";}s:8:"langcode";s:2:"en";s:7:"message";s:93:"@site is currently under maintenance. We should be back shortly. Thank you for your patience.";}'),
('', 'system.menu.account', 'a:9:{s:4:"uuid";s:36:"07bdd5ba-df13-4567-ba56-32d965725304";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"M_Bh81osDyUQ4wV0GgU_NdBNqkzM87sLxjaCdFj9mnw";}s:2:"id";s:7:"account";s:5:"label";s:17:"User account menu";s:11:"description";s:40:"Links related to the active user account";s:6:"locked";b:1;}'),
('', 'system.menu.admin', 'a:9:{s:4:"uuid";s:36:"80fc3a59-58ad-4c77-b4fb-3017ec6a534e";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"sapEi2YDGoI9yQIT_WgIV2vUdQ6DScH0V3fAyTadAL0";}s:2:"id";s:5:"admin";s:5:"label";s:14:"Administration";s:11:"description";s:25:"Administrative task links";s:6:"locked";b:1;}'),
('', 'system.menu.footer', 'a:9:{s:4:"uuid";s:36:"f102c3e3-f44a-4e11-94bd-fc8998e4cea2";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"7yrlW5z9zdg2eBucB2GPqXKSMQfH9lSRSO4DbWF7AFc";}s:2:"id";s:6:"footer";s:5:"label";s:6:"Footer";s:11:"description";s:22:"Site information links";s:6:"locked";b:1;}'),
('', 'system.menu.main', 'a:9:{s:4:"uuid";s:36:"94e9f4d5-90f5-4917-9663-996774e659d5";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"Q2Ra3jfoIVk0f3SjxJX61byRQFVBAbpzYDQOiY-kno8";}s:2:"id";s:4:"main";s:5:"label";s:15:"Main navigation";s:11:"description";s:18:"Site section links";s:6:"locked";b:1;}'),
('', 'system.menu.tools', 'a:9:{s:4:"uuid";s:36:"6d470c5b-07cd-4125-88a9-90be9b25a2a4";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"BCM-vV1zzRaLHN18dqAR_CuGOj8AFJvTx7BKl_8Gcxc";}s:2:"id";s:5:"tools";s:5:"label";s:5:"Tools";s:11:"description";s:39:"User tool links, often added by modules";s:6:"locked";b:1;}'),
('', 'system.performance', 'a:5:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"jtno5biznHZbrIgKwzq-ze-7XaQxLCGe6PeUOR7bRiQ";}s:5:"cache";a:1:{s:4:"page";a:1:{s:7:"max_age";i:0;}}s:3:"css";a:2:{s:10:"preprocess";b:1;s:4:"gzip";b:1;}s:8:"fast_404";a:4:{s:7:"enabled";b:1;s:5:"paths";s:69:"/\\.(?:txt|png|gif|jpe?g|css|js|ico|swf|flv|cgi|bat|pl|dll|exe|asp)$/i";s:13:"exclude_paths";s:27:"/\\/(?:styles|imagecache)\\//";s:4:"html";s:162:"<!DOCTYPE html><html><head><title>404 Not Found</title></head><body><h1>Not Found</h1><p>The requested URL "@path" was not found on this server.</p></body></html>";}s:2:"js";a:2:{s:10:"preprocess";b:1;s:4:"gzip";b:1;}}'),
('', 'system.rss', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"MIpNzlG4gPunfS7vTCwUPum6QH3GUsEBMj-qS631Jw0";}s:5:"items";a:1:{s:9:"view_mode";s:3:"rss";}}'),
('', 'system.site', 'a:11:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"ijfbzDTN4CbE7Sr-6ubWzy_t1vH4OtU1doNCLssVz-4";}s:8:"langcode";s:2:"en";s:4:"uuid";s:36:"46a31383-fb45-4af1-bdb0-b2107ea496c7";s:4:"name";[[ser_site_name]]s:4:"mail";[[site_mail]]s:6:"slogan";s:0:"";s:4:"page";a:3:{i:403;s:0:"";i:404;s:0:"";s:5:"front";s:5:"/node";}s:18:"admin_compact_mode";b:0;s:17:"weight_select_max";i:100;s:16:"default_langcode";s:2:"en";s:17:"mail_notification";N;}'),
('', 'system.theme', 'a:3:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"eJ529VM1gSIA_vgTy2PdiDvJuG0xhSxfQjCyl5WKlv4";}s:5:"admin";s:5:"claro";s:7:"default";s:7:"olivero";}'),
('', 'system.theme.global', 'a:4:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"KZiV2LB312xgJBphfq5BTjmp16xiR5KM8InBJ-pff7Y";}s:7:"favicon";a:4:{s:8:"mimetype";s:24:"image/vnd.microsoft.icon";s:4:"path";s:0:"";s:3:"url";s:0:"";s:11:"use_default";b:1;}s:8:"features";a:4:{s:20:"comment_user_picture";b:1;s:25:"comment_user_verification";b:1;s:7:"favicon";b:1;s:17:"node_user_picture";b:1;}s:4:"logo";a:3:{s:4:"path";s:0:"";s:3:"url";N;s:11:"use_default";b:1;}}'),
('', 'taxonomy.settings', 'a:4:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"zKpaWT6cJc1tVQQaTqatGELaCqU_oyRym6zTl27Yias";}s:20:"maintain_index_table";b:1;s:17:"override_selector";b:0;s:20:"terms_per_page_admin";i:100;}'),
('', 'taxonomy.vocabulary.tags', 'a:10:{s:4:"uuid";s:36:"ccce2ae7-b7bc-439f-acb3-b1ca27be0322";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"iTEzwrEQ_4JIb-OYGiqzyF2TmMgWyWayresXcWgwGWM";}s:4:"name";s:4:"Tags";s:3:"vid";s:4:"tags";s:11:"description";s:61:"Use tags to group articles on similar topics into categories.";s:6:"weight";i:0;s:12:"new_revision";b:0;}'),
('', 'text.settings', 'a:2:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"Bkewb77RBOK3_aXMPsp8p87gbc03NvmC5gBLzPl7hVA";}s:22:"default_summary_length";i:600;}'),
('', 'update.settings', 'a:4:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"xbYr66-g0FjNgVBkGypCuN46vBI2XHntXN1URawq1s4";}s:5:"check";a:2:{s:19:"disabled_extensions";b:0;s:13:"interval_days";i:1;}s:5:"fetch";a:3:{s:3:"url";N;s:12:"max_attempts";i:2;s:7:"timeout";i:30;}s:12:"notification";a:2:{s:6:"emails";a:1:{i:0;[[site_mail]]}s:9:"threshold";s:3:"all";}}'),
('', 'user.flood', 'a:6:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"UYfMzeP1S8jKm9PSvxf7nQNe8DsNS-3bc2WSNNXBQWs";}s:8:"uid_only";b:0;s:8:"ip_limit";i:50;s:9:"ip_window";i:3600;s:10:"user_limit";i:5;s:11:"user_window";i:21600;}');
INSERT INTO `[[dbprefix]]config` VALUES
('', 'user.mail', 'a:11:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"6CZIzFifRq3qbdq3n3nDpEOO4hWIQtKOAQNPvGNGKeM";}s:8:"langcode";s:2:"en";s:14:"cancel_confirm";a:2:{s:7:"subject";s:67:"Account cancellation request for [user:display-name] at [site:name]";s:4:"body";s:376:"[user:display-name]\n\nA request to cancel your account has been made at [site:name].\n\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\n\n[user:cancel-url]\n\nNOTE: The cancellation of your account is not reversible.\n\nThis link expires in one day and nothing will happen if it is not used.\n\n--  [site:name] team";}s:14:"password_reset";a:2:{s:7:"subject";s:68:"Replacement login information for [user:display-name] at [site:name]";s:4:"body";s:407:"[user:display-name],\n\nA request to reset the password for your account has been made at [site:name].\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it''s not used.\n\n--  [site:name] team";}s:22:"register_admin_created";a:2:{s:7:"subject";s:58:"An administrator created an account for you at [site:name]";s:4:"body";s:473:"[user:display-name],\n\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team";}s:29:"register_no_approval_required";a:2:{s:7:"subject";s:54:"Account details for [user:display-name] at [site:name]";s:4:"body";s:447:"[user:display-name],\n\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team";}s:25:"register_pending_approval";a:2:{s:7:"subject";s:79:"Account details for [user:display-name] at [site:name] (pending admin approval)";s:4:"body";s:288:"[user:display-name],\n\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another email containing information about how to log in, set your password, and other details.\n\n--  [site:name] team";}s:31:"register_pending_approval_admin";a:2:{s:7:"subject";s:79:"Account details for [user:display-name] at [site:name] (pending admin approval)";s:4:"body";s:64:"[user:display-name] has applied for an account.\n\n[user:edit-url]";}s:16:"status_activated";a:2:{s:7:"subject";s:65:"Account details for [user:display-name] at [site:name] (approved)";s:4:"body";s:462:"[user:display-name],\n\nYour account at [site:name] has been activated.\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:account-name]\npassword: Your password\n\n--  [site:name] team";}s:14:"status_blocked";a:2:{s:7:"subject";s:64:"Account details for [user:display-name] at [site:name] (blocked)";s:4:"body";s:89:"[user:display-name],\n\nYour account on [site:name] has been blocked.\n\n--  [site:name] team";}s:15:"status_canceled";a:2:{s:7:"subject";s:65:"Account details for [user:display-name] at [site:name] (canceled)";s:4:"body";s:90:"[user:display-name],\n\nYour account on [site:name] has been canceled.\n\n--  [site:name] team";}}'),
('', 'user.role.administrator', 'a:10:{s:4:"uuid";s:36:"614e22bb-70ca-4525-8752-985223631575";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:0:{}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"OeKGIkmZA_c-t6QLH81WNQx8gDCc1MRmxaTuQgxBByU";}s:2:"id";s:13:"administrator";s:5:"label";s:13:"Administrator";s:6:"weight";i:3;s:8:"is_admin";b:1;s:11:"permissions";a:0:{}}'),
('', 'user.role.anonymous', 'a:10:{s:4:"uuid";s:36:"ac57508d-539d-40f0-a137-7dcd49ca6d4c";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:29:"filter.format.restricted_html";}s:6:"module";a:5:{i:0;s:7:"comment";i:1;s:7:"contact";i:2;s:6:"filter";i:3;s:6:"search";i:4;s:6:"system";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"6WavjUYXIegP9AAg2zXGx54MWIVoomC3SZhNiqe-Dyk";}s:2:"id";s:9:"anonymous";s:5:"label";s:14:"Anonymous user";s:6:"weight";i:0;s:8:"is_admin";b:0;s:11:"permissions";a:5:{i:0;s:15:"access comments";i:1;s:14:"access content";i:2;s:29:"access site-wide contact form";i:3;s:14:"search content";i:4;s:31:"use text format restricted_html";}}'),
('', 'user.role.authenticated', 'a:10:{s:4:"uuid";s:36:"add9f9dc-7a23-4dd5-9834-e663f98b8eea";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:24:"filter.format.basic_html";}s:6:"module";a:7:{i:0;s:7:"comment";i:1;s:7:"contact";i:2;s:4:"file";i:3;s:6:"filter";i:4;s:6:"search";i:5;s:8:"shortcut";i:6;s:6:"system";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"cFrlqjtkTfvY3RGccjJkPf1SGIfJ942IrxTLWAO4mgA";}s:2:"id";s:13:"authenticated";s:5:"label";s:18:"Authenticated user";s:6:"weight";i:1;s:8:"is_admin";b:0;s:11:"permissions";a:9:{i:0;s:15:"access comments";i:1;s:14:"access content";i:2;s:16:"access shortcuts";i:3;s:29:"access site-wide contact form";i:4;s:16:"delete own files";i:5;s:13:"post comments";i:6;s:14:"search content";i:7;s:21:"skip comment approval";i:8;s:26:"use text format basic_html";}}'),
('', 'user.role.content_editor', 'a:10:{s:4:"uuid";s:36:"3ab79215-d614-42bc-a0d0-ef8cb3134ec3";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:3:{i:0;s:17:"node.type.article";i:1;s:14:"node.type.page";i:2;s:24:"taxonomy.vocabulary.tags";}s:6:"module";a:8:{i:0;s:7:"comment";i:1;s:10:"contextual";i:2;s:4:"file";i:3;s:4:"node";i:4;s:4:"path";i:5;s:6:"system";i:6;s:8:"taxonomy";i:7;s:7:"toolbar";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"e_wG1u7SrGaJbY2-Szgbgl-c8T3kdirU3uTNq2c_QJQ";}s:2:"id";s:14:"content_editor";s:5:"label";s:14:"Content editor";s:6:"weight";i:2;s:8:"is_admin";b:0;s:11:"permissions";a:23:{i:0;s:27:"access administration pages";i:1;s:23:"access content overview";i:2;s:23:"access contextual links";i:3;s:21:"access files overview";i:4;s:14:"access toolbar";i:5;s:22:"administer url aliases";i:6;s:22:"create article content";i:7;s:19:"create page content";i:8;s:20:"create terms in tags";i:9;s:18:"create url aliases";i:10;s:24:"delete article revisions";i:11;s:26:"delete own article content";i:12;s:16:"delete own files";i:13;s:23:"delete own page content";i:14;s:21:"delete page revisions";i:15;s:24:"edit own article content";i:16;s:17:"edit own comments";i:17;s:21:"edit own page content";i:18;s:18:"edit terms in tags";i:19;s:20:"revert all revisions";i:20;s:18:"view all revisions";i:21;s:28:"view own unpublished content";i:22;s:29:"view the administration theme";}}'),
('', 'user.settings', 'a:9:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"-htDFWUv1S4OlJMzta2nhFl4QbhJvu0D9xsJ-clxo-M";}s:8:"langcode";s:2:"en";s:9:"anonymous";s:9:"Anonymous";s:11:"verify_mail";b:1;s:6:"notify";a:8:{s:14:"cancel_confirm";b:1;s:14:"password_reset";b:1;s:16:"status_activated";b:1;s:14:"status_blocked";b:0;s:15:"status_canceled";b:0;s:22:"register_admin_created";b:1;s:29:"register_no_approval_required";b:1;s:25:"register_pending_approval";b:1;}s:8:"register";s:23:"visitors_admin_approval";s:13:"cancel_method";s:17:"user_cancel_block";s:22:"password_reset_timeout";i:86400;s:17:"password_strength";b:1;}'),
('', 'views.settings', 'a:5:{s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"8oDr9oPVb_ostrNnVV6V7VdphwoH_u-NqTS0u7SE7qc";}s:17:"display_extenders";a:0:{}s:13:"sql_signature";b:0;s:2:"ui";a:3:{s:4:"show";a:7:{s:18:"additional_queries";b:0;s:15:"advanced_column";b:0;s:15:"default_display";b:0;s:22:"performance_statistics";b:0;s:19:"preview_information";b:1;s:9:"sql_query";a:2:{s:7:"enabled";b:0;s:5:"where";s:5:"above";}s:13:"display_embed";b:0;}s:19:"always_live_preview";b:1;s:24:"exposed_filter_any_label";s:7:"old_any";}s:22:"field_rewrite_elements";a:29:{s:3:"div";s:3:"DIV";s:4:"span";s:4:"SPAN";s:2:"h1";s:2:"H1";s:2:"h2";s:2:"H2";s:2:"h3";s:2:"H3";s:2:"h4";s:2:"H4";s:2:"h5";s:2:"H5";s:2:"h6";s:2:"H6";s:1:"p";s:1:"P";s:6:"header";s:6:"HEADER";s:6:"footer";s:6:"FOOTER";s:7:"article";s:7:"ARTICLE";s:7:"section";s:7:"SECTION";s:5:"aside";s:5:"ASIDE";s:7:"details";s:7:"DETAILS";s:10:"blockquote";s:10:"BLOCKQUOTE";s:6:"figure";s:6:"FIGURE";s:7:"address";s:7:"ADDRESS";s:4:"code";s:4:"CODE";s:3:"pre";s:3:"PRE";s:3:"var";s:3:"VAR";s:4:"samp";s:4:"SAMP";s:3:"kbd";s:3:"KBD";s:6:"strong";s:6:"STRONG";s:2:"em";s:2:"EM";s:3:"del";s:3:"DEL";s:3:"ins";s:3:"INS";s:1:"q";s:1:"Q";s:1:"s";s:1:"S";}}'),
('', 'views.view.archive', 'a:13:{s:4:"uuid";s:36:"dc8eafc4-60d5-41b9-bbcc-1d7409216063";s:8:"langcode";s:2:"en";s:6:"status";b:0;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:33:"core.entity_view_mode.node.teaser";}s:6:"module";a:2:{i:0;s:4:"node";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"exIF08PTvYSK6tJCsAzBqMEKUBKIptPorMn74SVhevc";}s:2:"id";s:7:"archive";s:5:"label";s:7:"Archive";s:6:"module";s:4:"node";s:11:"description";s:22:"All content, by month.";s:3:"tag";s:7:"default";s:10:"base_table";s:15:"node_field_data";s:10:"base_field";s:3:"nid";s:7:"display";a:3:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:17:{s:5:"title";s:15:"Monthly archive";s:6:"fields";a:0:{}s:5:"pager";a:2:{s:4:"type";s:4:"mini";s:7:"options";a:7:{s:6:"offset";i:0;s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:10;s:11:"total_pages";i:0;s:2:"id";i:0;s:4:"tags";a:2:{s:4:"next";s:6:"››";s:8:"previous";s:6:"‹‹";}s:6:"expose";a:7:{s:14:"items_per_page";b:0;s:20:"items_per_page_label";s:14:"Items per page";s:22:"items_per_page_options";s:13:"5, 10, 25, 50";s:26:"items_per_page_options_all";b:0;s:32:"items_per_page_options_all_label";s:7:"- All -";s:6:"offset";b:0;s:12:"offset_label";s:6:"Offset";}}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:5:"Apply";s:12:"reset_button";b:0;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:14:"access content";}}s:5:"cache";a:2:{s:4:"type";s:3:"tag";s:7:"options";a:0:{}}s:5:"empty";a:0:{}s:5:"sorts";a:1:{s:7:"created";a:13:{s:2:"id";s:7:"created";s:5:"table";s:15:"node_field_data";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:7:"created";s:9:"plugin_id";s:4:"date";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:7:"created";}s:7:"exposed";b:0;s:11:"granularity";s:6:"second";}}s:9:"arguments";a:1:{s:18:"created_year_month";a:13:{s:2:"id";s:18:"created_year_month";s:5:"table";s:15:"node_field_data";s:5:"field";s:18:"created_year_month";s:11:"entity_type";s:4:"node";s:9:"plugin_id";s:15:"date_year_month";s:14:"default_action";s:7:"summary";s:9:"exception";a:1:{s:12:"title_enable";b:1;}s:12:"title_enable";b:1;s:5:"title";s:34:"{{ arguments.created_year_month }}";s:21:"default_argument_type";s:5:"fixed";s:15:"summary_options";a:2:{s:8:"override";b:1;s:14:"items_per_page";i:30;}s:7:"summary";a:2:{s:10:"sort_order";s:4:"desc";s:6:"format";s:15:"default_summary";}s:18:"specify_validation";b:1;}}s:7:"filters";a:2:{s:6:"status";a:9:{s:2:"id";s:6:"status";s:5:"table";s:15:"node_field_data";s:5:"field";s:6:"status";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:5:"value";s:1:"1";s:5:"group";i:0;s:6:"expose";a:3:{s:8:"operator";s:1:"0";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}}}s:8:"langcode";a:16:{s:2:"id";s:8:"langcode";s:5:"table";s:15:"node_field_data";s:5:"field";s:8:"langcode";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:8:"langcode";s:9:"plugin_id";s:8:"language";s:8:"operator";s:2:"in";s:5:"value";a:1:{s:31:"***LANGUAGE_language_content***";s:31:"***LANGUAGE_language_content***";}s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:13:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:5:"style";a:2:{s:4:"type";s:7:"default";s:7:"options";a:4:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:11:"uses_fields";b:0;}}s:3:"row";a:2:{s:4:"type";s:11:"entity:node";s:7:"options";a:1:{s:9:"view_mode";s:6:"teaser";}}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:0:{}s:6:"header";a:0:{}s:6:"footer";a:0:{}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:28:"languages:language_interface";i:1;s:3:"url";i:2;s:14:"url.query_args";i:3;s:21:"user.node_grants:view";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:7:"block_1";a:6:{s:2:"id";s:7:"block_1";s:13:"display_title";s:5:"Block";s:14:"display_plugin";s:5:"block";s:8:"position";i:1;s:15:"display_options";a:4:{s:9:"arguments";a:1:{s:18:"created_year_month";a:13:{s:2:"id";s:18:"created_year_month";s:5:"table";s:15:"node_field_data";s:5:"field";s:18:"created_year_month";s:11:"entity_type";s:4:"node";s:9:"plugin_id";s:15:"date_year_month";s:14:"default_action";s:7:"summary";s:9:"exception";a:1:{s:12:"title_enable";b:1;}s:12:"title_enable";b:1;s:5:"title";s:34:"{{ arguments.created_year_month }}";s:21:"default_argument_type";s:5:"fixed";s:15:"summary_options";a:1:{s:14:"items_per_page";i:30;}s:7:"summary";a:1:{s:6:"format";s:15:"default_summary";}s:18:"specify_validation";b:1;}}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:8:"defaults";a:1:{s:9:"arguments";b:0;}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:28:"languages:language_interface";i:1;s:3:"url";i:2;s:14:"url.query_args";i:3;s:21:"user.node_grants:view";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"page_1";a:6:{s:2:"id";s:6:"page_1";s:13:"display_title";s:4:"Page";s:14:"display_plugin";s:4:"page";s:8:"position";i:2;s:15:"display_options";a:3:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:17:"display_extenders";a:0:{}s:4:"path";s:7:"archive";}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:28:"languages:language_interface";i:1;s:3:"url";i:2;s:14:"url.query_args";i:3;s:21:"user.node_grants:view";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}'),
('', 'views.view.block_content', 'a:13:{s:4:"uuid";s:36:"13189bd4-33d0-4da8-8ed6-80b6208a5c93";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:13:"block_content";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"HfvTcWhiVuvxchoh4DjIkXhKkj9ow2TGgHkLHSvRLq8";}s:2:"id";s:13:"block_content";s:5:"label";s:14:"Content blocks";s:6:"module";s:5:"views";s:11:"description";s:31:"Find and manage content blocks.";s:3:"tag";s:7:"default";s:10:"base_table";s:24:"block_content_field_data";s:10:"base_field";s:2:"id";s:7:"display";a:2:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:17:{s:5:"title";s:14:"Content blocks";s:6:"fields";a:4:{s:4:"info";a:37:{s:2:"id";s:4:"info";s:5:"table";s:24:"block_content_field_data";s:5:"field";s:4:"info";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";N;s:12:"entity_field";s:4:"info";s:9:"plugin_id";s:5:"field";s:5:"label";s:17:"Block description";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:6:"string";s:8:"settings";a:1:{s:14:"link_to_entity";b:1;}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:4:"type";a:37:{s:2:"id";s:4:"type";s:5:"table";s:24:"block_content_field_data";s:5:"field";s:4:"type";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:13:"block_content";s:12:"entity_field";s:4:"type";s:9:"plugin_id";s:5:"field";s:5:"label";s:10:"Block type";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:9:"target_id";s:4:"type";s:22:"entity_reference_label";s:8:"settings";a:1:{s:4:"link";b:0;}s:12:"group_column";s:9:"target_id";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:7:"changed";a:26:{s:2:"id";s:7:"changed";s:5:"table";s:24:"block_content_field_data";s:5:"field";s:7:"changed";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:13:"block_content";s:12:"entity_field";s:7:"changed";s:9:"plugin_id";s:5:"field";s:5:"label";s:7:"Updated";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"timestamp";s:8:"settings";a:5:{s:11:"date_format";s:5:"short";s:18:"custom_date_format";s:0:"";s:8:"timezone";s:0:"";s:7:"tooltip";a:2:{s:11:"date_format";s:4:"long";s:18:"custom_date_format";s:0:"";}s:9:"time_diff";a:5:{s:7:"enabled";b:0;s:13:"future_format";s:15:"@interval hence";s:11:"past_format";s:13:"@interval ago";s:11:"granularity";i:2;s:7:"refresh";i:60;}}}s:10:"operations";a:24:{s:2:"id";s:10:"operations";s:5:"table";s:13:"block_content";s:5:"field";s:10:"operations";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:13:"block_content";s:9:"plugin_id";s:17:"entity_operations";s:5:"label";s:10:"Operations";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:11:"destination";b:1;}}s:5:"pager";a:2:{s:4:"type";s:4:"mini";s:7:"options";a:7:{s:6:"offset";i:0;s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:50;s:11:"total_pages";N;s:2:"id";i:0;s:4:"tags";a:2:{s:4:"next";s:8:"Next ›";s:8:"previous";s:12:"‹ Previous";}s:6:"expose";a:7:{s:14:"items_per_page";b:0;s:20:"items_per_page_label";s:14:"Items per page";s:22:"items_per_page_options";s:13:"5, 10, 25, 50";s:26:"items_per_page_options_all";b:0;s:32:"items_per_page_options_all_label";s:7:"- All -";s:6:"offset";b:0;s:12:"offset_label";s:6:"Offset";}}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:5:"Apply";s:12:"reset_button";b:1;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:20:"access block library";}}s:5:"cache";a:2:{s:4:"type";s:3:"tag";s:7:"options";a:0:{}}s:5:"empty";a:2:{s:16:"area_text_custom";a:10:{s:2:"id";s:16:"area_text_custom";s:5:"table";s:5:"views";s:5:"field";s:16:"area_text_custom";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:11:"text_custom";s:5:"empty";b:1;s:7:"content";s:38:"There are no content blocks available.";s:8:"tokenize";b:0;}s:27:"block_content_listing_empty";a:10:{s:2:"id";s:27:"block_content_listing_empty";s:5:"table";s:13:"block_content";s:5:"field";s:27:"block_content_listing_empty";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:13:"block_content";s:9:"plugin_id";s:27:"block_content_listing_empty";s:5:"label";s:0:"";s:5:"empty";b:1;}}s:5:"sorts";a:0:{}s:9:"arguments";a:0:{}s:7:"filters";a:3:{s:4:"info";a:16:{s:2:"id";s:4:"info";s:5:"table";s:24:"block_content_field_data";s:5:"field";s:4:"info";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:13:"block_content";s:12:"entity_field";s:4:"info";s:9:"plugin_id";s:6:"string";s:8:"operator";s:8:"contains";s:5:"value";s:0:"";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:7:"info_op";s:5:"label";s:17:"Block description";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:7:"info_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:4:"info";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:4:"type";a:16:{s:2:"id";s:4:"type";s:5:"table";s:24:"block_content_field_data";s:5:"field";s:4:"type";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:13:"block_content";s:12:"entity_field";s:4:"type";s:9:"plugin_id";s:6:"bundle";s:8:"operator";s:2:"in";s:5:"value";a:0:{}s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:13:{s:11:"operator_id";s:7:"type_op";s:5:"label";s:10:"Block type";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:7:"type_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:4:"type";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:8:"reusable";a:16:{s:2:"id";s:8:"reusable";s:5:"table";s:24:"block_content_field_data";s:5:"field";s:8:"reusable";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:13:"block_content";s:12:"entity_field";s:8:"reusable";s:9:"plugin_id";s:7:"boolean";s:8:"operator";s:1:"=";s:5:"value";s:1:"1";s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:12:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:5:"style";a:2:{s:4:"type";s:5:"table";s:7:"options";a:12:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:7:"columns";a:4:{s:4:"info";s:4:"info";s:4:"type";s:4:"type";s:7:"changed";s:7:"changed";s:10:"operations";s:10:"operations";}s:7:"default";s:7:"changed";s:4:"info";a:4:{s:4:"info";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:4:"type";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:7:"changed";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:4:"desc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:10:"operations";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}}s:8:"override";b:1;s:6:"sticky";b:0;s:7:"summary";s:0:"";s:11:"empty_table";b:1;s:7:"caption";s:0:"";s:11:"description";s:0:"";}}s:3:"row";a:1:{s:4:"type";s:6:"fields";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:0:{}s:6:"header";a:0:{}s:6:"footer";a:0:{}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"page_1";a:6:{s:2:"id";s:6:"page_1";s:13:"display_title";s:4:"Page";s:14:"display_plugin";s:4:"page";s:8:"position";i:1;s:15:"display_options";a:3:{s:17:"display_extenders";a:0:{}s:4:"path";s:19:"admin/content/block";s:4:"menu";a:7:{s:4:"type";s:3:"tab";s:5:"title";s:6:"Blocks";s:11:"description";s:31:"Create and edit content blocks.";s:6:"weight";i:0;s:9:"menu_name";s:5:"admin";s:6:"parent";s:20:"system.admin_content";s:7:"context";s:1:"0";}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}');
INSERT INTO `[[dbprefix]]config` VALUES
('', 'views.view.comment', 'a:13:{s:4:"uuid";s:36:"0c149538-5042-44ca-8372-4756d74e6ef7";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:7:"comment";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"H6JHGXl97yOKmVaV62SoY1ki1tWVdyD44fgOkdmVyRM";}s:2:"id";s:7:"comment";s:5:"label";s:8:"Comments";s:6:"module";s:7:"comment";s:11:"description";s:25:"Find and manage comments.";s:3:"tag";s:7:"default";s:10:"base_table";s:18:"comment_field_data";s:10:"base_field";s:3:"cid";s:7:"display";a:3:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:26:{s:5:"title";s:8:"Comments";s:6:"fields";a:8:{s:17:"comment_bulk_form";a:26:{s:2:"id";s:17:"comment_bulk_form";s:5:"table";s:7:"comment";s:5:"field";s:17:"comment_bulk_form";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:9:"plugin_id";s:17:"comment_bulk_form";s:5:"label";s:0:"";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:12:"action_title";s:6:"Action";s:15:"include_exclude";s:7:"include";s:16:"selected_actions";a:2:{i:0;s:21:"comment_delete_action";i:1;s:24:"comment_unpublish_action";}}s:7:"subject";a:37:{s:2:"id";s:7:"subject";s:5:"table";s:18:"comment_field_data";s:5:"field";s:7:"subject";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:7:"subject";s:9:"plugin_id";s:5:"field";s:5:"label";s:7:"Subject";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:17:"comment_permalink";s:8:"settings";a:1:{s:14:"link_to_entity";b:1;}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:3:"uid";a:37:{s:2:"id";s:3:"uid";s:5:"table";s:18:"comment_field_data";s:5:"field";s:3:"uid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:3:"uid";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:1;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:9:"target_id";s:4:"type";s:22:"entity_reference_label";s:8:"settings";a:1:{s:4:"link";b:1;}s:12:"group_column";s:9:"target_id";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:4:"name";a:37:{s:2:"id";s:4:"name";s:5:"table";s:18:"comment_field_data";s:5:"field";s:4:"name";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:4:"name";s:9:"plugin_id";s:5:"field";s:5:"label";s:6:"Author";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:9:"{{ uid }}";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:16:"comment_username";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:9:"entity_id";a:37:{s:2:"id";s:9:"entity_id";s:5:"table";s:18:"comment_field_data";s:5:"field";s:9:"entity_id";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:9:"entity_id";s:9:"plugin_id";s:16:"commented_entity";s:5:"label";s:9:"Posted in";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:9:"target_id";s:4:"type";s:22:"entity_reference_label";s:8:"settings";a:1:{s:4:"link";b:1;}s:12:"group_column";s:9:"target_id";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:7:"changed";a:37:{s:2:"id";s:7:"changed";s:5:"table";s:18:"comment_field_data";s:5:"field";s:7:"changed";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:7:"changed";s:9:"plugin_id";s:5:"field";s:5:"label";s:7:"Updated";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:9:"timestamp";s:8:"settings";a:5:{s:11:"date_format";s:5:"short";s:18:"custom_date_format";s:0:"";s:8:"timezone";s:0:"";s:7:"tooltip";a:2:{s:11:"date_format";s:4:"long";s:18:"custom_date_format";s:0:"";}s:9:"time_diff";a:5:{s:7:"enabled";b:0;s:13:"future_format";s:15:"@interval hence";s:11:"past_format";s:13:"@interval ago";s:11:"granularity";i:2;s:7:"refresh";i:60;}}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:10:"operations";a:24:{s:2:"id";s:10:"operations";s:5:"table";s:7:"comment";s:5:"field";s:10:"operations";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:9:"plugin_id";s:17:"entity_operations";s:5:"label";s:10:"Operations";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:11:"destination";b:1;}s:6:"name_1";a:37:{s:2:"id";s:6:"name_1";s:5:"table";s:16:"users_field_data";s:5:"field";s:4:"name";s:12:"relationship";s:3:"uid";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:4:"name";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:1;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:9:"user_name";s:8:"settings";a:1:{s:14:"link_to_entity";b:1;}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}}s:5:"pager";a:2:{s:4:"type";s:4:"full";s:7:"options";a:8:{s:6:"offset";i:0;s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:50;s:11:"total_pages";N;s:2:"id";i:0;s:4:"tags";a:4:{s:4:"next";s:8:"next ›";s:8:"previous";s:12:"‹ previous";s:5:"first";s:8:"« first";s:4:"last";s:7:"last »";}s:6:"expose";a:7:{s:14:"items_per_page";b:0;s:20:"items_per_page_label";s:14:"Items per page";s:22:"items_per_page_options";s:13:"5, 10, 25, 50";s:26:"items_per_page_options_all";b:0;s:32:"items_per_page_options_all_label";s:7:"- All -";s:6:"offset";b:0;s:12:"offset_label";s:6:"Offset";}s:8:"quantity";i:9;}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:6:"Filter";s:12:"reset_button";b:0;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:19:"administer comments";}}s:5:"cache";a:2:{s:4:"type";s:3:"tag";s:7:"options";a:0:{}}s:5:"empty";a:1:{s:16:"area_text_custom";a:10:{s:2:"id";s:16:"area_text_custom";s:5:"table";s:5:"views";s:5:"field";s:16:"area_text_custom";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:11:"text_custom";s:5:"empty";b:1;s:7:"content";s:22:"No comments available.";s:8:"tokenize";b:0;}}s:5:"sorts";a:1:{s:7:"changed";a:13:{s:2:"id";s:7:"changed";s:5:"table";s:18:"comment_field_data";s:5:"field";s:7:"changed";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:7:"changed";s:9:"plugin_id";s:4:"date";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:7:"changed";}s:7:"exposed";b:0;s:11:"granularity";s:6:"second";}}s:9:"arguments";a:0:{}s:7:"filters";a:4:{s:6:"status";a:16:{s:2:"id";s:6:"status";s:5:"table";s:18:"comment_field_data";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:8:"operator";s:1:"=";s:5:"value";s:1:"1";s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:12:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:7:"subject";a:16:{s:2:"id";s:7:"subject";s:5:"table";s:18:"comment_field_data";s:5:"field";s:7:"subject";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:7:"subject";s:9:"plugin_id";s:6:"string";s:8:"operator";s:8:"contains";s:5:"value";s:0:"";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:10:"subject_op";s:5:"label";s:7:"Subject";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:10:"subject_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:7:"subject";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:7:"combine";a:15:{s:2:"id";s:7:"combine";s:5:"table";s:5:"views";s:5:"field";s:7:"combine";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:7:"combine";s:8:"operator";s:8:"contains";s:5:"value";s:0:"";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:10:"combine_op";s:5:"label";s:11:"Author name";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:10:"combine_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:11:"author_name";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}s:6:"fields";a:2:{s:4:"name";s:4:"name";s:6:"name_1";s:6:"name_1";}}s:8:"langcode";a:16:{s:2:"id";s:8:"langcode";s:5:"table";s:18:"comment_field_data";s:5:"field";s:8:"langcode";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:8:"langcode";s:9:"plugin_id";s:8:"language";s:8:"operator";s:2:"in";s:5:"value";a:0:{}s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:13:{s:11:"operator_id";s:11:"langcode_op";s:5:"label";s:8:"Language";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:11:"langcode_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:8:"langcode";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:1;s:3:"AND";}}s:5:"style";a:2:{s:4:"type";s:5:"table";s:7:"options";a:12:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:7:"columns";a:6:{s:17:"comment_bulk_form";s:17:"comment_bulk_form";s:7:"subject";s:7:"subject";s:3:"uid";s:3:"uid";s:9:"entity_id";s:9:"entity_id";s:7:"changed";s:7:"changed";s:10:"operations";s:10:"operations";}s:7:"default";s:7:"changed";s:4:"info";a:6:{s:17:"comment_bulk_form";a:4:{s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:7:"subject";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:3:"uid";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:9:"entity_id";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:7:"changed";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:4:"desc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:10:"operations";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}}s:8:"override";b:1;s:6:"sticky";b:1;s:7:"summary";s:0:"";s:11:"empty_table";b:1;s:7:"caption";s:0:"";s:11:"description";s:0:"";}}s:3:"row";a:1:{s:4:"type";s:6:"fields";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:1:{s:3:"uid";a:10:{s:2:"id";s:3:"uid";s:5:"table";s:18:"comment_field_data";s:5:"field";s:3:"uid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:6:"author";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:3:"uid";s:9:"plugin_id";s:8:"standard";s:8:"required";b:0;}}s:9:"css_class";s:0:"";s:8:"use_ajax";b:0;s:8:"group_by";b:0;s:16:"show_admin_links";b:1;s:8:"use_more";b:0;s:15:"use_more_always";b:1;s:13:"use_more_text";s:4:"more";s:6:"header";a:0:{}s:6:"footer";a:0:{}s:23:"hide_attachment_summary";b:0;s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:4:{s:7:"max-age";i:0;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}s:9:"cacheable";b:0;}}s:14:"page_published";a:6:{s:2:"id";s:14:"page_published";s:13:"display_title";s:18:"Published comments";s:14:"display_plugin";s:4:"page";s:8:"position";i:1;s:15:"display_options";a:6:{s:19:"display_description";s:30:"The approved comments listing.";s:15:"display_comment";s:0:"";s:13:"exposed_block";b:0;s:17:"display_extenders";a:0:{}s:4:"path";s:21:"admin/content/comment";s:4:"menu";a:7:{s:4:"type";s:3:"tab";s:5:"title";s:8:"Comments";s:11:"description";s:18:"Comments published";s:6:"weight";i:0;s:9:"menu_name";s:5:"admin";s:6:"parent";s:0:"";s:7:"context";s:1:"0";}}s:14:"cache_metadata";a:4:{s:7:"max-age";i:0;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}s:9:"cacheable";b:0;}}s:15:"page_unapproved";a:6:{s:2:"id";s:15:"page_unapproved";s:13:"display_title";s:19:"Unapproved comments";s:14:"display_plugin";s:4:"page";s:8:"position";i:2;s:15:"display_options";a:8:{s:6:"fields";a:8:{s:17:"comment_bulk_form";a:26:{s:2:"id";s:17:"comment_bulk_form";s:5:"table";s:7:"comment";s:5:"field";s:17:"comment_bulk_form";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:9:"plugin_id";s:17:"comment_bulk_form";s:5:"label";s:0:"";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:12:"action_title";s:6:"Action";s:15:"include_exclude";s:7:"include";s:16:"selected_actions";a:2:{i:0;s:21:"comment_delete_action";i:1;s:22:"comment_publish_action";}}s:7:"subject";a:37:{s:2:"id";s:7:"subject";s:5:"table";s:18:"comment_field_data";s:5:"field";s:7:"subject";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:7:"subject";s:9:"plugin_id";s:5:"field";s:5:"label";s:7:"Subject";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:17:"comment_permalink";s:8:"settings";a:1:{s:14:"link_to_entity";b:1;}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:3:"uid";a:37:{s:2:"id";s:3:"uid";s:5:"table";s:18:"comment_field_data";s:5:"field";s:3:"uid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:3:"uid";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:1;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:9:"target_id";s:4:"type";s:22:"entity_reference_label";s:8:"settings";a:1:{s:4:"link";b:1;}s:12:"group_column";s:9:"target_id";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:4:"name";a:37:{s:2:"id";s:4:"name";s:5:"table";s:18:"comment_field_data";s:5:"field";s:4:"name";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:4:"name";s:9:"plugin_id";s:5:"field";s:5:"label";s:6:"Author";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:9:"{{ uid }}";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:16:"comment_username";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:9:"entity_id";a:37:{s:2:"id";s:9:"entity_id";s:5:"table";s:18:"comment_field_data";s:5:"field";s:9:"entity_id";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:9:"entity_id";s:9:"plugin_id";s:16:"commented_entity";s:5:"label";s:9:"Posted in";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:9:"target_id";s:4:"type";s:22:"entity_reference_label";s:8:"settings";a:1:{s:4:"link";b:1;}s:12:"group_column";s:9:"target_id";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:7:"changed";a:37:{s:2:"id";s:7:"changed";s:5:"table";s:18:"comment_field_data";s:5:"field";s:7:"changed";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:7:"changed";s:9:"plugin_id";s:5:"field";s:5:"label";s:7:"Updated";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:9:"timestamp";s:8:"settings";a:5:{s:11:"date_format";s:5:"short";s:18:"custom_date_format";s:0:"";s:8:"timezone";s:0:"";s:7:"tooltip";a:2:{s:11:"date_format";s:4:"long";s:18:"custom_date_format";s:0:"";}s:9:"time_diff";a:5:{s:7:"enabled";b:0;s:13:"future_format";s:15:"@interval hence";s:11:"past_format";s:13:"@interval ago";s:11:"granularity";i:2;s:7:"refresh";i:60;}}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:10:"operations";a:24:{s:2:"id";s:10:"operations";s:5:"table";s:7:"comment";s:5:"field";s:10:"operations";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:9:"plugin_id";s:17:"entity_operations";s:5:"label";s:10:"Operations";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:11:"destination";b:1;}s:6:"name_1";a:37:{s:2:"id";s:6:"name_1";s:5:"table";s:16:"users_field_data";s:5:"field";s:4:"name";s:12:"relationship";s:3:"uid";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:4:"name";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:1;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:9:"user_name";s:8:"settings";a:1:{s:14:"link_to_entity";b:0;}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}}s:7:"filters";a:4:{s:6:"status";a:16:{s:2:"id";s:6:"status";s:5:"table";s:18:"comment_field_data";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:8:"operator";s:1:"=";s:5:"value";s:1:"0";s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:12:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:7:"subject";a:16:{s:2:"id";s:7:"subject";s:5:"table";s:18:"comment_field_data";s:5:"field";s:7:"subject";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:7:"subject";s:9:"plugin_id";s:6:"string";s:8:"operator";s:8:"contains";s:5:"value";s:0:"";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:10:"subject_op";s:5:"label";s:7:"Subject";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:10:"subject_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:7:"subject";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:7:"combine";a:15:{s:2:"id";s:7:"combine";s:5:"table";s:5:"views";s:5:"field";s:7:"combine";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:7:"combine";s:8:"operator";s:8:"contains";s:5:"value";s:0:"";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:10:"combine_op";s:5:"label";s:11:"Author Name";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:10:"combine_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:11:"author_name";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}s:6:"fields";a:2:{s:4:"name";s:4:"name";s:6:"name_1";s:6:"name_1";}}s:8:"langcode";a:16:{s:2:"id";s:8:"langcode";s:5:"table";s:18:"comment_field_data";s:5:"field";s:8:"langcode";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:8:"langcode";s:9:"plugin_id";s:8:"language";s:8:"operator";s:2:"in";s:5:"value";a:0:{}s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:13:{s:11:"operator_id";s:11:"langcode_op";s:5:"label";s:8:"Language";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:11:"langcode_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:8:"langcode";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:1;s:3:"AND";}}s:8:"defaults";a:3:{s:6:"fields";b:0;s:7:"filters";b:0;s:13:"filter_groups";b:0;}s:19:"display_description";s:32:"The unapproved comments listing.";s:17:"display_extenders";a:0:{}s:4:"path";s:30:"admin/content/comment/approval";s:4:"menu";a:7:{s:4:"type";s:3:"tab";s:5:"title";s:19:"Unapproved comments";s:11:"description";s:19:"Comments unapproved";s:6:"weight";i:1;s:9:"menu_name";s:5:"admin";s:6:"parent";s:0:"";s:7:"context";s:1:"0";}}s:14:"cache_metadata";a:4:{s:7:"max-age";i:0;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}s:9:"cacheable";b:0;}}}}'),
('', 'views.view.comments_recent', 'a:13:{s:4:"uuid";s:36:"b79cd01e-e4f9-41c0-acf1-14cc2ae1c750";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:3:{i:0;s:7:"comment";i:1;s:4:"node";i:2;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"cFOucxH8PAXDQ2kViCcAHgK-JMCcxVkpIMzD56EfpZo";}s:2:"id";s:15:"comments_recent";s:5:"label";s:15:"Recent comments";s:6:"module";s:5:"views";s:11:"description";s:16:"Recent comments.";s:3:"tag";s:7:"default";s:10:"base_table";s:18:"comment_field_data";s:10:"base_field";s:3:"cid";s:7:"display";a:2:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:14:{s:5:"title";s:15:"Recent comments";s:6:"fields";a:2:{s:7:"subject";a:26:{s:2:"id";s:7:"subject";s:5:"table";s:18:"comment_field_data";s:5:"field";s:7:"subject";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:7:"subject";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:0;s:8:"ellipsis";b:0;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:6:"string";s:8:"settings";a:1:{s:14:"link_to_entity";b:1;}}s:7:"changed";a:26:{s:2:"id";s:7:"changed";s:5:"table";s:18:"comment_field_data";s:5:"field";s:7:"changed";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:7:"changed";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:13:"timestamp_ago";s:8:"settings";a:3:{s:13:"future_format";s:15:"@interval hence";s:11:"past_format";s:13:"@interval ago";s:11:"granularity";i:2;}}}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:6:"offset";i:0;s:14:"items_per_page";i:10;}}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:15:"access comments";}}s:5:"cache";a:1:{s:4:"type";s:3:"tag";}s:5:"empty";a:1:{s:16:"area_text_custom";a:11:{s:2:"id";s:16:"area_text_custom";s:5:"table";s:5:"views";s:5:"field";s:16:"area_text_custom";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:11:"text_custom";s:5:"label";s:0:"";s:5:"empty";b:1;s:7:"content";s:22:"No comments available.";s:8:"tokenize";b:0;}}s:5:"sorts";a:2:{s:7:"created";a:12:{s:2:"id";s:7:"created";s:5:"table";s:18:"comment_field_data";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:7:"created";s:9:"plugin_id";s:4:"date";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:7:"created";}s:7:"exposed";b:0;}s:3:"cid";a:12:{s:2:"id";s:3:"cid";s:5:"table";s:18:"comment_field_data";s:5:"field";s:3:"cid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:3:"cid";s:9:"plugin_id";s:8:"standard";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:3:"cid";}s:7:"exposed";b:0;}}s:7:"filters";a:2:{s:6:"status";a:9:{s:2:"id";s:6:"status";s:5:"table";s:18:"comment_field_data";s:5:"field";s:6:"status";s:11:"entity_type";s:7:"comment";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:5:"value";s:1:"1";s:5:"group";i:1;s:6:"expose";a:3:{s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}}}s:11:"status_node";a:10:{s:2:"id";s:11:"status_node";s:5:"table";s:15:"node_field_data";s:5:"field";s:6:"status";s:12:"relationship";s:4:"node";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:5:"value";s:1:"1";s:5:"group";i:1;s:6:"expose";a:3:{s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}}}}s:5:"style";a:2:{s:4:"type";s:9:"html_list";s:7:"options";a:6:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:4:"type";s:2:"ul";s:13:"wrapper_class";s:9:"item-list";s:5:"class";s:0:"";}}s:3:"row";a:2:{s:4:"type";s:6:"fields";s:7:"options";a:2:{s:22:"default_field_elements";b:1;s:10:"hide_empty";b:0;}}s:5:"query";a:1:{s:4:"type";s:11:"views_query";}s:13:"relationships";a:1:{s:4:"node";a:5:{s:2:"id";s:4:"node";s:5:"table";s:18:"comment_field_data";s:5:"field";s:4:"node";s:9:"plugin_id";s:8:"standard";s:8:"required";b:1;}}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:3:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:7:"block_1";a:6:{s:2:"id";s:7:"block_1";s:13:"display_title";s:5:"Block";s:14:"display_plugin";s:5:"block";s:8:"position";i:1;s:15:"display_options";a:4:{s:17:"display_extenders";a:0:{}s:17:"block_description";s:15:"Recent comments";s:14:"block_category";s:13:"Lists (Views)";s:5:"allow";a:1:{s:14:"items_per_page";b:1;}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:3:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}');
INSERT INTO `[[dbprefix]]config` VALUES
('', 'views.view.content', 'a:13:{s:4:"uuid";s:36:"06656631-9c66-4445-b2fb-f4bbe0145322";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:4:"node";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"whBYBAcXQuQblGEdvQ9QfGuuW3zC49F2-5vXSm1slFM";}s:2:"id";s:7:"content";s:5:"label";s:7:"Content";s:6:"module";s:4:"node";s:11:"description";s:24:"Find and manage content.";s:3:"tag";s:7:"default";s:10:"base_table";s:15:"node_field_data";s:10:"base_field";s:3:"nid";s:7:"display";a:2:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:17:{s:5:"title";s:7:"Content";s:6:"fields";a:8:{s:14:"node_bulk_form";a:14:{s:2:"id";s:14:"node_bulk_form";s:5:"table";s:4:"node";s:5:"field";s:14:"node_bulk_form";s:11:"entity_type";s:4:"node";s:9:"plugin_id";s:14:"node_bulk_form";s:5:"label";s:0:"";s:7:"exclude";b:0;s:5:"alter";a:1:{s:10:"alter_text";b:0;}s:13:"element_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;}s:5:"title";a:17:{s:2:"id";s:5:"title";s:5:"table";s:15:"node_field_data";s:5:"field";s:5:"title";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:5:"title";s:9:"plugin_id";s:5:"field";s:5:"label";s:5:"Title";s:7:"exclude";b:0;s:5:"alter";a:1:{s:10:"alter_text";b:0;}s:13:"element_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:6:"string";s:8:"settings";a:1:{s:14:"link_to_entity";b:1;}}s:4:"type";a:37:{s:2:"id";s:4:"type";s:5:"table";s:15:"node_field_data";s:5:"field";s:4:"type";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:4:"type";s:9:"plugin_id";s:5:"field";s:5:"label";s:12:"Content type";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:9:"target_id";s:4:"type";s:22:"entity_reference_label";s:8:"settings";a:1:{s:4:"link";b:0;}s:12:"group_column";s:9:"target_id";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:4:"name";a:17:{s:2:"id";s:4:"name";s:5:"table";s:16:"users_field_data";s:5:"field";s:4:"name";s:12:"relationship";s:3:"uid";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:4:"name";s:9:"plugin_id";s:5:"field";s:5:"label";s:6:"Author";s:7:"exclude";b:0;s:5:"alter";a:1:{s:10:"alter_text";b:0;}s:13:"element_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"user_name";}s:6:"status";a:17:{s:2:"id";s:6:"status";s:5:"table";s:15:"node_field_data";s:5:"field";s:6:"status";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:5:"field";s:5:"label";s:6:"Status";s:7:"exclude";b:0;s:5:"alter";a:1:{s:10:"alter_text";b:0;}s:13:"element_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:7:"boolean";s:8:"settings";a:3:{s:6:"format";s:6:"custom";s:19:"format_custom_false";s:11:"Unpublished";s:18:"format_custom_true";s:9:"Published";}}s:7:"changed";a:17:{s:2:"id";s:7:"changed";s:5:"table";s:15:"node_field_data";s:5:"field";s:7:"changed";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:7:"changed";s:9:"plugin_id";s:5:"field";s:5:"label";s:7:"Updated";s:7:"exclude";b:0;s:5:"alter";a:1:{s:10:"alter_text";b:0;}s:13:"element_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"timestamp";s:8:"settings";a:5:{s:11:"date_format";s:5:"short";s:18:"custom_date_format";s:0:"";s:8:"timezone";s:0:"";s:7:"tooltip";a:2:{s:11:"date_format";s:4:"long";s:18:"custom_date_format";s:0:"";}s:9:"time_diff";a:5:{s:7:"enabled";b:0;s:13:"future_format";s:15:"@interval hence";s:11:"past_format";s:13:"@interval ago";s:11:"granularity";i:2;s:7:"refresh";i:60;}}}s:8:"langcode";a:37:{s:2:"id";s:8:"langcode";s:5:"table";s:15:"node_field_data";s:5:"field";s:8:"langcode";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:8:"langcode";s:9:"plugin_id";s:5:"field";s:5:"label";s:8:"Language";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:8:"language";s:8:"settings";a:2:{s:14:"link_to_entity";b:0;s:15:"native_language";b:0;}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:10:"operations";a:23:{s:2:"id";s:10:"operations";s:5:"table";s:4:"node";s:5:"field";s:10:"operations";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:17:"entity_operations";s:5:"label";s:10:"Operations";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:11:"destination";b:1;}}s:5:"pager";a:2:{s:4:"type";s:4:"full";s:7:"options";a:3:{s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:50;s:4:"tags";a:4:{s:4:"next";s:8:"Next ›";s:8:"previous";s:12:"‹ Previous";s:5:"first";s:8:"« First";s:4:"last";s:7:"Last »";}}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:6:"Filter";s:12:"reset_button";b:1;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:23:"access content overview";}}s:5:"cache";a:1:{s:4:"type";s:3:"tag";}s:5:"empty";a:1:{s:16:"area_text_custom";a:6:{s:2:"id";s:16:"area_text_custom";s:5:"table";s:5:"views";s:5:"field";s:16:"area_text_custom";s:9:"plugin_id";s:11:"text_custom";s:5:"empty";b:1;s:7:"content";s:21:"No content available.";}}s:5:"sorts";a:0:{}s:9:"arguments";a:0:{}s:7:"filters";a:5:{s:5:"title";a:16:{s:2:"id";s:5:"title";s:5:"table";s:15:"node_field_data";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:5:"title";s:9:"plugin_id";s:6:"string";s:8:"operator";s:8:"contains";s:5:"value";s:0:"";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:8:"title_op";s:5:"label";s:5:"Title";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:8:"title_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:5:"title";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:4:"type";a:16:{s:2:"id";s:4:"type";s:5:"table";s:15:"node_field_data";s:5:"field";s:4:"type";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:4:"type";s:9:"plugin_id";s:6:"bundle";s:8:"operator";s:2:"in";s:5:"value";a:0:{}s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:13:{s:11:"operator_id";s:7:"type_op";s:5:"label";s:12:"Content type";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:7:"type_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:4:"type";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:6:"status";a:16:{s:2:"id";s:6:"status";s:5:"table";s:15:"node_field_data";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:8:"operator";s:1:"=";s:5:"value";s:1:"1";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:0:"";s:5:"label";s:6:"Status";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:9:"status_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:6:"status";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}}s:10:"is_grouped";b:1;s:10:"group_info";a:10:{s:5:"label";s:16:"Published status";s:11:"description";s:0:"";s:10:"identifier";s:6:"status";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:2:{i:1;a:3:{s:5:"title";s:9:"Published";s:8:"operator";s:1:"=";s:5:"value";s:1:"1";}i:2;a:3:{s:5:"title";s:11:"Unpublished";s:8:"operator";s:1:"=";s:5:"value";s:1:"0";}}}}s:8:"langcode";a:16:{s:2:"id";s:8:"langcode";s:5:"table";s:15:"node_field_data";s:5:"field";s:8:"langcode";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:8:"langcode";s:9:"plugin_id";s:8:"language";s:8:"operator";s:2:"in";s:5:"value";a:0:{}s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:13:{s:11:"operator_id";s:11:"langcode_op";s:5:"label";s:8:"Language";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:11:"langcode_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:8:"langcode";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:12:"status_extra";a:9:{s:2:"id";s:12:"status_extra";s:5:"table";s:15:"node_field_data";s:5:"field";s:12:"status_extra";s:11:"entity_type";s:4:"node";s:9:"plugin_id";s:11:"node_status";s:8:"operator";s:1:"=";s:5:"value";b:0;s:5:"group";i:1;s:6:"expose";a:2:{s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}}}}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:1;s:3:"AND";}}s:5:"style";a:2:{s:4:"type";s:5:"table";s:7:"options";a:12:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:7:"columns";a:10:{s:14:"node_bulk_form";s:14:"node_bulk_form";s:5:"title";s:5:"title";s:4:"type";s:4:"type";s:4:"name";s:4:"name";s:6:"status";s:6:"status";s:7:"changed";s:7:"changed";s:9:"edit_node";s:9:"edit_node";s:11:"delete_node";s:11:"delete_node";s:10:"dropbutton";s:10:"dropbutton";s:9:"timestamp";s:5:"title";}s:7:"default";s:7:"changed";s:4:"info";a:10:{s:14:"node_bulk_form";a:4:{s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:5:"title";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:4:"type";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:4:"name";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:6:"status";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:7:"changed";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:4:"desc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:9:"edit_node";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:11:"delete_node";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:10:"dropbutton";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:9:"timestamp";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}}s:8:"override";b:1;s:6:"sticky";b:1;s:7:"summary";s:0:"";s:11:"empty_table";b:1;s:7:"caption";s:0:"";s:11:"description";s:0:"";}}s:3:"row";a:1:{s:4:"type";s:6:"fields";}s:5:"query";a:1:{s:4:"type";s:11:"views_query";}s:13:"relationships";a:1:{s:3:"uid";a:6:{s:2:"id";s:3:"uid";s:5:"table";s:15:"node_field_data";s:5:"field";s:3:"uid";s:11:"admin_label";s:6:"author";s:9:"plugin_id";s:8:"standard";s:8:"required";b:1;}}s:16:"show_admin_links";b:0;s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:0;s:8:"contexts";a:7:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:4:"user";i:5;s:21:"user.node_grants:view";i:6;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"page_1";a:6:{s:2:"id";s:6:"page_1";s:13:"display_title";s:4:"Page";s:14:"display_plugin";s:4:"page";s:8:"position";i:1;s:15:"display_options";a:4:{s:17:"display_extenders";a:0:{}s:4:"path";s:18:"admin/content/node";s:4:"menu";a:6:{s:4:"type";s:11:"default tab";s:5:"title";s:7:"Content";s:11:"description";s:0:"";s:6:"weight";i:-10;s:9:"menu_name";s:5:"admin";s:7:"context";s:0:"";}s:11:"tab_options";a:5:{s:4:"type";s:6:"normal";s:5:"title";s:7:"Content";s:11:"description";s:23:"Find and manage content";s:6:"weight";i:-10;s:9:"menu_name";s:5:"admin";}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:0;s:8:"contexts";a:7:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:4:"user";i:5;s:21:"user.node_grants:view";i:6;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}'),
('', 'views.view.content_recent', 'a:13:{s:4:"uuid";s:36:"1c834e54-c008-466b-8cbf-971936b9a549";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:4:"node";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"YqZN5rc7XDQcFcInc8wkzuaHJmC5YvirhTmDcrarT6M";}s:2:"id";s:14:"content_recent";s:5:"label";s:14:"Recent content";s:6:"module";s:4:"node";s:11:"description";s:15:"Recent content.";s:3:"tag";s:7:"default";s:10:"base_table";s:15:"node_field_data";s:10:"base_field";s:3:"nid";s:7:"display";a:2:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:22:{s:5:"title";s:14:"Recent content";s:6:"fields";a:2:{s:5:"title";a:26:{s:2:"id";s:5:"title";s:5:"table";s:15:"node_field_data";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:5:"title";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:0;s:5:"alter";a:8:{s:10:"alter_text";b:0;s:9:"make_link";b:0;s:8:"absolute";b:0;s:13:"word_boundary";b:0;s:8:"ellipsis";b:0;s:10:"strip_tags";b:0;s:4:"trim";b:0;s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:6:"string";s:8:"settings";a:1:{s:14:"link_to_entity";b:1;}}s:7:"changed";a:37:{s:2:"id";s:7:"changed";s:5:"table";s:15:"node_field_data";s:5:"field";s:7:"changed";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:7:"changed";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:13:"timestamp_ago";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:6:"offset";i:0;s:14:"items_per_page";i:10;}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:5:"Apply";s:12:"reset_button";b:0;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:14:"access content";}}s:5:"cache";a:2:{s:4:"type";s:3:"tag";s:7:"options";a:0:{}}s:5:"empty";a:1:{s:16:"area_text_custom";a:10:{s:2:"id";s:16:"area_text_custom";s:5:"table";s:5:"views";s:5:"field";s:16:"area_text_custom";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:11:"text_custom";s:5:"empty";b:1;s:7:"content";s:21:"No content available.";s:8:"tokenize";b:0;}}s:5:"sorts";a:1:{s:7:"changed";a:13:{s:2:"id";s:7:"changed";s:5:"table";s:15:"node_field_data";s:5:"field";s:7:"changed";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:7:"changed";s:9:"plugin_id";s:4:"date";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:7:"changed";}s:7:"exposed";b:0;s:11:"granularity";s:6:"second";}}s:9:"arguments";a:0:{}s:7:"filters";a:2:{s:12:"status_extra";a:15:{s:2:"id";s:12:"status_extra";s:5:"table";s:15:"node_field_data";s:5:"field";s:12:"status_extra";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:9:"plugin_id";s:11:"node_status";s:8:"operator";s:1:"=";s:5:"value";b:0;s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:12:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:8:"langcode";a:16:{s:2:"id";s:8:"langcode";s:5:"table";s:15:"node_field_data";s:5:"field";s:8:"langcode";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:8:"langcode";s:9:"plugin_id";s:8:"language";s:8:"operator";s:2:"in";s:5:"value";a:1:{s:31:"***LANGUAGE_language_content***";s:31:"***LANGUAGE_language_content***";}s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:13:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:5:"style";a:2:{s:4:"type";s:9:"html_list";s:7:"options";a:6:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:4:"type";s:2:"ul";s:13:"wrapper_class";s:9:"item-list";s:5:"class";s:0:"";}}s:3:"row";a:1:{s:4:"type";s:6:"fields";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:1:{s:3:"uid";a:10:{s:2:"id";s:3:"uid";s:5:"table";s:15:"node_field_data";s:5:"field";s:3:"uid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:6:"author";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:3:"uid";s:9:"plugin_id";s:8:"standard";s:8:"required";b:1;}}s:8:"use_more";b:0;s:15:"use_more_always";b:0;s:13:"use_more_text";s:4:"More";s:12:"link_display";s:1:"0";s:8:"link_url";s:0:"";s:6:"header";a:0:{}s:6:"footer";a:0:{}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:4:"user";i:3;s:21:"user.node_grants:view";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:7:"block_1";a:6:{s:2:"id";s:7:"block_1";s:13:"display_title";s:5:"Block";s:14:"display_plugin";s:5:"block";s:8:"position";i:1;s:15:"display_options";a:1:{s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:4:"user";i:3;s:21:"user.node_grants:view";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}');
INSERT INTO `[[dbprefix]]config` VALUES
('', 'views.view.files', 'a:13:{s:4:"uuid";s:36:"52cf11f7-0c9b-4e67-bae2-9f3c9beb00f5";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:4:"file";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"blP1XdpU4RqVoA_8po7qnIokIbHB6DJt0lpilgY5ovM";}s:2:"id";s:5:"files";s:5:"label";s:5:"Files";s:6:"module";s:4:"file";s:11:"description";s:22:"Find and manage files.";s:3:"tag";s:7:"default";s:10:"base_table";s:12:"file_managed";s:10:"base_field";s:3:"fid";s:7:"display";a:3:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:19:{s:5:"title";s:5:"Files";s:6:"fields";a:9:{s:3:"fid";a:24:{s:2:"id";s:3:"fid";s:5:"table";s:12:"file_managed";s:5:"field";s:3:"fid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:3:"fid";s:9:"plugin_id";s:5:"field";s:5:"label";s:3:"Fid";s:7:"exclude";b:1;s:5:"alter";a:8:{s:10:"alter_text";b:0;s:9:"make_link";b:0;s:8:"absolute";b:0;s:13:"word_boundary";b:0;s:8:"ellipsis";b:0;s:10:"strip_tags";b:0;s:4:"trim";b:0;s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;}s:8:"filename";a:36:{s:2:"id";s:8:"filename";s:5:"table";s:12:"file_managed";s:5:"field";s:8:"filename";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:8:"filename";s:9:"plugin_id";s:5:"field";s:5:"label";s:4:"Name";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:0;s:8:"ellipsis";b:0;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:9:"file_link";s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:8:"filemime";a:25:{s:2:"id";s:8:"filemime";s:5:"table";s:12:"file_managed";s:5:"field";s:8:"filemime";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:8:"filemime";s:9:"plugin_id";s:5:"field";s:5:"label";s:9:"MIME type";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:13:"file_filemime";}s:8:"filesize";a:25:{s:2:"id";s:8:"filesize";s:5:"table";s:12:"file_managed";s:5:"field";s:8:"filesize";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:8:"filesize";s:9:"plugin_id";s:5:"field";s:5:"label";s:4:"Size";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"file_size";}s:6:"status";a:26:{s:2:"id";s:6:"status";s:5:"table";s:12:"file_managed";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:5:"field";s:5:"label";s:6:"Status";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:7:"boolean";s:8:"settings";a:3:{s:6:"format";s:6:"custom";s:19:"format_custom_false";s:9:"Temporary";s:18:"format_custom_true";s:9:"Permanent";}}s:7:"created";a:26:{s:2:"id";s:7:"created";s:5:"table";s:12:"file_managed";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:7:"created";s:9:"plugin_id";s:5:"field";s:5:"label";s:11:"Upload date";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"timestamp";s:8:"settings";a:5:{s:11:"date_format";s:6:"medium";s:18:"custom_date_format";s:0:"";s:8:"timezone";s:0:"";s:7:"tooltip";a:2:{s:11:"date_format";s:4:"long";s:18:"custom_date_format";s:0:"";}s:9:"time_diff";a:5:{s:7:"enabled";b:0;s:13:"future_format";s:15:"@interval hence";s:11:"past_format";s:13:"@interval ago";s:11:"granularity";i:2;s:7:"refresh";i:60;}}}s:7:"changed";a:26:{s:2:"id";s:7:"changed";s:5:"table";s:12:"file_managed";s:5:"field";s:7:"changed";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:7:"changed";s:9:"plugin_id";s:5:"field";s:5:"label";s:12:"Changed date";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"timestamp";s:8:"settings";a:5:{s:11:"date_format";s:6:"medium";s:18:"custom_date_format";s:0:"";s:8:"timezone";s:0:"";s:7:"tooltip";a:2:{s:11:"date_format";s:4:"long";s:18:"custom_date_format";s:0:"";}s:9:"time_diff";a:5:{s:7:"enabled";b:0;s:13:"future_format";s:15:"@interval hence";s:11:"past_format";s:13:"@interval ago";s:11:"granularity";i:2;s:7:"refresh";i:60;}}}s:5:"count";a:30:{s:2:"id";s:5:"count";s:5:"table";s:10:"file_usage";s:5:"field";s:5:"count";s:12:"relationship";s:3:"fid";s:10:"group_type";s:3:"sum";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:7:"numeric";s:5:"label";s:7:"Used in";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:1;s:4:"path";s:35:"admin/content/files/usage/{{ fid }}";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:13:"set_precision";b:0;s:9:"precision";i:0;s:7:"decimal";s:1:".";s:9:"separator";s:1:",";s:13:"format_plural";b:1;s:20:"format_plural_string";s:21:"1 place@count places";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}s:10:"operations";a:24:{s:2:"id";s:10:"operations";s:5:"table";s:12:"file_managed";s:5:"field";s:10:"operations";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:9:"plugin_id";s:17:"entity_operations";s:5:"label";s:10:"Operations";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:11:"destination";b:0;}}s:5:"pager";a:2:{s:4:"type";s:4:"mini";s:7:"options";a:7:{s:6:"offset";i:0;s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:50;s:11:"total_pages";i:0;s:2:"id";i:0;s:4:"tags";a:2:{s:4:"next";s:8:"Next ›";s:8:"previous";s:12:"‹ Previous";}s:6:"expose";a:7:{s:14:"items_per_page";b:0;s:20:"items_per_page_label";s:14:"Items per page";s:22:"items_per_page_options";s:13:"5, 10, 25, 50";s:26:"items_per_page_options_all";b:0;s:32:"items_per_page_options_all_label";s:7:"- All -";s:6:"offset";b:0;s:12:"offset_label";s:6:"Offset";}}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:6:"Filter";s:12:"reset_button";b:0;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:21:"access files overview";}}s:5:"cache";a:2:{s:4:"type";s:3:"tag";s:7:"options";a:0:{}}s:5:"empty";a:1:{s:16:"area_text_custom";a:6:{s:2:"id";s:16:"area_text_custom";s:5:"table";s:5:"views";s:5:"field";s:16:"area_text_custom";s:9:"plugin_id";s:11:"text_custom";s:5:"empty";b:1;s:7:"content";s:19:"No files available.";}}s:5:"sorts";a:0:{}s:9:"arguments";a:0:{}s:7:"filters";a:3:{s:8:"filename";a:16:{s:2:"id";s:8:"filename";s:5:"table";s:12:"file_managed";s:5:"field";s:8:"filename";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:8:"filename";s:9:"plugin_id";s:6:"string";s:8:"operator";s:4:"word";s:5:"value";s:0:"";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:11:"filemime_op";s:5:"label";s:8:"Filename";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:11:"filename_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:8:"filename";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:8:"filemime";a:16:{s:2:"id";s:8:"filemime";s:5:"table";s:12:"file_managed";s:5:"field";s:8:"filemime";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:8:"filemime";s:9:"plugin_id";s:6:"string";s:8:"operator";s:4:"word";s:5:"value";s:0:"";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:11:"filemime_op";s:5:"label";s:9:"MIME type";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:11:"filemime_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:8:"filemime";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:6:"status";a:16:{s:2:"id";s:6:"status";s:5:"table";s:12:"file_managed";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:11:"file_status";s:8:"operator";s:2:"in";s:5:"value";a:0:{}s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:13:{s:11:"operator_id";s:9:"status_op";s:5:"label";s:6:"Status";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:9:"status_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:6:"status";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:5:"style";a:2:{s:4:"type";s:5:"table";s:7:"options";a:12:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:7:"columns";a:8:{s:3:"fid";s:3:"fid";s:8:"filename";s:8:"filename";s:8:"filemime";s:8:"filemime";s:8:"filesize";s:8:"filesize";s:6:"status";s:6:"status";s:7:"created";s:7:"created";s:7:"changed";s:7:"changed";s:5:"count";s:5:"count";}s:7:"default";s:7:"changed";s:4:"info";a:8:{s:3:"fid";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:8:"filename";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:8:"filemime";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:15:"priority-medium";}s:8:"filesize";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:6:"status";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:7:"created";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:4:"desc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:7:"changed";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:4:"desc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:5:"count";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:15:"priority-medium";}}s:8:"override";b:1;s:6:"sticky";b:0;s:7:"summary";s:0:"";s:11:"empty_table";b:1;s:7:"caption";s:0:"";s:11:"description";s:0:"";}}s:3:"row";a:1:{s:4:"type";s:6:"fields";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:1:{s:3:"fid";a:7:{s:2:"id";s:3:"fid";s:5:"table";s:12:"file_managed";s:5:"field";s:3:"fid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:10:"File usage";s:8:"required";b:1;}}s:8:"group_by";b:1;s:16:"show_admin_links";b:1;s:6:"header";a:0:{}s:6:"footer";a:0:{}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"page_1";a:6:{s:2:"id";s:6:"page_1";s:13:"display_title";s:14:"Files overview";s:14:"display_plugin";s:4:"page";s:8:"position";i:1;s:15:"display_options";a:6:{s:8:"defaults";a:2:{s:5:"pager";b:1;s:13:"relationships";b:0;}s:13:"relationships";a:1:{s:3:"fid";a:7:{s:2:"id";s:3:"fid";s:5:"table";s:12:"file_managed";s:5:"field";s:3:"fid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:10:"File usage";s:8:"required";b:0;}}s:19:"display_description";s:0:"";s:17:"display_extenders";a:0:{}s:4:"path";s:19:"admin/content/files";s:4:"menu";a:6:{s:4:"type";s:3:"tab";s:5:"title";s:5:"Files";s:11:"description";s:0:"";s:6:"weight";i:0;s:9:"menu_name";s:5:"admin";s:7:"context";s:0:"";}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"page_2";a:6:{s:2:"id";s:6:"page_2";s:13:"display_title";s:10:"File usage";s:14:"display_plugin";s:4:"page";s:8:"position";i:2;s:15:"display_options";a:15:{s:5:"title";s:10:"File usage";s:6:"fields";a:4:{s:12:"entity_label";a:23:{s:2:"id";s:12:"entity_label";s:5:"table";s:10:"file_usage";s:5:"field";s:12:"entity_label";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:12:"entity_label";s:5:"label";s:6:"Entity";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:14:"link_to_entity";b:1;}s:4:"type";a:22:{s:2:"id";s:4:"type";s:5:"table";s:10:"file_usage";s:5:"field";s:4:"type";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:8:"standard";s:5:"label";s:11:"Entity type";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;}s:6:"module";a:22:{s:2:"id";s:6:"module";s:5:"table";s:10:"file_usage";s:5:"field";s:6:"module";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:8:"standard";s:5:"label";s:18:"Registering module";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;}s:5:"count";a:30:{s:2:"id";s:5:"count";s:5:"table";s:10:"file_usage";s:5:"field";s:5:"count";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:7:"numeric";s:5:"label";s:9:"Use count";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:13:"set_precision";b:0;s:9:"precision";i:0;s:7:"decimal";s:1:".";s:9:"separator";s:1:",";s:13:"format_plural";b:0;s:20:"format_plural_string";s:8:"1@count";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:5:"pager";a:2:{s:4:"type";s:4:"mini";s:7:"options";a:7:{s:6:"offset";i:0;s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:10;s:11:"total_pages";i:0;s:2:"id";i:0;s:4:"tags";a:2:{s:4:"next";s:8:"Next ›";s:8:"previous";s:12:"‹ Previous";}s:6:"expose";a:7:{s:14:"items_per_page";b:0;s:20:"items_per_page_label";s:14:"Items per page";s:22:"items_per_page_options";s:13:"5, 10, 25, 50";s:26:"items_per_page_options_all";b:0;s:32:"items_per_page_options_all_label";s:7:"- All -";s:6:"offset";b:0;s:12:"offset_label";s:6:"Offset";}}}s:5:"empty";a:0:{}s:9:"arguments";a:1:{s:3:"fid";a:22:{s:2:"id";s:3:"fid";s:5:"table";s:12:"file_managed";s:5:"field";s:3:"fid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"file";s:12:"entity_field";s:3:"fid";s:9:"plugin_id";s:8:"file_fid";s:14:"default_action";s:9:"not found";s:9:"exception";a:3:{s:5:"value";s:3:"all";s:12:"title_enable";b:0;s:5:"title";s:3:"All";}s:12:"title_enable";b:1;s:5:"title";s:46:"File usage information for {{ arguments.fid }}";s:21:"default_argument_type";s:5:"fixed";s:24:"default_argument_options";a:1:{s:8:"argument";s:0:"";}s:15:"summary_options";a:4:{s:9:"base_path";s:0:"";s:5:"count";b:1;s:8:"override";b:0;s:14:"items_per_page";i:25;}s:7:"summary";a:3:{s:10:"sort_order";s:3:"asc";s:17:"number_of_records";i:0;s:6:"format";s:15:"default_summary";}s:18:"specify_validation";b:0;s:8:"validate";a:2:{s:4:"type";s:4:"none";s:4:"fail";s:9:"not found";}s:16:"validate_options";a:0:{}s:12:"break_phrase";b:0;s:3:"not";b:0;}}s:7:"filters";a:0:{}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:0:{}}s:5:"style";a:2:{s:4:"type";s:5:"table";s:7:"options";a:12:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:7:"columns";a:4:{s:12:"entity_label";s:12:"entity_label";s:4:"type";s:4:"type";s:6:"module";s:6:"module";s:5:"count";s:5:"count";}s:7:"default";s:12:"entity_label";s:4:"info";a:4:{s:12:"entity_label";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:4:"type";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:15:"priority-medium";}s:6:"module";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:5:"count";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}}s:8:"override";b:1;s:6:"sticky";b:0;s:7:"summary";s:0:"";s:11:"empty_table";b:1;s:7:"caption";s:0:"";s:11:"description";s:0:"";}}s:3:"row";a:2:{s:4:"type";s:6:"fields";s:7:"options";a:0:{}}s:8:"defaults";a:11:{s:5:"empty";b:0;s:5:"title";b:0;s:5:"pager";b:0;s:8:"group_by";b:0;s:5:"style";b:0;s:3:"row";b:0;s:13:"relationships";b:0;s:6:"fields";b:0;s:9:"arguments";b:0;s:7:"filters";b:0;s:13:"filter_groups";b:0;}s:13:"relationships";a:1:{s:3:"fid";a:7:{s:2:"id";s:3:"fid";s:5:"table";s:12:"file_managed";s:5:"field";s:3:"fid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:10:"File usage";s:8:"required";b:1;}}s:8:"group_by";b:0;s:19:"display_description";s:0:"";s:17:"display_extenders";a:0:{}s:4:"path";s:27:"admin/content/files/usage/%";}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:4:{i:0;s:28:"languages:language_interface";i:1;s:3:"url";i:2;s:14:"url.query_args";i:3;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}'),
('', 'views.view.frontpage', 'a:13:{s:4:"uuid";s:36:"7619b68f-92b7-4e6a-b460-a2b241a4f03d";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:2:{i:0;s:30:"core.entity_view_mode.node.rss";i:1;s:33:"core.entity_view_mode.node.teaser";}s:6:"module";a:2:{i:0;s:4:"node";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"OEEnRQIjfIaCFRsz8U3VqDrE82ltQKlo8wNbQJRZXu0";}s:2:"id";s:9:"frontpage";s:5:"label";s:9:"Frontpage";s:6:"module";s:4:"node";s:11:"description";s:39:"All content promoted to the front page.";s:3:"tag";s:7:"default";s:10:"base_table";s:15:"node_field_data";s:10:"base_field";s:3:"nid";s:7:"display";a:3:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:17:{s:5:"title";s:0:"";s:6:"fields";a:0:{}s:5:"pager";a:2:{s:4:"type";s:4:"full";s:7:"options";a:8:{s:6:"offset";i:0;s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:10;s:11:"total_pages";i:0;s:2:"id";i:0;s:4:"tags";a:4:{s:4:"next";s:8:"Next ›";s:8:"previous";s:12:"‹ Previous";s:5:"first";s:8:"« First";s:4:"last";s:7:"Last »";}s:6:"expose";a:7:{s:14:"items_per_page";b:0;s:20:"items_per_page_label";s:14:"Items per page";s:22:"items_per_page_options";s:13:"5, 10, 25, 50";s:26:"items_per_page_options_all";b:0;s:32:"items_per_page_options_all_label";s:7:"- All -";s:6:"offset";b:0;s:12:"offset_label";s:6:"Offset";}s:8:"quantity";i:9;}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:5:"Apply";s:12:"reset_button";b:0;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:14:"access content";}}s:5:"cache";a:2:{s:4:"type";s:3:"tag";s:7:"options";a:0:{}}s:5:"empty";a:3:{s:16:"area_text_custom";a:11:{s:2:"id";s:16:"area_text_custom";s:5:"table";s:5:"views";s:5:"field";s:16:"area_text_custom";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:11:"text_custom";s:5:"label";s:0:"";s:5:"empty";b:1;s:7:"content";s:181:"No front page content has been created yet.<br/>Follow the <a target="_blank" href="https://www.drupal.org/docs/user_guide/en/index.html">User Guide</a> to start building your site.";s:8:"tokenize";b:0;}s:18:"node_listing_empty";a:10:{s:2:"id";s:18:"node_listing_empty";s:5:"table";s:4:"node";s:5:"field";s:18:"node_listing_empty";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:9:"plugin_id";s:18:"node_listing_empty";s:5:"label";s:0:"";s:5:"empty";b:1;}s:5:"title";a:10:{s:2:"id";s:5:"title";s:5:"table";s:5:"views";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:5:"title";s:5:"label";s:0:"";s:5:"empty";b:1;s:5:"title";s:8:"Welcome!";}}s:5:"sorts";a:2:{s:6:"sticky";a:12:{s:2:"id";s:6:"sticky";s:5:"table";s:15:"node_field_data";s:5:"field";s:6:"sticky";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:6:"sticky";s:9:"plugin_id";s:8:"standard";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:6:"sticky";}s:7:"exposed";b:0;}s:7:"created";a:13:{s:2:"id";s:7:"created";s:5:"table";s:15:"node_field_data";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:7:"created";s:9:"plugin_id";s:4:"date";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:7:"created";}s:7:"exposed";b:0;s:11:"granularity";s:6:"second";}}s:9:"arguments";a:0:{}s:7:"filters";a:3:{s:7:"promote";a:16:{s:2:"id";s:7:"promote";s:5:"table";s:15:"node_field_data";s:5:"field";s:7:"promote";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:7:"promote";s:9:"plugin_id";s:7:"boolean";s:8:"operator";s:1:"=";s:5:"value";s:1:"1";s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:12:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:6:"status";a:9:{s:2:"id";s:6:"status";s:5:"table";s:15:"node_field_data";s:5:"field";s:6:"status";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:5:"value";s:1:"1";s:5:"group";i:1;s:6:"expose";a:3:{s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}}}s:8:"langcode";a:16:{s:2:"id";s:8:"langcode";s:5:"table";s:15:"node_field_data";s:5:"field";s:8:"langcode";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:8:"langcode";s:9:"plugin_id";s:8:"language";s:8:"operator";s:2:"in";s:5:"value";a:1:{s:31:"***LANGUAGE_language_content***";s:31:"***LANGUAGE_language_content***";}s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:13:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:5:"style";a:2:{s:4:"type";s:7:"default";s:7:"options";a:4:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:11:"uses_fields";b:0;}}s:3:"row";a:2:{s:4:"type";s:11:"entity:node";s:7:"options";a:1:{s:9:"view_mode";s:6:"teaser";}}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:0:{}s:6:"header";a:0:{}s:6:"footer";a:0:{}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:4:{i:0;s:28:"languages:language_interface";i:1;s:14:"url.query_args";i:2;s:21:"user.node_grants:view";i:3;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"feed_1";a:6:{s:2:"id";s:6:"feed_1";s:13:"display_title";s:4:"Feed";s:14:"display_plugin";s:4:"feed";s:8:"position";i:2;s:15:"display_options";a:7:{s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:6:"offset";i:0;s:14:"items_per_page";i:10;}}s:5:"style";a:2:{s:4:"type";s:3:"rss";s:7:"options";a:3:{s:8:"grouping";a:0:{}s:11:"uses_fields";b:0;s:11:"description";s:0:"";}}s:3:"row";a:2:{s:4:"type";s:8:"node_rss";s:7:"options";a:2:{s:12:"relationship";s:4:"none";s:9:"view_mode";s:3:"rss";}}s:17:"display_extenders";a:0:{}s:4:"path";s:7:"rss.xml";s:14:"sitename_title";b:1;s:8:"displays";a:2:{s:6:"page_1";s:6:"page_1";s:7:"default";s:0:"";}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:3:{i:0;s:28:"languages:language_interface";i:1;s:21:"user.node_grants:view";i:2;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"page_1";a:6:{s:2:"id";s:6:"page_1";s:13:"display_title";s:4:"Page";s:14:"display_plugin";s:4:"page";s:8:"position";i:1;s:15:"display_options";a:2:{s:17:"display_extenders";a:0:{}s:4:"path";s:4:"node";}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:4:{i:0;s:28:"languages:language_interface";i:1;s:14:"url.query_args";i:2;s:21:"user.node_grants:view";i:3;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}');
INSERT INTO `[[dbprefix]]config` VALUES
('', 'views.view.glossary', 'a:13:{s:4:"uuid";s:36:"ddb31458-f097-484d-8f7b-d4d0d0e77fce";s:8:"langcode";s:2:"en";s:6:"status";b:0;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:16:"system.menu.main";}s:6:"module";a:2:{i:0;s:4:"node";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"r-klgGeO4haVHqAwxW1HXZLzdzLSMUVC08OuTBrRh58";}s:2:"id";s:8:"glossary";s:5:"label";s:8:"Glossary";s:6:"module";s:4:"node";s:11:"description";s:23:"All content, by letter.";s:3:"tag";s:7:"default";s:10:"base_table";s:15:"node_field_data";s:10:"base_field";s:3:"nid";s:7:"display";a:3:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:17:{s:6:"fields";a:3:{s:5:"title";a:24:{s:2:"id";s:5:"title";s:5:"table";s:15:"node_field_data";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:5:"title";s:9:"plugin_id";s:5:"field";s:5:"label";s:5:"Title";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;}s:4:"name";a:25:{s:2:"id";s:4:"name";s:5:"table";s:16:"users_field_data";s:5:"field";s:4:"name";s:12:"relationship";s:3:"uid";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:4:"name";s:9:"plugin_id";s:5:"field";s:5:"label";s:6:"Author";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"user_name";}s:7:"changed";a:26:{s:2:"id";s:7:"changed";s:5:"table";s:15:"node_field_data";s:5:"field";s:7:"changed";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:7:"changed";s:9:"plugin_id";s:5:"field";s:5:"label";s:11:"Last update";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"timestamp";s:8:"settings";a:5:{s:11:"date_format";s:4:"long";s:18:"custom_date_format";s:0:"";s:8:"timezone";s:0:"";s:7:"tooltip";a:2:{s:11:"date_format";s:4:"long";s:18:"custom_date_format";s:0:"";}s:9:"time_diff";a:5:{s:7:"enabled";b:0;s:13:"future_format";s:15:"@interval hence";s:11:"past_format";s:13:"@interval ago";s:11:"granularity";i:2;s:7:"refresh";i:60;}}}}s:5:"pager";a:2:{s:4:"type";s:4:"mini";s:7:"options";a:7:{s:6:"offset";i:0;s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:36;s:11:"total_pages";i:0;s:2:"id";i:0;s:4:"tags";a:2:{s:4:"next";s:6:"››";s:8:"previous";s:6:"‹‹";}s:6:"expose";a:7:{s:14:"items_per_page";b:0;s:20:"items_per_page_label";s:14:"Items per page";s:22:"items_per_page_options";s:13:"5, 10, 25, 50";s:26:"items_per_page_options_all";b:0;s:32:"items_per_page_options_all_label";s:7:"- All -";s:6:"offset";b:0;s:12:"offset_label";s:6:"Offset";}}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:5:"Apply";s:12:"reset_button";b:0;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:14:"access content";}}s:5:"cache";a:2:{s:4:"type";s:3:"tag";s:7:"options";a:0:{}}s:5:"empty";a:0:{}s:5:"sorts";a:0:{}s:9:"arguments";a:1:{s:5:"title";a:26:{s:2:"id";s:5:"title";s:5:"table";s:15:"node_field_data";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:5:"title";s:9:"plugin_id";s:6:"string";s:14:"default_action";s:7:"default";s:9:"exception";a:1:{s:12:"title_enable";b:1;}s:12:"title_enable";b:0;s:5:"title";s:0:"";s:21:"default_argument_type";s:5:"fixed";s:24:"default_argument_options";a:1:{s:8:"argument";s:1:"a";}s:15:"summary_options";a:0:{}s:7:"summary";a:1:{s:6:"format";s:15:"default_summary";}s:18:"specify_validation";b:1;s:8:"validate";a:2:{s:4:"type";s:4:"none";s:4:"fail";s:9:"not found";}s:16:"validate_options";a:0:{}s:8:"glossary";b:1;s:5:"limit";i:1;s:4:"case";s:5:"upper";s:9:"path_case";s:5:"lower";s:14:"transform_dash";b:0;s:12:"break_phrase";b:0;}}s:7:"filters";a:2:{s:6:"status";a:9:{s:2:"id";s:6:"status";s:5:"table";s:15:"node_field_data";s:5:"field";s:6:"status";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:5:"value";s:1:"1";s:5:"group";i:1;s:6:"expose";a:3:{s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}}}s:8:"langcode";a:16:{s:2:"id";s:8:"langcode";s:5:"table";s:15:"node_field_data";s:5:"field";s:8:"langcode";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:8:"langcode";s:9:"plugin_id";s:8:"language";s:8:"operator";s:2:"in";s:5:"value";a:1:{s:31:"***LANGUAGE_language_content***";s:31:"***LANGUAGE_language_content***";}s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:13:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:5:"style";a:2:{s:4:"type";s:5:"table";s:7:"options";a:12:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:11:"uses_fields";b:0;s:7:"columns";a:3:{s:5:"title";s:5:"title";s:4:"name";s:4:"name";s:7:"changed";s:7:"changed";}s:7:"default";s:5:"title";s:4:"info";a:3:{s:5:"title";a:2:{s:8:"sortable";b:1;s:9:"separator";s:0:"";}s:4:"name";a:2:{s:8:"sortable";b:1;s:9:"separator";s:0:"";}s:7:"changed";a:2:{s:8:"sortable";b:1;s:9:"separator";s:0:"";}}s:8:"override";b:1;s:6:"sticky";b:0;s:7:"summary";s:0:"";s:5:"order";s:3:"asc";s:11:"empty_table";b:0;}}s:3:"row";a:2:{s:4:"type";s:6:"fields";s:7:"options";a:4:{s:22:"default_field_elements";b:1;s:6:"inline";a:0:{}s:9:"separator";s:0:"";s:10:"hide_empty";b:0;}}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:1:{s:3:"uid";a:8:{s:2:"id";s:3:"uid";s:5:"table";s:15:"node_field_data";s:5:"field";s:3:"uid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:6:"author";s:9:"plugin_id";s:8:"standard";s:8:"required";b:0;}}s:8:"use_ajax";b:1;s:6:"header";a:0:{}s:6:"footer";a:0:{}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:6:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:21:"user.node_grants:view";i:5;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:12:"attachment_1";a:6:{s:2:"id";s:12:"attachment_1";s:13:"display_title";s:10:"Attachment";s:14:"display_plugin";s:10:"attachment";s:8:"position";i:2;s:15:"display_options";a:7:{s:5:"pager";a:2:{s:4:"type";s:4:"none";s:7:"options";a:2:{s:6:"offset";i:0;s:14:"items_per_page";i:0;}}s:9:"arguments";a:1:{s:5:"title";a:26:{s:2:"id";s:5:"title";s:5:"table";s:15:"node_field_data";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:5:"title";s:9:"plugin_id";s:6:"string";s:14:"default_action";s:7:"summary";s:9:"exception";a:1:{s:12:"title_enable";b:1;}s:12:"title_enable";b:0;s:5:"title";s:0:"";s:21:"default_argument_type";s:5:"fixed";s:24:"default_argument_options";a:1:{s:8:"argument";s:1:"a";}s:15:"summary_options";a:3:{s:14:"items_per_page";i:25;s:6:"inline";b:1;s:9:"separator";s:3:" | ";}s:7:"summary";a:1:{s:6:"format";s:19:"unformatted_summary";}s:18:"specify_validation";b:1;s:8:"validate";a:2:{s:4:"type";s:4:"none";s:4:"fail";s:9:"not found";}s:16:"validate_options";a:0:{}s:8:"glossary";b:1;s:5:"limit";i:1;s:4:"case";s:5:"upper";s:9:"path_case";s:5:"lower";s:14:"transform_dash";b:0;s:12:"break_phrase";b:0;}}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:8:"defaults";a:1:{s:9:"arguments";b:0;}s:17:"display_extenders";a:0:{}s:8:"displays";a:2:{s:7:"default";s:7:"default";s:6:"page_1";s:6:"page_1";}s:17:"inherit_arguments";b:0;}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:6:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:21:"user.node_grants:view";i:5;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"page_1";a:6:{s:2:"id";s:6:"page_1";s:13:"display_title";s:4:"Page";s:14:"display_plugin";s:4:"page";s:8:"position";i:1;s:15:"display_options";a:4:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:17:"display_extenders";a:0:{}s:4:"path";s:8:"glossary";s:4:"menu";a:5:{s:4:"type";s:6:"normal";s:5:"title";s:8:"Glossary";s:6:"weight";i:0;s:9:"menu_name";s:4:"main";s:6:"parent";s:0:"";}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:6:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:21:"user.node_grants:view";i:5;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}'),
('', 'views.view.taxonomy_term', 'a:13:{s:4:"uuid";s:36:"6548d3fb-c842-4a86-aa73-6a51a5797d57";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:2:{s:6:"config";a:1:{i:0;s:33:"core.entity_view_mode.node.teaser";}s:6:"module";a:3:{i:0;s:4:"node";i:1;s:8:"taxonomy";i:2;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"KejdxDJQmx8SaO-t83OVekLw6ar4ldjmsJMGcotGxnQ";}s:2:"id";s:13:"taxonomy_term";s:5:"label";s:13:"Taxonomy term";s:6:"module";s:8:"taxonomy";s:11:"description";s:45:"Content belonging to a certain taxonomy term.";s:3:"tag";s:7:"default";s:10:"base_table";s:15:"node_field_data";s:10:"base_field";s:3:"nid";s:7:"display";a:3:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:18:{s:6:"fields";a:0:{}s:5:"pager";a:2:{s:4:"type";s:4:"mini";s:7:"options";a:7:{s:6:"offset";i:0;s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:10;s:11:"total_pages";i:0;s:2:"id";i:0;s:4:"tags";a:2:{s:4:"next";s:6:"››";s:8:"previous";s:6:"‹‹";}s:6:"expose";a:7:{s:14:"items_per_page";b:0;s:20:"items_per_page_label";s:14:"Items per page";s:22:"items_per_page_options";s:13:"5, 10, 25, 50";s:26:"items_per_page_options_all";b:0;s:32:"items_per_page_options_all_label";s:7:"- All -";s:6:"offset";b:0;s:12:"offset_label";s:6:"Offset";}}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:5:"Apply";s:12:"reset_button";b:0;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:14:"access content";}}s:5:"cache";a:2:{s:4:"type";s:3:"tag";s:7:"options";a:0:{}}s:5:"empty";a:0:{}s:5:"sorts";a:2:{s:6:"sticky";a:10:{s:2:"id";s:6:"sticky";s:5:"table";s:14:"taxonomy_index";s:5:"field";s:6:"sticky";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:8:"standard";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:6:"sticky";}s:7:"exposed";b:0;}s:7:"created";a:11:{s:2:"id";s:7:"created";s:5:"table";s:14:"taxonomy_index";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:4:"date";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:7:"created";}s:7:"exposed";b:0;s:11:"granularity";s:6:"second";}}s:9:"arguments";a:1:{s:3:"tid";a:22:{s:2:"id";s:3:"tid";s:5:"table";s:14:"taxonomy_index";s:5:"field";s:3:"tid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:18:"taxonomy_index_tid";s:14:"default_action";s:9:"not found";s:9:"exception";a:3:{s:5:"value";s:0:"";s:12:"title_enable";b:0;s:5:"title";s:3:"All";}s:12:"title_enable";b:1;s:5:"title";s:19:"{{ arguments.tid }}";s:21:"default_argument_type";s:5:"fixed";s:24:"default_argument_options";a:1:{s:8:"argument";s:0:"";}s:15:"summary_options";a:4:{s:9:"base_path";s:0:"";s:5:"count";b:1;s:8:"override";b:0;s:14:"items_per_page";i:25;}s:7:"summary";a:3:{s:10:"sort_order";s:3:"asc";s:17:"number_of_records";i:0;s:6:"format";s:15:"default_summary";}s:18:"specify_validation";b:1;s:8:"validate";a:2:{s:4:"type";s:20:"entity:taxonomy_term";s:4:"fail";s:9:"not found";}s:16:"validate_options";a:4:{s:7:"bundles";a:0:{}s:6:"access";b:1;s:9:"operation";s:4:"view";s:8:"multiple";i:0;}s:12:"break_phrase";b:0;s:9:"add_table";b:0;s:13:"require_value";b:0;s:17:"reduce_duplicates";b:0;}}s:7:"filters";a:2:{s:8:"langcode";a:16:{s:2:"id";s:8:"langcode";s:5:"table";s:15:"node_field_data";s:5:"field";s:8:"langcode";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"node";s:12:"entity_field";s:8:"langcode";s:9:"plugin_id";s:8:"language";s:8:"operator";s:2:"in";s:5:"value";a:1:{s:31:"***LANGUAGE_language_content***";s:31:"***LANGUAGE_language_content***";}s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:13:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:6:"status";a:14:{s:2:"id";s:6:"status";s:5:"table";s:14:"taxonomy_index";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:7:"boolean";s:8:"operator";s:1:"=";s:5:"value";s:1:"1";s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:12:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:5:"style";a:2:{s:4:"type";s:7:"default";s:7:"options";a:4:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:11:"uses_fields";b:0;}}s:3:"row";a:2:{s:4:"type";s:11:"entity:node";s:7:"options";a:1:{s:9:"view_mode";s:6:"teaser";}}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:0:{}s:12:"link_display";s:6:"page_1";s:8:"link_url";s:0:"";s:6:"header";a:1:{s:20:"entity_taxonomy_term";a:12:{s:2:"id";s:20:"entity_taxonomy_term";s:5:"table";s:5:"views";s:5:"field";s:20:"entity_taxonomy_term";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:6:"entity";s:5:"empty";b:1;s:6:"target";s:23:"{{ raw_arguments.tid }}";s:9:"view_mode";s:4:"full";s:8:"tokenize";b:1;s:13:"bypass_access";b:0;}}s:6:"footer";a:0:{}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:28:"languages:language_interface";i:1;s:3:"url";i:2;s:14:"url.query_args";i:3;s:21:"user.node_grants:view";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"feed_1";a:6:{s:2:"id";s:6:"feed_1";s:13:"display_title";s:4:"Feed";s:14:"display_plugin";s:4:"feed";s:8:"position";i:2;s:15:"display_options";a:7:{s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:6:"offset";i:0;s:14:"items_per_page";i:10;}}s:5:"style";a:2:{s:4:"type";s:3:"rss";s:7:"options";a:3:{s:8:"grouping";a:0:{}s:11:"uses_fields";b:0;s:11:"description";s:0:"";}}s:3:"row";a:2:{s:4:"type";s:8:"node_rss";s:7:"options";a:2:{s:12:"relationship";s:4:"none";s:9:"view_mode";s:7:"default";}}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:17:"display_extenders";a:0:{}s:4:"path";s:20:"taxonomy/term/%/feed";s:8:"displays";a:2:{s:6:"page_1";s:6:"page_1";s:7:"default";s:1:"0";}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:4:{i:0;s:28:"languages:language_interface";i:1;s:3:"url";i:2;s:21:"user.node_grants:view";i:3;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"page_1";a:6:{s:2:"id";s:6:"page_1";s:13:"display_title";s:4:"Page";s:14:"display_plugin";s:4:"page";s:8:"position";i:1;s:15:"display_options";a:3:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:17:"display_extenders";a:0:{}s:4:"path";s:15:"taxonomy/term/%";}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:28:"languages:language_interface";i:1;s:3:"url";i:2;s:14:"url.query_args";i:3;s:21:"user.node_grants:view";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}'),
('', 'views.view.user_admin_people', 'a:13:{s:4:"uuid";s:36:"73e831ee-8d4a-4b51-b805-9543b12b679b";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"FFLg74mnzRE10lgg5fspPCZWLnIEcvCnJMlNzj8OEtw";}s:2:"id";s:17:"user_admin_people";s:5:"label";s:6:"People";s:6:"module";s:4:"user";s:11:"description";s:50:"Find and manage people interacting with your site.";s:3:"tag";s:7:"default";s:10:"base_table";s:16:"users_field_data";s:10:"base_field";s:3:"uid";s:7:"display";a:2:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:25:{s:5:"title";s:6:"People";s:6:"fields";a:8:{s:14:"user_bulk_form";a:23:{s:2:"id";s:14:"user_bulk_form";s:5:"table";s:5:"users";s:5:"field";s:14:"user_bulk_form";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:9:"plugin_id";s:14:"user_bulk_form";s:5:"label";s:11:"Bulk update";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;}s:4:"name";a:25:{s:2:"id";s:4:"name";s:5:"table";s:16:"users_field_data";s:5:"field";s:4:"name";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:4:"name";s:9:"plugin_id";s:5:"field";s:5:"label";s:8:"Username";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"user_name";}s:6:"status";a:26:{s:2:"id";s:6:"status";s:5:"table";s:16:"users_field_data";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:5:"field";s:5:"label";s:6:"Status";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:7:"boolean";s:8:"settings";a:3:{s:6:"format";s:6:"custom";s:19:"format_custom_false";s:7:"Blocked";s:18:"format_custom_true";s:6:"Active";}}s:15:"roles_target_id";a:24:{s:2:"id";s:15:"roles_target_id";s:5:"table";s:11:"user__roles";s:5:"field";s:15:"roles_target_id";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:10:"user_roles";s:5:"label";s:5:"Roles";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:2:"ul";s:9:"separator";s:2:", ";}s:7:"created";a:26:{s:2:"id";s:7:"created";s:5:"table";s:16:"users_field_data";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:7:"created";s:9:"plugin_id";s:5:"field";s:5:"label";s:10:"Member for";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:13:"timestamp_ago";s:8:"settings";a:3:{s:13:"future_format";s:9:"@interval";s:11:"past_format";s:9:"@interval";s:11:"granularity";i:2;}}s:6:"access";a:26:{s:2:"id";s:6:"access";s:5:"table";s:16:"users_field_data";s:5:"field";s:6:"access";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:6:"access";s:9:"plugin_id";s:5:"field";s:5:"label";s:11:"Last access";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:13:"timestamp_ago";s:8:"settings";a:3:{s:13:"future_format";s:15:"@interval hence";s:11:"past_format";s:13:"@interval ago";s:11:"granularity";i:2;}}s:10:"operations";a:24:{s:2:"id";s:10:"operations";s:5:"table";s:5:"users";s:5:"field";s:10:"operations";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:9:"plugin_id";s:17:"entity_operations";s:5:"label";s:10:"Operations";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:11:"destination";b:1;}s:4:"mail";a:37:{s:2:"id";s:4:"mail";s:5:"table";s:16:"users_field_data";s:5:"field";s:4:"mail";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:4:"mail";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:1;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"basic_string";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}}s:5:"pager";a:2:{s:4:"type";s:4:"full";s:7:"options";a:8:{s:6:"offset";i:0;s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:50;s:11:"total_pages";i:0;s:2:"id";i:0;s:4:"tags";a:4:{s:4:"next";s:8:"Next ›";s:8:"previous";s:12:"‹ Previous";s:5:"first";s:8:"« First";s:4:"last";s:7:"Last »";}s:6:"expose";a:7:{s:14:"items_per_page";b:0;s:20:"items_per_page_label";s:14:"Items per page";s:22:"items_per_page_options";s:13:"5, 10, 25, 50";s:26:"items_per_page_options_all";b:0;s:32:"items_per_page_options_all_label";s:7:"- All -";s:6:"offset";b:0;s:12:"offset_label";s:6:"Offset";}s:8:"quantity";i:9;}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:6:"Filter";s:12:"reset_button";b:1;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:16:"administer users";}}s:5:"cache";a:1:{s:4:"type";s:3:"tag";}s:5:"empty";a:1:{s:16:"area_text_custom";a:10:{s:2:"id";s:16:"area_text_custom";s:5:"table";s:5:"views";s:5:"field";s:16:"area_text_custom";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:11:"text_custom";s:5:"empty";b:1;s:7:"content";s:20:"No people available.";s:8:"tokenize";b:0;}}s:5:"sorts";a:1:{s:7:"created";a:13:{s:2:"id";s:7:"created";s:5:"table";s:16:"users_field_data";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:7:"created";s:9:"plugin_id";s:4:"date";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:7:"created";}s:7:"exposed";b:0;s:11:"granularity";s:6:"second";}}s:7:"filters";a:6:{s:7:"combine";a:15:{s:2:"id";s:7:"combine";s:5:"table";s:5:"views";s:5:"field";s:7:"combine";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:7:"combine";s:8:"operator";s:8:"contains";s:5:"value";s:0:"";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:10:"combine_op";s:5:"label";s:22:"Name or email contains";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:10:"combine_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:4:"user";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}s:6:"fields";a:2:{s:4:"name";s:4:"name";s:4:"mail";s:4:"mail";}}s:6:"status";a:16:{s:2:"id";s:6:"status";s:5:"table";s:16:"users_field_data";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:8:"operator";s:1:"=";s:5:"value";s:1:"1";s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:12:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:9:"status_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:6:"status";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:1;s:10:"group_info";a:10:{s:5:"label";s:6:"Status";s:11:"description";s:0:"";s:10:"identifier";s:6:"status";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:2:{i:1;a:3:{s:5:"title";s:6:"Active";s:8:"operator";s:1:"=";s:5:"value";s:1:"1";}i:2;a:3:{s:5:"title";s:7:"Blocked";s:8:"operator";s:1:"=";s:5:"value";s:1:"0";}}}}s:15:"roles_target_id";a:15:{s:2:"id";s:15:"roles_target_id";s:5:"table";s:11:"user__roles";s:5:"field";s:15:"roles_target_id";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:10:"user_roles";s:8:"operator";s:2:"or";s:5:"value";a:0:{}s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:13:{s:11:"operator_id";s:18:"roles_target_id_op";s:5:"label";s:4:"Role";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:18:"roles_target_id_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:4:"role";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}s:17:"reduce_duplicates";b:0;}s:10:"permission";a:15:{s:2:"id";s:10:"permission";s:5:"table";s:11:"user__roles";s:5:"field";s:10:"permission";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:16:"user_permissions";s:8:"operator";s:2:"or";s:5:"value";a:0:{}s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:13:{s:11:"operator_id";s:13:"permission_op";s:5:"label";s:10:"Permission";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:13:"permission_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:10:"permission";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}s:17:"reduce_duplicates";b:0;}s:16:"default_langcode";a:16:{s:2:"id";s:16:"default_langcode";s:5:"table";s:16:"users_field_data";s:5:"field";s:16:"default_langcode";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:16:"default_langcode";s:9:"plugin_id";s:7:"boolean";s:8:"operator";s:1:"=";s:5:"value";s:1:"1";s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:12:{s:11:"operator_id";s:0:"";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:7:"uid_raw";a:15:{s:2:"id";s:7:"uid_raw";s:5:"table";s:16:"users_field_data";s:5:"field";s:7:"uid_raw";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:9:"plugin_id";s:7:"numeric";s:8:"operator";s:2:"!=";s:5:"value";a:3:{s:3:"min";s:0:"";s:3:"max";s:0:"";s:5:"value";s:1:"0";}s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:12:{s:11:"operator_id";s:1:"0";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:1;s:3:"AND";}}s:5:"style";a:2:{s:4:"type";s:5:"table";s:7:"options";a:10:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:7:"columns";a:8:{s:14:"user_bulk_form";s:14:"user_bulk_form";s:4:"name";s:4:"name";s:6:"status";s:6:"status";s:3:"rid";s:3:"rid";s:7:"created";s:7:"created";s:6:"access";s:6:"access";s:9:"edit_node";s:9:"edit_node";s:10:"dropbutton";s:10:"dropbutton";}s:7:"default";s:7:"created";s:4:"info";a:8:{s:14:"user_bulk_form";a:4:{s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:4:"name";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:6:"status";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:3:"rid";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:7:"created";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:4:"desc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:6:"access";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:4:"desc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:9:"edit_node";a:4:{s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:10:"dropbutton";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}}s:8:"override";b:1;s:6:"sticky";b:0;s:7:"summary";s:0:"";s:11:"empty_table";b:1;}}s:3:"row";a:1:{s:4:"type";s:6:"fields";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:9:"css_class";s:0:"";s:8:"use_ajax";b:0;s:8:"group_by";b:0;s:16:"show_admin_links";b:1;s:8:"use_more";b:0;s:15:"use_more_always";b:0;s:13:"use_more_text";s:4:"more";s:12:"link_display";s:6:"page_1";s:8:"link_url";s:0:"";s:15:"display_comment";s:0:"";s:23:"hide_attachment_summary";b:0;s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:0;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:6:"page_1";a:6:{s:2:"id";s:6:"page_1";s:13:"display_title";s:4:"Page";s:14:"display_plugin";s:4:"page";s:8:"position";i:1;s:15:"display_options";a:6:{s:8:"defaults";a:1:{s:16:"show_admin_links";b:0;}s:16:"show_admin_links";b:0;s:17:"display_extenders";a:0:{}s:4:"path";s:17:"admin/people/list";s:4:"menu";a:6:{s:4:"type";s:11:"default tab";s:5:"title";s:4:"List";s:11:"description";s:50:"Find and manage people interacting with your site.";s:6:"weight";i:-10;s:9:"menu_name";s:5:"admin";s:7:"context";s:0:"";}s:11:"tab_options";a:5:{s:4:"type";s:6:"normal";s:5:"title";s:6:"People";s:11:"description";s:45:"Manage user accounts, roles, and permissions.";s:6:"weight";i:0;s:9:"menu_name";s:5:"admin";}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:0;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}');
INSERT INTO `[[dbprefix]]config` VALUES
('', 'views.view.watchdog', 'a:13:{s:4:"uuid";s:36:"bbd9d797-0496-468c-a293-eba20850c052";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:2:{i:0;s:5:"dblog";i:1;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"SR5P89f0vUTPC7WY2YpLAffkDx8-Ar8LKFfowVXeqNU";}s:2:"id";s:8:"watchdog";s:5:"label";s:8:"Watchdog";s:6:"module";s:5:"views";s:11:"description";s:19:"Recent log messages";s:3:"tag";s:0:"";s:10:"base_table";s:8:"watchdog";s:10:"base_field";s:3:"wid";s:7:"display";a:2:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:19:{s:5:"title";s:19:"Recent log messages";s:6:"fields";a:8:{s:7:"nothing";a:22:{s:2:"id";s:7:"nothing";s:5:"table";s:5:"views";s:5:"field";s:7:"nothing";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:4:"Icon";s:9:"plugin_id";s:6:"custom";s:5:"label";s:0:"";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:1;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:4:"icon";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:0;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:0;}s:3:"wid";a:22:{s:2:"id";s:3:"wid";s:5:"table";s:8:"watchdog";s:5:"field";s:3:"wid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:8:"standard";s:5:"label";s:3:"WID";s:7:"exclude";b:1;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;}s:8:"severity";a:23:{s:2:"id";s:8:"severity";s:5:"table";s:8:"watchdog";s:5:"field";s:8:"severity";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:12:"machine_name";s:5:"label";s:8:"Severity";s:7:"exclude";b:1;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:12:"machine_name";b:0;}s:4:"type";a:22:{s:2:"id";s:4:"type";s:5:"table";s:8:"watchdog";s:5:"field";s:4:"type";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:8:"standard";s:5:"label";s:4:"Type";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;}s:9:"timestamp";a:25:{s:2:"id";s:9:"timestamp";s:5:"table";s:8:"watchdog";s:5:"field";s:9:"timestamp";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:4:"date";s:5:"label";s:4:"Date";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:11:"date_format";s:5:"short";s:18:"custom_date_format";s:0:"";s:8:"timezone";s:0:"";}s:7:"message";a:23:{s:2:"id";s:7:"message";s:5:"table";s:8:"watchdog";s:5:"field";s:7:"message";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:13:"dblog_message";s:5:"label";s:7:"Message";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:1;s:4:"path";s:35:"admin/reports/dblog/event/{{ wid }}";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:13:"{{ message }}";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:56;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:1;s:4:"trim";b:1;s:13:"preserve_tags";s:0:"";s:4:"html";b:1;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"replace_variables";b:1;}s:4:"name";a:37:{s:2:"id";s:4:"name";s:5:"table";s:16:"users_field_data";s:5:"field";s:4:"name";s:12:"relationship";s:3:"uid";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:4:"name";s:9:"plugin_id";s:5:"field";s:5:"label";s:4:"User";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:9:"user_name";s:8:"settings";a:1:{s:14:"link_to_entity";b:1;}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";i:0;s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";b:0;}s:4:"link";a:22:{s:2:"id";s:4:"link";s:5:"table";s:8:"watchdog";s:5:"field";s:4:"link";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:16:"dblog_operations";s:5:"label";s:10:"Operations";s:7:"exclude";b:0;s:5:"alter";a:26:{s:10:"alter_text";b:0;s:4:"text";s:0:"";s:9:"make_link";b:0;s:4:"path";s:0:"";s:8:"absolute";b:0;s:8:"external";b:0;s:14:"replace_spaces";b:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";b:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";b:0;s:10:"max_length";i:0;s:13:"word_boundary";b:1;s:8:"ellipsis";b:1;s:9:"more_link";b:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";b:0;s:4:"trim";b:0;s:13:"preserve_tags";s:0:"";s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;}}s:5:"pager";a:2:{s:4:"type";s:4:"mini";s:7:"options";a:7:{s:6:"offset";i:0;s:24:"pagination_heading_level";s:2:"h4";s:14:"items_per_page";i:50;s:11:"total_pages";N;s:2:"id";i:0;s:4:"tags";a:2:{s:4:"next";s:6:"››";s:8:"previous";s:6:"‹‹";}s:6:"expose";a:7:{s:14:"items_per_page";b:0;s:20:"items_per_page_label";s:14:"Items per page";s:22:"items_per_page_options";s:13:"5, 10, 25, 50";s:26:"items_per_page_options_all";b:0;s:32:"items_per_page_options_all_label";s:7:"- All -";s:6:"offset";b:0;s:12:"offset_label";s:6:"Offset";}}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:6:"Filter";s:12:"reset_button";b:1;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:0;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:19:"access site reports";}}s:5:"cache";a:2:{s:4:"type";s:4:"none";s:7:"options";a:0:{}}s:5:"empty";a:1:{s:4:"area";a:10:{s:2:"id";s:16:"area_text_custom";s:5:"table";s:5:"views";s:5:"field";s:16:"area_text_custom";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:26:"No log messages available.";s:9:"plugin_id";s:11:"text_custom";s:5:"empty";b:1;s:7:"content";s:26:"No log messages available.";s:8:"tokenize";b:0;}}s:5:"sorts";a:1:{s:3:"wid";a:10:{s:2:"id";s:3:"wid";s:5:"table";s:8:"watchdog";s:5:"field";s:3:"wid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:8:"standard";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:3:"wid";}s:7:"exposed";b:0;}}s:9:"arguments";a:0:{}s:7:"filters";a:2:{s:4:"type";a:14:{s:2:"id";s:4:"type";s:5:"table";s:8:"watchdog";s:5:"field";s:4:"type";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:11:"dblog_types";s:8:"operator";s:2:"in";s:5:"value";a:0:{}s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:13:{s:11:"operator_id";s:7:"type_op";s:5:"label";s:4:"Type";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:7:"type_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:4:"type";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:1;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}s:8:"severity";a:14:{s:2:"id";s:8:"severity";s:5:"table";s:8:"watchdog";s:5:"field";s:8:"severity";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:11:"in_operator";s:8:"operator";s:2:"in";s:5:"value";a:0:{}s:5:"group";i:1;s:7:"exposed";b:1;s:6:"expose";a:13:{s:11:"operator_id";s:11:"severity_op";s:5:"label";s:8:"Severity";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:11:"severity_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:8:"severity";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:1;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:1;s:3:"AND";}}s:5:"style";a:2:{s:4:"type";s:5:"table";s:7:"options";a:12:{s:8:"grouping";a:0:{}s:9:"row_class";s:25:"{{ type }} {{ severity }}";s:17:"default_row_class";b:1;s:7:"columns";a:8:{s:7:"nothing";s:7:"nothing";s:3:"wid";s:3:"wid";s:8:"severity";s:8:"severity";s:4:"type";s:4:"type";s:9:"timestamp";s:9:"timestamp";s:7:"message";s:7:"message";s:4:"name";s:4:"name";s:4:"link";s:4:"link";}s:7:"default";s:3:"wid";s:4:"info";a:8:{s:7:"nothing";a:4:{s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:15:"priority-medium";}s:3:"wid";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:4:"desc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:8:"severity";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:4:"type";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:15:"priority-medium";}s:9:"timestamp";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:4:"desc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}s:7:"message";a:6:{s:8:"sortable";b:0;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:0:"";}s:4:"name";a:6:{s:8:"sortable";b:1;s:18:"default_sort_order";s:3:"asc";s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:15:"priority-medium";}s:4:"link";a:4:{s:5:"align";s:0:"";s:9:"separator";s:0:"";s:12:"empty_column";b:0;s:10:"responsive";s:12:"priority-low";}}s:8:"override";b:1;s:6:"sticky";b:0;s:7:"summary";s:0:"";s:11:"empty_table";b:0;s:7:"caption";s:0:"";s:11:"description";s:0:"";}}s:3:"row";a:1:{s:4:"type";s:6:"fields";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:1:{s:3:"uid";a:8:{s:2:"id";s:3:"uid";s:5:"table";s:8:"watchdog";s:5:"field";s:3:"uid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:4:"User";s:9:"plugin_id";s:8:"standard";s:8:"required";b:0;}}s:9:"css_class";s:11:"admin-dblog";s:6:"header";a:0:{}s:6:"footer";a:0:{}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:4:"page";a:6:{s:2:"id";s:4:"page";s:13:"display_title";s:4:"Page";s:14:"display_plugin";s:4:"page";s:8:"position";i:1;s:15:"display_options";a:2:{s:17:"display_extenders";a:0:{}s:4:"path";s:19:"admin/reports/dblog";}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:5:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:3:"url";i:3;s:14:"url.query_args";i:4;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}'),
('', 'views.view.who_s_new', 'a:13:{s:4:"uuid";s:36:"dde34907-2247-403d-b942-d12cf6e92231";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"zji0_13MyVGK7Bn1lUMDeZyyOIZedWvqpYUeM_SioPI";}s:2:"id";s:9:"who_s_new";s:5:"label";s:9:"Who''s new";s:6:"module";s:4:"user";s:11:"description";s:53:"Shows a list of the newest user accounts on the site.";s:3:"tag";s:7:"default";s:10:"base_table";s:16:"users_field_data";s:10:"base_field";s:3:"uid";s:7:"display";a:2:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:17:{s:5:"title";s:9:"Who''s new";s:6:"fields";a:1:{s:4:"name";a:25:{s:2:"id";s:4:"name";s:5:"table";s:16:"users_field_data";s:5:"field";s:4:"name";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:4:"name";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:0;s:5:"alter";a:8:{s:10:"alter_text";b:0;s:9:"make_link";b:0;s:8:"absolute";b:0;s:13:"word_boundary";b:0;s:8:"ellipsis";b:0;s:10:"strip_tags";b:0;s:4:"trim";b:0;s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"user_name";}}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:6:"offset";i:0;s:14:"items_per_page";i:5;}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:5:"Apply";s:12:"reset_button";b:0;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:14:"access content";}}s:5:"cache";a:2:{s:4:"type";s:3:"tag";s:7:"options";a:0:{}}s:5:"empty";a:0:{}s:5:"sorts";a:1:{s:7:"created";a:13:{s:2:"id";s:7:"created";s:5:"table";s:16:"users_field_data";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:7:"created";s:9:"plugin_id";s:4:"date";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:7:"created";}s:7:"exposed";b:0;s:11:"granularity";s:6:"second";}}s:9:"arguments";a:0:{}s:7:"filters";a:2:{s:6:"status";a:9:{s:2:"id";s:6:"status";s:5:"table";s:16:"users_field_data";s:5:"field";s:6:"status";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:5:"value";s:1:"1";s:5:"group";i:1;s:6:"expose";a:3:{s:8:"operator";s:1:"0";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}}}s:6:"access";a:16:{s:2:"id";s:6:"access";s:5:"table";s:16:"users_field_data";s:5:"field";s:6:"access";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:6:"access";s:9:"plugin_id";s:4:"date";s:8:"operator";s:1:">";s:5:"value";a:4:{s:3:"min";s:0:"";s:3:"max";s:0:"";s:5:"value";s:10:"1970-01-01";s:4:"type";s:4:"date";}s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:12:{s:11:"operator_id";s:1:"0";s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{s:13:"authenticated";s:13:"authenticated";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:5:"style";a:1:{s:4:"type";s:9:"html_list";}s:3:"row";a:1:{s:4:"type";s:6:"fields";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:0:{}s:6:"header";a:0:{}s:6:"footer";a:0:{}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:3:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:7:"block_1";a:6:{s:2:"id";s:7:"block_1";s:13:"display_title";s:9:"Who''s new";s:14:"display_plugin";s:5:"block";s:8:"position";i:1;s:15:"display_options";a:4:{s:19:"display_description";s:19:"A list of new users";s:17:"display_extenders";a:0:{}s:17:"block_description";s:9:"Who''s new";s:14:"block_category";s:4:"User";}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:3:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}'),
('', 'views.view.who_s_online', 'a:13:{s:4:"uuid";s:36:"5ffca9bd-168c-472c-932d-8b0e34081ac7";s:8:"langcode";s:2:"en";s:6:"status";b:1;s:12:"dependencies";a:1:{s:6:"module";a:1:{i:0;s:4:"user";}}s:5:"_core";a:1:{s:19:"default_config_hash";s:43:"suDsVMgawXoQt4rfmdfpr05EVX3z3KyfDDTYgeSM898";}s:2:"id";s:12:"who_s_online";s:5:"label";s:18:"Who''s online block";s:6:"module";s:4:"user";s:11:"description";s:93:"Shows the user names of the most recently active users, and the total number of active users.";s:3:"tag";s:7:"default";s:10:"base_table";s:16:"users_field_data";s:10:"base_field";s:3:"uid";s:7:"display";a:2:{s:7:"default";a:6:{s:2:"id";s:7:"default";s:13:"display_title";s:7:"Default";s:14:"display_plugin";s:7:"default";s:8:"position";i:0;s:15:"display_options";a:17:{s:5:"title";s:12:"Who''s online";s:6:"fields";a:1:{s:4:"name";a:25:{s:2:"id";s:4:"name";s:5:"table";s:16:"users_field_data";s:5:"field";s:4:"name";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:4:"name";s:9:"plugin_id";s:5:"field";s:5:"label";s:0:"";s:7:"exclude";b:0;s:5:"alter";a:8:{s:10:"alter_text";b:0;s:9:"make_link";b:0;s:8:"absolute";b:0;s:13:"word_boundary";b:0;s:8:"ellipsis";b:0;s:10:"strip_tags";b:0;s:4:"trim";b:0;s:4:"html";b:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:1;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";b:1;s:5:"empty";s:0:"";s:10:"hide_empty";b:0;s:10:"empty_zero";b:0;s:16:"hide_alter_empty";b:1;s:4:"type";s:9:"user_name";}}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:6:"offset";i:0;s:14:"items_per_page";i:10;}}s:12:"exposed_form";a:2:{s:4:"type";s:5:"basic";s:7:"options";a:7:{s:13:"submit_button";s:5:"Apply";s:12:"reset_button";b:0;s:18:"reset_button_label";s:5:"Reset";s:19:"exposed_sorts_label";s:7:"Sort by";s:17:"expose_sort_order";b:1;s:14:"sort_asc_label";s:3:"Asc";s:15:"sort_desc_label";s:4:"Desc";}}s:6:"access";a:2:{s:4:"type";s:4:"perm";s:7:"options";a:1:{s:4:"perm";s:20:"access user profiles";}}s:5:"cache";a:2:{s:4:"type";s:3:"tag";s:7:"options";a:0:{}}s:5:"empty";a:1:{s:16:"area_text_custom";a:10:{s:2:"id";s:16:"area_text_custom";s:5:"table";s:5:"views";s:5:"field";s:16:"area_text_custom";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:11:"text_custom";s:5:"empty";b:1;s:7:"content";s:35:"There are currently 0 users online.";s:8:"tokenize";b:0;}}s:5:"sorts";a:1:{s:6:"access";a:13:{s:2:"id";s:6:"access";s:5:"table";s:16:"users_field_data";s:5:"field";s:6:"access";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:6:"access";s:9:"plugin_id";s:4:"date";s:5:"order";s:4:"DESC";s:6:"expose";a:2:{s:5:"label";s:0:"";s:16:"field_identifier";s:6:"access";}s:7:"exposed";b:0;s:11:"granularity";s:6:"second";}}s:9:"arguments";a:0:{}s:7:"filters";a:2:{s:6:"status";a:9:{s:2:"id";s:6:"status";s:5:"table";s:16:"users_field_data";s:5:"field";s:6:"status";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:6:"status";s:9:"plugin_id";s:7:"boolean";s:5:"value";s:1:"1";s:5:"group";i:1;s:6:"expose";a:3:{s:8:"operator";s:1:"0";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}}}s:6:"access";a:16:{s:2:"id";s:6:"access";s:5:"table";s:16:"users_field_data";s:5:"field";s:6:"access";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:11:"entity_type";s:4:"user";s:12:"entity_field";s:6:"access";s:9:"plugin_id";s:4:"date";s:8:"operator";s:2:">=";s:5:"value";a:4:{s:3:"min";s:0:"";s:3:"max";s:0:"";s:5:"value";s:11:"-15 minutes";s:4:"type";s:6:"offset";}s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:12:{s:11:"operator_id";s:9:"access_op";s:5:"label";s:11:"Last access";s:11:"description";s:77:"A user is considered online for this long after they have last viewed a page.";s:12:"use_operator";b:0;s:8:"operator";s:9:"access_op";s:24:"operator_limit_selection";b:0;s:13:"operator_list";a:0:{}s:10:"identifier";s:6:"access";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:3:{s:13:"authenticated";s:13:"authenticated";s:9:"anonymous";s:1:"0";s:13:"administrator";s:1:"0";}}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";b:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}}}s:5:"style";a:2:{s:4:"type";s:9:"html_list";s:7:"options";a:6:{s:8:"grouping";a:0:{}s:9:"row_class";s:0:"";s:17:"default_row_class";b:1;s:4:"type";s:2:"ul";s:13:"wrapper_class";s:9:"item-list";s:5:"class";s:0:"";}}s:3:"row";a:1:{s:4:"type";s:6:"fields";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:5:{s:13:"query_comment";s:0:"";s:19:"disable_sql_rewrite";b:0;s:8:"distinct";b:0;s:7:"replica";b:0;s:10:"query_tags";a:0:{}}}s:13:"relationships";a:0:{}s:6:"header";a:1:{s:6:"result";a:9:{s:2:"id";s:6:"result";s:5:"table";s:5:"views";s:5:"field";s:6:"result";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:11:"admin_label";s:0:"";s:9:"plugin_id";s:6:"result";s:5:"empty";b:0;s:7:"content";s:40:"There are currently @total users online.";}}s:6:"footer";a:0:{}s:17:"display_extenders";a:0:{}}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:3:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:16:"user.permissions";}s:4:"tags";a:0:{}}}s:18:"who_s_online_block";a:6:{s:2:"id";s:18:"who_s_online_block";s:13:"display_title";s:12:"Who''s online";s:14:"display_plugin";s:5:"block";s:8:"position";i:1;s:15:"display_options";a:3:{s:19:"display_description";s:45:"A list of users that are currently logged in.";s:17:"display_extenders";a:0:{}s:17:"block_description";s:12:"Who''s online";}s:14:"cache_metadata";a:3:{s:7:"max-age";i:-1;s:8:"contexts";a:3:{i:0;s:26:"languages:language_content";i:1;s:28:"languages:language_interface";i:2;s:16:"user.permissions";}s:4:"tags";a:0:{}}}}}');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]file_managed`
--

CREATE TABLE `[[dbprefix]]file_managed` (
  `fid` int unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `filename` varchar(255) DEFAULT NULL,
  `uri` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  `filemime` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `filesize` bigint unsigned DEFAULT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `changed` int NOT NULL,
  PRIMARY KEY (`fid`),
  UNIQUE KEY `file_field__uuid__value` (`uuid`),
  KEY `file_field__uid__target_id` (`uid`),
  KEY `file_field__uri` (`uri`(191)),
  KEY `file_field__status` (`status`),
  KEY `file_field__changed` (`changed`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The base table for file entities.' AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]file_usage`
--

CREATE TABLE `[[dbprefix]]file_usage` (
  `fid` int unsigned NOT NULL COMMENT 'File ID.',
  `module` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the module that is using the file.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the object type in which the file is used.',
  `id` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '0' COMMENT 'The primary key of the object using the file.',
  `count` int unsigned NOT NULL DEFAULT '0' COMMENT 'The number of times this file is used by this object.',
  PRIMARY KEY (`fid`,`type`,`id`,`module`),
  KEY `type_id` (`type`,`id`),
  KEY `fid_count` (`fid`,`count`),
  KEY `fid_module` (`fid`,`module`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Track where a file is used.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]help_search_items`
--

CREATE TABLE `[[dbprefix]]help_search_items` (
  `sid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Numeric index of this item in the search index',
  `section_plugin_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The help section the item comes from',
  `permission` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The permission needed to view this item',
  `topic_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The topic ID of the item',
  PRIMARY KEY (`sid`),
  KEY `section_plugin_id` (`section_plugin_id`),
  KEY `topic_id` (`topic_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COMMENT='Stores information about indexed help search items' AUTO_INCREMENT=86 ;

--
-- Dumping data for table `[[dbprefix]]help_search_items`
--

INSERT INTO `[[dbprefix]]help_search_items` VALUES
(1, 'help_topics', '', 'config.export_full'),
(2, 'help_topics', '', 'config.export_single'),
(3, 'help_topics', '', 'config.import_full'),
(4, 'help_topics', '', 'config.import_single'),
(5, 'help_topics', '', 'contact.adding_fields'),
(6, 'help_topics', '', 'contact.configuring_personal'),
(7, 'help_topics', '', 'contact.creating'),
(8, 'help_topics', '', 'contact.overview'),
(9, 'help_topics', '', 'contact.setting_default'),
(10, 'help_topics', '', 'core.appearance'),
(11, 'help_topics', '', 'core.config_overview'),
(12, 'help_topics', '', 'core.content_structure'),
(13, 'help_topics', '', 'core.cron'),
(14, 'help_topics', '', 'core.extending'),
(15, 'help_topics', '', 'core.maintenance'),
(16, 'help_topics', '', 'core.media'),
(17, 'help_topics', '', 'core.menus'),
(18, 'help_topics', '', 'core.performance'),
(19, 'help_topics', '', 'core.security'),
(20, 'help_topics', '', 'core.settings_tray'),
(21, 'help_topics', '', 'core.tracking_content'),
(22, 'help_topics', '', 'core.translations'),
(23, 'help_topics', '', 'core.ui_accessibility'),
(24, 'help_topics', '', 'core.ui_components'),
(25, 'help_topics', '', 'core.web_services'),
(26, 'help_topics', '', 'help.help_topic_search'),
(27, 'help_topics', '', 'help.overview'),
(28, 'help_topics', '', 'search.configuring'),
(29, 'help_topics', '', 'search.index'),
(30, 'help_topics', '', 'search.overview'),
(31, 'help_topics', '', 'system.cache'),
(32, 'help_topics', '', 'system.config_basic'),
(33, 'help_topics', '', 'system.config_error'),
(34, 'help_topics', '', 'system.maintenance_mode'),
(35, 'help_topics', '', 'system.module_install'),
(36, 'help_topics', '', 'system.module_uninstall'),
(37, 'help_topics', '', 'system.reports'),
(38, 'help_topics', '', 'system.theme_install'),
(39, 'help_topics', '', 'system.theme_uninstall'),
(40, 'help_topics', '', 'user.create'),
(41, 'help_topics', '', 'user.new_role'),
(42, 'help_topics', '', 'user.overview'),
(43, 'help_topics', '', 'user.permissions'),
(44, 'help_topics', '', 'user.security_account_settings'),
(45, 'help_topics', '', 'user.update'),
(46, 'help_topics', '', 'announcements_feed.overview'),
(47, 'help_topics', '', 'block.configure'),
(48, 'help_topics', '', 'block.overview'),
(49, 'help_topics', '', 'block.place'),
(50, 'help_topics', '', 'filter.overview'),
(51, 'help_topics', '', 'block_content.add'),
(52, 'help_topics', '', 'block_content.type'),
(53, 'help_topics', '', 'breakpoint.overview'),
(54, 'help_topics', '', 'editor.overview'),
(55, 'help_topics', '', 'comment.configuring'),
(56, 'help_topics', '', 'comment.creating_type'),
(57, 'help_topics', '', 'comment.disabling'),
(58, 'help_topics', '', 'comment.moderating'),
(59, 'help_topics', '', 'comment.overview'),
(60, 'help_topics', '', 'contextual.overview'),
(61, 'help_topics', '', 'field_ui.add_field'),
(62, 'help_topics', '', 'field_ui.manage_display'),
(63, 'help_topics', '', 'field_ui.manage_form'),
(64, 'help_topics', '', 'field_ui.reference_field'),
(65, 'help_topics', '', 'node.creating_content'),
(66, 'help_topics', '', 'node.creating_type'),
(67, 'help_topics', '', 'node.editing'),
(68, 'help_topics', '', 'node.overview'),
(69, 'help_topics', '', 'history.tracking_user_content'),
(70, 'help_topics', '', 'image.style'),
(71, 'help_topics', '', 'views.overview'),
(72, 'help_topics', '', 'menu_ui.content_type_configuration'),
(73, 'help_topics', '', 'menu_ui.menu_item_add'),
(74, 'help_topics', '', 'menu_ui.menu_operations'),
(75, 'help_topics', '', 'menu_ui.overriding'),
(76, 'help_topics', '', 'path.creating_alias'),
(77, 'help_topics', '', 'path.editing_alias'),
(78, 'help_topics', '', 'path.overview'),
(79, 'help_topics', '', 'shortcut.overview'),
(80, 'help_topics', '', 'taxonomy.configuring'),
(81, 'help_topics', '', 'taxonomy.overview'),
(82, 'help_topics', '', 'views_ui.add_display'),
(83, 'help_topics', '', 'views_ui.bulk_operations'),
(84, 'help_topics', '', 'views_ui.create'),
(85, 'help_topics', '', 'views_ui.edit');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]history`
--

CREATE TABLE `[[dbprefix]]history` (
  `uid` int NOT NULL DEFAULT '0' COMMENT 'The "[[dbprefix]]users".uid that read the "[[dbprefix]]node" nid.',
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "[[dbprefix]]node".nid that was read.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp at which the read occurred.',
  PRIMARY KEY (`uid`,`nid`),
  KEY `nid` (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='A record of which "[[dbprefix]]users" have read which "[[dbprefix]]node…';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]key_value`
--

CREATE TABLE `[[dbprefix]]key_value` (
  `collection` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A named collection of key and value pairs.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The key of the key-value pair. As KEY is a SQL reserved keyword, name was chosen instead.',
  `value` longblob NOT NULL COMMENT 'The value.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Generic key-value storage table. See the state system for…';

--
-- Dumping data for table `[[dbprefix]]key_value`
--

INSERT INTO `[[dbprefix]]key_value` VALUES
('config.entity.key_store.action', 'uuid:185dac4e-65cc-4ebc-9b72-fecea81b7447', 'a:1:{i:0;s:42:"system.action.taxonomy_term_publish_action";}'),
('config.entity.key_store.action', 'uuid:252809a9-7844-4a72-bb02-8766aa53e8f0', 'a:1:{i:0;s:49:"system.action.user_add_role_action.content_editor";}'),
('config.entity.key_store.action', 'uuid:44fd7ebc-0c6c-4403-b2c9-5198940c80f2', 'a:1:{i:0;s:37:"system.action.node_make_sticky_action";}'),
('config.entity.key_store.action', 'uuid:604609d8-ec4c-4e56-96b0-7c588d0fd294', 'a:1:{i:0;s:36:"system.action.user_block_user_action";}'),
('config.entity.key_store.action', 'uuid:6796d819-0b36-46f0-a1a6-25ca87ac42f5', 'a:1:{i:0;s:32:"system.action.node_delete_action";}'),
('config.entity.key_store.action', 'uuid:6921cc0b-5cdb-4f4e-bc3c-0e92be8e7e4d', 'a:1:{i:0;s:51:"system.action.user_remove_role_action.administrator";}'),
('config.entity.key_store.action', 'uuid:72abe7b6-a935-4bf6-a823-2f9e63657a9b', 'a:1:{i:0;s:37:"system.action.user_cancel_user_action";}'),
('config.entity.key_store.action', 'uuid:7611458e-aaff-4499-911d-c951fbf6c97d', 'a:1:{i:0;s:44:"system.action.taxonomy_term_unpublish_action";}'),
('config.entity.key_store.action', 'uuid:763fa5d1-021b-42ca-8166-6754bcae6d68', 'a:1:{i:0;s:48:"system.action.user_add_role_action.administrator";}'),
('config.entity.key_store.action', 'uuid:891ae484-6a65-41d3-a061-c1de60d2ca51', 'a:1:{i:0;s:38:"system.action.comment_unpublish_action";}'),
('config.entity.key_store.action', 'uuid:947b8d1c-b1d7-41b6-9926-b6d3f3fffba1', 'a:1:{i:0;s:39:"system.action.node_make_unsticky_action";}'),
('config.entity.key_store.action', 'uuid:9576c5af-0977-46e0-9278-2130c407aa5e', 'a:1:{i:0;s:35:"system.action.node_unpublish_action";}'),
('config.entity.key_store.action', 'uuid:a15f3224-f521-4f70-85b7-7bd74477a229', 'a:1:{i:0;s:30:"system.action.node_save_action";}'),
('config.entity.key_store.action', 'uuid:a3072b0e-5e7b-4939-acd7-6ea93d4c6343', 'a:1:{i:0;s:33:"system.action.node_promote_action";}'),
('config.entity.key_store.action', 'uuid:c0884e7c-2f3b-4c1e-afcc-340ddc314022', 'a:1:{i:0;s:33:"system.action.node_publish_action";}'),
('config.entity.key_store.action', 'uuid:c34ff704-ae20-4fd1-95dd-7cd9814400bf', 'a:1:{i:0;s:35:"system.action.node_unpromote_action";}'),
('config.entity.key_store.action', 'uuid:c866e7f5-fdd4-453a-9d4e-10b8f07604d7', 'a:1:{i:0;s:33:"system.action.comment_save_action";}'),
('config.entity.key_store.action', 'uuid:d4a82d44-3643-4e78-82dd-9fdc6c117f5d', 'a:1:{i:0;s:52:"system.action.user_remove_role_action.content_editor";}'),
('config.entity.key_store.action', 'uuid:ea263e3e-9392-4d9c-b5d6-020de34b7b44', 'a:1:{i:0;s:38:"system.action.user_unblock_user_action";}'),
('config.entity.key_store.action', 'uuid:ee170ca8-05e4-4c9e-acce-fb79e6655f9c', 'a:1:{i:0;s:36:"system.action.comment_publish_action";}'),
('config.entity.key_store.action', 'uuid:f4e9fbbc-4215-46b3-a9f8-4a1ab1e6259e', 'a:1:{i:0;s:35:"system.action.comment_delete_action";}'),
('config.entity.key_store.base_field_override', 'uuid:9a0a8f27-e940-43fe-a940-ed0f985924cf', 'a:1:{i:0;s:42:"core.base_field_override.node.page.promote";}'),
('config.entity.key_store.block', 'theme:claro', 'a:9:{i:0;s:31:"block.block.claro_local_actions";i:1;s:28:"block.block.claro_page_title";i:2;s:37:"block.block.claro_primary_local_tasks";i:3;s:39:"block.block.claro_secondary_local_tasks";i:4;s:22:"block.block.claro_help";i:5;s:29:"block.block.claro_help_search";i:6;s:29:"block.block.claro_breadcrumbs";i:7;s:25:"block.block.claro_content";i:8;s:26:"block.block.claro_messages";}'),
('config.entity.key_store.block', 'theme:olivero', 'a:15:{i:0;s:24:"block.block.olivero_help";i:1;s:30:"block.block.olivero_page_title";i:2;s:41:"block.block.olivero_primary_admin_actions";i:3;s:39:"block.block.olivero_primary_local_tasks";i:4;s:41:"block.block.olivero_secondary_local_tasks";i:5;s:29:"block.block.olivero_syndicate";i:6;s:38:"block.block.olivero_search_form_narrow";i:7;s:36:"block.block.olivero_search_form_wide";i:8;s:31:"block.block.olivero_breadcrumbs";i:9;s:27:"block.block.olivero_content";i:10;s:28:"block.block.olivero_messages";i:11;s:27:"block.block.olivero_powered";i:12;s:33:"block.block.olivero_site_branding";i:13;s:32:"block.block.olivero_account_menu";i:14;s:29:"block.block.olivero_main_menu";}'),
('config.entity.key_store.block', 'uuid:05dad6b8-2007-4914-9f28-09f909d4c797', 'a:1:{i:0;s:26:"block.block.claro_messages";}'),
('config.entity.key_store.block', 'uuid:06cef69f-00dc-4a06-a6eb-5f79ae63c06e', 'a:1:{i:0;s:31:"block.block.olivero_breadcrumbs";}'),
('config.entity.key_store.block', 'uuid:14923216-919d-4ec9-ab04-fffb90b233e9', 'a:1:{i:0;s:27:"block.block.olivero_content";}'),
('config.entity.key_store.block', 'uuid:247f58ed-7454-425c-9dbb-6d7bc53b7b68', 'a:1:{i:0;s:27:"block.block.olivero_powered";}'),
('config.entity.key_store.block', 'uuid:2c9e0d19-49d2-4b4e-a179-c386470bda58', 'a:1:{i:0;s:29:"block.block.olivero_main_menu";}'),
('config.entity.key_store.block', 'uuid:2f3d3006-55c0-41bd-8d90-50b965d32756', 'a:1:{i:0;s:22:"block.block.claro_help";}'),
('config.entity.key_store.block', 'uuid:303d9913-97fc-402d-a3dc-88b1fcd6dde9', 'a:1:{i:0;s:29:"block.block.claro_breadcrumbs";}'),
('config.entity.key_store.block', 'uuid:36af0246-a6f8-4b6f-91e8-fa9e05fd69ac', 'a:1:{i:0;s:32:"block.block.olivero_account_menu";}'),
('config.entity.key_store.block', 'uuid:4608a49e-d742-43b3-bdf0-19564706be05', 'a:1:{i:0;s:41:"block.block.olivero_secondary_local_tasks";}'),
('config.entity.key_store.block', 'uuid:46636a48-9c80-4e79-9036-e0097a006aed', 'a:1:{i:0;s:37:"block.block.claro_primary_local_tasks";}'),
('config.entity.key_store.block', 'uuid:5cb78c6b-d165-4e4f-8a5f-90070bb1359e', 'a:1:{i:0;s:33:"block.block.olivero_site_branding";}'),
('config.entity.key_store.block', 'uuid:63bdc52f-5e57-42a7-8f92-7d760792086c', 'a:1:{i:0;s:24:"block.block.olivero_help";}'),
('config.entity.key_store.block', 'uuid:6466c4e0-5d42-4bc4-9671-569dbf4b60d8', 'a:1:{i:0;s:28:"block.block.claro_page_title";}'),
('config.entity.key_store.block', 'uuid:6bef9a54-1d94-4340-a3d1-cb5f35b3e061', 'a:1:{i:0;s:29:"block.block.claro_help_search";}'),
('config.entity.key_store.block', 'uuid:7843ce95-19a0-41bd-80f4-2cca6dc7f5b6', 'a:1:{i:0;s:41:"block.block.olivero_primary_admin_actions";}'),
('config.entity.key_store.block', 'uuid:7f713f72-12ea-4661-bfc3-cdcb88686ef4', 'a:1:{i:0;s:39:"block.block.olivero_primary_local_tasks";}'),
('config.entity.key_store.block', 'uuid:929a4472-d1e7-4dde-bec0-8738e80e2ad6', 'a:1:{i:0;s:30:"block.block.olivero_page_title";}'),
('config.entity.key_store.block', 'uuid:ac40eed0-a7f4-45d8-90b4-485c237ec255', 'a:1:{i:0;s:36:"block.block.olivero_search_form_wide";}'),
('config.entity.key_store.block', 'uuid:b4ae1d15-1adb-4ec4-9b07-f0c33294df85', 'a:1:{i:0;s:31:"block.block.claro_local_actions";}'),
('config.entity.key_store.block', 'uuid:c8c70524-3fc0-41eb-8f1c-cd6baee9e745', 'a:1:{i:0;s:38:"block.block.olivero_search_form_narrow";}'),
('config.entity.key_store.block', 'uuid:d3769e61-82ac-48ed-a7b7-82667768846a', 'a:1:{i:0;s:25:"block.block.claro_content";}'),
('config.entity.key_store.block', 'uuid:d3efc778-f391-4111-b150-4e5f8f4405bf', 'a:1:{i:0;s:29:"block.block.olivero_syndicate";}'),
('config.entity.key_store.block', 'uuid:e257b9fc-cd97-428e-aa25-db965faf5f51', 'a:1:{i:0;s:39:"block.block.claro_secondary_local_tasks";}'),
('config.entity.key_store.block', 'uuid:f6d3456b-668d-4f76-a737-c0d40d47b7d4', 'a:1:{i:0;s:28:"block.block.olivero_messages";}'),
('config.entity.key_store.block_content_type', 'uuid:7a717b00-8ba3-4dd8-881c-747a8a230a50', 'a:1:{i:0;s:24:"block_content.type.basic";}'),
('config.entity.key_store.comment_type', 'uuid:0c9a00bd-c8de-4cd5-93fe-7d5809edfb5c', 'a:1:{i:0;s:20:"comment.type.comment";}'),
('config.entity.key_store.contact_form', 'uuid:8894f18a-a90f-41a7-806f-e4cf3038e7e0', 'a:1:{i:0;s:21:"contact.form.feedback";}'),
('config.entity.key_store.contact_form', 'uuid:fb580b41-ff44-4496-943a-f2858cfb9708', 'a:1:{i:0;s:21:"contact.form.personal";}'),
('config.entity.key_store.date_format', 'uuid:08dfa482-4a6e-4f85-a9ce-a1f2e69fcf98', 'a:1:{i:0;s:22:"core.date_format.short";}'),
('config.entity.key_store.date_format', 'uuid:14b69244-ffec-4dbb-a37a-650eb8fef1c0', 'a:1:{i:0;s:26:"core.date_format.html_date";}'),
('config.entity.key_store.date_format', 'uuid:1a1d6ac2-3239-4f41-ba13-d502c64c6cbc', 'a:1:{i:0;s:27:"core.date_format.html_month";}'),
('config.entity.key_store.date_format', 'uuid:3d404085-7c28-42b0-8cd2-bad13eadeb94', 'a:1:{i:0;s:26:"core.date_format.html_time";}'),
('config.entity.key_store.date_format', 'uuid:69881563-98cb-4f9d-baad-50f645b81d18', 'a:1:{i:0;s:25:"core.date_format.fallback";}'),
('config.entity.key_store.date_format', 'uuid:976ef5de-de0f-4a83-861e-4441b90732c5', 'a:1:{i:0;s:31:"core.date_format.olivero_medium";}'),
('config.entity.key_store.date_format', 'uuid:b65a0c7a-bda0-4dc4-b329-8d78d46fddf8', 'a:1:{i:0;s:26:"core.date_format.html_week";}'),
('config.entity.key_store.date_format', 'uuid:c8dc50e2-9daf-4ee7-8f00-b489c001583b', 'a:1:{i:0;s:23:"core.date_format.medium";}'),
('config.entity.key_store.date_format', 'uuid:cbbca4c4-74d0-41b9-8835-a3ebed5199c8', 'a:1:{i:0;s:35:"core.date_format.html_yearless_date";}'),
('config.entity.key_store.date_format', 'uuid:cc1b05ca-6d1f-4ed2-a51e-3b644676fad0', 'a:1:{i:0;s:30:"core.date_format.html_datetime";}'),
('config.entity.key_store.date_format', 'uuid:d0292129-252a-453c-b925-e331e6c742a8', 'a:1:{i:0;s:21:"core.date_format.long";}'),
('config.entity.key_store.date_format', 'uuid:d2c8ba26-18bc-4d59-8bae-e17abe4fc226', 'a:1:{i:0;s:26:"core.date_format.html_year";}'),
('config.entity.key_store.editor', 'uuid:2067e04f-0094-4ea7-94f0-11056c835b43', 'a:1:{i:0;s:24:"editor.editor.basic_html";}'),
('config.entity.key_store.editor', 'uuid:baf2a3c0-0038-45f8-917c-7f737e630c96', 'a:1:{i:0;s:23:"editor.editor.full_html";}'),
('config.entity.key_store.entity_form_display', 'uuid:1797bfec-e120-4911-b079-026c9a764a1e', 'a:1:{i:0;s:45:"core.entity_form_display.node.article.default";}'),
('config.entity.key_store.entity_form_display', 'uuid:82a67875-24fb-437a-8d8f-6b0f40f699b6', 'a:1:{i:0;s:48:"core.entity_form_display.comment.comment.default";}'),
('config.entity.key_store.entity_form_display', 'uuid:dcb997d7-8084-47b2-90ea-c8a684d9a98d', 'a:1:{i:0;s:52:"core.entity_form_display.block_content.basic.default";}'),
('config.entity.key_store.entity_form_display', 'uuid:ec3461fd-45fb-4c9a-b85d-757e33f73ede', 'a:1:{i:0;s:42:"core.entity_form_display.user.user.default";}'),
('config.entity.key_store.entity_form_display', 'uuid:ffc56d8a-983b-4c39-a402-9be9dd3e29a5', 'a:1:{i:0;s:42:"core.entity_form_display.node.page.default";}'),
('config.entity.key_store.entity_form_mode', 'uuid:9cb89199-0eb6-42fb-9fc2-6d6b3320610a', 'a:1:{i:0;s:35:"core.entity_form_mode.user.register";}'),
('config.entity.key_store.entity_view_display', 'uuid:3a2f70f6-695e-4b69-9f32-19422a28951c', 'a:1:{i:0;s:45:"core.entity_view_display.node.article.default";}'),
('config.entity.key_store.entity_view_display', 'uuid:8b6e095a-16df-4934-a17a-db7eb1d28867', 'a:1:{i:0;s:42:"core.entity_view_display.node.page.default";}'),
('config.entity.key_store.entity_view_display', 'uuid:970b5c1c-ae15-4a2a-a6ed-efbc270b7fdc', 'a:1:{i:0;s:42:"core.entity_view_display.user.user.default";}'),
('config.entity.key_store.entity_view_display', 'uuid:9fb143d8-b81d-4e70-aea9-25049f54cea7', 'a:1:{i:0;s:41:"core.entity_view_display.node.article.rss";}'),
('config.entity.key_store.entity_view_display', 'uuid:da2af7c6-e616-4175-9760-2ea5e31b959b', 'a:1:{i:0;s:48:"core.entity_view_display.comment.comment.default";}'),
('config.entity.key_store.entity_view_display', 'uuid:e5897eaf-2da1-48b3-813e-98b2dbdb06c9', 'a:1:{i:0;s:44:"core.entity_view_display.node.article.teaser";}'),
('config.entity.key_store.entity_view_display', 'uuid:eaccd6e8-0b9f-415f-ab39-2470fdbabb15', 'a:1:{i:0;s:52:"core.entity_view_display.block_content.basic.default";}'),
('config.entity.key_store.entity_view_display', 'uuid:ec4a784c-74c3-41e2-a937-6888f3512a35', 'a:1:{i:0;s:41:"core.entity_view_display.node.page.teaser";}'),
('config.entity.key_store.entity_view_display', 'uuid:fdda2e97-d213-4a8d-b380-ced42df80ba4', 'a:1:{i:0;s:42:"core.entity_view_display.user.user.compact";}'),
('config.entity.key_store.entity_view_mode', 'uuid:19cfcd88-2c67-433b-a179-10fd6337c176', 'a:1:{i:0;s:33:"core.entity_view_mode.node.teaser";}'),
('config.entity.key_store.entity_view_mode', 'uuid:326c1f72-87f3-40cb-9a0c-3811aba557c6', 'a:1:{i:0;s:40:"core.entity_view_mode.node.search_result";}'),
('config.entity.key_store.entity_view_mode', 'uuid:4f2b3a08-517f-49ca-8ceb-3be1027509c6', 'a:1:{i:0;s:31:"core.entity_view_mode.user.full";}'),
('config.entity.key_store.entity_view_mode', 'uuid:60d5f0c0-5347-400c-a767-0befdaf74db3', 'a:1:{i:0;s:40:"core.entity_view_mode.block_content.full";}'),
('config.entity.key_store.entity_view_mode', 'uuid:669b65ea-e626-4a86-acef-aacb5d947b59', 'a:1:{i:0;s:34:"core.entity_view_mode.comment.full";}'),
('config.entity.key_store.entity_view_mode', 'uuid:76728183-3321-4875-988e-b69488fc0bc6', 'a:1:{i:0;s:31:"core.entity_view_mode.node.full";}'),
('config.entity.key_store.entity_view_mode', 'uuid:9ccca42e-72b9-4b63-9367-cc677075973d', 'a:1:{i:0;s:39:"core.entity_view_mode.node.search_index";}'),
('config.entity.key_store.entity_view_mode', 'uuid:a0ab9a4b-b6ae-4cf6-8fd1-6fa61bb9d929', 'a:1:{i:0;s:30:"core.entity_view_mode.node.rss";}'),
('config.entity.key_store.entity_view_mode', 'uuid:ba9b1777-193d-45b3-9fb3-2be0a3c5154b', 'a:1:{i:0;s:34:"core.entity_view_mode.user.compact";}'),
('config.entity.key_store.entity_view_mode', 'uuid:bbbcd2dd-4ae1-41fa-a3fb-6e87c20e3a6b', 'a:1:{i:0;s:40:"core.entity_view_mode.taxonomy_term.full";}'),
('config.entity.key_store.field_config', 'uuid:05ad2534-241a-4ed6-871e-799464d991a4', 'a:1:{i:0;s:29:"field.field.node.article.body";}'),
('config.entity.key_store.field_config', 'uuid:2f5a24cf-d040-4a30-8225-7c2e0c09080d', 'a:1:{i:0;s:34:"field.field.user.user.user_picture";}'),
('config.entity.key_store.field_config', 'uuid:314bb960-496c-42a5-99f3-2c20e83fc553', 'a:1:{i:0;s:26:"field.field.node.page.body";}'),
('config.entity.key_store.field_config', 'uuid:83b38220-7cae-4156-b1ab-f26c109f7c53', 'a:1:{i:0;s:32:"field.field.node.article.comment";}'),
('config.entity.key_store.field_config', 'uuid:98d032c0-0cac-41e6-8d55-48d1dfcb4909', 'a:1:{i:0;s:35:"field.field.node.article.field_tags";}'),
('config.entity.key_store.field_config', 'uuid:a1a3e111-c95e-4500-ba43-64c27f84f863', 'a:1:{i:0;s:40:"field.field.comment.comment.comment_body";}'),
('config.entity.key_store.field_config', 'uuid:b20166b5-ed72-45b0-8551-7219b8ae98c5', 'a:1:{i:0;s:36:"field.field.block_content.basic.body";}'),
('config.entity.key_store.field_config', 'uuid:c3539d99-630b-4b4d-b07a-61515727a187', 'a:1:{i:0;s:36:"field.field.node.article.field_image";}'),
('config.entity.key_store.field_storage_config', 'uuid:2b96be3b-b152-45c3-b641-eb7aa053b6aa', 'a:1:{i:0;s:29:"field.storage.node.field_tags";}'),
('config.entity.key_store.field_storage_config', 'uuid:4197b587-d8c1-48a4-832c-ffa48b177a67', 'a:1:{i:0;s:30:"field.storage.node.field_image";}'),
('config.entity.key_store.field_storage_config', 'uuid:71f98988-aa58-42f6-b766-9d7a71cb01d9', 'a:1:{i:0;s:32:"field.storage.block_content.body";}'),
('config.entity.key_store.field_storage_config', 'uuid:a16c5662-b6e3-442f-b490-f840f6c7f095', 'a:1:{i:0;s:26:"field.storage.node.comment";}'),
('config.entity.key_store.field_storage_config', 'uuid:aa3202fe-45b4-46af-99eb-a871cb54985b', 'a:1:{i:0;s:34:"field.storage.comment.comment_body";}'),
('config.entity.key_store.field_storage_config', 'uuid:ba3d61d8-4eb7-46de-ba22-28dcaaa22262', 'a:1:{i:0;s:31:"field.storage.user.user_picture";}'),
('config.entity.key_store.field_storage_config', 'uuid:d8f860c7-f93a-446c-bdce-18ff53e81cc9', 'a:1:{i:0;s:23:"field.storage.node.body";}'),
('config.entity.key_store.filter_format', 'uuid:3fb39974-c855-4bd7-8483-2fd31beedc6f', 'a:1:{i:0;s:23:"filter.format.full_html";}'),
('config.entity.key_store.filter_format', 'uuid:aebc09f6-c5b1-47a2-ba77-3057d5a5e38f', 'a:1:{i:0;s:29:"filter.format.restricted_html";}'),
('config.entity.key_store.filter_format', 'uuid:af4426ab-3b1f-4061-ac02-13abf9672aab', 'a:1:{i:0;s:24:"filter.format.plain_text";}'),
('config.entity.key_store.filter_format', 'uuid:efbbd834-71f0-410e-a7c1-16e22df1b8fb', 'a:1:{i:0;s:24:"filter.format.basic_html";}'),
('config.entity.key_store.image_style', 'uuid:1845b698-fff3-4a4f-8dd2-9928c638e925', 'a:1:{i:0;s:18:"image.style.medium";}'),
('config.entity.key_store.image_style', 'uuid:8c9d250b-f29b-4112-9ec0-2921ae917d3d', 'a:1:{i:0;s:21:"image.style.thumbnail";}'),
('config.entity.key_store.image_style', 'uuid:9dd42401-666c-44a4-b7bb-30fba679cf4d', 'a:1:{i:0;s:17:"image.style.large";}'),
('config.entity.key_store.image_style', 'uuid:d3f45111-f962-462a-b272-e1fe0d5c0a98', 'a:1:{i:0;s:16:"image.style.wide";}'),
('config.entity.key_store.menu', 'uuid:07bdd5ba-df13-4567-ba56-32d965725304', 'a:1:{i:0;s:19:"system.menu.account";}'),
('config.entity.key_store.menu', 'uuid:6d470c5b-07cd-4125-88a9-90be9b25a2a4', 'a:1:{i:0;s:17:"system.menu.tools";}'),
('config.entity.key_store.menu', 'uuid:80fc3a59-58ad-4c77-b4fb-3017ec6a534e', 'a:1:{i:0;s:17:"system.menu.admin";}'),
('config.entity.key_store.menu', 'uuid:94e9f4d5-90f5-4917-9663-996774e659d5', 'a:1:{i:0;s:16:"system.menu.main";}'),
('config.entity.key_store.menu', 'uuid:f102c3e3-f44a-4e11-94bd-fc8998e4cea2', 'a:1:{i:0;s:18:"system.menu.footer";}'),
('config.entity.key_store.node_type', 'uuid:39c96fb8-f8a0-4092-943f-fc3b72331c9f', 'a:1:{i:0;s:14:"node.type.page";}'),
('config.entity.key_store.node_type', 'uuid:3ee06044-7dde-40ec-b915-d970a4686cab', 'a:1:{i:0;s:17:"node.type.article";}'),
('config.entity.key_store.search_page', 'uuid:28698998-9349-41ff-aa07-85677d583124', 'a:1:{i:0;s:23:"search.page.help_search";}'),
('config.entity.key_store.search_page', 'uuid:72d55c92-3be9-4368-bf45-d3ff7ee01051', 'a:1:{i:0;s:23:"search.page.user_search";}'),
('config.entity.key_store.search_page', 'uuid:82a27bc3-9284-4a81-974f-71ad5b5ce51c', 'a:1:{i:0;s:23:"search.page.node_search";}'),
('config.entity.key_store.shortcut_set', 'uuid:55b875ef-d9ad-4f74-bbf9-2f3803cda8bb', 'a:1:{i:0;s:20:"shortcut.set.default";}'),
('config.entity.key_store.taxonomy_vocabulary', 'uuid:ccce2ae7-b7bc-439f-acb3-b1ca27be0322', 'a:1:{i:0;s:24:"taxonomy.vocabulary.tags";}'),
('config.entity.key_store.user_role', 'uuid:3ab79215-d614-42bc-a0d0-ef8cb3134ec3', 'a:1:{i:0;s:24:"user.role.content_editor";}'),
('config.entity.key_store.user_role', 'uuid:614e22bb-70ca-4525-8752-985223631575', 'a:1:{i:0;s:23:"user.role.administrator";}'),
('config.entity.key_store.user_role', 'uuid:ac57508d-539d-40f0-a137-7dcd49ca6d4c', 'a:1:{i:0;s:19:"user.role.anonymous";}'),
('config.entity.key_store.user_role', 'uuid:add9f9dc-7a23-4dd5-9834-e663f98b8eea', 'a:1:{i:0;s:23:"user.role.authenticated";}'),
('config.entity.key_store.view', 'uuid:06656631-9c66-4445-b2fb-f4bbe0145322', 'a:1:{i:0;s:18:"views.view.content";}'),
('config.entity.key_store.view', 'uuid:0c149538-5042-44ca-8372-4756d74e6ef7', 'a:1:{i:0;s:18:"views.view.comment";}'),
('config.entity.key_store.view', 'uuid:13189bd4-33d0-4da8-8ed6-80b6208a5c93', 'a:1:{i:0;s:24:"views.view.block_content";}'),
('config.entity.key_store.view', 'uuid:1c834e54-c008-466b-8cbf-971936b9a549', 'a:1:{i:0;s:25:"views.view.content_recent";}'),
('config.entity.key_store.view', 'uuid:52cf11f7-0c9b-4e67-bae2-9f3c9beb00f5', 'a:1:{i:0;s:16:"views.view.files";}'),
('config.entity.key_store.view', 'uuid:5ffca9bd-168c-472c-932d-8b0e34081ac7', 'a:1:{i:0;s:23:"views.view.who_s_online";}'),
('config.entity.key_store.view', 'uuid:6548d3fb-c842-4a86-aa73-6a51a5797d57', 'a:1:{i:0;s:24:"views.view.taxonomy_term";}'),
('config.entity.key_store.view', 'uuid:73e831ee-8d4a-4b51-b805-9543b12b679b', 'a:1:{i:0;s:28:"views.view.user_admin_people";}'),
('config.entity.key_store.view', 'uuid:7619b68f-92b7-4e6a-b460-a2b241a4f03d', 'a:1:{i:0;s:20:"views.view.frontpage";}'),
('config.entity.key_store.view', 'uuid:b79cd01e-e4f9-41c0-acf1-14cc2ae1c750', 'a:1:{i:0;s:26:"views.view.comments_recent";}'),
('config.entity.key_store.view', 'uuid:bbd9d797-0496-468c-a293-eba20850c052', 'a:1:{i:0;s:19:"views.view.watchdog";}'),
('config.entity.key_store.view', 'uuid:dc8eafc4-60d5-41b9-bbcc-1d7409216063', 'a:1:{i:0;s:18:"views.view.archive";}'),
('config.entity.key_store.view', 'uuid:ddb31458-f097-484d-8f7b-d4d0d0e77fce', 'a:1:{i:0;s:19:"views.view.glossary";}'),
('config.entity.key_store.view', 'uuid:dde34907-2247-403d-b942-d12cf6e92231', 'a:1:{i:0;s:20:"views.view.who_s_new";}'),
('entity.definitions.bundle_field_map', 'block_content', 'a:1:{s:4:"body";a:2:{s:4:"type";s:17:"text_with_summary";s:7:"bundles";a:1:{s:5:"basic";s:5:"basic";}}}'),
('entity.definitions.bundle_field_map', 'comment', 'a:1:{s:12:"comment_body";a:2:{s:4:"type";s:9:"text_long";s:7:"bundles";a:1:{s:7:"comment";s:7:"comment";}}}'),
('entity.definitions.bundle_field_map', 'node', 'a:4:{s:11:"field_image";a:2:{s:4:"type";s:5:"image";s:7:"bundles";a:1:{s:7:"article";s:7:"article";}}s:7:"comment";a:2:{s:4:"type";s:7:"comment";s:7:"bundles";a:1:{s:7:"article";s:7:"article";}}s:10:"field_tags";a:2:{s:4:"type";s:16:"entity_reference";s:7:"bundles";a:1:{s:7:"article";s:7:"article";}}s:4:"body";a:2:{s:4:"type";s:17:"text_with_summary";s:7:"bundles";a:2:{s:4:"page";s:4:"page";s:7:"article";s:7:"article";}}}'),
('entity.definitions.bundle_field_map', 'user', 'a:1:{s:12:"user_picture";a:2:{s:4:"type";s:5:"image";s:7:"bundles";a:1:{s:4:"user";s:4:"user";}}}'),
('entity.definitions.installed', 'action.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:6:"action";s:8:"\0*\0class";s:27:"Drupal\\system\\Entity\\Action";s:11:"\0*\0provider";s:6:"system";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:27:"Drupal\\system\\Entity\\Action";s:11:"\0*\0handlers";a:2:{s:6:"access";s:45:"Drupal\\Core\\Entity\\EntityAccessControlHandler";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";s:18:"administer actions";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"Action";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Actions";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"action";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"actions";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:13:"@count action";s:6:"plural";s:14:"@count actions";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:18:"config:action_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";N;s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:5:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:4:"type";i:3;s:6:"plugin";i:4;s:13:"configuration";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'base_field_override.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:19:"base_field_override";s:8:"\0*\0class";s:42:"Drupal\\Core\\Field\\Entity\\BaseFieldOverride";s:11:"\0*\0provider";s:4:"core";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:42:"Drupal\\Core\\Field\\Entity\\BaseFieldOverride";s:11:"\0*\0handlers";a:2:{s:7:"storage";s:42:"Drupal\\Core\\Field\\BaseFieldOverrideStorage";s:6:"access";s:55:"Drupal\\Core\\Field\\BaseFieldOverrideAccessControlHandler";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Base field override";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";s:0:"";s:17:"\0*\0label_singular";s:0:"";s:15:"\0*\0label_plural";s:0:"";s:14:"\0*\0label_count";a:0:{}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:31:"config:base_field_override_list";}s:14:"\0*\0constraints";a:1:{s:19:"ImmutableProperties";a:5:{i:0;s:2:"id";i:1;s:11:"entity_type";i:2;s:6:"bundle";i:3;s:10:"field_name";i:4;s:10:"field_type";}}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:19:"base_field_override";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:12:{i:0;s:2:"id";i:1;s:10:"field_name";i:2;s:11:"entity_type";i:3;s:6:"bundle";i:4;s:5:"label";i:5;s:11:"description";i:6;s:8:"required";i:7;s:12:"translatable";i:8;s:13:"default_value";i:9;s:22:"default_value_callback";i:10;s:8:"settings";i:11;s:10:"field_type";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'block.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:5:"block";s:8:"\0*\0class";s:25:"Drupal\\block\\Entity\\Block";s:11:"\0*\0provider";s:5:"block";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:6:"status";s:6:"status";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:25:"Drupal\\block\\Entity\\Block";s:11:"\0*\0handlers";a:5:{s:6:"access";s:38:"Drupal\\block\\BlockAccessControlHandler";s:12:"view_builder";s:29:"Drupal\\block\\BlockViewBuilder";s:12:"list_builder";s:29:"Drupal\\block\\BlockListBuilder";s:4:"form";a:2:{s:7:"default";s:22:"Drupal\\block\\BlockForm";s:6:"delete";s:33:"Drupal\\block\\Form\\BlockDeleteForm";}s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";s:17:"administer blocks";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:4:{s:11:"delete-form";s:44:"/admin/structure/block/manage/{block}/delete";s:9:"edit-form";s:37:"/admin/structure/block/manage/{block}";s:6:"enable";s:44:"/admin/structure/block/manage/{block}/enable";s:7:"disable";s:45:"/admin/structure/block/manage/{block}/disable";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Block";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"Blocks";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"block";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"blocks";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:12:"@count block";s:6:"plural";s:13:"@count blocks";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:17:"config:block_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";N;s:14:"\0*\0lookup_keys";a:2:{i:0;s:5:"theme";i:1;s:4:"uuid";}s:16:"\0*\0config_export";a:8:{i:0;s:2:"id";i:1;s:5:"theme";i:2;s:6:"region";i:3;s:6:"weight";i:4;s:8:"provider";i:5;s:6:"plugin";i:6;s:8:"settings";i:7;s:10:"visibility";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'block_content.entity_type', 'O:36:"Drupal\\Core\\Entity\\ContentEntityType":41:{s:5:"\0*\0id";s:13:"block_content";s:8:"\0*\0class";s:40:"Drupal\\block_content\\Entity\\BlockContent";s:11:"\0*\0provider";s:13:"block_content";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:0;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:9:{s:2:"id";s:2:"id";s:8:"revision";s:11:"revision_id";s:6:"bundle";s:4:"type";s:5:"label";s:4:"info";s:8:"langcode";s:8:"langcode";s:4:"uuid";s:4:"uuid";s:9:"published";s:6:"status";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";}s:16:"\0*\0originalClass";s:40:"Drupal\\block_content\\Entity\\BlockContent";s:11:"\0*\0handlers";a:9:{s:7:"storage";s:46:"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage";s:14:"storage_schema";s:46:"Drupal\\block_content\\BlockContentStorageSchema";s:6:"access";s:53:"Drupal\\block_content\\BlockContentAccessControlHandler";s:12:"list_builder";s:44:"Drupal\\block_content\\BlockContentListBuilder";s:12:"view_builder";s:44:"Drupal\\block_content\\BlockContentViewBuilder";s:10:"views_data";s:42:"Drupal\\block_content\\BlockContentViewsData";s:4:"form";a:6:{s:3:"add";s:37:"Drupal\\block_content\\BlockContentForm";s:4:"edit";s:37:"Drupal\\block_content\\BlockContentForm";s:6:"delete";s:48:"Drupal\\block_content\\Form\\BlockContentDeleteForm";s:7:"default";s:37:"Drupal\\block_content\\BlockContentForm";s:15:"revision-delete";s:42:"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm";s:15:"revision-revert";s:42:"Drupal\\Core\\Entity\\Form\\RevisionRevertForm";}s:14:"route_provider";a:1:{s:8:"revision";s:52:"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider";}s:11:"translation";s:51:"Drupal\\block_content\\BlockContentTranslationHandler";}s:19:"\0*\0admin_permission";s:24:"administer block content";s:24:"\0*\0collection_permission";s:20:"access block library";s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:8:{s:9:"canonical";s:36:"/admin/content/block/{block_content}";s:11:"delete-form";s:43:"/admin/content/block/{block_content}/delete";s:9:"edit-form";s:36:"/admin/content/block/{block_content}";s:10:"collection";s:20:"/admin/content/block";s:6:"create";s:6:"/block";s:20:"revision-delete-form";s:77:"/admin/content/block/{block_content}/revision/{block_content_revision}/delete";s:20:"revision-revert-form";s:77:"/admin/content/block/{block_content}/revision/{block_content_revision}/revert";s:15:"version-history";s:46:"/admin/content/block/{block_content}/revisions";}s:21:"\0*\0bundle_entity_type";s:18:"block_content_type";s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"Block type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"\0*\0base_table";s:13:"block_content";s:22:"\0*\0revision_data_table";s:28:"block_content_field_revision";s:17:"\0*\0revision_table";s:22:"block_content_revision";s:13:"\0*\0data_table";s:24:"block_content_field_data";s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:1;s:19:"\0*\0show_revision_ui";b:1;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Content block";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"Content blocks";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"content block";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"content blocks";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:20:"@count content block";s:6:"plural";s:21:"@count content blocks";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:7:"content";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";s:35:"entity.block_content_type.edit_form";s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:18:"block_content_list";}s:14:"\0*\0constraints";a:2:{s:26:"EntityUntranslatableFields";N;s:25:"BlockContentEntityChanged";N;}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:25:"\0*\0revision_metadata_keys";a:4:{s:13:"revision_user";s:13:"revision_user";s:16:"revision_created";s:16:"revision_created";s:20:"revision_log_message";s:12:"revision_log";s:16:"revision_default";s:16:"revision_default";}}');
INSERT INTO `[[dbprefix]]key_value` VALUES
('entity.definitions.installed', 'block_content.field_storage_definitions', 'a:16:{s:2:"id";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Content block ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:21:"The content block ID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:13:"block_content";s:10:"field_name";s:2:"id";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:2;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"uuid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"UUID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:23:"The content block UUID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:13:"block_content";s:10:"field_name";s:4:"uuid";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:uuid";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:40;}s:7:"\0*\0type";s:4:"uuid";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;}}s:11:"unique keys";a:1:{s:5:"value";a:1:{i:0;s:5:"value";}}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:11:"revision_id";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Revision ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"The revision ID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:13:"block_content";s:10:"field_name";s:11:"revision_id";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:77;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Language";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:15:"language_select";s:6:"weight";i:2;}}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:32:"The content block language code.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:13:"block_content";s:10:"field_name";s:8:"langcode";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:115;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"type";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"Block type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:15:"The block type.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:13:"block_content";s:10:"field_name";s:4:"type";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:18:"block_content_type";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:155;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"revision_created";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:20:"Revision create time";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:47:"The time that the current revision was created.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:8:"provider";s:13:"block_content";s:10:"field_name";s:16:"revision_created";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:created";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:193;}s:7:"\0*\0type";s:7:"created";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:13:"revision_user";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Revision user";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:50:"The user ID of the author of the current revision.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:8:"provider";s:13:"block_content";s:10:"field_name";s:13:"revision_user";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:4:"user";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:223;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:12:"revision_log";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:20:"Revision log message";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:54:"The log entry explaining the changes in this revision.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";s:0:"";}}s:7:"display";a:1:{s:4:"form";a:1:{s:7:"options";a:3:{s:4:"type";s:15:"string_textarea";s:6:"weight";i:25;s:8:"settings";a:1:{s:4:"rows";i:4;}}}}s:8:"provider";s:13:"block_content";s:10:"field_name";s:12:"revision_log";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:22:"field_item:string_long";s:8:"settings";a:1:{s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:260;}s:7:"\0*\0type";s:11:"string_long";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"status";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Published";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:8:"provider";s:13:"block_content";s:10:"field_name";s:6:"status";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:302;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"info";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:11:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:17:"Block description";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:34:"A brief description of your block.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:8:"required";b:1;s:7:"display";a:1:{s:4:"form";a:2:{s:7:"options";a:2:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:-5;}s:12:"configurable";b:1;}}s:8:"provider";s:13:"block_content";s:10:"field_name";s:4:"info";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:341;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"changed";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Changed";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:48:"The time that the content block was last edited.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:8:"provider";s:13:"block_content";s:10:"field_name";s:7:"changed";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:changed";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:384;}s:7:"\0*\0type";s:7:"changed";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"reusable";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Reusable";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:52:"A boolean indicating whether this block is reusable.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:0;s:12:"revisionable";b:0;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:8:"provider";s:13:"block_content";s:10:"field_name";s:8:"reusable";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:415;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"default_langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Default translation";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:58:"A flag indicating whether this is the default translation.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:8:"provider";s:13:"block_content";s:10:"field_name";s:16:"default_langcode";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:458;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"revision_default";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:11:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Default revision";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:72:"A flag indicating whether this was a default revision when it was saved.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:16:"storage_required";b:1;s:8:"internal";b:1;s:12:"translatable";b:0;s:12:"revisionable";b:1;s:8:"provider";s:13:"block_content";s:10:"field_name";s:16:"revision_default";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:501;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:29:"revision_translation_affected";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:29:"Revision translation affected";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:72:"Indicates if the last edit of a translation belongs to current revision.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:12:"revisionable";b:1;s:12:"translatable";b:1;s:8:"provider";s:13:"block_content";s:10:"field_name";s:29:"revision_translation_affected";s:11:"entity_type";s:13:"block_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:543;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"body";O:38:"Drupal\\field\\Entity\\FieldStorageConfig":30:{s:15:"\0*\0entityTypeId";s:20:"field_storage_config";s:15:"\0*\0enforceIsNew";b:1;s:12:"\0*\0typedData";N;s:16:"\0*\0cacheContexts";a:0:{}s:12:"\0*\0cacheTags";a:0:{}s:14:"\0*\0cacheMaxAge";i:-1;s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:13:"\0*\0originalId";s:18:"block_content.body";s:9:"\0*\0status";b:1;s:7:"\0*\0uuid";s:36:"71f98988-aa58-42f6-b766-9d7a71cb01d9";s:11:"\0*\0langcode";s:2:"en";s:23:"\0*\0third_party_settings";a:0:{}s:8:"\0*\0_core";a:1:{s:19:"default_config_hash";s:43:"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc";}s:14:"\0*\0trustedData";b:1;s:15:"\0*\0dependencies";a:1:{s:6:"module";a:2:{i:0;s:13:"block_content";i:1;s:4:"text";}}s:12:"\0*\0isSyncing";b:0;s:5:"\0*\0id";s:18:"block_content.body";s:13:"\0*\0field_name";s:4:"body";s:14:"\0*\0entity_type";s:13:"block_content";s:7:"\0*\0type";s:17:"text_with_summary";s:9:"\0*\0module";s:4:"text";s:11:"\0*\0settings";a:0:{}s:14:"\0*\0cardinality";i:1;s:15:"\0*\0translatable";b:1;s:9:"\0*\0locked";b:0;s:25:"\0*\0persist_with_no_fields";b:1;s:14:"custom_storage";b:0;s:10:"\0*\0indexes";a:0:{}s:10:"\0*\0deleted";b:0;}}'),
('entity.definitions.installed', 'block_content_type.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:18:"block_content_type";s:8:"\0*\0class";s:44:"Drupal\\block_content\\Entity\\BlockContentType";s:11:"\0*\0provider";s:13:"block_content";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:44:"Drupal\\block_content\\Entity\\BlockContentType";s:11:"\0*\0handlers";a:5:{s:6:"access";s:50:"Drupal\\block_content\\BlockTypeAccessControlHandler";s:4:"form";a:4:{s:7:"default";s:41:"Drupal\\block_content\\BlockContentTypeForm";s:3:"add";s:41:"Drupal\\block_content\\BlockContentTypeForm";s:4:"edit";s:41:"Drupal\\block_content\\BlockContentTypeForm";s:6:"delete";s:52:"Drupal\\block_content\\Form\\BlockContentTypeDeleteForm";}s:14:"route_provider";a:2:{s:4:"html";s:49:"Drupal\\Core\\Entity\\Routing\\AdminHtmlRouteProvider";s:11:"permissions";s:49:"Drupal\\user\\Entity\\EntityPermissionsRouteProvider";}s:12:"list_builder";s:48:"Drupal\\block_content\\BlockContentTypeListBuilder";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";s:22:"administer block types";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:4:{s:11:"delete-form";s:65:"/admin/structure/block-content/manage/{block_content_type}/delete";s:9:"edit-form";s:58:"/admin/structure/block-content/manage/{block_content_type}";s:23:"entity-permissions-form";s:70:"/admin/structure/block-content/manage/{block_content_type}/permissions";s:10:"collection";s:30:"/admin/structure/block-content";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";s:13:"block_content";s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"Block type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Block types";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"block type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"block types";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:17:"@count block type";s:6:"plural";s:18:"@count block types";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:30:"config:block_content_type_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:4:"type";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:4:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:8:"revision";i:3;s:11:"description";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'comment.entity_type', 'O:36:"Drupal\\Core\\Entity\\ContentEntityType":41:{s:5:"\0*\0id";s:7:"comment";s:8:"\0*\0class";s:29:"Drupal\\comment\\Entity\\Comment";s:11:"\0*\0provider";s:7:"comment";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:10:{s:2:"id";s:3:"cid";s:6:"bundle";s:12:"comment_type";s:5:"label";s:7:"subject";s:8:"langcode";s:8:"langcode";s:4:"uuid";s:4:"uuid";s:9:"published";s:6:"status";s:5:"owner";s:3:"uid";s:8:"revision";s:0:"";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";}s:16:"\0*\0originalClass";s:29:"Drupal\\comment\\Entity\\Comment";s:11:"\0*\0handlers";a:8:{s:7:"storage";s:29:"Drupal\\comment\\CommentStorage";s:14:"storage_schema";s:35:"Drupal\\comment\\CommentStorageSchema";s:6:"access";s:42:"Drupal\\comment\\CommentAccessControlHandler";s:12:"list_builder";s:36:"Drupal\\Core\\Entity\\EntityListBuilder";s:12:"view_builder";s:33:"Drupal\\comment\\CommentViewBuilder";s:10:"views_data";s:31:"Drupal\\comment\\CommentViewsData";s:4:"form";a:2:{s:7:"default";s:26:"Drupal\\comment\\CommentForm";s:6:"delete";s:30:"Drupal\\comment\\Form\\DeleteForm";}s:11:"translation";s:40:"Drupal\\comment\\CommentTranslationHandler";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:5:{s:9:"canonical";s:18:"/comment/{comment}";s:11:"delete-form";s:25:"/comment/{comment}/delete";s:20:"delete-multiple-form";s:29:"/admin/content/comment/delete";s:9:"edit-form";s:23:"/comment/{comment}/edit";s:6:"create";s:8:"/comment";}s:21:"\0*\0bundle_entity_type";s:12:"comment_type";s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Comment type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"\0*\0base_table";s:7:"comment";s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";s:18:"comment_field_data";s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:1;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Comment";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";s:0:"";s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"comment";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"comments";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:14:"@count comment";s:6:"plural";s:15:"@count comments";s:7:"context";N;}s:15:"\0*\0uri_callback";s:11:"comment_uri";s:8:"\0*\0group";s:7:"content";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";s:29:"entity.comment_type.edit_form";s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:12:"comment_list";}s:14:"\0*\0constraints";a:3:{s:11:"CommentName";a:0:{}s:13:"EntityChanged";N;s:26:"EntityUntranslatableFields";N;}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:25:"\0*\0revision_metadata_keys";a:1:{s:16:"revision_default";s:16:"revision_default";}}');
INSERT INTO `[[dbprefix]]key_value` VALUES
('entity.definitions.installed', 'comment.field_storage_definitions', 'a:20:{s:3:"cid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"Comment ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:15:"The comment ID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"comment";s:10:"field_name";s:3:"cid";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:2;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"uuid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"UUID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:17:"The comment UUID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"comment";s:10:"field_name";s:4:"uuid";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:uuid";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:40;}s:7:"\0*\0type";s:4:"uuid";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;}}s:11:"unique keys";a:1:{s:5:"value";a:1:{i:0;s:5:"value";}}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Language";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:15:"language_select";s:6:"weight";i:2;}}}s:12:"translatable";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:26:"The comment language code.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"comment";s:10:"field_name";s:8:"langcode";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:77;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:12:"comment_type";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Comment Type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:17:"The comment type.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"comment";s:10:"field_name";s:12:"comment_type";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:12:"comment_type";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:116;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"status";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Published";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:22:"default_value_callback";s:47:"Drupal\\comment\\Entity\\Comment::getDefaultStatus";s:8:"provider";s:7:"comment";s:10:"field_name";s:6:"status";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:154;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:3:"uid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"User ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:22:"default_value_callback";s:52:"Drupal\\comment\\Entity\\Comment::getDefaultEntityOwner";s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:34:"The user ID of the comment author.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"comment";s:10:"field_name";s:3:"uid";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:4:"user";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:194;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:3:"pid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Parent ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:54:"The parent comment ID if this is a reply to a comment.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"comment";s:10:"field_name";s:3:"pid";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:7:"comment";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:232;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:9:"entity_id";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Entity ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:54:"The ID of the entity of which this comment is a reply.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:8:"provider";s:7:"comment";s:10:"field_name";s:9:"entity_id";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:4:"user";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:268;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"subject";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Subject";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:7:"display";a:1:{s:4:"form";a:2:{s:7:"options";a:2:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:10;}s:12:"configurable";b:1;}}s:8:"provider";s:7:"comment";s:10:"field_name";s:7:"subject";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:64;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:305;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:64;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"name";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Name";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:26:"The comment author''s name.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";s:0:"";}}s:8:"provider";s:7:"comment";s:10:"field_name";s:4:"name";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:60;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:342;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:60;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"mail";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Email";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:35:"The comment author''s email address.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:8:"provider";s:7:"comment";s:10:"field_name";s:4:"mail";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:16:"field_item:email";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:380;}s:7:"\0*\0type";s:5:"email";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:7:"varchar";s:6:"length";i:254;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"homepage";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Homepage";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:39:"The comment author''s home page address.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:8:"provider";s:7:"comment";s:10:"field_name";s:8:"homepage";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:14:"field_item:uri";s:8:"settings";a:2:{s:10:"max_length";i:255;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:411;}s:7:"\0*\0type";s:3:"uri";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"hostname";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Hostname";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:30:"The comment author''s hostname.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:22:"default_value_callback";s:49:"Drupal\\comment\\Entity\\Comment::getDefaultHostname";s:8:"provider";s:7:"comment";s:10:"field_name";s:8:"hostname";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:445;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:128;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"created";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Created";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:38:"The time that the comment was created.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:8:"provider";s:7:"comment";s:10:"field_name";s:7:"created";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:created";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:481;}s:7:"\0*\0type";s:7:"created";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"changed";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Changed";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:42:"The time that the comment was last edited.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:8:"provider";s:7:"comment";s:10:"field_name";s:7:"changed";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:changed";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:511;}s:7:"\0*\0type";s:7:"changed";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"thread";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Thread place";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:144:"The alphadecimal representation of the comment''s place in a thread, consisting of a base 36 string prefixed by an integer indicating its length.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"comment";s:10:"field_name";s:6:"thread";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:541;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:11:"entity_type";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Entity type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:50:"The entity type to which this comment is attached.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"comment";s:10:"field_name";s:11:"entity_type";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:32;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:575;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:10:"field_name";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:18:"Comment field name";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:52:"The field name through which this comment was added.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"comment";s:10:"field_name";s:10:"field_name";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:32;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:610;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"default_langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Default translation";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:58:"A flag indicating whether this is the default translation.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:8:"provider";s:7:"comment";s:10:"field_name";s:16:"default_langcode";s:11:"entity_type";s:7:"comment";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:645;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:12:"comment_body";O:38:"Drupal\\field\\Entity\\FieldStorageConfig":30:{s:15:"\0*\0entityTypeId";s:20:"field_storage_config";s:15:"\0*\0enforceIsNew";b:1;s:12:"\0*\0typedData";N;s:16:"\0*\0cacheContexts";a:0:{}s:12:"\0*\0cacheTags";a:0:{}s:14:"\0*\0cacheMaxAge";i:-1;s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:13:"\0*\0originalId";s:20:"comment.comment_body";s:9:"\0*\0status";b:1;s:7:"\0*\0uuid";s:36:"aa3202fe-45b4-46af-99eb-a871cb54985b";s:11:"\0*\0langcode";s:2:"en";s:23:"\0*\0third_party_settings";a:0:{}s:8:"\0*\0_core";a:1:{s:19:"default_config_hash";s:43:"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw";}s:14:"\0*\0trustedData";b:1;s:15:"\0*\0dependencies";a:1:{s:6:"module";a:2:{i:0;s:7:"comment";i:1;s:4:"text";}}s:12:"\0*\0isSyncing";b:0;s:5:"\0*\0id";s:20:"comment.comment_body";s:13:"\0*\0field_name";s:12:"comment_body";s:14:"\0*\0entity_type";s:7:"comment";s:7:"\0*\0type";s:9:"text_long";s:9:"\0*\0module";s:4:"text";s:11:"\0*\0settings";a:0:{}s:14:"\0*\0cardinality";i:1;s:15:"\0*\0translatable";b:1;s:9:"\0*\0locked";b:0;s:25:"\0*\0persist_with_no_fields";b:1;s:14:"custom_storage";b:0;s:10:"\0*\0indexes";a:0:{}s:10:"\0*\0deleted";b:0;}}'),
('entity.definitions.installed', 'comment_type.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:12:"comment_type";s:8:"\0*\0class";s:33:"Drupal\\comment\\Entity\\CommentType";s:11:"\0*\0provider";s:7:"comment";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:33:"Drupal\\comment\\Entity\\CommentType";s:11:"\0*\0handlers";a:5:{s:4:"form";a:4:{s:7:"default";s:30:"Drupal\\comment\\CommentTypeForm";s:3:"add";s:30:"Drupal\\comment\\CommentTypeForm";s:4:"edit";s:30:"Drupal\\comment\\CommentTypeForm";s:6:"delete";s:41:"Drupal\\comment\\Form\\CommentTypeDeleteForm";}s:14:"route_provider";a:1:{s:11:"permissions";s:58:"Drupal\\user\\Entity\\EntityPermissionsRouteProviderWithCheck";}s:12:"list_builder";s:37:"Drupal\\comment\\CommentTypeListBuilder";s:6:"access";s:45:"Drupal\\Core\\Entity\\EntityAccessControlHandler";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";s:24:"administer comment types";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:5:{s:11:"delete-form";s:53:"/admin/structure/comment/manage/{comment_type}/delete";s:9:"edit-form";s:46:"/admin/structure/comment/manage/{comment_type}";s:8:"add-form";s:34:"/admin/structure/comment/types/add";s:23:"entity-permissions-form";s:58:"/admin/structure/comment/manage/{comment_type}/permissions";s:10:"collection";s:24:"/admin/structure/comment";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";s:7:"comment";s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Comment type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";s:0:"";s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"comment type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"comment types";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:19:"@count comment type";s:6:"plural";s:20:"@count comment types";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:24:"config:comment_type_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:4:"type";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:4:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:21:"target_entity_type_id";i:3;s:11:"description";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'contact_form.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:12:"contact_form";s:8:"\0*\0class";s:33:"Drupal\\contact\\Entity\\ContactForm";s:11:"\0*\0provider";s:7:"contact";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:33:"Drupal\\contact\\Entity\\ContactForm";s:11:"\0*\0handlers";a:5:{s:6:"access";s:46:"Drupal\\contact\\ContactFormAccessControlHandler";s:12:"list_builder";s:37:"Drupal\\contact\\ContactFormListBuilder";s:4:"form";a:3:{s:3:"add";s:34:"Drupal\\contact\\ContactFormEditForm";s:4:"edit";s:34:"Drupal\\contact\\ContactFormEditForm";s:6:"delete";s:35:"Drupal\\Core\\Entity\\EntityDeleteForm";}s:14:"route_provider";a:1:{s:11:"permissions";s:58:"Drupal\\user\\Entity\\EntityPermissionsRouteProviderWithCheck";}s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";s:24:"administer contact forms";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:5:{s:11:"delete-form";s:53:"/admin/structure/contact/manage/{contact_form}/delete";s:9:"edit-form";s:46:"/admin/structure/contact/manage/{contact_form}";s:23:"entity-permissions-form";s:58:"/admin/structure/contact/manage/{contact_form}/permissions";s:10:"collection";s:24:"/admin/structure/contact";s:9:"canonical";s:23:"/contact/{contact_form}";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";s:15:"contact_message";s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Contact form";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Contact forms";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"contact form";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"contact forms";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:19:"@count contact form";s:6:"plural";s:20:"@count contact forms";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:24:"config:contact_form_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:4:"form";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:7:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:10:"recipients";i:3;s:5:"reply";i:4;s:6:"weight";i:5;s:7:"message";i:6;s:8:"redirect";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'contact_message.entity_type', 'O:36:"Drupal\\Core\\Entity\\ContentEntityType":41:{s:5:"\0*\0id";s:15:"contact_message";s:8:"\0*\0class";s:29:"Drupal\\contact\\Entity\\Message";s:11:"\0*\0provider";s:7:"contact";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:6:{s:6:"bundle";s:12:"contact_form";s:4:"uuid";s:4:"uuid";s:8:"langcode";s:8:"langcode";s:8:"revision";s:0:"";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";}s:16:"\0*\0originalClass";s:29:"Drupal\\contact\\Entity\\Message";s:11:"\0*\0handlers";a:4:{s:6:"access";s:49:"Drupal\\contact\\ContactMessageAccessControlHandler";s:7:"storage";s:43:"Drupal\\Core\\Entity\\ContentEntityNullStorage";s:12:"view_builder";s:33:"Drupal\\contact\\MessageViewBuilder";s:4:"form";a:1:{s:7:"default";s:26:"Drupal\\contact\\MessageForm";}}s:19:"\0*\0admin_permission";s:24:"administer contact forms";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";s:12:"contact_form";s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Contact form";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:15:"Contact message";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Contact messages";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:15:"contact message";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"contact messages";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:22:"@count contact message";s:6:"plural";s:23:"@count contact messages";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:7:"content";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";s:29:"entity.contact_form.edit_form";s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:20:"contact_message_list";}s:14:"\0*\0constraints";a:1:{s:26:"EntityUntranslatableFields";N;}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:25:"\0*\0revision_metadata_keys";a:1:{s:16:"revision_default";s:16:"revision_default";}}'),
('entity.definitions.installed', 'contact_message.field_storage_definitions', 'a:9:{s:4:"uuid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"UUID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:17:"The message UUID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"contact";s:10:"field_name";s:4:"uuid";s:11:"entity_type";s:15:"contact_message";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:uuid";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:2;}s:7:"\0*\0type";s:4:"uuid";s:9:"\0*\0schema";N;s:10:"\0*\0indexes";a:0:{}}s:8:"langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Language";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:15:"language_select";s:6:"weight";i:2;}}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:26:"The message language code.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"contact";s:10:"field_name";s:8:"langcode";s:11:"entity_type";s:15:"contact_message";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:28;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";N;s:10:"\0*\0indexes";a:0:{}}s:12:"contact_form";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Form ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:30:"The ID of the associated form.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"contact";s:10:"field_name";s:12:"contact_form";s:11:"entity_type";s:15:"contact_message";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:12:"contact_form";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:58;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";N;s:10:"\0*\0indexes";a:0:{}}s:4:"name";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:6:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:17:"The sender''s name";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:59:"The name of the person that is sending the contact message.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"contact";s:10:"field_name";s:4:"name";s:11:"entity_type";s:15:"contact_message";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:85;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";N;s:10:"\0*\0indexes";a:0:{}}s:4:"mail";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:6:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:18:"The sender''s email";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:60:"The email of the person that is sending the contact message.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"contact";s:10:"field_name";s:4:"mail";s:11:"entity_type";s:15:"contact_message";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:16:"field_item:email";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:110;}s:7:"\0*\0type";s:5:"email";s:9:"\0*\0schema";N;s:10:"\0*\0indexes";a:0:{}}s:7:"subject";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Subject";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:7:"display";a:1:{s:4:"form";a:2:{s:7:"options";a:2:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:-10;}s:12:"configurable";b:1;}}s:8:"provider";s:7:"contact";s:10:"field_name";s:7:"subject";s:11:"entity_type";s:15:"contact_message";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:100;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:132;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";N;s:10:"\0*\0indexes";a:0:{}}s:7:"message";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Message";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:7:"display";a:2:{s:4:"form";a:2:{s:7:"options";a:3:{s:4:"type";s:15:"string_textarea";s:6:"weight";i:0;s:8:"settings";a:1:{s:4:"rows";i:12;}}s:12:"configurable";b:1;}s:4:"view";a:2:{s:7:"options";a:3:{s:4:"type";s:6:"string";s:6:"weight";i:0;s:5:"label";s:5:"above";}s:12:"configurable";b:1;}}s:8:"provider";s:7:"contact";s:10:"field_name";s:7:"message";s:11:"entity_type";s:15:"contact_message";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:22:"field_item:string_long";s:8:"settings";a:1:{s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:160;}s:7:"\0*\0type";s:11:"string_long";s:9:"\0*\0schema";N;s:10:"\0*\0indexes";a:0:{}}s:4:"copy";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:6:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Copy";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:52:"Whether to send a copy of the message to the sender.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"contact";s:10:"field_name";s:4:"copy";s:11:"entity_type";s:15:"contact_message";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:194;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";N;s:10:"\0*\0indexes";a:0:{}}s:9:"recipient";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:6:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Recipient ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:59:"The ID of the recipient user for personal contact messages.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:7:"contact";s:10:"field_name";s:9:"recipient";s:11:"entity_type";s:15:"contact_message";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:4:"user";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:224;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";N;s:10:"\0*\0indexes";a:0:{}}}'),
('entity.definitions.installed', 'date_format.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:11:"date_format";s:8:"\0*\0class";s:38:"Drupal\\Core\\Datetime\\Entity\\DateFormat";s:11:"\0*\0provider";s:4:"core";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:38:"Drupal\\Core\\Datetime\\Entity\\DateFormat";s:11:"\0*\0handlers";a:4:{s:6:"access";s:44:"Drupal\\system\\DateFormatAccessControlHandler";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";s:4:"form";a:3:{s:3:"add";s:36:"Drupal\\system\\Form\\DateFormatAddForm";s:4:"edit";s:37:"Drupal\\system\\Form\\DateFormatEditForm";s:6:"delete";s:39:"Drupal\\system\\Form\\DateFormatDeleteForm";}s:12:"list_builder";s:35:"Drupal\\system\\DateFormatListBuilder";}s:19:"\0*\0admin_permission";s:29:"administer site configuration";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:3:{s:9:"edit-form";s:61:"/admin/config/regional/date-time/formats/manage/{date_format}";s:11:"delete-form";s:68:"/admin/config/regional/date-time/formats/manage/{date_format}/delete";s:10:"collection";s:40:"/admin/config/regional/date-time/formats";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Date format";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";s:0:"";s:17:"\0*\0label_singular";s:0:"";s:15:"\0*\0label_plural";s:0:"";s:14:"\0*\0label_count";a:0:{}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:8:"rendered";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";N;s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:4:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:6:"locked";i:3;s:7:"pattern";}s:21:"\0*\0mergedConfigExport";a:10:{s:4:"uuid";s:4:"uuid";s:8:"langcode";s:8:"langcode";s:6:"status";s:6:"status";s:12:"dependencies";s:12:"dependencies";s:20:"third_party_settings";s:20:"third_party_settings";s:5:"_core";s:5:"_core";s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:6:"locked";s:6:"locked";s:7:"pattern";s:7:"pattern";}}');
INSERT INTO `[[dbprefix]]key_value` VALUES
('entity.definitions.installed', 'editor.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:6:"editor";s:8:"\0*\0class";s:27:"Drupal\\editor\\Entity\\Editor";s:11:"\0*\0provider";s:6:"editor";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:7:{s:2:"id";s:6:"format";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:27:"Drupal\\editor\\Entity\\Editor";s:11:"\0*\0handlers";a:2:{s:6:"access";s:40:"Drupal\\editor\\EditorAccessControlHandler";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Text editor";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Text editors";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"text editor";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"text editors";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:18:"@count text editor";s:6:"plural";s:19:"@count text editors";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:18:"config:editor_list";}s:14:"\0*\0constraints";a:1:{s:26:"RequiredConfigDependencies";a:1:{i:0;s:13:"filter_format";}}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";N;s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:4:{i:0;s:6:"format";i:1;s:6:"editor";i:2;s:8:"settings";i:3;s:12:"image_upload";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'entity_form_display.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:19:"entity_form_display";s:8:"\0*\0class";s:43:"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay";s:11:"\0*\0provider";s:4:"core";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:6:"status";s:6:"status";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:43:"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay";s:11:"\0*\0handlers";a:2:{s:6:"access";s:71:"\\Drupal\\Core\\Entity\\Entity\\Access\\EntityFormDisplayAccessControlHandler";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Entity form display";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";s:0:"";s:17:"\0*\0label_singular";s:0:"";s:15:"\0*\0label_plural";s:0:"";s:14:"\0*\0label_count";a:0:{}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:31:"config:entity_form_display_list";}s:14:"\0*\0constraints";a:1:{s:19:"ImmutableProperties";a:4:{i:0;s:2:"id";i:1;s:16:"targetEntityType";i:2;s:6:"bundle";i:3;s:4:"mode";}}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";N;s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:6:{i:0;s:2:"id";i:1;s:16:"targetEntityType";i:2;s:6:"bundle";i:3;s:4:"mode";i:4;s:7:"content";i:5;s:6:"hidden";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'entity_form_mode.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:16:"entity_form_mode";s:8:"\0*\0class";s:40:"Drupal\\Core\\Entity\\Entity\\EntityFormMode";s:11:"\0*\0provider";s:4:"core";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:9:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:11:"description";s:11:"description";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:40:"Drupal\\Core\\Entity\\Entity\\EntityFormMode";s:11:"\0*\0handlers";a:2:{s:6:"access";s:45:"Drupal\\Core\\Entity\\EntityAccessControlHandler";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Form mode";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";s:0:"";s:17:"\0*\0label_singular";s:0:"";s:15:"\0*\0label_plural";s:0:"";s:14:"\0*\0label_count";a:0:{}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:28:"config:entity_form_mode_list";}s:14:"\0*\0constraints";a:1:{s:19:"ImmutableProperties";a:2:{i:0;s:2:"id";i:1;s:16:"targetEntityType";}}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";N;s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:5:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:11:"description";i:3;s:16:"targetEntityType";i:4;s:5:"cache";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'entity_view_display.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:19:"entity_view_display";s:8:"\0*\0class";s:43:"Drupal\\Core\\Entity\\Entity\\EntityViewDisplay";s:11:"\0*\0provider";s:4:"core";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:6:"status";s:6:"status";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:43:"Drupal\\Core\\Entity\\Entity\\EntityViewDisplay";s:11:"\0*\0handlers";a:2:{s:6:"access";s:71:"\\Drupal\\Core\\Entity\\Entity\\Access\\EntityViewDisplayAccessControlHandler";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Entity view display";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";s:0:"";s:17:"\0*\0label_singular";s:0:"";s:15:"\0*\0label_plural";s:0:"";s:14:"\0*\0label_count";a:0:{}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:31:"config:entity_view_display_list";}s:14:"\0*\0constraints";a:1:{s:19:"ImmutableProperties";a:4:{i:0;s:2:"id";i:1;s:16:"targetEntityType";i:2;s:6:"bundle";i:3;s:4:"mode";}}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";N;s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:6:{i:0;s:2:"id";i:1;s:16:"targetEntityType";i:2;s:6:"bundle";i:3;s:4:"mode";i:4;s:7:"content";i:5;s:6:"hidden";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'entity_view_mode.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:16:"entity_view_mode";s:8:"\0*\0class";s:40:"Drupal\\Core\\Entity\\Entity\\EntityViewMode";s:11:"\0*\0provider";s:4:"core";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:9:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:11:"description";s:11:"description";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:40:"Drupal\\Core\\Entity\\Entity\\EntityViewMode";s:11:"\0*\0handlers";a:2:{s:6:"access";s:45:"Drupal\\Core\\Entity\\EntityAccessControlHandler";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"View mode";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";s:0:"";s:17:"\0*\0label_singular";s:0:"";s:15:"\0*\0label_plural";s:0:"";s:14:"\0*\0label_count";a:0:{}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:28:"config:entity_view_mode_list";}s:14:"\0*\0constraints";a:1:{s:19:"ImmutableProperties";a:2:{i:0;s:2:"id";i:1;s:16:"targetEntityType";}}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";N;s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:5:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:11:"description";i:3;s:16:"targetEntityType";i:4;s:5:"cache";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'field_config.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:12:"field_config";s:8:"\0*\0class";s:31:"Drupal\\field\\Entity\\FieldConfig";s:11:"\0*\0provider";s:5:"field";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:31:"Drupal\\field\\Entity\\FieldConfig";s:11:"\0*\0handlers";a:2:{s:6:"access";s:44:"Drupal\\field\\FieldConfigAccessControlHandler";s:7:"storage";s:31:"Drupal\\field\\FieldConfigStorage";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Field";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"Fields";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"field";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"fields";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:12:"@count field";s:6:"plural";s:13:"@count fields";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:24:"config:field_config_list";}s:14:"\0*\0constraints";a:2:{s:26:"RequiredConfigDependencies";a:1:{i:0;s:20:"field_storage_config";}s:19:"ImmutableProperties";a:5:{i:0;s:2:"id";i:1;s:11:"entity_type";i:2;s:10:"field_name";i:3;s:6:"bundle";i:4;s:10:"field_type";}}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:5:"field";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:12:{i:0;s:2:"id";i:1;s:10:"field_name";i:2;s:11:"entity_type";i:3;s:6:"bundle";i:4;s:5:"label";i:5;s:11:"description";i:6;s:8:"required";i:7;s:12:"translatable";i:8;s:13:"default_value";i:9;s:22:"default_value_callback";i:10;s:8:"settings";i:11;s:10:"field_type";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'field_storage_config.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:20:"field_storage_config";s:8:"\0*\0class";s:38:"Drupal\\field\\Entity\\FieldStorageConfig";s:11:"\0*\0provider";s:5:"field";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:5:"label";s:2:"id";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:38:"Drupal\\field\\Entity\\FieldStorageConfig";s:11:"\0*\0handlers";a:2:{s:6:"access";s:51:"Drupal\\field\\FieldStorageConfigAccessControlHandler";s:7:"storage";s:38:"Drupal\\field\\FieldStorageConfigStorage";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Field storage";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"Field storages";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"field storage";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"field storages";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:20:"@count field storage";s:6:"plural";s:21:"@count field storages";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:32:"config:field_storage_config_list";}s:14:"\0*\0constraints";a:1:{s:19:"ImmutableProperties";a:4:{i:0;s:2:"id";i:1;s:11:"entity_type";i:2;s:10:"field_name";i:3;s:4:"type";}}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:7:"storage";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:12:{i:0;s:2:"id";i:1;s:10:"field_name";i:2;s:11:"entity_type";i:3;s:4:"type";i:4;s:8:"settings";i:5;s:6:"module";i:6;s:6:"locked";i:7;s:11:"cardinality";i:8;s:12:"translatable";i:9;s:7:"indexes";i:10;s:22:"persist_with_no_fields";i:11;s:14:"custom_storage";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'file.entity_type', 'O:36:"Drupal\\Core\\Entity\\ContentEntityType":41:{s:5:"\0*\0id";s:4:"file";s:8:"\0*\0class";s:23:"Drupal\\file\\Entity\\File";s:11:"\0*\0provider";s:4:"file";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:9:{s:2:"id";s:3:"fid";s:5:"label";s:8:"filename";s:8:"langcode";s:8:"langcode";s:4:"uuid";s:4:"uuid";s:5:"owner";s:3:"uid";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";}s:16:"\0*\0originalClass";s:23:"Drupal\\file\\Entity\\File";s:11:"\0*\0handlers";a:8:{s:7:"storage";s:23:"Drupal\\file\\FileStorage";s:14:"storage_schema";s:29:"Drupal\\file\\FileStorageSchema";s:6:"access";s:36:"Drupal\\file\\FileAccessControlHandler";s:10:"views_data";s:25:"Drupal\\file\\FileViewsData";s:12:"list_builder";s:36:"Drupal\\Core\\Entity\\EntityListBuilder";s:4:"form";a:1:{s:6:"delete";s:42:"Drupal\\Core\\Entity\\ContentEntityDeleteForm";}s:14:"route_provider";a:1:{s:4:"html";s:36:"Drupal\\file\\Entity\\FileRouteProvider";}s:12:"view_builder";s:36:"Drupal\\Core\\Entity\\EntityViewBuilder";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:1:{s:11:"delete-form";s:19:"/file/{file}/delete";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";s:12:"file_managed";s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"File";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Files";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"file";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"files";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:11:"@count file";s:6:"plural";s:12:"@count files";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:7:"content";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:9:"file_list";}s:14:"\0*\0constraints";a:2:{s:13:"EntityChanged";N;s:26:"EntityUntranslatableFields";N;}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:25:"\0*\0revision_metadata_keys";a:1:{s:16:"revision_default";s:16:"revision_default";}}'),
('entity.definitions.installed', 'file.field_storage_definitions', 'a:11:{s:3:"fid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"File ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"The file ID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"file";s:10:"field_name";s:3:"fid";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:2;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"uuid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"UUID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"The file UUID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"file";s:10:"field_name";s:4:"uuid";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:uuid";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:40;}s:7:"\0*\0type";s:4:"uuid";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;}}s:11:"unique keys";a:1:{s:5:"value";a:1:{i:0;s:5:"value";}}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Language code";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:15:"language_select";s:6:"weight";i:2;}}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:23:"The file language code.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"file";s:10:"field_name";s:8:"langcode";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:77;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:3:"uid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"User ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:0;s:22:"default_value_callback";s:46:"Drupal\\file\\Entity\\File::getDefaultEntityOwner";s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:24:"The user ID of the file.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"file";s:10:"field_name";s:3:"uid";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:4:"user";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:115;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"filename";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Filename";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:41:"Name of the file with no path components.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"file";s:10:"field_name";s:8:"filename";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:153;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:3:"uri";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"URI";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:52:"The URI to access the file (either local or remote).";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"constraints";a:1:{s:13:"FileUriUnique";N;}s:8:"provider";s:4:"file";s:10:"field_name";s:3:"uri";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:file_uri";s:8:"settings";a:2:{s:10:"max_length";i:255;s:14:"case_sensitive";b:1;}}s:18:"\0*\0fieldDefinition";r:187;}s:7:"\0*\0type";s:8:"file_uri";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:1;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"filemime";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"File MIME type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:21:"The file''s MIME type.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"file";s:10:"field_name";s:8:"filemime";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:222;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"filesize";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"File size";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:30:"The size of the file in bytes.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"file";s:10:"field_name";s:8:"filesize";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:3:"big";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:256;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:3:"big";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"status";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"Status";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:63:"The status of the file, temporary (FALSE) and permanent (TRUE).";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:0;}}s:8:"provider";s:4:"file";s:10:"field_name";s:6:"status";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:293;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"created";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Created";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:40:"The timestamp that the file was created.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"file";s:10:"field_name";s:7:"created";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:created";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:334;}s:7:"\0*\0type";s:7:"created";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"changed";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Changed";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:45:"The timestamp that the file was last changed.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"file";s:10:"field_name";s:7:"changed";s:11:"entity_type";s:4:"file";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:changed";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:363;}s:7:"\0*\0type";s:7:"changed";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}}'),
('entity.definitions.installed', 'filter_format.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:13:"filter_format";s:8:"\0*\0class";s:33:"Drupal\\filter\\Entity\\FilterFormat";s:11:"\0*\0provider";s:6:"filter";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:10:{s:2:"id";s:6:"format";s:5:"label";s:4:"name";s:6:"weight";s:6:"weight";s:6:"status";s:6:"status";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:33:"Drupal\\filter\\Entity\\FilterFormat";s:11:"\0*\0handlers";a:4:{s:4:"form";a:3:{s:3:"add";s:33:"Drupal\\filter\\FilterFormatAddForm";s:4:"edit";s:34:"Drupal\\filter\\FilterFormatEditForm";s:7:"disable";s:36:"Drupal\\filter\\Form\\FilterDisableForm";}s:12:"list_builder";s:37:"Drupal\\filter\\FilterFormatListBuilder";s:6:"access";s:46:"Drupal\\filter\\FilterFormatAccessControlHandler";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";s:18:"administer filters";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:2:{s:9:"edit-form";s:52:"/admin/config/content/formats/manage/{filter_format}";s:7:"disable";s:60:"/admin/config/content/formats/manage/{filter_format}/disable";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Text format";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Text formats";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"text format";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"text formats";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:18:"@count text format";s:6:"plural";s:19:"@count text formats";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:25:"config:filter_format_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:6:"format";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:5:{i:0;s:4:"name";i:1;s:6:"format";i:2;s:6:"weight";i:3;s:5:"roles";i:4;s:7:"filters";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'image_style.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:11:"image_style";s:8:"\0*\0class";s:30:"Drupal\\image\\Entity\\ImageStyle";s:11:"\0*\0provider";s:5:"image";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:4:"name";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:30:"Drupal\\image\\Entity\\ImageStyle";s:11:"\0*\0handlers";a:4:{s:4:"form";a:4:{s:3:"add";s:35:"Drupal\\image\\Form\\ImageStyleAddForm";s:4:"edit";s:36:"Drupal\\image\\Form\\ImageStyleEditForm";s:6:"delete";s:38:"Drupal\\image\\Form\\ImageStyleDeleteForm";s:5:"flush";s:37:"Drupal\\image\\Form\\ImageStyleFlushForm";}s:12:"list_builder";s:34:"Drupal\\image\\ImageStyleListBuilder";s:7:"storage";s:30:"Drupal\\image\\ImageStyleStorage";s:6:"access";s:45:"Drupal\\Core\\Entity\\EntityAccessControlHandler";}s:19:"\0*\0admin_permission";s:23:"administer image styles";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:4:{s:10:"flush-form";s:59:"/admin/config/media/image-styles/manage/{image_style}/flush";s:9:"edit-form";s:53:"/admin/config/media/image-styles/manage/{image_style}";s:11:"delete-form";s:60:"/admin/config/media/image-styles/manage/{image_style}/delete";s:10:"collection";s:32:"/admin/config/media/image-styles";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Image style";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Image styles";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"image style";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"image styles";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:18:"@count image style";s:6:"plural";s:19:"@count image styles";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:23:"config:image_style_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:5:"style";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:3:{i:0;s:4:"name";i:1;s:5:"label";i:2;s:7:"effects";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'menu.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:4:"menu";s:8:"\0*\0class";s:25:"Drupal\\system\\Entity\\Menu";s:11:"\0*\0provider";s:6:"system";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:25:"Drupal\\system\\Entity\\Menu";s:11:"\0*\0handlers";a:2:{s:6:"access";s:38:"Drupal\\system\\MenuAccessControlHandler";s:7:"storage";s:25:"Drupal\\system\\MenuStorage";}s:19:"\0*\0admin_permission";s:15:"administer menu";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Menu";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Menus";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"menu";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"menus";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:11:"@count menu";s:6:"plural";s:12:"@count menus";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:16:"config:menu_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";N;s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:4:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:11:"description";i:3;s:6:"locked";}s:21:"\0*\0mergedConfigExport";a:0:{}}');
INSERT INTO `[[dbprefix]]key_value` VALUES
('entity.definitions.installed', 'menu_link_content.entity_type', 'O:36:"Drupal\\Core\\Entity\\ContentEntityType":40:{s:5:"\0*\0id";s:17:"menu_link_content";s:8:"\0*\0class";s:47:"Drupal\\menu_link_content\\Entity\\MenuLinkContent";s:11:"\0*\0provider";s:17:"menu_link_content";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:9:{s:2:"id";s:2:"id";s:8:"revision";s:11:"revision_id";s:5:"label";s:5:"title";s:8:"langcode";s:8:"langcode";s:4:"uuid";s:4:"uuid";s:6:"bundle";s:6:"bundle";s:9:"published";s:7:"enabled";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";}s:16:"\0*\0originalClass";s:47:"Drupal\\menu_link_content\\Entity\\MenuLinkContent";s:11:"\0*\0handlers";a:7:{s:7:"storage";s:48:"\\Drupal\\menu_link_content\\MenuLinkContentStorage";s:14:"storage_schema";s:53:"Drupal\\menu_link_content\\MenuLinkContentStorageSchema";s:6:"access";s:60:"Drupal\\menu_link_content\\MenuLinkContentAccessControlHandler";s:4:"form";a:2:{s:7:"default";s:49:"Drupal\\menu_link_content\\Form\\MenuLinkContentForm";s:6:"delete";s:55:"Drupal\\menu_link_content\\Form\\MenuLinkContentDeleteForm";}s:12:"list_builder";s:44:"Drupal\\menu_link_content\\MenuLinkListBuilder";s:12:"view_builder";s:36:"Drupal\\Core\\Entity\\EntityViewBuilder";s:10:"moderation";s:0:"";}s:19:"\0*\0admin_permission";s:15:"administer menu";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:3:{s:9:"canonical";s:51:"/admin/structure/menu/item/{menu_link_content}/edit";s:9:"edit-form";s:51:"/admin/structure/menu/item/{menu_link_content}/edit";s:11:"delete-form";s:53:"/admin/structure/menu/item/{menu_link_content}/delete";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";s:17:"menu_link_content";s:22:"\0*\0revision_data_table";s:32:"menu_link_content_field_revision";s:17:"\0*\0revision_table";s:26:"menu_link_content_revision";s:13:"\0*\0data_table";s:22:"menu_link_content_data";s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:1;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Custom menu link";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:17:"Custom menu links";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"custom menu link";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:17:"custom menu links";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:23:"@count custom menu link";s:6:"plural";s:24:"@count custom menu links";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:7:"content";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:22:"menu_link_content_list";}s:14:"\0*\0constraints";a:3:{s:17:"MenuTreeHierarchy";a:0:{}s:13:"EntityChanged";N;s:26:"EntityUntranslatableFields";N;}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:1:{s:17:"stringTranslation";s:18:"string_translation";}s:18:"\0*\0_entityStorages";a:0:{}s:25:"\0*\0revision_metadata_keys";a:4:{s:13:"revision_user";s:13:"revision_user";s:16:"revision_created";s:16:"revision_created";s:20:"revision_log_message";s:20:"revision_log_message";s:16:"revision_default";s:16:"revision_default";}}'),
('entity.definitions.installed', 'menu_link_content.field_storage_definitions', 'a:22:{s:2:"id";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Entity ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:48:"The entity ID for this menu link content entity.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:2:"id";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:2;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"uuid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"UUID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:27:"The content menu link UUID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:4:"uuid";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:uuid";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:40;}s:7:"\0*\0type";s:4:"uuid";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;}}s:11:"unique keys";a:1:{s:5:"value";a:1:{i:0;s:5:"value";}}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:11:"revision_id";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Revision ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:11:"revision_id";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:77;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Language";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:15:"language_select";s:6:"weight";i:2;}}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:28:"The menu link language code.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:8:"langcode";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:111;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"bundle";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";s:23:"Custom menu link bundle";s:8:"required";b:1;s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:29:"The content menu link bundle.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:6:"bundle";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:32;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:151;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"revision_created";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:20:"Revision create time";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:47:"The time that the current revision was created.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:16:"revision_created";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:created";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:184;}s:7:"\0*\0type";s:7:"created";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:13:"revision_user";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Revision user";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:50:"The user ID of the author of the current revision.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:13:"revision_user";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:4:"user";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:214;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:20:"revision_log_message";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:20:"Revision log message";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:43:"Briefly describe the changes you have made.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";s:0:"";}}s:7:"display";a:1:{s:4:"form";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:20:"revision_log_message";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:22:"field_item:string_long";s:8:"settings";a:1:{s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:251;}s:7:"\0*\0type";s:11:"string_long";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"enabled";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:11:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Enabled";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:0;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:65:"A flag for whether the link should be enabled in menus or hidden.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:3:{s:5:"label";s:6:"hidden";s:4:"type";s:7:"boolean";s:6:"weight";i:0;}}s:4:"form";a:1:{s:7:"options";a:2:{s:8:"settings";a:1:{s:13:"display_label";b:1;}s:6:"weight";i:-1;}}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:7:"enabled";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:290;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:5:"title";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:11:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:15:"Menu link title";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:46:"The text to be used for this link in the menu.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:12:"translatable";b:1;s:12:"revisionable";b:1;s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:3:{s:5:"label";s:6:"hidden";s:4:"type";s:6:"string";s:6:"weight";i:-5;}}s:4:"form";a:2:{s:7:"options";a:2:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:-5;}s:12:"configurable";b:1;}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:5:"title";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:344;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:11:"description";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Description";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:39:"Shown when hovering over the menu link.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:3:{s:5:"label";s:6:"hidden";s:4:"type";s:6:"string";s:6:"weight";i:0;}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:0;}}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:11:"description";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:392;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:9:"menu_name";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Menu name";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:93:"The menu name. All links with the same menu name (such as "tools") are part of the same menu.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";s:5:"tools";}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:9:"menu_name";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:438;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"link";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Link";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:38:"The location this menu link points to.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:8:"required";b:1;s:7:"display";a:1:{s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:12:"link_default";s:6:"weight";i:-2;}}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:4:"link";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:link";s:8:"settings";a:2:{s:5:"title";i:0;s:9:"link_type";i:17;}}s:18:"\0*\0fieldDefinition";r:475;}s:7:"\0*\0type";s:4:"link";s:9:"\0*\0schema";a:4:{s:7:"columns";a:3:{s:3:"uri";a:3:{s:11:"description";s:20:"The URI of the link.";s:4:"type";s:7:"varchar";s:6:"length";i:2048;}s:5:"title";a:3:{s:11:"description";s:14:"The link text.";s:4:"type";s:7:"varchar";s:6:"length";i:255;}s:7:"options";a:4:{s:11:"description";s:41:"Serialized array of options for the link.";s:4:"type";s:4:"blob";s:4:"size";s:3:"big";s:9:"serialize";b:1;}}s:7:"indexes";a:1:{s:3:"uri";a:1:{i:0;a:2:{i:0;s:3:"uri";i:1;i:30;}}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"external";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"External";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:120:"A flag to indicate if the link points to a full URL starting with a protocol, like http:// (1 = external, 0 = internal).";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:0;}}s:12:"revisionable";b:1;s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:8:"external";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:528;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:10:"rediscover";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:54:"Indicates whether the menu link should be rediscovered";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:0;}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:10:"rediscover";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:570;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"weight";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"Weight";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:172:"Link weight among links in the same menu at the same depth. In the menu, the links with high weight will sink and links with a low weight will be positioned nearer the top.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";i:0;}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:3:{s:5:"label";s:6:"hidden";s:4:"type";s:14:"number_integer";s:6:"weight";i:0;}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:6:"number";s:6:"weight";i:20;}}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:6:"weight";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:0;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:607;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:0;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"expanded";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Show as expanded";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:164:"If selected and this menu link has children, the menu will always appear expanded. This option may be overridden for the entire menu tree when placing a menu block.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:0;}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:3:{s:5:"label";s:6:"hidden";s:4:"type";s:7:"boolean";s:6:"weight";i:0;}}s:4:"form";a:1:{s:7:"options";a:2:{s:8:"settings";a:1:{s:13:"display_label";b:1;}s:6:"weight";i:0;}}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:8:"expanded";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:657;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"parent";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Parent plugin ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:94:"The ID of the parent menu link plugin, or empty string when at the top level of the hierarchy.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:6:"parent";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:709;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"changed";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Changed";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:44:"The time that the menu link was last edited.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:7:"changed";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:changed";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:743;}s:7:"\0*\0type";s:7:"changed";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"default_langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Default translation";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:58:"A flag indicating whether this is the default translation.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:16:"default_langcode";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:774;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"revision_default";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:11:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Default revision";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:72:"A flag indicating whether this was a default revision when it was saved.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:16:"storage_required";b:1;s:8:"internal";b:1;s:12:"translatable";b:0;s:12:"revisionable";b:1;s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:16:"revision_default";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:817;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:29:"revision_translation_affected";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:29:"Revision translation affected";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:72:"Indicates if the last edit of a translation belongs to current revision.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:12:"revisionable";b:1;s:12:"translatable";b:1;s:8:"provider";s:17:"menu_link_content";s:10:"field_name";s:29:"revision_translation_affected";s:11:"entity_type";s:17:"menu_link_content";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:859;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}}'),
('entity.definitions.installed', 'node.entity_type', 'O:36:"Drupal\\Core\\Entity\\ContentEntityType":41:{s:5:"\0*\0id";s:4:"node";s:8:"\0*\0class";s:23:"Drupal\\node\\Entity\\Node";s:11:"\0*\0provider";s:4:"node";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:12:{s:2:"id";s:3:"nid";s:8:"revision";s:3:"vid";s:6:"bundle";s:4:"type";s:5:"label";s:5:"title";s:8:"langcode";s:8:"langcode";s:4:"uuid";s:4:"uuid";s:6:"status";s:6:"status";s:9:"published";s:6:"status";s:3:"uid";s:3:"uid";s:5:"owner";s:3:"uid";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";}s:16:"\0*\0originalClass";s:23:"Drupal\\node\\Entity\\Node";s:11:"\0*\0handlers";a:9:{s:7:"storage";s:23:"Drupal\\node\\NodeStorage";s:14:"storage_schema";s:29:"Drupal\\node\\NodeStorageSchema";s:12:"view_builder";s:27:"Drupal\\node\\NodeViewBuilder";s:6:"access";s:36:"Drupal\\node\\NodeAccessControlHandler";s:10:"views_data";s:25:"Drupal\\node\\NodeViewsData";s:4:"form";a:4:{s:7:"default";s:20:"Drupal\\node\\NodeForm";s:6:"delete";s:31:"Drupal\\node\\Form\\NodeDeleteForm";s:4:"edit";s:20:"Drupal\\node\\NodeForm";s:23:"delete-multiple-confirm";s:31:"Drupal\\node\\Form\\DeleteMultiple";}s:14:"route_provider";a:1:{s:4:"html";s:36:"Drupal\\node\\Entity\\NodeRouteProvider";}s:12:"list_builder";s:27:"Drupal\\node\\NodeListBuilder";s:11:"translation";s:34:"Drupal\\node\\NodeTranslationHandler";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";s:23:"access content overview";s:25:"\0*\0permission_granularity";s:6:"bundle";s:8:"\0*\0links";a:7:{s:9:"canonical";s:12:"/node/{node}";s:11:"delete-form";s:19:"/node/{node}/delete";s:20:"delete-multiple-form";s:26:"/admin/content/node/delete";s:9:"edit-form";s:17:"/node/{node}/edit";s:15:"version-history";s:22:"/node/{node}/revisions";s:8:"revision";s:43:"/node/{node}/revisions/{node_revision}/view";s:6:"create";s:5:"/node";}s:21:"\0*\0bundle_entity_type";s:9:"node_type";s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Content type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"\0*\0base_table";s:4:"node";s:22:"\0*\0revision_data_table";s:19:"node_field_revision";s:17:"\0*\0revision_table";s:13:"node_revision";s:13:"\0*\0data_table";s:15:"node_field_data";s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:1;s:19:"\0*\0show_revision_ui";b:1;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"content item";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"content items";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:19:"@count content item";s:6:"plural";s:20:"@count content items";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:7:"content";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";s:26:"entity.node_type.edit_form";s:26:"\0*\0common_reference_target";b:1;s:22:"\0*\0list_cache_contexts";a:1:{i:0;s:21:"user.node_grants:view";}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:9:"node_list";}s:14:"\0*\0constraints";a:2:{s:13:"EntityChanged";N;s:26:"EntityUntranslatableFields";N;}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:25:"\0*\0revision_metadata_keys";a:4:{s:13:"revision_user";s:12:"revision_uid";s:16:"revision_created";s:18:"revision_timestamp";s:20:"revision_log_message";s:12:"revision_log";s:16:"revision_default";s:16:"revision_default";}}');
INSERT INTO `[[dbprefix]]key_value` VALUES
('entity.definitions.installed', 'node.field_storage_definitions', 'a:22:{s:3:"nid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:8:"provider";s:4:"node";s:10:"field_name";s:3:"nid";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:2;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"uuid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"UUID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:8:"provider";s:4:"node";s:10:"field_name";s:4:"uuid";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:uuid";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:36;}s:7:"\0*\0type";s:4:"uuid";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;}}s:11:"unique keys";a:1:{s:5:"value";a:1:{i:0;s:5:"value";}}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:3:"vid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Revision ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:8:"provider";s:4:"node";s:10:"field_name";s:3:"vid";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:69;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Language";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:15:"language_select";s:6:"weight";i:2;}}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:8:"provider";s:4:"node";s:10:"field_name";s:8:"langcode";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:103;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"type";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";s:12:"Content type";s:8:"required";b:1;s:9:"read-only";b:1;s:8:"provider";s:4:"node";s:10:"field_name";s:4:"type";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:9:"node_type";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:139;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:18:"revision_timestamp";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:20:"Revision create time";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:47:"The time that the current revision was created.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:8:"provider";s:4:"node";s:10:"field_name";s:18:"revision_timestamp";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:created";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:170;}s:7:"\0*\0type";s:7:"created";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:12:"revision_uid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Revision user";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:50:"The user ID of the author of the current revision.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:8:"provider";s:4:"node";s:10:"field_name";s:12:"revision_uid";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:4:"user";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:200;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:12:"revision_log";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:20:"Revision log message";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:43:"Briefly describe the changes you have made.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";s:0:"";}}s:7:"display";a:1:{s:4:"form";a:1:{s:7:"options";a:3:{s:4:"type";s:15:"string_textarea";s:6:"weight";i:25;s:8:"settings";a:1:{s:4:"rows";i:4;}}}}s:8:"provider";s:4:"node";s:10:"field_name";s:12:"revision_log";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:22:"field_item:string_long";s:8:"settings";a:1:{s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:237;}s:7:"\0*\0type";s:11:"string_long";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"status";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Published";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:7:"display";a:1:{s:4:"form";a:2:{s:7:"options";a:3:{s:4:"type";s:16:"boolean_checkbox";s:8:"settings";a:1:{s:13:"display_label";b:1;}s:6:"weight";i:120;}s:12:"configurable";b:1;}}s:8:"provider";s:4:"node";s:10:"field_name";s:6:"status";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:279;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:3:"uid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:11:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Authored by";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:22:"default_value_callback";s:46:"Drupal\\node\\Entity\\Node::getDefaultEntityOwner";s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:35:"The username of the content author.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:3:{s:5:"label";s:6:"hidden";s:4:"type";s:6:"author";s:6:"weight";i:0;}}s:4:"form";a:2:{s:7:"options";a:3:{s:4:"type";s:29:"entity_reference_autocomplete";s:6:"weight";i:5;s:8:"settings";a:3:{s:14:"match_operator";s:8:"CONTAINS";s:4:"size";s:2:"60";s:11:"placeholder";s:0:"";}}s:12:"configurable";b:1;}}s:8:"provider";s:4:"node";s:10:"field_name";s:3:"uid";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:4:"user";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:326;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:5:"title";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Title";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:12:"translatable";b:1;s:12:"revisionable";b:1;s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:3:{s:5:"label";s:6:"hidden";s:4:"type";s:6:"string";s:6:"weight";i:-5;}}s:4:"form";a:2:{s:7:"options";a:2:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:-5;}s:12:"configurable";b:1;}}s:8:"provider";s:4:"node";s:10:"field_name";s:5:"title";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:380;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"created";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Authored on";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:47:"The date and time that the content was created.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:3:{s:5:"label";s:6:"hidden";s:4:"type";s:9:"timestamp";s:6:"weight";i:0;}}s:4:"form";a:2:{s:7:"options";a:2:{s:4:"type";s:18:"datetime_timestamp";s:6:"weight";i:10;}s:12:"configurable";b:1;}}s:8:"provider";s:4:"node";s:10:"field_name";s:7:"created";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:created";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:424;}s:7:"\0*\0type";s:7:"created";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"changed";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Changed";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:39:"The time that the node was last edited.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:8:"provider";s:4:"node";s:10:"field_name";s:7:"changed";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:changed";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:466;}s:7:"\0*\0type";s:7:"changed";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"promote";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:22:"Promoted to front page";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:7:"display";a:1:{s:4:"form";a:2:{s:7:"options";a:3:{s:4:"type";s:16:"boolean_checkbox";s:8:"settings";a:1:{s:13:"display_label";b:1;}s:6:"weight";i:15;}s:12:"configurable";b:1;}}s:8:"provider";s:4:"node";s:10:"field_name";s:7:"promote";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:497;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"sticky";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:22:"Sticky at top of lists";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:0;}}s:7:"display";a:1:{s:4:"form";a:2:{s:7:"options";a:3:{s:4:"type";s:16:"boolean_checkbox";s:8:"settings";a:1:{s:13:"display_label";b:1;}s:6:"weight";i:16;}s:12:"configurable";b:1;}}s:8:"provider";s:4:"node";s:10:"field_name";s:6:"sticky";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:544;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"default_langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Default translation";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:58:"A flag indicating whether this is the default translation.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:8:"provider";s:4:"node";s:10:"field_name";s:16:"default_langcode";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:591;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"revision_default";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:11:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Default revision";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:72:"A flag indicating whether this was a default revision when it was saved.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:16:"storage_required";b:1;s:8:"internal";b:1;s:12:"translatable";b:0;s:12:"revisionable";b:1;s:8:"provider";s:4:"node";s:10:"field_name";s:16:"revision_default";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:634;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:29:"revision_translation_affected";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:29:"Revision translation affected";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:72:"Indicates if the last edit of a translation belongs to current revision.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:12:"revisionable";b:1;s:12:"translatable";b:1;s:8:"provider";s:4:"node";s:10:"field_name";s:29:"revision_translation_affected";s:11:"entity_type";s:4:"node";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:676;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"body";O:38:"Drupal\\field\\Entity\\FieldStorageConfig":30:{s:15:"\0*\0entityTypeId";s:20:"field_storage_config";s:15:"\0*\0enforceIsNew";b:1;s:12:"\0*\0typedData";N;s:16:"\0*\0cacheContexts";a:0:{}s:12:"\0*\0cacheTags";a:0:{}s:14:"\0*\0cacheMaxAge";i:-1;s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:13:"\0*\0originalId";s:9:"node.body";s:9:"\0*\0status";b:1;s:7:"\0*\0uuid";s:36:"d8f860c7-f93a-446c-bdce-18ff53e81cc9";s:11:"\0*\0langcode";s:2:"en";s:23:"\0*\0third_party_settings";a:0:{}s:8:"\0*\0_core";a:1:{s:19:"default_config_hash";s:43:"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY";}s:14:"\0*\0trustedData";b:1;s:15:"\0*\0dependencies";a:1:{s:6:"module";a:2:{i:0;s:4:"node";i:1;s:4:"text";}}s:12:"\0*\0isSyncing";b:0;s:5:"\0*\0id";s:9:"node.body";s:13:"\0*\0field_name";s:4:"body";s:14:"\0*\0entity_type";s:4:"node";s:7:"\0*\0type";s:17:"text_with_summary";s:9:"\0*\0module";s:4:"text";s:11:"\0*\0settings";a:0:{}s:14:"\0*\0cardinality";i:1;s:15:"\0*\0translatable";b:1;s:9:"\0*\0locked";b:0;s:25:"\0*\0persist_with_no_fields";b:1;s:14:"custom_storage";b:0;s:10:"\0*\0indexes";a:0:{}s:10:"\0*\0deleted";b:0;}s:11:"field_image";O:38:"Drupal\\field\\Entity\\FieldStorageConfig":30:{s:15:"\0*\0entityTypeId";s:20:"field_storage_config";s:15:"\0*\0enforceIsNew";b:1;s:12:"\0*\0typedData";N;s:16:"\0*\0cacheContexts";a:0:{}s:12:"\0*\0cacheTags";a:0:{}s:14:"\0*\0cacheMaxAge";i:-1;s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:13:"\0*\0originalId";s:16:"node.field_image";s:9:"\0*\0status";b:1;s:7:"\0*\0uuid";s:36:"4197b587-d8c1-48a4-832c-ffa48b177a67";s:11:"\0*\0langcode";s:2:"en";s:23:"\0*\0third_party_settings";a:0:{}s:8:"\0*\0_core";a:1:{s:19:"default_config_hash";s:43:"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE";}s:14:"\0*\0trustedData";b:1;s:15:"\0*\0dependencies";a:1:{s:6:"module";a:3:{i:0;s:4:"file";i:1;s:5:"image";i:2;s:4:"node";}}s:12:"\0*\0isSyncing";b:0;s:5:"\0*\0id";s:16:"node.field_image";s:13:"\0*\0field_name";s:11:"field_image";s:14:"\0*\0entity_type";s:4:"node";s:7:"\0*\0type";s:5:"image";s:9:"\0*\0module";s:5:"image";s:11:"\0*\0settings";a:5:{s:11:"target_type";s:4:"file";s:13:"display_field";b:0;s:15:"display_default";b:0;s:10:"uri_scheme";s:6:"public";s:13:"default_image";a:5:{s:4:"uuid";N;s:3:"alt";s:0:"";s:5:"title";s:0:"";s:5:"width";N;s:6:"height";N;}}s:14:"\0*\0cardinality";i:1;s:15:"\0*\0translatable";b:1;s:9:"\0*\0locked";b:0;s:25:"\0*\0persist_with_no_fields";b:0;s:14:"custom_storage";b:0;s:10:"\0*\0indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:10:"\0*\0deleted";b:0;}s:7:"comment";O:38:"Drupal\\field\\Entity\\FieldStorageConfig":30:{s:15:"\0*\0entityTypeId";s:20:"field_storage_config";s:15:"\0*\0enforceIsNew";b:1;s:12:"\0*\0typedData";N;s:16:"\0*\0cacheContexts";a:0:{}s:12:"\0*\0cacheTags";a:0:{}s:14:"\0*\0cacheMaxAge";i:-1;s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:13:"\0*\0originalId";s:12:"node.comment";s:9:"\0*\0status";b:1;s:7:"\0*\0uuid";s:36:"a16c5662-b6e3-442f-b490-f840f6c7f095";s:11:"\0*\0langcode";s:2:"en";s:23:"\0*\0third_party_settings";a:0:{}s:8:"\0*\0_core";a:1:{s:19:"default_config_hash";s:43:"ktCna9xmWvYZIUfOCUyDQvedn5RtnS4CRmEIwNmvYjc";}s:14:"\0*\0trustedData";b:1;s:15:"\0*\0dependencies";a:1:{s:6:"module";a:2:{i:0;s:7:"comment";i:1;s:4:"node";}}s:12:"\0*\0isSyncing";b:0;s:5:"\0*\0id";s:12:"node.comment";s:13:"\0*\0field_name";s:7:"comment";s:14:"\0*\0entity_type";s:4:"node";s:7:"\0*\0type";s:7:"comment";s:9:"\0*\0module";s:7:"comment";s:11:"\0*\0settings";a:1:{s:12:"comment_type";s:7:"comment";}s:14:"\0*\0cardinality";i:1;s:15:"\0*\0translatable";b:1;s:9:"\0*\0locked";b:0;s:25:"\0*\0persist_with_no_fields";b:0;s:14:"custom_storage";b:0;s:10:"\0*\0indexes";a:0:{}s:10:"\0*\0deleted";b:0;}s:10:"field_tags";O:38:"Drupal\\field\\Entity\\FieldStorageConfig":30:{s:15:"\0*\0entityTypeId";s:20:"field_storage_config";s:15:"\0*\0enforceIsNew";b:1;s:12:"\0*\0typedData";N;s:16:"\0*\0cacheContexts";a:0:{}s:12:"\0*\0cacheTags";a:0:{}s:14:"\0*\0cacheMaxAge";i:-1;s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:13:"\0*\0originalId";s:15:"node.field_tags";s:9:"\0*\0status";b:1;s:7:"\0*\0uuid";s:36:"2b96be3b-b152-45c3-b641-eb7aa053b6aa";s:11:"\0*\0langcode";s:2:"en";s:23:"\0*\0third_party_settings";a:0:{}s:8:"\0*\0_core";a:1:{s:19:"default_config_hash";s:43:"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs";}s:14:"\0*\0trustedData";b:1;s:15:"\0*\0dependencies";a:1:{s:6:"module";a:2:{i:0;s:4:"node";i:1;s:8:"taxonomy";}}s:12:"\0*\0isSyncing";b:0;s:5:"\0*\0id";s:15:"node.field_tags";s:13:"\0*\0field_name";s:10:"field_tags";s:14:"\0*\0entity_type";s:4:"node";s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0module";s:4:"core";s:11:"\0*\0settings";a:1:{s:11:"target_type";s:13:"taxonomy_term";}s:14:"\0*\0cardinality";i:-1;s:15:"\0*\0translatable";b:1;s:9:"\0*\0locked";b:0;s:25:"\0*\0persist_with_no_fields";b:0;s:14:"custom_storage";b:0;s:10:"\0*\0indexes";a:0:{}s:10:"\0*\0deleted";b:0;}}'),
('entity.definitions.installed', 'node_type.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:9:"node_type";s:8:"\0*\0class";s:27:"Drupal\\node\\Entity\\NodeType";s:11:"\0*\0provider";s:4:"node";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:4:"type";s:5:"label";s:4:"name";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:27:"Drupal\\node\\Entity\\NodeType";s:11:"\0*\0handlers";a:5:{s:6:"access";s:40:"Drupal\\node\\NodeTypeAccessControlHandler";s:4:"form";a:3:{s:3:"add";s:24:"Drupal\\node\\NodeTypeForm";s:4:"edit";s:24:"Drupal\\node\\NodeTypeForm";s:6:"delete";s:38:"Drupal\\node\\Form\\NodeTypeDeleteConfirm";}s:14:"route_provider";a:1:{s:11:"permissions";s:49:"Drupal\\user\\Entity\\EntityPermissionsRouteProvider";}s:12:"list_builder";s:31:"Drupal\\node\\NodeTypeListBuilder";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";s:24:"administer content types";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:4:{s:9:"edit-form";s:41:"/admin/structure/types/manage/{node_type}";s:11:"delete-form";s:48:"/admin/structure/types/manage/{node_type}/delete";s:23:"entity-permissions-form";s:53:"/admin/structure/types/manage/{node_type}/permissions";s:10:"collection";s:22:"/admin/structure/types";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";s:4:"node";s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Content type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Content types";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"content type";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"content types";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:19:"@count content type";s:6:"plural";s:20:"@count content types";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:21:"config:node_type_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:4:"type";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:7:{i:0;s:4:"name";i:1;s:4:"type";i:2;s:11:"description";i:3;s:4:"help";i:4;s:12:"new_revision";i:5;s:12:"preview_mode";i:6;s:17:"display_submitted";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'path_alias.entity_type', 'O:36:"Drupal\\Core\\Entity\\ContentEntityType":41:{s:5:"\0*\0id";s:10:"path_alias";s:8:"\0*\0class";s:34:"Drupal\\path_alias\\Entity\\PathAlias";s:11:"\0*\0provider";s:10:"path_alias";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:8:"revision";s:11:"revision_id";s:8:"langcode";s:8:"langcode";s:4:"uuid";s:4:"uuid";s:9:"published";s:6:"status";s:6:"bundle";s:0:"";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";}s:16:"\0*\0originalClass";s:34:"Drupal\\path_alias\\Entity\\PathAlias";s:11:"\0*\0handlers";a:4:{s:7:"storage";s:34:"Drupal\\path_alias\\PathAliasStorage";s:14:"storage_schema";s:40:"Drupal\\path_alias\\PathAliasStorageSchema";s:6:"access";s:45:"Drupal\\Core\\Entity\\EntityAccessControlHandler";s:12:"view_builder";s:36:"Drupal\\Core\\Entity\\EntityViewBuilder";}s:19:"\0*\0admin_permission";s:22:"administer url aliases";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";s:10:"path_alias";s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";s:19:"path_alias_revision";s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"URL alias";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"URL aliases";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"URL alias";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"URL aliases";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:16:"@count URL alias";s:6:"plural";s:18:"@count URL aliases";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:7:"content";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:11:"route_match";}s:14:"\0*\0constraints";a:2:{s:15:"UniquePathAlias";a:0:{}s:26:"EntityUntranslatableFields";N;}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:25:"\0*\0revision_metadata_keys";a:1:{s:16:"revision_default";s:16:"revision_default";}}'),
('entity.definitions.installed', 'path_alias.field_storage_definitions', 'a:8:{s:2:"id";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:8:"provider";s:10:"path_alias";s:10:"field_name";s:2:"id";s:11:"entity_type";s:10:"path_alias";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:2;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"uuid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"UUID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:8:"provider";s:10:"path_alias";s:10:"field_name";s:4:"uuid";s:11:"entity_type";s:10:"path_alias";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:uuid";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:36;}s:7:"\0*\0type";s:4:"uuid";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;}}s:11:"unique keys";a:1:{s:5:"value";a:1:{i:0;s:5:"value";}}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:11:"revision_id";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Revision ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:8:"provider";s:10:"path_alias";s:10:"field_name";s:11:"revision_id";s:11:"entity_type";s:10:"path_alias";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:69;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Language";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:15:"language_select";s:6:"weight";i:2;}}}s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";s:3:"und";}}s:8:"provider";s:10:"path_alias";s:10:"field_name";s:8:"langcode";s:11:"entity_type";s:10:"path_alias";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:103;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"path";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"System path";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:36:"The path that this alias belongs to.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:12:"revisionable";b:1;s:8:"provider";s:10:"path_alias";s:10:"field_name";s:4:"path";s:11:"entity_type";s:10:"path_alias";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:3:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}s:11:"constraints";a:1:{s:11:"ComplexData";a:1:{s:5:"value";a:2:{s:9:"ValidPath";a:0:{}s:5:"Regex";a:2:{s:7:"pattern";s:6:"/^\\//i";s:7:"message";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:42:"The source path has to start with a slash.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}}}}s:18:"\0*\0fieldDefinition";r:141;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:5:"alias";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"URL alias";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:29:"An alias used with this path.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:12:"revisionable";b:1;s:8:"provider";s:10:"path_alias";s:10:"field_name";s:5:"alias";s:11:"entity_type";s:10:"path_alias";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:3:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}s:11:"constraints";a:1:{s:11:"ComplexData";a:1:{s:5:"value";a:1:{s:5:"Regex";a:2:{s:7:"pattern";s:6:"/^\\//i";s:7:"message";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:41:"The alias path has to start with a slash.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}}}}s:18:"\0*\0fieldDefinition";r:187;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"status";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Published";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:0;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:8:"provider";s:10:"path_alias";s:10:"field_name";s:6:"status";s:11:"entity_type";s:10:"path_alias";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:232;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"revision_default";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:11:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Default revision";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:72:"A flag indicating whether this was a default revision when it was saved.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:16:"storage_required";b:1;s:8:"internal";b:1;s:12:"translatable";b:0;s:12:"revisionable";b:1;s:8:"provider";s:10:"path_alias";s:10:"field_name";s:16:"revision_default";s:11:"entity_type";s:10:"path_alias";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:271;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}}'),
('entity.definitions.installed', 'search_page.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:11:"search_page";s:8:"\0*\0class";s:31:"Drupal\\search\\Entity\\SearchPage";s:11:"\0*\0provider";s:6:"search";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:10:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:6:"weight";s:6:"weight";s:6:"status";s:6:"status";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:31:"Drupal\\search\\Entity\\SearchPage";s:11:"\0*\0handlers";a:4:{s:6:"access";s:44:"Drupal\\search\\SearchPageAccessControlHandler";s:12:"list_builder";s:35:"Drupal\\search\\SearchPageListBuilder";s:4:"form";a:3:{s:3:"add";s:36:"Drupal\\search\\Form\\SearchPageAddForm";s:4:"edit";s:37:"Drupal\\search\\Form\\SearchPageEditForm";s:6:"delete";s:35:"Drupal\\Core\\Entity\\EntityDeleteForm";}s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";s:17:"administer search";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:6:{s:9:"edit-form";s:47:"/admin/config/search/pages/manage/{search_page}";s:11:"delete-form";s:54:"/admin/config/search/pages/manage/{search_page}/delete";s:6:"enable";s:54:"/admin/config/search/pages/manage/{search_page}/enable";s:7:"disable";s:55:"/admin/config/search/pages/manage/{search_page}/disable";s:11:"set-default";s:59:"/admin/config/search/pages/manage/{search_page}/set-default";s:10:"collection";s:26:"/admin/config/search/pages";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Search page";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Search pages";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"search page";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"search pages";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:18:"@count search page";s:6:"plural";s:19:"@count search pages";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:23:"config:search_page_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:4:"page";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:6:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:4:"path";i:3;s:6:"weight";i:4;s:6:"plugin";i:5;s:13:"configuration";}s:21:"\0*\0mergedConfigExport";a:0:{}}');
INSERT INTO `[[dbprefix]]key_value` VALUES
('entity.definitions.installed', 'shortcut.entity_type', 'O:36:"Drupal\\Core\\Entity\\ContentEntityType":41:{s:5:"\0*\0id";s:8:"shortcut";s:8:"\0*\0class";s:31:"Drupal\\shortcut\\Entity\\Shortcut";s:11:"\0*\0provider";s:8:"shortcut";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:4:"uuid";s:4:"uuid";s:6:"bundle";s:12:"shortcut_set";s:5:"label";s:5:"title";s:8:"langcode";s:8:"langcode";s:8:"revision";s:0:"";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";}s:16:"\0*\0originalClass";s:31:"Drupal\\shortcut\\Entity\\Shortcut";s:11:"\0*\0handlers";a:4:{s:6:"access";s:44:"Drupal\\shortcut\\ShortcutAccessControlHandler";s:4:"form";a:4:{s:7:"default";s:28:"Drupal\\shortcut\\ShortcutForm";s:3:"add";s:28:"Drupal\\shortcut\\ShortcutForm";s:4:"edit";s:28:"Drupal\\shortcut\\ShortcutForm";s:6:"delete";s:39:"Drupal\\shortcut\\Form\\ShortcutDeleteForm";}s:7:"storage";s:46:"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage";s:12:"view_builder";s:36:"Drupal\\Core\\Entity\\EntityViewBuilder";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:3:{s:9:"canonical";s:53:"/admin/config/user-interface/shortcut/link/{shortcut}";s:11:"delete-form";s:60:"/admin/config/user-interface/shortcut/link/{shortcut}/delete";s:9:"edit-form";s:53:"/admin/config/user-interface/shortcut/link/{shortcut}";}s:21:"\0*\0bundle_entity_type";s:12:"shortcut_set";s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Shortcut set";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"\0*\0base_table";s:8:"shortcut";s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";s:19:"shortcut_field_data";s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:1;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Shortcut link";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"Shortcut links";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"shortcut link";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"shortcut links";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:20:"@count shortcut link";s:6:"plural";s:21:"@count shortcut links";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:7:"content";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:24:"config:shortcut_set_list";}s:14:"\0*\0constraints";a:1:{s:26:"EntityUntranslatableFields";N;}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:25:"\0*\0revision_metadata_keys";a:1:{s:16:"revision_default";s:16:"revision_default";}}'),
('entity.definitions.installed', 'shortcut.field_storage_definitions', 'a:8:{s:2:"id";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:23:"The ID of the shortcut.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:8:"shortcut";s:10:"field_name";s:2:"id";s:11:"entity_type";s:8:"shortcut";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:2;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"uuid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"UUID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:25:"The UUID of the shortcut.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:8:"shortcut";s:10:"field_name";s:4:"uuid";s:11:"entity_type";s:8:"shortcut";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:uuid";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:40;}s:7:"\0*\0type";s:4:"uuid";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;}}s:11:"unique keys";a:1:{s:5:"value";a:1:{i:0;s:5:"value";}}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Language";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:15:"language_select";s:6:"weight";i:2;}}}s:12:"translatable";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:34:"The language code of the shortcut.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:8:"shortcut";s:10:"field_name";s:8:"langcode";s:11:"entity_type";s:8:"shortcut";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:77;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:12:"shortcut_set";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Shortcut set";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:27:"The bundle of the shortcut.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:8:"shortcut";s:10:"field_name";s:12:"shortcut_set";s:11:"entity_type";s:8:"shortcut";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:12:"shortcut_set";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:116;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:5:"title";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Name";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:25:"The name of the shortcut.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:12:"translatable";b:1;s:7:"display";a:1:{s:4:"form";a:1:{s:7:"options";a:3:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:-10;s:8:"settings";a:1:{s:4:"size";i:40;}}}}s:8:"provider";s:8:"shortcut";s:10:"field_name";s:5:"title";s:11:"entity_type";s:8:"shortcut";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:154;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"weight";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"Weight";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:48:"Weight among shortcuts in the same shortcut set.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:8:"shortcut";s:10:"field_name";s:6:"weight";s:11:"entity_type";s:8:"shortcut";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:0;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:197;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:0;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"link";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Path";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:37:"The location this shortcut points to.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:7:"display";a:1:{s:4:"form";a:2:{s:7:"options";a:2:{s:4:"type";s:12:"link_default";s:6:"weight";i:0;}s:12:"configurable";b:1;}}s:8:"provider";s:8:"shortcut";s:10:"field_name";s:4:"link";s:11:"entity_type";s:8:"shortcut";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:link";s:8:"settings";a:2:{s:5:"title";i:0;s:9:"link_type";i:1;}}s:18:"\0*\0fieldDefinition";r:234;}s:7:"\0*\0type";s:4:"link";s:9:"\0*\0schema";a:4:{s:7:"columns";a:3:{s:3:"uri";a:3:{s:11:"description";s:20:"The URI of the link.";s:4:"type";s:7:"varchar";s:6:"length";i:2048;}s:5:"title";a:3:{s:11:"description";s:14:"The link text.";s:4:"type";s:7:"varchar";s:6:"length";i:255;}s:7:"options";a:4:{s:11:"description";s:41:"Serialized array of options for the link.";s:4:"type";s:4:"blob";s:4:"size";s:3:"big";s:9:"serialize";b:1;}}s:7:"indexes";a:1:{s:3:"uri";a:1:{i:0;a:2:{i:0;s:3:"uri";i:1;i:30;}}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"default_langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Default translation";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:58:"A flag indicating whether this is the default translation.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:8:"provider";s:8:"shortcut";s:10:"field_name";s:16:"default_langcode";s:11:"entity_type";s:8:"shortcut";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:287;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}}'),
('entity.definitions.installed', 'shortcut_set.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:12:"shortcut_set";s:8:"\0*\0class";s:34:"Drupal\\shortcut\\Entity\\ShortcutSet";s:11:"\0*\0provider";s:8:"shortcut";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:8:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:34:"Drupal\\shortcut\\Entity\\ShortcutSet";s:11:"\0*\0handlers";a:4:{s:7:"storage";s:34:"Drupal\\shortcut\\ShortcutSetStorage";s:6:"access";s:47:"Drupal\\shortcut\\ShortcutSetAccessControlHandler";s:12:"list_builder";s:38:"Drupal\\shortcut\\ShortcutSetListBuilder";s:4:"form";a:5:{s:7:"default";s:31:"Drupal\\shortcut\\ShortcutSetForm";s:3:"add";s:31:"Drupal\\shortcut\\ShortcutSetForm";s:4:"edit";s:31:"Drupal\\shortcut\\ShortcutSetForm";s:9:"customize";s:33:"Drupal\\shortcut\\Form\\SetCustomize";s:6:"delete";s:42:"Drupal\\shortcut\\Form\\ShortcutSetDeleteForm";}}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:4:{s:14:"customize-form";s:69:"/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize";s:11:"delete-form";s:66:"/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete";s:9:"edit-form";s:59:"/admin/config/user-interface/shortcut/manage/{shortcut_set}";s:10:"collection";s:37:"/admin/config/user-interface/shortcut";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";s:8:"shortcut";s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Shortcut set";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Shortcut sets";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"shortcut set";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"shortcut sets";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:19:"@count shortcut set";s:6:"plural";s:20:"@count shortcut sets";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:24:"config:shortcut_set_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:3:"set";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:2:{i:0;s:2:"id";i:1;s:5:"label";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'taxonomy_term.entity_type', 'O:36:"Drupal\\Core\\Entity\\ContentEntityType":41:{s:5:"\0*\0id";s:13:"taxonomy_term";s:8:"\0*\0class";s:27:"Drupal\\taxonomy\\Entity\\Term";s:11:"\0*\0provider";s:8:"taxonomy";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:9:{s:2:"id";s:3:"tid";s:8:"revision";s:11:"revision_id";s:6:"bundle";s:3:"vid";s:5:"label";s:4:"name";s:8:"langcode";s:8:"langcode";s:4:"uuid";s:4:"uuid";s:9:"published";s:6:"status";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";}s:16:"\0*\0originalClass";s:27:"Drupal\\taxonomy\\Entity\\Term";s:11:"\0*\0handlers";a:9:{s:7:"storage";s:27:"Drupal\\taxonomy\\TermStorage";s:14:"storage_schema";s:33:"Drupal\\taxonomy\\TermStorageSchema";s:12:"view_builder";s:36:"Drupal\\Core\\Entity\\EntityViewBuilder";s:12:"list_builder";s:36:"Drupal\\Core\\Entity\\EntityListBuilder";s:6:"access";s:40:"Drupal\\taxonomy\\TermAccessControlHandler";s:10:"views_data";s:29:"Drupal\\taxonomy\\TermViewsData";s:4:"form";a:4:{s:7:"default";s:24:"Drupal\\taxonomy\\TermForm";s:6:"delete";s:35:"Drupal\\taxonomy\\Form\\TermDeleteForm";s:15:"revision-delete";s:42:"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm";s:15:"revision-revert";s:42:"Drupal\\Core\\Entity\\Form\\RevisionRevertForm";}s:14:"route_provider";a:1:{s:8:"revision";s:52:"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider";}s:11:"translation";s:38:"Drupal\\taxonomy\\TermTranslationHandler";}s:19:"\0*\0admin_permission";N;s:24:"\0*\0collection_permission";s:24:"access taxonomy overview";s:25:"\0*\0permission_granularity";s:6:"bundle";s:8:"\0*\0links";a:8:{s:9:"canonical";s:30:"/taxonomy/term/{taxonomy_term}";s:11:"delete-form";s:37:"/taxonomy/term/{taxonomy_term}/delete";s:9:"edit-form";s:35:"/taxonomy/term/{taxonomy_term}/edit";s:6:"create";s:14:"/taxonomy/term";s:8:"revision";s:69:"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view";s:20:"revision-delete-form";s:71:"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete";s:20:"revision-revert-form";s:71:"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert";s:15:"version-history";s:40:"/taxonomy/term/{taxonomy_term}/revisions";}s:21:"\0*\0bundle_entity_type";s:19:"taxonomy_vocabulary";s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"Vocabulary";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"\0*\0base_table";s:18:"taxonomy_term_data";s:22:"\0*\0revision_data_table";s:28:"taxonomy_term_field_revision";s:17:"\0*\0revision_table";s:22:"taxonomy_term_revision";s:13:"\0*\0data_table";s:24:"taxonomy_term_field_data";s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:1;s:19:"\0*\0show_revision_ui";b:1;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Taxonomy term";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"Taxonomy terms";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"taxonomy term";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"taxonomy terms";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:20:"@count taxonomy term";s:6:"plural";s:21:"@count taxonomy terms";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:7:"content";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";s:40:"entity.taxonomy_vocabulary.overview_form";s:26:"\0*\0common_reference_target";b:1;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:18:"taxonomy_term_list";}s:14:"\0*\0constraints";a:3:{s:17:"TaxonomyHierarchy";a:0:{}s:13:"EntityChanged";N;s:26:"EntityUntranslatableFields";N;}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:25:"\0*\0revision_metadata_keys";a:4:{s:13:"revision_user";s:13:"revision_user";s:16:"revision_created";s:16:"revision_created";s:20:"revision_log_message";s:20:"revision_log_message";s:16:"revision_default";s:16:"revision_default";}}'),
('entity.definitions.installed', 'taxonomy_term.field_storage_definitions', 'a:17:{s:3:"tid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Term ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"The term ID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:3:"tid";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:2;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"uuid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"UUID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"The term UUID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:4:"uuid";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:uuid";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:40;}s:7:"\0*\0type";s:4:"uuid";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;}}s:11:"unique keys";a:1:{s:5:"value";a:1:{i:0;s:5:"value";}}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:11:"revision_id";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Revision ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:11:"revision_id";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:77;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Language";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}s:4:"form";a:1:{s:7:"options";a:2:{s:4:"type";s:15:"language_select";s:6:"weight";i:2;}}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:23:"The term language code.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:8:"langcode";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:111;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:3:"vid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"Vocabulary";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:45:"The vocabulary to which the term is assigned.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:3:"vid";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:19:"taxonomy_vocabulary";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:151;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"revision_created";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:20:"Revision create time";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:47:"The time that the current revision was created.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:16:"revision_created";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:created";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:189;}s:7:"\0*\0type";s:7:"created";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:13:"revision_user";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Revision user";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:50:"The user ID of the author of the current revision.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:13:"revision_user";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:4:"user";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:219;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:20:"revision_log_message";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:20:"Revision log message";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:43:"Briefly describe the changes you have made.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";s:0:"";}}s:7:"display";a:1:{s:4:"form";a:1:{s:7:"options";a:3:{s:4:"type";s:15:"string_textarea";s:6:"weight";i:25;s:8:"settings";a:1:{s:4:"rows";i:4;}}}}s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:20:"revision_log_message";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:22:"field_item:string_long";s:8:"settings";a:1:{s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:256;}s:7:"\0*\0type";s:11:"string_long";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"status";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Published";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"revisionable";b:1;s:12:"translatable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:7:"display";a:1:{s:4:"form";a:2:{s:7:"options";a:3:{s:4:"type";s:16:"boolean_checkbox";s:8:"settings";a:1:{s:13:"display_label";b:1;}s:6:"weight";i:100;}s:12:"configurable";b:1;}}s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:6:"status";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:3:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}s:5:"class";s:22:"Drupal\\user\\StatusItem";}s:18:"\0*\0fieldDefinition";r:298;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"name";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Name";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:8:"required";b:1;s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:3:{s:5:"label";s:6:"hidden";s:4:"type";s:6:"string";s:6:"weight";i:-5;}}s:4:"form";a:2:{s:7:"options";a:2:{s:4:"type";s:16:"string_textfield";s:6:"weight";i:-5;}s:12:"configurable";b:1;}}s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:4:"name";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:346;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:11:"description";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Description";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:7:"display";a:2:{s:4:"view";a:2:{s:7:"options";a:3:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;}s:12:"configurable";b:1;}s:4:"form";a:2:{s:7:"options";a:2:{s:4:"type";s:14:"text_textfield";s:6:"weight";i:0;}s:12:"configurable";b:1;}}s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:11:"description";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:20:"field_item:text_long";s:8:"settings";a:1:{s:15:"allowed_formats";a:0:{}}}s:18:"\0*\0fieldDefinition";r:390;}s:7:"\0*\0type";s:9:"text_long";s:9:"\0*\0schema";a:4:{s:7:"columns";a:2:{s:5:"value";a:2:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";}s:6:"format";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;}}s:7:"indexes";a:1:{s:6:"format";a:1:{i:0;s:6:"format";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"weight";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"Weight";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:51:"The weight of this term in relation to other terms.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";i:0;}}s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:6:"weight";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:0;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:436;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:0;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"parent";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Term Parents";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:25:"The parents of this term.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"cardinality";i:-1;s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:6:"parent";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:13:"taxonomy_term";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:476;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"changed";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Changed";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:39:"The time that the term was last edited.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:7:"changed";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:changed";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:512;}s:7:"\0*\0type";s:7:"changed";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"default_langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Default translation";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:58:"A flag indicating whether this is the default translation.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:16:"default_langcode";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:543;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"revision_default";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:11:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Default revision";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:72:"A flag indicating whether this was a default revision when it was saved.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:16:"storage_required";b:1;s:8:"internal";b:1;s:12:"translatable";b:0;s:12:"revisionable";b:1;s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:16:"revision_default";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:586;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:29:"revision_translation_affected";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:29:"Revision translation affected";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:72:"Indicates if the last edit of a translation belongs to current revision.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:12:"revisionable";b:1;s:12:"translatable";b:1;s:8:"provider";s:8:"taxonomy";s:10:"field_name";s:29:"revision_translation_affected";s:11:"entity_type";s:13:"taxonomy_term";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:628;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}}'),
('entity.definitions.installed', 'taxonomy_vocabulary.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:19:"taxonomy_vocabulary";s:8:"\0*\0class";s:33:"Drupal\\taxonomy\\Entity\\Vocabulary";s:11:"\0*\0provider";s:8:"taxonomy";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:9:{s:2:"id";s:3:"vid";s:5:"label";s:4:"name";s:6:"weight";s:6:"weight";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:33:"Drupal\\taxonomy\\Entity\\Vocabulary";s:11:"\0*\0handlers";a:5:{s:7:"storage";s:33:"Drupal\\taxonomy\\VocabularyStorage";s:12:"list_builder";s:37:"Drupal\\taxonomy\\VocabularyListBuilder";s:6:"access";s:46:"Drupal\\taxonomy\\VocabularyAccessControlHandler";s:4:"form";a:4:{s:7:"default";s:30:"Drupal\\taxonomy\\VocabularyForm";s:5:"reset";s:40:"Drupal\\taxonomy\\Form\\VocabularyResetForm";s:6:"delete";s:41:"Drupal\\taxonomy\\Form\\VocabularyDeleteForm";s:8:"overview";s:34:"Drupal\\taxonomy\\Form\\OverviewTerms";}s:14:"route_provider";a:2:{s:4:"html";s:54:"Drupal\\taxonomy\\Entity\\Routing\\VocabularyRouteProvider";s:11:"permissions";s:49:"Drupal\\user\\Entity\\EntityPermissionsRouteProvider";}}s:19:"\0*\0admin_permission";s:19:"administer taxonomy";s:24:"\0*\0collection_permission";s:24:"access taxonomy overview";s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:7:{s:8:"add-form";s:29:"/admin/structure/taxonomy/add";s:11:"delete-form";s:61:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete";s:10:"reset-form";s:60:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset";s:13:"overview-form";s:63:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview";s:9:"edit-form";s:54:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}";s:23:"entity-permissions-form";s:75:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions";s:10:"collection";s:25:"/admin/structure/taxonomy";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";s:13:"taxonomy_term";s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Taxonomy vocabulary";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Taxonomy";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"vocabulary";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"vocabularies";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:17:"@count vocabulary";s:6:"plural";s:19:"@count vocabularies";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:31:"config:taxonomy_vocabulary_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:10:"vocabulary";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:5:{i:0;s:4:"name";i:1;s:3:"vid";i:2;s:11:"description";i:3;s:6:"weight";i:4;s:12:"new_revision";}s:21:"\0*\0mergedConfigExport";a:0:{}}');
INSERT INTO `[[dbprefix]]key_value` VALUES
('entity.definitions.installed', 'user.entity_type', 'O:36:"Drupal\\Core\\Entity\\ContentEntityType":41:{s:5:"\0*\0id";s:4:"user";s:8:"\0*\0class";s:23:"Drupal\\user\\Entity\\User";s:11:"\0*\0provider";s:4:"user";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:7:{s:2:"id";s:3:"uid";s:8:"langcode";s:8:"langcode";s:4:"uuid";s:4:"uuid";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";}s:16:"\0*\0originalClass";s:23:"Drupal\\user\\Entity\\User";s:11:"\0*\0handlers";a:9:{s:7:"storage";s:23:"Drupal\\user\\UserStorage";s:14:"storage_schema";s:29:"Drupal\\user\\UserStorageSchema";s:6:"access";s:36:"Drupal\\user\\UserAccessControlHandler";s:12:"list_builder";s:27:"Drupal\\user\\UserListBuilder";s:10:"views_data";s:25:"Drupal\\user\\UserViewsData";s:14:"route_provider";a:1:{s:4:"html";s:36:"Drupal\\user\\Entity\\UserRouteProvider";}s:4:"form";a:3:{s:7:"default";s:23:"Drupal\\user\\ProfileForm";s:6:"cancel";s:31:"Drupal\\user\\Form\\UserCancelForm";s:8:"register";s:24:"Drupal\\user\\RegisterForm";}s:11:"translation";s:37:"Drupal\\user\\ProfileTranslationHandler";s:12:"view_builder";s:36:"Drupal\\Core\\Entity\\EntityViewBuilder";}s:19:"\0*\0admin_permission";s:16:"administer users";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:4:{s:9:"canonical";s:12:"/user/{user}";s:9:"edit-form";s:17:"/user/{user}/edit";s:11:"cancel-form";s:19:"/user/{user}/cancel";s:10:"collection";s:13:"/admin/people";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";s:5:"users";s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";s:16:"users_field_data";s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:1;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"User";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Users";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"user";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"users";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:11:"@count user";s:6:"plural";s:12:"@count users";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:7:"content";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";s:22:"entity.user.admin_form";s:26:"\0*\0common_reference_target";b:1;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:9:"user_list";}s:14:"\0*\0constraints";a:2:{s:13:"EntityChanged";N;s:26:"EntityUntranslatableFields";N;}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:25:"\0*\0revision_metadata_keys";a:1:{s:16:"revision_default";s:16:"revision_default";}}'),
('entity.definitions.installed', 'user.field_storage_definitions', 'a:18:{s:3:"uid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"User ID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"The user ID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"user";s:10:"field_name";s:3:"uid";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:integer";s:8:"settings";a:6:{s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:3:"min";s:0:"";s:3:"max";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";}}s:18:"\0*\0fieldDefinition";r:2;}s:7:"\0*\0type";s:7:"integer";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"uuid";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"UUID";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"read-only";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"The user UUID.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"user";s:10:"field_name";s:4:"uuid";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:15:"field_item:uuid";s:8:"settings";a:3:{s:10:"max_length";i:128;s:8:"is_ascii";b:1;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:40;}s:7:"\0*\0type";s:4:"uuid";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;}}s:11:"unique keys";a:1:{s:5:"value";a:1:{i:0;s:5:"value";}}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Language code";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:7:"display";a:2:{s:4:"view";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}s:4:"form";a:1:{s:7:"options";a:1:{s:6:"region";s:6:"hidden";}}}s:12:"translatable";b:1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:23:"The user language code.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"user";s:10:"field_name";s:8:"langcode";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:77;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:18:"preferred_langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:23:"Preferred language code";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:77:"The user''s preferred language code for receiving emails and viewing the site.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"user";s:10:"field_name";s:18:"preferred_langcode";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:3:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}s:11:"constraints";a:1:{s:11:"ComplexData";a:1:{s:5:"value";a:2:{s:13:"AllowedValues";a:1:{s:8:"callback";s:60:"Drupal\\user\\Entity\\User::getAllowedConfigurableLanguageCodes";}s:6:"Length";a:1:{s:3:"max";i:12;}}}}}s:18:"\0*\0fieldDefinition";r:115;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:24:"preferred_admin_langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:29:"Preferred admin language code";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:68:"The user''s preferred language code for viewing administration pages.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";N;}}s:8:"provider";s:4:"user";s:10:"field_name";s:24:"preferred_admin_langcode";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:3:{s:4:"type";s:19:"field_item:language";s:8:"settings";a:0:{}s:11:"constraints";a:1:{s:11:"ComplexData";a:1:{s:5:"value";a:2:{s:13:"AllowedValues";a:1:{s:8:"callback";s:60:"Drupal\\user\\Entity\\User::getAllowedConfigurableLanguageCodes";}s:6:"Length";a:1:{s:3:"max";i:12;}}}}}s:18:"\0*\0fieldDefinition";r:152;}s:7:"\0*\0type";s:8:"language";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"name";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Name";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:22:"The name of this user.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"required";b:1;s:11:"constraints";a:2:{s:8:"UserName";a:0:{}s:14:"UserNameUnique";a:0:{}}s:8:"provider";s:4:"user";s:10:"field_name";s:4:"name";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:3:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}s:5:"class";s:25:"\\Drupal\\user\\UserNameItem";}s:18:"\0*\0fieldDefinition";r:192;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"pass";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Password";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:35:"The password of this user (hashed).";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"constraints";a:1:{s:18:"ProtectedUserField";N;}s:8:"provider";s:4:"user";s:10:"field_name";s:4:"pass";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:19:"field_item:password";s:8:"settings";a:3:{s:10:"max_length";i:255;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}}s:18:"\0*\0fieldDefinition";r:231;}s:7:"\0*\0type";s:8:"password";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"mail";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:9:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Email";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:23:"The email of this user.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";s:0:"";}}s:11:"constraints";a:3:{s:14:"UserMailUnique";N;s:16:"UserMailRequired";N;s:18:"ProtectedUserField";N;}s:8:"provider";s:4:"user";s:10:"field_name";s:4:"mail";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:16:"field_item:email";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:267;}s:7:"\0*\0type";s:5:"email";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:7:"varchar";s:6:"length";i:254;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:8:"timezone";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Timezone";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:26:"The timezone of this user.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"user";s:10:"field_name";s:8:"timezone";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:4:{s:4:"type";s:17:"field_item:string";s:8:"settings";a:3:{s:10:"max_length";i:32;s:8:"is_ascii";b:0;s:14:"case_sensitive";b:0;}s:11:"constraints";a:1:{s:11:"ComplexData";a:1:{s:5:"value";a:1:{s:13:"AllowedValues";a:1:{s:8:"callback";s:44:"Drupal\\user\\Entity\\User::getAllowedTimezones";}}}}s:5:"class";s:24:"Drupal\\user\\TimeZoneItem";}s:18:"\0*\0fieldDefinition";r:304;}s:7:"\0*\0type";s:6:"string";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:32;s:6:"binary";b:0;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"status";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"User status";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:38:"Whether the user is active or blocked.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:0;}}s:8:"provider";s:4:"user";s:10:"field_name";s:6:"status";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:3:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}s:5:"class";s:22:"Drupal\\user\\StatusItem";}s:18:"\0*\0fieldDefinition";r:344;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"created";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Created";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:35:"The time that the user was created.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"user";s:10:"field_name";s:7:"created";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:created";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:386;}s:7:"\0*\0type";s:7:"created";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:7:"changed";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Changed";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:39:"The time that the user was last edited.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:8:"provider";s:4:"user";s:10:"field_name";s:7:"changed";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:changed";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:415;}s:7:"\0*\0type";s:7:"changed";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:6:"access";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Last access";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:46:"The time that the user last accessed the site.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";i:0;}}s:8:"provider";s:4:"user";s:10:"field_name";s:6:"access";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:20:"field_item:timestamp";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:445;}s:7:"\0*\0type";s:9:"timestamp";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:5:"login";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"Last login";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:38:"The time that the user last logged in.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";i:0;}}s:8:"provider";s:4:"user";s:10:"field_name";s:5:"login";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:20:"field_item:timestamp";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:477;}s:7:"\0*\0type";s:9:"timestamp";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:1:{s:4:"type";s:3:"int";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:4:"init";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:8:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Initial email";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:52:"The email address used for initial account creation.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";s:0:"";}}s:8:"provider";s:4:"user";s:10:"field_name";s:4:"init";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:16:"field_item:email";s:8:"settings";a:0:{}}s:18:"\0*\0fieldDefinition";r:509;}s:7:"\0*\0type";s:5:"email";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:7:"varchar";s:6:"length";i:254;}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:5:"roles";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:7:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Roles";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"cardinality";i:-1;s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:23:"The roles the user has.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:8:"provider";s:4:"user";s:10:"field_name";s:5:"roles";s:11:"entity_type";s:4:"user";s:6:"bundle";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:27:"field_item:entity_reference";s:8:"settings";a:3:{s:11:"target_type";s:9:"user_role";s:7:"handler";s:7:"default";s:16:"handler_settings";a:0:{}}}s:18:"\0*\0fieldDefinition";r:542;}s:7:"\0*\0type";s:16:"entity_reference";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:9:"target_id";a:3:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;}}s:7:"indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:11:"unique keys";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:16:"default_langcode";O:37:"Drupal\\Core\\Field\\BaseFieldDefinition":5:{s:13:"\0*\0definition";a:10:{s:5:"label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Default translation";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:11:"description";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:58:"A flag indicating whether this is the default translation.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:12:"translatable";b:1;s:12:"revisionable";b:1;s:13:"default_value";a:1:{i:0;a:1:{s:5:"value";b:1;}}s:8:"provider";s:4:"user";s:10:"field_name";s:16:"default_langcode";s:11:"entity_type";s:4:"user";s:6:"bundle";N;s:13:"initial_value";N;}s:17:"\0*\0itemDefinition";O:51:"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition":2:{s:13:"\0*\0definition";a:2:{s:4:"type";s:18:"field_item:boolean";s:8:"settings";a:2:{s:8:"on_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:2:"On";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:9:"off_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:3:"Off";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}}}s:18:"\0*\0fieldDefinition";r:578;}s:7:"\0*\0type";s:7:"boolean";s:9:"\0*\0schema";a:4:{s:7:"columns";a:1:{s:5:"value";a:2:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";}}s:11:"unique keys";a:0:{}s:7:"indexes";a:0:{}s:12:"foreign keys";a:0:{}}s:10:"\0*\0indexes";a:0:{}}s:12:"user_picture";O:38:"Drupal\\field\\Entity\\FieldStorageConfig":30:{s:15:"\0*\0entityTypeId";s:20:"field_storage_config";s:15:"\0*\0enforceIsNew";b:1;s:12:"\0*\0typedData";N;s:16:"\0*\0cacheContexts";a:0:{}s:12:"\0*\0cacheTags";a:0:{}s:14:"\0*\0cacheMaxAge";i:-1;s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:13:"\0*\0originalId";s:17:"user.user_picture";s:9:"\0*\0status";b:1;s:7:"\0*\0uuid";s:36:"ba3d61d8-4eb7-46de-ba22-28dcaaa22262";s:11:"\0*\0langcode";s:2:"en";s:23:"\0*\0third_party_settings";a:0:{}s:8:"\0*\0_core";a:1:{s:19:"default_config_hash";s:43:"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E";}s:14:"\0*\0trustedData";b:1;s:15:"\0*\0dependencies";a:1:{s:6:"module";a:3:{i:0;s:4:"file";i:1;s:5:"image";i:2;s:4:"user";}}s:12:"\0*\0isSyncing";b:0;s:5:"\0*\0id";s:17:"user.user_picture";s:13:"\0*\0field_name";s:12:"user_picture";s:14:"\0*\0entity_type";s:4:"user";s:7:"\0*\0type";s:5:"image";s:9:"\0*\0module";s:5:"image";s:11:"\0*\0settings";a:5:{s:11:"target_type";s:4:"file";s:13:"display_field";b:0;s:15:"display_default";b:0;s:10:"uri_scheme";s:6:"public";s:13:"default_image";a:5:{s:4:"uuid";N;s:3:"alt";s:0:"";s:5:"title";s:0:"";s:5:"width";N;s:6:"height";N;}}s:14:"\0*\0cardinality";i:1;s:15:"\0*\0translatable";b:1;s:9:"\0*\0locked";b:0;s:25:"\0*\0persist_with_no_fields";b:0;s:14:"custom_storage";b:0;s:10:"\0*\0indexes";a:1:{s:9:"target_id";a:1:{i:0;s:9:"target_id";}}s:10:"\0*\0deleted";b:0;}}'),
('entity.definitions.installed', 'user_role.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:9:"user_role";s:8:"\0*\0class";s:23:"Drupal\\user\\Entity\\Role";s:11:"\0*\0provider";s:4:"user";s:15:"\0*\0static_cache";b:1;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:9:{s:2:"id";s:2:"id";s:6:"weight";s:6:"weight";s:5:"label";s:5:"label";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:23:"Drupal\\user\\Entity\\Role";s:11:"\0*\0handlers";a:4:{s:7:"storage";s:23:"Drupal\\user\\RoleStorage";s:6:"access";s:36:"Drupal\\user\\RoleAccessControlHandler";s:12:"list_builder";s:27:"Drupal\\user\\RoleListBuilder";s:4:"form";a:2:{s:7:"default";s:20:"Drupal\\user\\RoleForm";s:6:"delete";s:35:"Drupal\\Core\\Entity\\EntityDeleteForm";}}s:19:"\0*\0admin_permission";s:22:"administer permissions";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:4:{s:11:"delete-form";s:45:"/admin/people/roles/manage/{user_role}/delete";s:9:"edit-form";s:38:"/admin/people/roles/manage/{user_role}";s:21:"edit-permissions-form";s:37:"/admin/people/permissions/{user_role}";s:10:"collection";s:19:"/admin/people/roles";}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Role";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Roles";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"role";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"roles";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:11:"@count role";s:6:"plural";s:12:"@count roles";s:7:"context";N;}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:21:"config:user_role_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";s:4:"role";s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:5:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:6:"weight";i:3;s:8:"is_admin";i:4;s:11:"permissions";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.definitions.installed', 'view.entity_type', 'O:42:"Drupal\\Core\\Config\\Entity\\ConfigEntityType":44:{s:5:"\0*\0id";s:4:"view";s:8:"\0*\0class";s:24:"Drupal\\views\\Entity\\View";s:11:"\0*\0provider";s:5:"views";s:15:"\0*\0static_cache";b:0;s:15:"\0*\0render_cache";b:1;s:19:"\0*\0persistent_cache";b:1;s:14:"\0*\0entity_keys";a:9:{s:2:"id";s:2:"id";s:5:"label";s:5:"label";s:6:"status";s:6:"status";s:8:"revision";s:0:"";s:6:"bundle";s:0:"";s:8:"langcode";s:8:"langcode";s:16:"default_langcode";s:16:"default_langcode";s:29:"revision_translation_affected";s:29:"revision_translation_affected";s:4:"uuid";s:4:"uuid";}s:16:"\0*\0originalClass";s:24:"Drupal\\views\\Entity\\View";s:11:"\0*\0handlers";a:2:{s:6:"access";s:45:"Drupal\\Core\\Entity\\EntityAccessControlHandler";s:7:"storage";s:45:"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage";}s:19:"\0*\0admin_permission";s:16:"administer views";s:24:"\0*\0collection_permission";N;s:25:"\0*\0permission_granularity";s:11:"entity_type";s:8:"\0*\0links";a:0:{}s:21:"\0*\0bundle_entity_type";N;s:12:"\0*\0bundle_of";N;s:15:"\0*\0bundle_label";N;s:13:"\0*\0base_table";N;s:22:"\0*\0revision_data_table";N;s:17:"\0*\0revision_table";N;s:13:"\0*\0data_table";N;s:11:"\0*\0internal";b:0;s:15:"\0*\0translatable";b:0;s:19:"\0*\0show_revision_ui";b:0;s:8:"\0*\0label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"View";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:16:"View entity type";}}s:19:"\0*\0label_collection";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Views";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:16:"View entity type";}}s:17:"\0*\0label_singular";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"view";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:16:"View entity type";}}s:15:"\0*\0label_plural";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"views";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:16:"View entity type";}}s:14:"\0*\0label_count";a:3:{s:8:"singular";s:11:"@count view";s:6:"plural";s:12:"@count views";s:7:"context";s:16:"View entity type";}s:15:"\0*\0uri_callback";N;s:8:"\0*\0group";s:13:"configuration";s:14:"\0*\0group_label";O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:1:{s:7:"context";s:17:"Entity type group";}}s:22:"\0*\0field_ui_base_route";N;s:26:"\0*\0common_reference_target";b:0;s:22:"\0*\0list_cache_contexts";a:0:{}s:18:"\0*\0list_cache_tags";a:1:{i:0;s:16:"config:view_list";}s:14:"\0*\0constraints";a:0:{}s:13:"\0*\0additional";a:0:{}s:14:"\0*\0_serviceIds";a:0:{}s:18:"\0*\0_entityStorages";a:0:{}s:20:"\0*\0stringTranslation";N;s:16:"\0*\0config_prefix";N;s:14:"\0*\0lookup_keys";a:1:{i:0;s:4:"uuid";}s:16:"\0*\0config_export";a:8:{i:0;s:2:"id";i:1;s:5:"label";i:2;s:6:"module";i:3;s:11:"description";i:4;s:3:"tag";i:5;s:10:"base_table";i:6;s:10:"base_field";i:7;s:7:"display";}s:21:"\0*\0mergedConfigExport";a:0:{}}'),
('entity.storage_schema.sql', 'block_content.entity_schema_data', 'a:4:{s:13:"block_content";a:2:{s:11:"primary key";a:1:{i:0;s:2:"id";}s:11:"unique keys";a:1:{s:26:"block_content__revision_id";a:1:{i:0;s:11:"revision_id";}}}s:22:"block_content_revision";a:2:{s:11:"primary key";a:1:{i:0;s:11:"revision_id";}s:7:"indexes";a:1:{s:17:"block_content__id";a:1:{i:0;s:2:"id";}}}s:24:"block_content_field_data";a:2:{s:11:"primary key";a:2:{i:0;s:2:"id";i:1;s:8:"langcode";}s:7:"indexes";a:3:{s:45:"block_content__id__default_langcode__langcode";a:3:{i:0;s:2:"id";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}s:26:"block_content__revision_id";a:1:{i:0;s:11:"revision_id";}s:26:"block_content__status_type";a:3:{i:0;s:6:"status";i:1;s:4:"type";i:2;s:2:"id";}}}s:28:"block_content_field_revision";a:2:{s:11:"primary key";a:2:{i:0;s:11:"revision_id";i:1;s:8:"langcode";}s:7:"indexes";a:1:{s:45:"block_content__id__default_langcode__langcode";a:3:{i:0;s:2:"id";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.body', 'a:2:{s:19:"block_content__body";a:4:{s:11:"description";s:42:"Data storage for block_content field body.";s:6:"fields";a:9:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:10:"body_value";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:1;}s:12:"body_summary";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:0;}s:11:"body_format";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:8:"not null";b:0;}}s:11:"primary key";a:4:{i:0;s:9:"entity_id";i:1;s:7:"deleted";i:2;s:5:"delta";i:3;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:11:"body_format";a:1:{i:0;s:11:"body_format";}}}s:28:"block_content_revision__body";a:4:{s:11:"description";s:54:"Revision archive storage for block_content field body.";s:6:"fields";a:9:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:10:"body_value";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:1;}s:12:"body_summary";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:0;}s:11:"body_format";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:8:"not null";b:0;}}s:11:"primary key";a:5:{i:0;s:9:"entity_id";i:1;s:11:"revision_id";i:2;s:7:"deleted";i:3;s:5:"delta";i:4;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:11:"body_format";a:1:{i:0;s:11:"body_format";}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.changed', 'a:2:{s:24:"block_content_field_data";a:1:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}s:28:"block_content_field_revision";a:1:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.default_langcode', 'a:2:{s:24:"block_content_field_data";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:28:"block_content_field_revision";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.id', 'a:4:{s:13:"block_content";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:24:"block_content_field_data";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:22:"block_content_revision";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:28:"block_content_field_revision";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.info', 'a:2:{s:24:"block_content_field_data";a:1:{s:6:"fields";a:1:{s:4:"info";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}s:28:"block_content_field_revision";a:1:{s:6:"fields";a:1:{s:4:"info";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.langcode', 'a:4:{s:13:"block_content";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:24:"block_content_field_data";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:22:"block_content_revision";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:28:"block_content_field_revision";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.reusable', 'a:1:{s:24:"block_content_field_data";a:2:{s:6:"fields";a:1:{s:8:"reusable";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:29:"block_content_field__reusable";a:1:{i:0;s:8:"reusable";}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.revision_created', 'a:1:{s:22:"block_content_revision";a:1:{s:6:"fields";a:1:{s:16:"revision_created";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.revision_default', 'a:1:{s:22:"block_content_revision";a:1:{s:6:"fields";a:1:{s:16:"revision_default";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.revision_id', 'a:4:{s:13:"block_content";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:0;}}}s:24:"block_content_field_data";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:22:"block_content_revision";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:28:"block_content_field_revision";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.revision_log', 'a:1:{s:22:"block_content_revision";a:1:{s:6:"fields";a:1:{s:12:"revision_log";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.revision_translation_affected', 'a:2:{s:24:"block_content_field_data";a:1:{s:6:"fields";a:1:{s:29:"revision_translation_affected";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}s:28:"block_content_field_revision";a:1:{s:6:"fields";a:1:{s:29:"revision_translation_affected";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.revision_user', 'a:1:{s:22:"block_content_revision";a:2:{s:6:"fields";a:1:{s:13:"revision_user";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:45:"block_content_field__revision_user__target_id";a:1:{i:0;s:13:"revision_user";}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.status', 'a:2:{s:24:"block_content_field_data";a:1:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:28:"block_content_field_revision";a:1:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.type', 'a:2:{s:13:"block_content";a:2:{s:6:"fields";a:1:{s:4:"type";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:36:"block_content_field__type__target_id";a:1:{i:0;s:4:"type";}}}s:24:"block_content_field_data";a:2:{s:6:"fields";a:1:{s:4:"type";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:36:"block_content_field__type__target_id";a:1:{i:0;s:4:"type";}}}}'),
('entity.storage_schema.sql', 'block_content.field_schema_data.uuid', 'a:1:{s:13:"block_content";a:2:{s:6:"fields";a:1:{s:4:"uuid";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;s:8:"not null";b:1;}}s:11:"unique keys";a:1:{s:32:"block_content_field__uuid__value";a:1:{i:0;s:4:"uuid";}}}}'),
('entity.storage_schema.sql', 'comment.entity_schema_data', 'a:2:{s:7:"comment";a:1:{s:11:"primary key";a:1:{i:0;s:3:"cid";}}s:18:"comment_field_data";a:2:{s:11:"primary key";a:2:{i:0;s:3:"cid";i:1;s:8:"langcode";}s:7:"indexes";a:5:{s:39:"comment__id__default_langcode__langcode";a:3:{i:0;s:3:"cid";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}s:28:"comment__status_comment_type";a:3:{i:0;s:6:"status";i:1;s:12:"comment_type";i:2;s:3:"cid";}s:19:"comment__status_pid";a:2:{i:0;s:3:"pid";i:1;s:6:"status";}s:16:"comment__num_new";a:7:{i:0;s:9:"entity_id";i:1;s:11:"entity_type";i:2;s:12:"comment_type";i:3;s:6:"status";i:4;s:7:"created";i:5;s:3:"cid";i:6;s:6:"thread";}s:24:"comment__entity_langcode";a:4:{i:0;s:9:"entity_id";i:1;s:11:"entity_type";i:2;s:12:"comment_type";i:3;s:16:"default_langcode";}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.changed', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.cid', 'a:2:{s:7:"comment";a:1:{s:6:"fields";a:1:{s:3:"cid";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:3:"cid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.comment_body', 'a:1:{s:21:"comment__comment_body";a:4:{s:11:"description";s:44:"Data storage for comment field comment_body.";s:6:"fields";a:8:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:114:"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:18:"comment_body_value";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:1;}s:19:"comment_body_format";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:8:"not null";b:0;}}s:11:"primary key";a:4:{i:0;s:9:"entity_id";i:1;s:7:"deleted";i:2;s:5:"delta";i:3;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:19:"comment_body_format";a:1:{i:0;s:19:"comment_body_format";}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.comment_type', 'a:2:{s:7:"comment";a:2:{s:6:"fields";a:1:{s:12:"comment_type";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:38:"comment_field__comment_type__target_id";a:1:{i:0;s:12:"comment_type";}}}s:18:"comment_field_data";a:2:{s:6:"fields";a:1:{s:12:"comment_type";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:38:"comment_field__comment_type__target_id";a:1:{i:0;s:12:"comment_type";}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.created', 'a:1:{s:18:"comment_field_data";a:2:{s:6:"fields";a:1:{s:7:"created";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:22:"comment_field__created";a:1:{i:0;s:7:"created";}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.default_langcode', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.entity_id', 'a:1:{s:18:"comment_field_data";a:2:{s:6:"fields";a:1:{s:9:"entity_id";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}}s:7:"indexes";a:0:{}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.entity_type', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:11:"entity_type";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:6:"binary";b:0;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.field_name', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:10:"field_name";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:6:"binary";b:0;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.homepage', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:8:"homepage";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.hostname', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:8:"hostname";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:128;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.langcode', 'a:2:{s:7:"comment";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.mail', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:4:"mail";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:254;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.name', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:4:"name";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:60;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.pid', 'a:1:{s:18:"comment_field_data";a:2:{s:6:"fields";a:1:{s:3:"pid";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}}s:7:"indexes";a:0:{}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.status', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}');
INSERT INTO `[[dbprefix]]key_value` VALUES
('entity.storage_schema.sql', 'comment.field_schema_data.subject', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:7:"subject";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:64;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.thread', 'a:1:{s:18:"comment_field_data";a:1:{s:6:"fields";a:1:{s:6:"thread";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.uid', 'a:1:{s:18:"comment_field_data";a:3:{s:6:"fields";a:1:{s:3:"uid";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:29:"comment_field__uid__target_id";a:1:{i:0;s:3:"uid";}}s:12:"foreign keys";a:1:{s:18:"comment_field__uid";a:2:{s:5:"table";s:5:"users";s:7:"columns";a:1:{s:3:"uid";s:3:"uid";}}}}}'),
('entity.storage_schema.sql', 'comment.field_schema_data.uuid', 'a:1:{s:7:"comment";a:2:{s:6:"fields";a:1:{s:4:"uuid";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;s:8:"not null";b:1;}}s:11:"unique keys";a:1:{s:26:"comment_field__uuid__value";a:1:{i:0;s:4:"uuid";}}}}'),
('entity.storage_schema.sql', 'file.entity_schema_data', 'a:1:{s:12:"file_managed";a:1:{s:11:"primary key";a:1:{i:0;s:3:"fid";}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.changed', 'a:1:{s:12:"file_managed";a:2:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:19:"file_field__changed";a:1:{i:0;s:7:"changed";}}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.created', 'a:1:{s:12:"file_managed";a:1:{s:6:"fields";a:1:{s:7:"created";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.fid', 'a:1:{s:12:"file_managed";a:1:{s:6:"fields";a:1:{s:3:"fid";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.filemime', 'a:1:{s:12:"file_managed";a:1:{s:6:"fields";a:1:{s:8:"filemime";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.filename', 'a:1:{s:12:"file_managed";a:1:{s:6:"fields";a:1:{s:8:"filename";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.filesize', 'a:1:{s:12:"file_managed";a:1:{s:6:"fields";a:1:{s:8:"filesize";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:3:"big";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.langcode', 'a:1:{s:12:"file_managed";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.status', 'a:1:{s:12:"file_managed";a:2:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:18:"file_field__status";a:1:{i:0;s:6:"status";}}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.uid', 'a:1:{s:12:"file_managed";a:2:{s:6:"fields";a:1:{s:3:"uid";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:26:"file_field__uid__target_id";a:1:{i:0;s:3:"uid";}}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.uri', 'a:1:{s:12:"file_managed";a:2:{s:6:"fields";a:1:{s:3:"uri";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:1;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:15:"file_field__uri";a:1:{i:0;s:3:"uri";}}}}'),
('entity.storage_schema.sql', 'file.field_schema_data.uuid', 'a:1:{s:12:"file_managed";a:2:{s:6:"fields";a:1:{s:4:"uuid";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;s:8:"not null";b:1;}}s:11:"unique keys";a:1:{s:23:"file_field__uuid__value";a:1:{i:0;s:4:"uuid";}}}}'),
('entity.storage_schema.sql', 'menu_link_content.entity_schema_data', 'a:4:{s:17:"menu_link_content";a:2:{s:11:"primary key";a:1:{i:0;s:2:"id";}s:11:"unique keys";a:1:{s:30:"menu_link_content__revision_id";a:1:{i:0;s:11:"revision_id";}}}s:26:"menu_link_content_revision";a:2:{s:11:"primary key";a:1:{i:0;s:11:"revision_id";}s:7:"indexes";a:1:{s:21:"menu_link_content__id";a:1:{i:0;s:2:"id";}}}s:22:"menu_link_content_data";a:2:{s:11:"primary key";a:2:{i:0;s:2:"id";i:1;s:8:"langcode";}s:7:"indexes";a:3:{s:49:"menu_link_content__id__default_langcode__langcode";a:3:{i:0;s:2:"id";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}s:30:"menu_link_content__revision_id";a:1:{i:0;s:11:"revision_id";}s:33:"menu_link_content__enabled_bundle";a:3:{i:0;s:7:"enabled";i:1;s:6:"bundle";i:2;s:2:"id";}}}s:32:"menu_link_content_field_revision";a:2:{s:11:"primary key";a:2:{i:0;s:11:"revision_id";i:1;s:8:"langcode";}s:7:"indexes";a:1:{s:49:"menu_link_content__id__default_langcode__langcode";a:3:{i:0;s:2:"id";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.bundle', 'a:2:{s:17:"menu_link_content";a:1:{s:6:"fields";a:1:{s:6:"bundle";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:6:"binary";b:0;s:8:"not null";b:1;}}}s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:6:"bundle";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:6:"binary";b:0;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.changed', 'a:2:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}s:32:"menu_link_content_field_revision";a:1:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.default_langcode', 'a:2:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:32:"menu_link_content_field_revision";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.description', 'a:2:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:11:"description";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}s:32:"menu_link_content_field_revision";a:1:{s:6:"fields";a:1:{s:11:"description";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.enabled', 'a:2:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:7:"enabled";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:32:"menu_link_content_field_revision";a:1:{s:6:"fields";a:1:{s:7:"enabled";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.expanded', 'a:1:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:8:"expanded";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.external', 'a:2:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:8:"external";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}s:32:"menu_link_content_field_revision";a:1:{s:6:"fields";a:1:{s:8:"external";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.id', 'a:4:{s:17:"menu_link_content";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:26:"menu_link_content_revision";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:32:"menu_link_content_field_revision";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.langcode', 'a:4:{s:17:"menu_link_content";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:26:"menu_link_content_revision";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:32:"menu_link_content_field_revision";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.link', 'a:2:{s:22:"menu_link_content_data";a:2:{s:6:"fields";a:3:{s:9:"link__uri";a:4:{s:11:"description";s:20:"The URI of the link.";s:4:"type";s:7:"varchar";s:6:"length";i:2048;s:8:"not null";b:0;}s:11:"link__title";a:4:{s:11:"description";s:14:"The link text.";s:4:"type";s:7:"varchar";s:6:"length";i:255;s:8:"not null";b:0;}s:13:"link__options";a:5:{s:11:"description";s:41:"Serialized array of options for the link.";s:4:"type";s:4:"blob";s:4:"size";s:3:"big";s:9:"serialize";b:1;s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:34:"menu_link_content_field__link__uri";a:1:{i:0;a:2:{i:0;s:9:"link__uri";i:1;i:30;}}}}s:32:"menu_link_content_field_revision";a:2:{s:6:"fields";a:3:{s:9:"link__uri";a:4:{s:11:"description";s:20:"The URI of the link.";s:4:"type";s:7:"varchar";s:6:"length";i:2048;s:8:"not null";b:0;}s:11:"link__title";a:4:{s:11:"description";s:14:"The link text.";s:4:"type";s:7:"varchar";s:6:"length";i:255;s:8:"not null";b:0;}s:13:"link__options";a:5:{s:11:"description";s:41:"Serialized array of options for the link.";s:4:"type";s:4:"blob";s:4:"size";s:3:"big";s:9:"serialize";b:1;s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:34:"menu_link_content_field__link__uri";a:1:{i:0;a:2:{i:0;s:9:"link__uri";i:1;i:30;}}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.menu_name', 'a:1:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:9:"menu_name";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.parent', 'a:1:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:6:"parent";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.rediscover', 'a:1:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:10:"rediscover";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.revision_created', 'a:1:{s:26:"menu_link_content_revision";a:1:{s:6:"fields";a:1:{s:16:"revision_created";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.revision_default', 'a:1:{s:26:"menu_link_content_revision";a:1:{s:6:"fields";a:1:{s:16:"revision_default";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.revision_id', 'a:4:{s:17:"menu_link_content";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:0;}}}s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:26:"menu_link_content_revision";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:32:"menu_link_content_field_revision";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.revision_log_message', 'a:1:{s:26:"menu_link_content_revision";a:1:{s:6:"fields";a:1:{s:20:"revision_log_message";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.revision_translation_affected', 'a:2:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:29:"revision_translation_affected";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}s:32:"menu_link_content_field_revision";a:1:{s:6:"fields";a:1:{s:29:"revision_translation_affected";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.revision_user', 'a:1:{s:26:"menu_link_content_revision";a:2:{s:6:"fields";a:1:{s:13:"revision_user";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:29:"menu_link_content__ef029a1897";a:1:{i:0;s:13:"revision_user";}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.title', 'a:2:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:5:"title";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}s:32:"menu_link_content_field_revision";a:1:{s:6:"fields";a:1:{s:5:"title";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.uuid', 'a:1:{s:17:"menu_link_content";a:2:{s:6:"fields";a:1:{s:4:"uuid";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;s:8:"not null";b:1;}}s:11:"unique keys";a:1:{s:36:"menu_link_content_field__uuid__value";a:1:{i:0;s:4:"uuid";}}}}'),
('entity.storage_schema.sql', 'menu_link_content.field_schema_data.weight', 'a:1:{s:22:"menu_link_content_data";a:1:{s:6:"fields";a:1:{s:6:"weight";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:0;s:4:"size";s:6:"normal";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'node.entity_schema_data', 'a:4:{s:4:"node";a:2:{s:11:"primary key";a:1:{i:0;s:3:"nid";}s:11:"unique keys";a:1:{s:9:"node__vid";a:1:{i:0;s:3:"vid";}}}s:13:"node_revision";a:2:{s:11:"primary key";a:1:{i:0;s:3:"vid";}s:7:"indexes";a:1:{s:9:"node__nid";a:1:{i:0;s:3:"nid";}}}s:15:"node_field_data";a:2:{s:11:"primary key";a:2:{i:0;s:3:"nid";i:1;s:8:"langcode";}s:7:"indexes";a:5:{s:36:"node__id__default_langcode__langcode";a:3:{i:0;s:3:"nid";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}s:9:"node__vid";a:1:{i:0;s:3:"vid";}s:17:"node__status_type";a:3:{i:0;s:6:"status";i:1;s:4:"type";i:2;s:3:"nid";}s:15:"node__frontpage";a:4:{i:0;s:7:"promote";i:1;s:6:"status";i:2;s:6:"sticky";i:3;s:7:"created";}s:16:"node__title_type";a:2:{i:0;s:5:"title";i:1;a:2:{i:0;s:4:"type";i:1;i:4;}}}}s:19:"node_field_revision";a:2:{s:11:"primary key";a:2:{i:0;s:3:"vid";i:1;s:8:"langcode";}s:7:"indexes";a:1:{s:36:"node__id__default_langcode__langcode";a:3:{i:0;s:3:"nid";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.body', 'a:2:{s:10:"node__body";a:4:{s:11:"description";s:33:"Data storage for node field body.";s:6:"fields";a:9:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:10:"body_value";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:1;}s:12:"body_summary";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:0;}s:11:"body_format";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:8:"not null";b:0;}}s:11:"primary key";a:4:{i:0;s:9:"entity_id";i:1;s:7:"deleted";i:2;s:5:"delta";i:3;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:11:"body_format";a:1:{i:0;s:11:"body_format";}}}s:19:"node_revision__body";a:4:{s:11:"description";s:45:"Revision archive storage for node field body.";s:6:"fields";a:9:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:10:"body_value";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:1;}s:12:"body_summary";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:0;}s:11:"body_format";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:8:"not null";b:0;}}s:11:"primary key";a:5:{i:0;s:9:"entity_id";i:1;s:11:"revision_id";i:2;s:7:"deleted";i:3;s:5:"delta";i:4;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:11:"body_format";a:1:{i:0;s:11:"body_format";}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.changed', 'a:2:{s:15:"node_field_data";a:2:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:19:"node_field__changed";a:1:{i:0;s:7:"changed";}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.comment', 'a:2:{s:13:"node__comment";a:4:{s:11:"description";s:36:"Data storage for node field comment.";s:6:"fields";a:7:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:14:"comment_status";a:4:{s:11:"description";s:99:"Whether comments are allowed on this entity: 0 = no, 1 = closed (read only), 2 = open (read/write).";s:4:"type";s:3:"int";s:7:"default";i:0;s:8:"not null";b:1;}}s:11:"primary key";a:4:{i:0;s:9:"entity_id";i:1;s:7:"deleted";i:2;s:5:"delta";i:3;s:8:"langcode";}s:7:"indexes";a:2:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}}}s:22:"node_revision__comment";a:4:{s:11:"description";s:48:"Revision archive storage for node field comment.";s:6:"fields";a:7:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:14:"comment_status";a:4:{s:11:"description";s:99:"Whether comments are allowed on this entity: 0 = no, 1 = closed (read only), 2 = open (read/write).";s:4:"type";s:3:"int";s:7:"default";i:0;s:8:"not null";b:1;}}s:11:"primary key";a:5:{i:0;s:9:"entity_id";i:1;s:11:"revision_id";i:2;s:7:"deleted";i:3;s:5:"delta";i:4;s:8:"langcode";}s:7:"indexes";a:2:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.created', 'a:2:{s:15:"node_field_data";a:2:{s:6:"fields";a:1:{s:7:"created";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:19:"node_field__created";a:1:{i:0;s:7:"created";}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:7:"created";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.default_langcode', 'a:2:{s:15:"node_field_data";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.field_image', 'a:2:{s:17:"node__field_image";a:5:{s:11:"description";s:40:"Data storage for node field field_image.";s:6:"fields";a:11:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:21:"field_image_target_id";a:4:{s:11:"description";s:26:"The ID of the file entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;}s:15:"field_image_alt";a:4:{s:11:"description";s:56:"Alternative image text, for the image''s ''alt'' attribute.";s:4:"type";s:7:"varchar";s:6:"length";i:512;s:8:"not null";b:0;}s:17:"field_image_title";a:4:{s:11:"description";s:52:"Image title text, for the image''s ''title'' attribute.";s:4:"type";s:7:"varchar";s:6:"length";i:1024;s:8:"not null";b:0;}s:17:"field_image_width";a:4:{s:11:"description";s:33:"The width of the image in pixels.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}s:18:"field_image_height";a:4:{s:11:"description";s:34:"The height of the image in pixels.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}}s:11:"primary key";a:4:{i:0;s:9:"entity_id";i:1;s:7:"deleted";i:2;s:5:"delta";i:3;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:21:"field_image_target_id";a:1:{i:0;s:21:"field_image_target_id";}}s:12:"foreign keys";a:1:{s:21:"field_image_target_id";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:21:"field_image_target_id";s:3:"fid";}}}}s:26:"node_revision__field_image";a:5:{s:11:"description";s:52:"Revision archive storage for node field field_image.";s:6:"fields";a:11:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:21:"field_image_target_id";a:4:{s:11:"description";s:26:"The ID of the file entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;}s:15:"field_image_alt";a:4:{s:11:"description";s:56:"Alternative image text, for the image''s ''alt'' attribute.";s:4:"type";s:7:"varchar";s:6:"length";i:512;s:8:"not null";b:0;}s:17:"field_image_title";a:4:{s:11:"description";s:52:"Image title text, for the image''s ''title'' attribute.";s:4:"type";s:7:"varchar";s:6:"length";i:1024;s:8:"not null";b:0;}s:17:"field_image_width";a:4:{s:11:"description";s:33:"The width of the image in pixels.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}s:18:"field_image_height";a:4:{s:11:"description";s:34:"The height of the image in pixels.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}}s:11:"primary key";a:5:{i:0;s:9:"entity_id";i:1;s:11:"revision_id";i:2;s:7:"deleted";i:3;s:5:"delta";i:4;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:21:"field_image_target_id";a:1:{i:0;s:21:"field_image_target_id";}}s:12:"foreign keys";a:1:{s:21:"field_image_target_id";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:21:"field_image_target_id";s:3:"fid";}}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.field_tags', 'a:2:{s:16:"node__field_tags";a:4:{s:11:"description";s:39:"Data storage for node field field_tags.";s:6:"fields";a:7:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:20:"field_tags_target_id";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;}}s:11:"primary key";a:4:{i:0;s:9:"entity_id";i:1;s:7:"deleted";i:2;s:5:"delta";i:3;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:20:"field_tags_target_id";a:1:{i:0;s:20:"field_tags_target_id";}}}s:25:"node_revision__field_tags";a:4:{s:11:"description";s:51:"Revision archive storage for node field field_tags.";s:6:"fields";a:7:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:20:"field_tags_target_id";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;}}s:11:"primary key";a:5:{i:0;s:9:"entity_id";i:1;s:11:"revision_id";i:2;s:7:"deleted";i:3;s:5:"delta";i:4;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:20:"field_tags_target_id";a:1:{i:0;s:20:"field_tags_target_id";}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.langcode', 'a:4:{s:4:"node";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:15:"node_field_data";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:13:"node_revision";a:2:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:20:"node_field__langcode";a:1:{i:0;s:8:"langcode";}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.nid', 'a:4:{s:4:"node";a:1:{s:6:"fields";a:1:{s:3:"nid";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:15:"node_field_data";a:1:{s:6:"fields";a:1:{s:3:"nid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:13:"node_revision";a:1:{s:6:"fields";a:1:{s:3:"nid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:3:"nid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.promote', 'a:2:{s:15:"node_field_data";a:1:{s:6:"fields";a:1:{s:7:"promote";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:7:"promote";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.revision_default', 'a:1:{s:13:"node_revision";a:1:{s:6:"fields";a:1:{s:16:"revision_default";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.revision_log', 'a:1:{s:13:"node_revision";a:1:{s:6:"fields";a:1:{s:12:"revision_log";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.revision_timestamp', 'a:1:{s:13:"node_revision";a:1:{s:6:"fields";a:1:{s:18:"revision_timestamp";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.revision_translation_affected', 'a:2:{s:15:"node_field_data";a:1:{s:6:"fields";a:1:{s:29:"revision_translation_affected";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:29:"revision_translation_affected";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.revision_uid', 'a:1:{s:13:"node_revision";a:3:{s:6:"fields";a:1:{s:12:"revision_uid";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:35:"node_field__revision_uid__target_id";a:1:{i:0;s:12:"revision_uid";}}s:12:"foreign keys";a:1:{s:24:"node_field__revision_uid";a:2:{s:5:"table";s:5:"users";s:7:"columns";a:1:{s:12:"revision_uid";s:3:"uid";}}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.status', 'a:2:{s:15:"node_field_data";a:1:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.sticky', 'a:2:{s:15:"node_field_data";a:1:{s:6:"fields";a:1:{s:6:"sticky";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:6:"sticky";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.title', 'a:2:{s:15:"node_field_data";a:1:{s:6:"fields";a:1:{s:5:"title";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:1;}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:5:"title";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.type', 'a:2:{s:4:"node";a:2:{s:6:"fields";a:1:{s:4:"type";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:27:"node_field__type__target_id";a:1:{i:0;s:4:"type";}}}s:15:"node_field_data";a:2:{s:6:"fields";a:1:{s:4:"type";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:27:"node_field__type__target_id";a:1:{i:0;s:4:"type";}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.uid', 'a:2:{s:15:"node_field_data";a:2:{s:6:"fields";a:1:{s:3:"uid";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:26:"node_field__uid__target_id";a:1:{i:0;s:3:"uid";}}}s:19:"node_field_revision";a:2:{s:6:"fields";a:1:{s:3:"uid";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:26:"node_field__uid__target_id";a:1:{i:0;s:3:"uid";}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.uuid', 'a:1:{s:4:"node";a:2:{s:6:"fields";a:1:{s:4:"uuid";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;s:8:"not null";b:1;}}s:11:"unique keys";a:1:{s:23:"node_field__uuid__value";a:1:{i:0;s:4:"uuid";}}}}'),
('entity.storage_schema.sql', 'node.field_schema_data.vid', 'a:4:{s:4:"node";a:1:{s:6:"fields";a:1:{s:3:"vid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:0;}}}s:15:"node_field_data";a:1:{s:6:"fields";a:1:{s:3:"vid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:13:"node_revision";a:1:{s:6:"fields";a:1:{s:3:"vid";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:19:"node_field_revision";a:1:{s:6:"fields";a:1:{s:3:"vid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'path_alias.entity_schema_data', 'a:2:{s:10:"path_alias";a:3:{s:11:"primary key";a:1:{i:0;s:2:"id";}s:7:"indexes";a:2:{s:36:"path_alias__alias_langcode_id_status";a:4:{i:0;s:5:"alias";i:1;s:8:"langcode";i:2;s:2:"id";i:3;s:6:"status";}s:35:"path_alias__path_langcode_id_status";a:4:{i:0;s:4:"path";i:1;s:8:"langcode";i:2;s:2:"id";i:3;s:6:"status";}}s:11:"unique keys";a:1:{s:23:"path_alias__revision_id";a:1:{i:0;s:11:"revision_id";}}}s:19:"path_alias_revision";a:2:{s:11:"primary key";a:1:{i:0;s:11:"revision_id";}s:7:"indexes";a:1:{s:14:"path_alias__id";a:1:{i:0;s:2:"id";}}}}'),
('entity.storage_schema.sql', 'path_alias.field_schema_data.alias', 'a:2:{s:10:"path_alias";a:1:{s:6:"fields";a:1:{s:5:"alias";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}s:19:"path_alias_revision";a:1:{s:6:"fields";a:1:{s:5:"alias";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'path_alias.field_schema_data.id', 'a:2:{s:10:"path_alias";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:19:"path_alias_revision";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'path_alias.field_schema_data.langcode', 'a:2:{s:10:"path_alias";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:19:"path_alias_revision";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'path_alias.field_schema_data.path', 'a:2:{s:10:"path_alias";a:1:{s:6:"fields";a:1:{s:4:"path";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}s:19:"path_alias_revision";a:1:{s:6:"fields";a:1:{s:4:"path";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'path_alias.field_schema_data.revision_default', 'a:1:{s:19:"path_alias_revision";a:1:{s:6:"fields";a:1:{s:16:"revision_default";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'path_alias.field_schema_data.revision_id', 'a:2:{s:10:"path_alias";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:0;}}}s:19:"path_alias_revision";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'path_alias.field_schema_data.status', 'a:2:{s:10:"path_alias";a:1:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:19:"path_alias_revision";a:1:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'path_alias.field_schema_data.uuid', 'a:1:{s:10:"path_alias";a:2:{s:6:"fields";a:1:{s:4:"uuid";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;s:8:"not null";b:1;}}s:11:"unique keys";a:1:{s:29:"path_alias_field__uuid__value";a:1:{i:0;s:4:"uuid";}}}}'),
('entity.storage_schema.sql', 'shortcut.entity_schema_data', 'a:2:{s:8:"shortcut";a:1:{s:11:"primary key";a:1:{i:0;s:2:"id";}}s:19:"shortcut_field_data";a:2:{s:11:"primary key";a:2:{i:0;s:2:"id";i:1;s:8:"langcode";}s:7:"indexes";a:1:{s:40:"shortcut__id__default_langcode__langcode";a:3:{i:0;s:2:"id";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}}}}'),
('entity.storage_schema.sql', 'shortcut.field_schema_data.default_langcode', 'a:1:{s:19:"shortcut_field_data";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'shortcut.field_schema_data.id', 'a:2:{s:8:"shortcut";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:19:"shortcut_field_data";a:1:{s:6:"fields";a:1:{s:2:"id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'shortcut.field_schema_data.langcode', 'a:2:{s:8:"shortcut";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:19:"shortcut_field_data";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'shortcut.field_schema_data.link', 'a:1:{s:19:"shortcut_field_data";a:2:{s:6:"fields";a:3:{s:9:"link__uri";a:4:{s:11:"description";s:20:"The URI of the link.";s:4:"type";s:7:"varchar";s:6:"length";i:2048;s:8:"not null";b:0;}s:11:"link__title";a:4:{s:11:"description";s:14:"The link text.";s:4:"type";s:7:"varchar";s:6:"length";i:255;s:8:"not null";b:0;}s:13:"link__options";a:5:{s:11:"description";s:41:"Serialized array of options for the link.";s:4:"type";s:4:"blob";s:4:"size";s:3:"big";s:9:"serialize";b:1;s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:25:"shortcut_field__link__uri";a:1:{i:0;a:2:{i:0;s:9:"link__uri";i:1;i:30;}}}}}'),
('entity.storage_schema.sql', 'shortcut.field_schema_data.shortcut_set', 'a:2:{s:8:"shortcut";a:2:{s:6:"fields";a:1:{s:12:"shortcut_set";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:39:"shortcut_field__shortcut_set__target_id";a:1:{i:0;s:12:"shortcut_set";}}}s:19:"shortcut_field_data";a:2:{s:6:"fields";a:1:{s:12:"shortcut_set";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:39:"shortcut_field__shortcut_set__target_id";a:1:{i:0;s:12:"shortcut_set";}}}}'),
('entity.storage_schema.sql', 'shortcut.field_schema_data.title', 'a:1:{s:19:"shortcut_field_data";a:1:{s:6:"fields";a:1:{s:5:"title";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'shortcut.field_schema_data.uuid', 'a:1:{s:8:"shortcut";a:2:{s:6:"fields";a:1:{s:4:"uuid";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;s:8:"not null";b:1;}}s:11:"unique keys";a:1:{s:27:"shortcut_field__uuid__value";a:1:{i:0;s:4:"uuid";}}}}'),
('entity.storage_schema.sql', 'shortcut.field_schema_data.weight', 'a:1:{s:19:"shortcut_field_data";a:1:{s:6:"fields";a:1:{s:6:"weight";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:0;s:4:"size";s:6:"normal";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.entity_schema_data', 'a:5:{s:18:"taxonomy_term_data";a:2:{s:11:"primary key";a:1:{i:0;s:3:"tid";}s:11:"unique keys";a:1:{s:26:"taxonomy_term__revision_id";a:1:{i:0;s:11:"revision_id";}}}s:22:"taxonomy_term_revision";a:2:{s:11:"primary key";a:1:{i:0;s:11:"revision_id";}s:7:"indexes";a:1:{s:18:"taxonomy_term__tid";a:1:{i:0;s:3:"tid";}}}s:24:"taxonomy_term_field_data";a:2:{s:11:"primary key";a:2:{i:0;s:3:"tid";i:1;s:8:"langcode";}s:7:"indexes";a:5:{s:45:"taxonomy_term__id__default_langcode__langcode";a:3:{i:0;s:3:"tid";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}s:26:"taxonomy_term__revision_id";a:1:{i:0;s:11:"revision_id";}s:25:"taxonomy_term__status_vid";a:3:{i:0;s:6:"status";i:1;s:3:"vid";i:2;s:3:"tid";}s:19:"taxonomy_term__tree";a:3:{i:0;s:3:"vid";i:1;s:6:"weight";i:2;s:4:"name";}s:23:"taxonomy_term__vid_name";a:2:{i:0;s:3:"vid";i:1;s:4:"name";}}}s:28:"taxonomy_term_field_revision";a:2:{s:11:"primary key";a:2:{i:0;s:11:"revision_id";i:1;s:8:"langcode";}s:7:"indexes";a:1:{s:45:"taxonomy_term__id__default_langcode__langcode";a:3:{i:0;s:3:"tid";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}}}s:14:"taxonomy_index";a:2:{s:11:"primary key";a:2:{i:0;s:3:"nid";i:1;s:3:"tid";}s:7:"indexes";a:1:{s:9:"term_node";a:4:{i:0;s:3:"tid";i:1;s:6:"status";i:2;s:6:"sticky";i:3;s:7:"created";}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.changed', 'a:2:{s:24:"taxonomy_term_field_data";a:1:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}s:28:"taxonomy_term_field_revision";a:1:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.default_langcode', 'a:2:{s:24:"taxonomy_term_field_data";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:28:"taxonomy_term_field_revision";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.description', 'a:2:{s:24:"taxonomy_term_field_data";a:2:{s:6:"fields";a:2:{s:18:"description__value";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:0;}s:19:"description__format";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:8:"not null";b:0;}}s:7:"indexes";a:0:{}}s:28:"taxonomy_term_field_revision";a:2:{s:6:"fields";a:2:{s:18:"description__value";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:0;}s:19:"description__format";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:40:"taxonomy_term_field__description__format";a:1:{i:0;s:19:"description__format";}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.langcode', 'a:4:{s:18:"taxonomy_term_data";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:24:"taxonomy_term_field_data";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:22:"taxonomy_term_revision";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:28:"taxonomy_term_field_revision";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.name', 'a:2:{s:24:"taxonomy_term_field_data";a:2:{s:6:"fields";a:1:{s:4:"name";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:25:"taxonomy_term_field__name";a:1:{i:0;s:4:"name";}}}s:28:"taxonomy_term_field_revision";a:1:{s:6:"fields";a:1:{s:4:"name";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}');
INSERT INTO `[[dbprefix]]key_value` VALUES
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.parent', 'a:2:{s:21:"taxonomy_term__parent";a:4:{s:11:"description";s:44:"Data storage for taxonomy_term field parent.";s:6:"fields";a:7:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:16:"parent_target_id";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;}}s:11:"primary key";a:4:{i:0;s:9:"entity_id";i:1;s:7:"deleted";i:2;s:5:"delta";i:3;s:8:"langcode";}s:7:"indexes";a:3:{s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:16:"parent_target_id";a:1:{i:0;s:16:"parent_target_id";}s:22:"bundle_delta_target_id";a:3:{i:0;s:6:"bundle";i:1;s:5:"delta";i:2;s:16:"parent_target_id";}}}s:30:"taxonomy_term_revision__parent";a:4:{s:11:"description";s:56:"Revision archive storage for taxonomy_term field parent.";s:6:"fields";a:7:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:47:"The entity revision id this data is attached to";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:16:"parent_target_id";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;}}s:11:"primary key";a:5:{i:0;s:9:"entity_id";i:1;s:11:"revision_id";i:2;s:7:"deleted";i:3;s:5:"delta";i:4;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:16:"parent_target_id";a:1:{i:0;s:16:"parent_target_id";}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.revision_created', 'a:1:{s:22:"taxonomy_term_revision";a:1:{s:6:"fields";a:1:{s:16:"revision_created";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.revision_default', 'a:1:{s:22:"taxonomy_term_revision";a:1:{s:6:"fields";a:1:{s:16:"revision_default";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.revision_id', 'a:4:{s:18:"taxonomy_term_data";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:0;}}}s:24:"taxonomy_term_field_data";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:22:"taxonomy_term_revision";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:28:"taxonomy_term_field_revision";a:1:{s:6:"fields";a:1:{s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.revision_log_message', 'a:1:{s:22:"taxonomy_term_revision";a:1:{s:6:"fields";a:1:{s:20:"revision_log_message";a:3:{s:4:"type";s:4:"text";s:4:"size";s:3:"big";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.revision_translation_affected', 'a:2:{s:24:"taxonomy_term_field_data";a:1:{s:6:"fields";a:1:{s:29:"revision_translation_affected";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}s:28:"taxonomy_term_field_revision";a:1:{s:6:"fields";a:1:{s:29:"revision_translation_affected";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.revision_user', 'a:1:{s:22:"taxonomy_term_revision";a:2:{s:6:"fields";a:1:{s:13:"revision_user";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:45:"taxonomy_term_field__revision_user__target_id";a:1:{i:0;s:13:"revision_user";}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.status', 'a:2:{s:24:"taxonomy_term_field_data";a:1:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}s:28:"taxonomy_term_field_revision";a:1:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.tid', 'a:4:{s:18:"taxonomy_term_data";a:1:{s:6:"fields";a:1:{s:3:"tid";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:24:"taxonomy_term_field_data";a:1:{s:6:"fields";a:1:{s:3:"tid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:22:"taxonomy_term_revision";a:1:{s:6:"fields";a:1:{s:3:"tid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:28:"taxonomy_term_field_revision";a:1:{s:6:"fields";a:1:{s:3:"tid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.uuid', 'a:1:{s:18:"taxonomy_term_data";a:2:{s:6:"fields";a:1:{s:4:"uuid";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;s:8:"not null";b:1;}}s:11:"unique keys";a:1:{s:32:"taxonomy_term_field__uuid__value";a:1:{i:0;s:4:"uuid";}}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.vid', 'a:2:{s:18:"taxonomy_term_data";a:2:{s:6:"fields";a:1:{s:3:"vid";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:35:"taxonomy_term_field__vid__target_id";a:1:{i:0;s:3:"vid";}}}s:24:"taxonomy_term_field_data";a:2:{s:6:"fields";a:1:{s:3:"vid";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;}}s:7:"indexes";a:0:{}}}'),
('entity.storage_schema.sql', 'taxonomy_term.field_schema_data.weight', 'a:1:{s:24:"taxonomy_term_field_data";a:1:{s:6:"fields";a:1:{s:6:"weight";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:0;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'user.entity_schema_data', 'a:2:{s:5:"users";a:1:{s:11:"primary key";a:1:{i:0;s:3:"uid";}}s:16:"users_field_data";a:3:{s:11:"primary key";a:2:{i:0;s:3:"uid";i:1;s:8:"langcode";}s:7:"indexes";a:1:{s:36:"user__id__default_langcode__langcode";a:3:{i:0;s:3:"uid";i:1;s:16:"default_langcode";i:2;s:8:"langcode";}}s:11:"unique keys";a:1:{s:10:"user__name";a:2:{i:0;s:4:"name";i:1;s:8:"langcode";}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.access', 'a:1:{s:16:"users_field_data";a:2:{s:6:"fields";a:1:{s:6:"access";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:18:"user_field__access";a:1:{i:0;s:6:"access";}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.changed', 'a:1:{s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:7:"changed";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.created', 'a:1:{s:16:"users_field_data";a:2:{s:6:"fields";a:1:{s:7:"created";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:1;}}s:7:"indexes";a:1:{s:19:"user_field__created";a:1:{i:0;s:7:"created";}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.default_langcode', 'a:1:{s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:16:"default_langcode";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.init', 'a:1:{s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:4:"init";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:254;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.langcode', 'a:2:{s:5:"users";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:8:"langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.login', 'a:1:{s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:5:"login";a:2:{s:4:"type";s:3:"int";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.mail', 'a:1:{s:16:"users_field_data";a:2:{s:6:"fields";a:1:{s:4:"mail";a:3:{s:4:"type";s:7:"varchar";s:6:"length";i:254;s:8:"not null";b:0;}}s:7:"indexes";a:1:{s:16:"user_field__mail";a:1:{i:0;s:4:"mail";}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.name', 'a:1:{s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:4:"name";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:60;s:6:"binary";b:0;s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.pass', 'a:1:{s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:4:"pass";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:255;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.preferred_admin_langcode', 'a:1:{s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:24:"preferred_admin_langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.preferred_langcode', 'a:1:{s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:18:"preferred_langcode";a:3:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:12;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.roles', 'a:1:{s:11:"user__roles";a:4:{s:11:"description";s:34:"Data storage for user field roles.";s:6:"fields";a:7:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:114:"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:15:"roles_target_id";a:4:{s:11:"description";s:28:"The ID of the target entity.";s:4:"type";s:13:"varchar_ascii";s:6:"length";i:255;s:8:"not null";b:1;}}s:11:"primary key";a:4:{i:0;s:9:"entity_id";i:1;s:7:"deleted";i:2;s:5:"delta";i:3;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:15:"roles_target_id";a:1:{i:0;s:15:"roles_target_id";}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.status', 'a:1:{s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:6:"status";a:3:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.timezone', 'a:1:{s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:8:"timezone";a:4:{s:4:"type";s:7:"varchar";s:6:"length";i:32;s:6:"binary";b:0;s:8:"not null";b:0;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.uid', 'a:2:{s:5:"users";a:1:{s:6:"fields";a:1:{s:3:"uid";a:4:{s:4:"type";s:6:"serial";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}s:16:"users_field_data";a:1:{s:6:"fields";a:1:{s:3:"uid";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:4:"size";s:6:"normal";s:8:"not null";b:1;}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.user_picture', 'a:1:{s:18:"user__user_picture";a:5:{s:11:"description";s:41:"Data storage for user field user_picture.";s:6:"fields";a:11:{s:6:"bundle";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:88:"The field instance bundle to which this row belongs, used when deleting a field instance";}s:7:"deleted";a:5:{s:4:"type";s:3:"int";s:4:"size";s:4:"tiny";s:8:"not null";b:1;s:7:"default";i:0;s:11:"description";s:60:"A boolean indicating whether this data item has been deleted";}s:9:"entity_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:38:"The entity id this data is attached to";}s:11:"revision_id";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:114:"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id";}s:8:"langcode";a:5:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:32;s:8:"not null";b:1;s:7:"default";s:0:"";s:11:"description";s:37:"The language code for this data item.";}s:5:"delta";a:4:{s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;s:11:"description";s:67:"The sequence number for this data item, used for multi-value fields";}s:22:"user_picture_target_id";a:4:{s:11:"description";s:26:"The ID of the file entity.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:1;}s:16:"user_picture_alt";a:4:{s:11:"description";s:56:"Alternative image text, for the image''s ''alt'' attribute.";s:4:"type";s:7:"varchar";s:6:"length";i:512;s:8:"not null";b:0;}s:18:"user_picture_title";a:4:{s:11:"description";s:52:"Image title text, for the image''s ''title'' attribute.";s:4:"type";s:7:"varchar";s:6:"length";i:1024;s:8:"not null";b:0;}s:18:"user_picture_width";a:4:{s:11:"description";s:33:"The width of the image in pixels.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}s:19:"user_picture_height";a:4:{s:11:"description";s:34:"The height of the image in pixels.";s:4:"type";s:3:"int";s:8:"unsigned";b:1;s:8:"not null";b:0;}}s:11:"primary key";a:4:{i:0;s:9:"entity_id";i:1;s:7:"deleted";i:2;s:5:"delta";i:3;s:8:"langcode";}s:7:"indexes";a:3:{s:6:"bundle";a:1:{i:0;s:6:"bundle";}s:11:"revision_id";a:1:{i:0;s:11:"revision_id";}s:22:"user_picture_target_id";a:1:{i:0;s:22:"user_picture_target_id";}}s:12:"foreign keys";a:1:{s:22:"user_picture_target_id";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:22:"user_picture_target_id";s:3:"fid";}}}}}'),
('entity.storage_schema.sql', 'user.field_schema_data.uuid', 'a:1:{s:5:"users";a:2:{s:6:"fields";a:1:{s:4:"uuid";a:4:{s:4:"type";s:13:"varchar_ascii";s:6:"length";i:128;s:6:"binary";b:0;s:8:"not null";b:1;}}s:11:"unique keys";a:1:{s:23:"user_field__uuid__value";a:1:{i:0;s:4:"uuid";}}}}'),
('post_update', 'existing_updates', 'a:153:{i:0;s:70:"system_post_update_convert_empty_country_and_timezone_settings_to_null";i:1;s:32:"system_post_update_sdc_uninstall";i:2;s:64:"system_post_update_recalculate_configuration_entity_dependencies";i:3;s:48:"system_post_update_add_region_to_entity_displays";i:4;s:37:"system_post_update_hashes_clear_cache";i:5;s:36:"system_post_update_timestamp_plugins";i:6;s:41:"system_post_update_classy_message_library";i:7;s:37:"system_post_update_field_type_plugins";i:8;s:48:"system_post_update_field_formatter_entity_schema";i:9;s:36:"system_post_update_fix_jquery_extend";i:10;s:40:"system_post_update_change_action_plugins";i:11;s:47:"system_post_update_change_delete_action_plugins";i:12;s:41:"system_post_update_language_item_callback";i:13;s:31:"system_post_update_extra_fields";i:14;s:37:"system_post_update_states_clear_cache";i:15;s:64:"system_post_update_add_expand_all_items_key_in_system_menu_block";i:16;s:35:"system_post_update_clear_menu_cache";i:17;s:46:"system_post_update_layout_plugin_schema_change";i:18;s:60:"system_post_update_entity_reference_autocomplete_match_limit";i:19;s:44:"system_post_update_extra_fields_form_display";i:20;s:39:"system_post_update_uninstall_simpletest";i:21;s:52:"system_post_update_uninstall_entity_reference_module";i:22;s:54:"system_post_update_entity_revision_metadata_bc_cleanup";i:23;s:35:"system_post_update_uninstall_classy";i:24;s:35:"system_post_update_uninstall_stable";i:25;s:44:"system_post_update_claro_dropbutton_variants";i:26;s:37:"system_post_update_schema_version_int";i:27;s:38:"system_post_update_delete_rss_settings";i:28;s:52:"system_post_update_remove_key_value_expire_all_index";i:29;s:44:"system_post_update_service_advisory_settings";i:30;s:44:"system_post_update_delete_authorize_settings";i:31;s:34:"system_post_update_sort_all_config";i:32;s:50:"system_post_update_enable_provider_database_driver";i:33;s:35:"system_post_update_linkset_settings";i:34;s:48:"system_post_update_enable_password_compatibility";i:35;s:39:"system_post_update_remove_asset_entries";i:36;s:44:"system_post_update_remove_asset_query_string";i:37;s:54:"system_post_update_add_description_to_entity_view_mode";i:38;s:54:"system_post_update_add_description_to_entity_form_mode";i:39;s:44:"system_post_update_set_blank_log_url_to_null";i:40;s:38:"system_post_update_mailer_dsn_settings";i:41;s:49:"system_post_update_mailer_structured_dsn_settings";i:42;s:47:"system_post_update_amend_config_sync_readme_url";i:43;s:44:"system_post_update_mail_notification_setting";i:44;s:54:"system_post_update_set_cron_logging_setting_to_boolean";i:45;s:56:"system_post_update_move_development_settings_to_keyvalue";i:46;s:58:"system_post_update_add_langcode_to_all_translatable_config";i:47;s:45:"user_post_update_enforce_order_of_permissions";i:48;s:29:"user_post_update_update_roles";i:49;s:33:"user_post_update_sort_permissions";i:50;s:39:"user_post_update_sort_permissions_again";i:51;s:51:"path_alias_post_update_drop_path_alias_status_index";i:52;s:62:"contact_post_update_add_message_redirect_field_to_contact_form";i:53;s:50:"contact_post_update_set_empty_default_form_to_null";i:54;s:35:"help_post_update_help_topics_search";i:55;s:38:"help_post_update_help_topics_uninstall";i:56;s:41:"help_post_update_add_permissions_to_roles";i:57;s:39:"big_pipe_post_update_html5_placeholders";i:58;s:49:"dblog_post_update_convert_recent_messages_to_view";i:59;s:29:"search_post_update_block_page";i:60;s:55:"search_post_update_reindex_after_diacritics_rule_change";i:61;s:54:"block_post_update_disable_blocks_with_missing_contexts";i:62;s:40:"block_post_update_disabled_region_update";i:63;s:42:"block_post_update_fix_negate_in_conditions";i:64;s:45:"block_post_update_replace_node_type_condition";i:65;s:46:"field_post_update_save_custom_storage_property";i:66;s:50:"field_post_update_entity_reference_handler_setting";i:67;s:43:"field_post_update_email_widget_size_setting";i:68;s:47:"field_post_update_remove_handler_submit_setting";i:69;s:31:"filter_post_update_sort_filters";i:70;s:44:"filter_post_update_consolidate_filter_config";i:71;s:42:"text_post_update_add_required_summary_flag";i:72;s:55:"text_post_update_add_required_summary_flag_form_display";i:73;s:32:"text_post_update_allowed_formats";i:74;s:51:"block_content_post_update_add_views_reusable_filter";i:75;s:51:"block_content_post_update_entity_changed_constraint";i:76;s:51:"block_content_post_update_move_custom_block_library";i:77;s:55:"block_content_post_update_block_library_view_permission";i:78;s:42:"block_content_post_update_sort_permissions";i:79;s:39:"block_content_post_update_revision_type";i:80;s:54:"file_post_update_add_txt_if_allows_insecure_extensions";i:81;s:41:"file_post_update_add_permissions_to_roles";i:82;s:64:"file_post_update_add_default_filename_sanitization_configuration";i:83;s:56:"editor_post_update_clear_cache_for_file_reference_filter";i:84;s:34:"editor_post_update_image_lazy_load";i:85;s:49:"editor_post_update_sanitize_image_upload_settings";i:86;s:39:"ckeditor5_post_update_alignment_buttons";i:87;s:40:"ckeditor5_post_update_image_toolbar_item";i:88;s:51:"ckeditor5_post_update_plugins_settings_export_order";i:89;s:32:"ckeditor5_post_update_code_block";i:90;s:37:"ckeditor5_post_update_list_multiblock";i:91;s:41:"ckeditor5_post_update_list_start_reversed";i:92;s:45:"comment_post_update_enable_comment_admin_view";i:93;s:42:"comment_post_update_add_ip_address_setting";i:94;s:48:"contextual_post_update_fixed_endpoint_and_markup";i:95;s:46:"node_post_update_configure_status_field_widget";i:96;s:41:"node_post_update_node_revision_views_data";i:97;s:40:"node_post_update_glossary_view_published";i:98;s:45:"node_post_update_rebuild_node_revision_routes";i:99;s:50:"node_post_update_modify_base_field_author_override";i:100;s:59:"node_post_update_set_node_type_description_and_help_to_null";i:101;s:42:"image_post_update_image_style_dependencies";i:102;s:50:"image_post_update_scale_and_crop_effect_add_anchor";i:103;s:41:"image_post_update_image_loading_attribute";i:104;s:47:"views_post_update_views_data_argument_plugin_id";i:105;s:46:"views_post_update_update_cacheability_metadata";i:106;s:46:"views_post_update_cleanup_duplicate_views_data";i:107;s:46:"views_post_update_field_formatter_dependencies";i:108;s:36:"views_post_update_taxonomy_index_tid";i:109;s:41:"views_post_update_serializer_dependencies";i:110;s:39:"views_post_update_boolean_filter_values";i:111;s:33:"views_post_update_grouped_filters";i:112;s:42:"views_post_update_revision_metadata_fields";i:113;s:33:"views_post_update_entity_link_url";i:114;s:34:"views_post_update_bulk_field_moved";i:115;s:41:"views_post_update_filter_placeholder_text";i:116;s:47:"views_post_update_views_data_table_dependencies";i:117;s:45:"views_post_update_table_display_cache_max_age";i:118;s:53:"views_post_update_exposed_filter_blocks_label_display";i:119;s:48:"views_post_update_make_placeholders_translatable";i:120;s:41:"views_post_update_limit_operator_defaults";i:121;s:33:"views_post_update_remove_core_key";i:122;s:51:"views_post_update_field_names_for_multivalue_fields";i:123;s:52:"views_post_update_configuration_entity_relationships";i:124;s:48:"views_post_update_rename_default_display_setting";i:125;s:50:"views_post_update_remove_sorting_global_text_field";i:126;s:36:"views_post_update_title_translations";i:127;s:33:"views_post_update_sort_identifier";i:128;s:53:"views_post_update_provide_revision_table_relationship";i:129;s:33:"views_post_update_image_lazy_load";i:130;s:39:"views_post_update_boolean_custom_titles";i:131;s:35:"views_post_update_oembed_eager_load";i:132;s:44:"views_post_update_responsive_image_lazy_load";i:133;s:37:"views_post_update_timestamp_formatter";i:134;s:38:"views_post_update_fix_revision_id_part";i:135;s:36:"views_post_update_add_missing_labels";i:136;s:43:"views_post_update_remove_skip_cache_setting";i:137;s:50:"views_post_update_remove_default_argument_skip_url";i:138;s:46:"views_post_update_taxonomy_filter_user_context";i:139;s:31:"views_post_update_pager_heading";i:140;s:54:"views_post_update_rendered_entity_field_cache_metadata";i:141;s:65:"menu_link_content_post_update_make_menu_link_content_revisionable";i:142;s:49:"path_post_update_create_language_content_settings";i:143;s:43:"taxonomy_post_update_clear_views_data_cache";i:144;s:64:"taxonomy_post_update_clear_entity_bundle_field_definitions_cache";i:145;s:63:"taxonomy_post_update_handle_publishing_status_addition_in_views";i:146;s:55:"taxonomy_post_update_remove_hierarchy_from_vocabularies";i:147;s:52:"taxonomy_post_update_make_taxonomy_term_revisionable";i:148;s:50:"taxonomy_post_update_configure_status_field_widget";i:149;s:65:"taxonomy_post_update_clear_views_argument_validator_plugins_cache";i:150;s:37:"taxonomy_post_update_set_new_revision";i:151;s:55:"taxonomy_post_update_set_vocabulary_description_to_null";i:152;s:45:"olivero_post_update_add_olivero_primary_color";}'),
('state', 'announcements_feed.last_fetch', 'i:[[timestamp]];'),
('state', 'asset.css_js_query_string', '[[css_js_query_string]]'),
('state', 'comment.maintain_entity_statistics', 'b:1;'),
('state', 'comment.node_comment_statistics_scale', 'd:1;'),
('state', 'help_search_unindexed_count', 's:1:"0";'),
('state', 'install_task', 's:4:"done";'),
('state', 'install_time', 'i:[[timestamp]];'),
('state', 'node.min_max_update_time', 'a:2:{s:11:"min_created";N;s:11:"max_created";N;}'),
('state', 'router.path_roots', 'a:30:{i:0;s:5:"admin";i:1;s:8:"big_pipe";i:2;s:14:"block-category";i:3;s:5:"block";i:4;s:9:"ckeditor5";i:5;s:7:"comment";i:6;s:8:"comments";i:7;s:7:"contact";i:8;s:4:"user";i:9;s:10:"contextual";i:10;s:6:"editor";i:11;s:4:"file";i:12;s:6:"filter";i:13;s:7:"history";i:14;s:5:"sites";i:15;s:6:"system";i:16;s:4:"node";i:17;s:6:"search";i:18;s:4:"cron";i:19;s:0:"";i:20;s:9:"<current>";i:21;s:5:"batch";i:22;s:10:"update.php";i:23;s:29:"entity_reference_autocomplete";i:24;s:7:"session";i:25;s:8:"taxonomy";i:26;s:7:"toolbar";i:27;s:11:".well-known";i:28;s:7:"rss.xml";i:29;s:5:"views";}'),
('state', 'routing.menu_masks.router', 'a:44:{i:0;i:501;i:1;i:493;i:2;i:492;i:3;i:464;i:4;i:253;i:5;i:252;i:6;i:250;i:7;i:247;i:8;i:246;i:9;i:245;i:10;i:244;i:11;i:232;i:12;i:126;i:13;i:125;i:14;i:124;i:15;i:123;i:16;i:122;i:17;i:117;i:18;i:116;i:19;i:63;i:20;i:62;i:21;i:61;i:22;i:60;i:23;i:53;i:24;i:49;i:25;i:42;i:26;i:31;i:27;i:30;i:28;i:29;i:29;i:28;i:30;i:24;i:31;i:21;i:32;i:15;i:33;i:14;i:34;i:13;i:35;i:12;i:36;i:11;i:37;i:8;i:38;i:7;i:39;i:6;i:40;i:5;i:41;i:3;i:42;i:2;i:43;i:1;}'),
('state', 'routing.non_admin_routes', 'a:92:{i:0;s:13:"big_pipe.nojs";i:1;s:27:"block.category_autocomplete";i:2;s:22:"block_content.add_page";i:3;s:22:"block_content.add_form";i:4;s:31:"ckeditor5.media_entity_metadata";i:5;s:24:"entity.comment.edit_form";i:6;s:15:"comment.approve";i:7;s:24:"entity.comment.canonical";i:8;s:26:"entity.comment.delete_form";i:9;s:13:"comment.reply";i:10;s:31:"comment.new_comments_node_links";i:11;s:21:"comment.node_redirect";i:12;s:17:"contact.site_page";i:13;s:29:"entity.contact_form.canonical";i:14;s:24:"entity.user.contact_form";i:15;s:17:"contextual.render";i:16;s:17:"editor.filter_xss";i:17;s:18:"file.ajax_progress";i:18;s:15:"filter.tips_all";i:19;s:11:"filter.tips";i:20;s:26:"history.get_last_node_view";i:21;s:17:"history.read_node";i:22;s:18:"image.style_public";i:23;s:19:"image.style_private";i:24;s:13:"node.add_page";i:25;s:8:"node.add";i:26;s:19:"entity.node.preview";i:27;s:27:"entity.node.version_history";i:28;s:20:"entity.node.revision";i:29;s:28:"node.revision_revert_confirm";i:30;s:40:"node.revision_revert_translation_confirm";i:31;s:28:"node.revision_delete_confirm";i:32;s:11:"search.view";i:33;s:23:"search.view_help_search";i:34;s:23:"search.help_help_search";i:35;s:23:"search.view_node_search";i:36;s:23:"search.help_node_search";i:37;s:23:"search.view_user_search";i:38;s:23:"search.help_user_search";i:39;s:19:"shortcut.set_switch";i:40;s:16:"system.css_asset";i:41;s:15:"system.js_asset";i:42;s:10:"system.401";i:43;s:10:"system.403";i:44;s:10:"system.404";i:45;s:10:"system.4xx";i:46;s:11:"system.cron";i:47;s:12:"system.files";i:48;s:28:"system.private_file_download";i:49;s:16:"system.temporary";i:50;s:7:"<front>";i:51;s:6:"<none>";i:52;s:8:"<nolink>";i:53;s:8:"<button>";i:54;s:9:"<current>";i:55;s:15:"system.timezone";i:56;s:22:"system.batch_page.html";i:57;s:16:"system.db_update";i:58;s:26:"system.entity_autocomplete";i:59;s:16:"system.csrftoken";i:60;s:30:"entity.taxonomy_term.edit_form";i:61;s:32:"entity.taxonomy_term.delete_form";i:62;s:16:"toolbar.subtrees";i:63;s:13:"user.register";i:64;s:11:"user.logout";i:65;s:19:"user.logout.confirm";i:66;s:9:"user.pass";i:67;s:9:"user.page";i:68;s:9:"user.edit";i:69;s:10:"user.login";i:70;s:19:"user.cancel_confirm";i:71;s:16:"user.reset.login";i:72;s:10:"user.reset";i:73;s:15:"user.reset.form";i:74;s:31:"user.well-known.change_password";i:75;s:21:"view.frontpage.feed_1";i:76;s:21:"view.frontpage.page_1";i:77;s:25:"view.taxonomy_term.feed_1";i:78;s:25:"view.taxonomy_term.page_1";i:79;s:10:"views.ajax";i:80;s:23:"entity.file.delete_form";i:81;s:21:"entity.node.canonical";i:82;s:23:"entity.node.delete_form";i:83;s:21:"entity.node.edit_form";i:84;s:36:"entity.taxonomy_term.version_history";i:85;s:29:"entity.taxonomy_term.revision";i:86;s:41:"entity.taxonomy_term.revision_revert_form";i:87;s:41:"entity.taxonomy_term.revision_delete_form";i:88;s:21:"entity.user.canonical";i:89;s:21:"entity.user.edit_form";i:90;s:23:"entity.user.cancel_form";i:91;s:30:"entity.taxonomy_term.canonical";}'),
('state', 'system.cron_key', '[[system_cron_key]]'),
('state', 'system.cron_last', 'i:[[timestamp]];'),
('state', 'system.private_key', '[[system_private_key]]'),
('state', 'system.profile.files', 'a:17:{s:10:"demo_umami";s:44:"core/profiles/demo_umami/demo_umami.info.yml";s:7:"minimal";s:38:"core/profiles/minimal/minimal.info.yml";s:23:"nightwatch_a11y_testing";s:70:"core/profiles/nightwatch_a11y_testing/nightwatch_a11y_testing.info.yml";s:18:"nightwatch_testing";s:60:"core/profiles/nightwatch_testing/nightwatch_testing.info.yml";s:8:"standard";s:40:"core/profiles/standard/standard.info.yml";s:25:"test_language_negotiation";s:74:"core/profiles/test_language_negotiation/test_language_negotiation.info.yml";s:7:"testing";s:38:"core/profiles/testing/testing.info.yml";s:21:"testing_config_import";s:66:"core/profiles/testing_config_import/testing_config_import.info.yml";s:24:"testing_config_overrides";s:72:"core/profiles/testing_config_overrides/testing_config_overrides.info.yml";s:40:"testing_install_profile_all_dependencies";s:104:"core/profiles/testing_install_profile_all_dependencies/testing_install_profile_all_dependencies.info.yml";s:36:"testing_install_profile_dependencies";s:96:"core/profiles/testing_install_profile_dependencies/testing_install_profile_dependencies.info.yml";s:28:"testing_missing_dependencies";s:80:"core/profiles/testing_missing_dependencies/testing_missing_dependencies.info.yml";s:20:"testing_multilingual";s:64:"core/profiles/testing_multilingual/testing_multilingual.info.yml";s:33:"testing_multilingual_with_english";s:90:"core/profiles/testing_multilingual_with_english/testing_multilingual_with_english.info.yml";s:20:"testing_requirements";s:64:"core/profiles/testing_requirements/testing_requirements.info.yml";s:19:"testing_site_config";s:62:"core/profiles/testing_site_config/testing_site_config.info.yml";s:21:"testing_themes_blocks";s:66:"core/profiles/testing_themes_blocks/testing_themes_blocks.info.yml";}'),
('state', 'system.theme.files', 'a:5:{s:5:"claro";s:32:"core/themes/claro/claro.info.yml";s:7:"olivero";s:36:"core/themes/olivero/olivero.info.yml";s:7:"stable9";s:36:"core/themes/stable9/stable9.info.yml";s:5:"stark";s:32:"core/themes/stark/stark.info.yml";s:16:"starterkit_theme";s:54:"core/themes/starterkit_theme/starterkit_theme.info.yml";}'),
('state', 'twig_extension_hash_prefix', 'a:2:{s:19:"twig_extension_hash";s:0:"";s:17:"twig_cache_prefix";s:0:"";}'),
('state', 'update.last_check', 'i:[[timestamp]];'),
('state', 'views.view_route_names', 'a:12:{s:13:"watchdog.page";s:14:"dblog.overview";s:24:"user_admin_people.page_1";s:22:"entity.user.collection";s:20:"taxonomy_term.page_1";s:30:"entity.taxonomy_term.canonical";s:14:"content.page_1";s:20:"system.admin_content";s:23:"comment.page_unapproved";s:22:"comment.admin_approval";s:22:"comment.page_published";s:13:"comment.admin";s:20:"block_content.page_1";s:31:"entity.block_content.collection";s:12:"files.page_1";s:17:"view.files.page_1";s:12:"files.page_2";s:17:"view.files.page_2";s:16:"frontpage.feed_1";s:21:"view.frontpage.feed_1";s:16:"frontpage.page_1";s:21:"view.frontpage.page_1";s:20:"taxonomy_term.feed_1";s:25:"view.taxonomy_term.feed_1";}'),
('system.schema', 'announcements_feed', 'i:8000;'),
('system.schema', 'automated_cron', 'i:8000;'),
('system.schema', 'big_pipe', 'i:8000;'),
('system.schema', 'block', 'i:8003;'),
('system.schema', 'block_content', 'i:10300;'),
('system.schema', 'breakpoint', 'i:8000;'),
('system.schema', 'ckeditor5', 'i:8000;'),
('system.schema', 'comment', 'i:10100;'),
('system.schema', 'config', 'i:8000;'),
('system.schema', 'contact', 'i:8000;'),
('system.schema', 'contextual', 'i:8000;'),
('system.schema', 'datetime', 'i:8000;'),
('system.schema', 'dblog', 'i:10101;'),
('system.schema', 'dynamic_page_cache', 'i:8000;'),
('system.schema', 'editor', 'i:8001;'),
('system.schema', 'field', 'i:8500;'),
('system.schema', 'field_ui', 'i:8000;'),
('system.schema', 'file', 'i:8700;'),
('system.schema', 'filter', 'i:8000;'),
('system.schema', 'help', 'i:10200;'),
('system.schema', 'history', 'i:10100;'),
('system.schema', 'image', 'i:8201;'),
('system.schema', 'link', 'i:8000;'),
('system.schema', 'menu_link_content', 'i:8601;'),
('system.schema', 'menu_ui', 'i:8000;'),
('system.schema', 'mysql', 'i:8000;'),
('system.schema', 'node', 'i:8700;'),
('system.schema', 'options', 'i:8000;'),
('system.schema', 'page_cache', 'i:8000;'),
('system.schema', 'path', 'i:8200;'),
('system.schema', 'path_alias', 'i:8000;'),
('system.schema', 'search', 'i:8000;'),
('system.schema', 'shortcut', 'i:8000;'),
('system.schema', 'standard', 'i:8000;'),
('system.schema', 'system', 'i:10201;'),
('system.schema', 'taxonomy', 'i:10100;'),
('system.schema', 'text', 'i:8000;'),
('system.schema', 'toolbar', 'i:8000;'),
('system.schema', 'update', 'i:8001;'),
('system.schema', 'user', 'i:10000;'),
('system.schema', 'views', 'i:8500;'),
('system.schema', 'views_ui', 'i:8000;');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]key_value_expire`
--

CREATE TABLE `[[dbprefix]]key_value_expire` (
  `collection` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A named collection of key and value pairs.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The key of the key/value pair.',
  `value` longblob NOT NULL COMMENT 'The value of the key/value pair.',
  `expire` int NOT NULL DEFAULT '2147483647' COMMENT 'The time since Unix epoch in seconds when this item expires. Defaults to the maximum possible time.',
  PRIMARY KEY (`collection`,`name`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Generic key/value storage table with an expiration.';

--
-- Dumping data for table `[[dbprefix]]key_value_expire`
--

INSERT INTO `[[dbprefix]]key_value_expire` VALUES
('announcements_feed', 'announcements', 'a:7:{i:1;a:7:{s:2:"id";s:7:"3427138";s:5:"title";s:52:"You''re invited to DrupalCon Portland | 6-9 May, 2024";s:12:"content_html";s:384:"<p>DrupalCon is an event for developers, marketers/content editors, site owners, and the Drupal-curious to join with the community. You''ll find incredible keynotes, session content from expert speakers who have helped to build Drupal, networking opportunities with your peers, fun social events, and the chance to deepen your connection by contributing to the open source project.</p>";s:3:"url";s:96:"https://www.drupal.org/about/announcements/blog/youre-invited-to-drupalcon-portland-6-9-may-2024";s:13:"date_modified";s:25:"2024-03-18T19:40:04+00:00";s:14:"date_published";s:25:"2024-03-11T16:49:53+00:00";s:10:"_drupalorg";a:2:{s:8:"featured";b:0;s:7:"version";s:5:">=7.0";}}i:2;a:7:{s:2:"id";s:7:"3408836";s:5:"title";s:28:"Drupal 10.2 is now available";s:12:"content_html";s:378:"<p>The <a href="https://www.drupal.org/project/drupal/releases/10.2.0">second feature release of Drupal 10</a> improves content modeling, block management, menu and taxonomy organization, and permission administration. New options to sanitize file names make it possible to clean up the names of uploaded files, and media item revisions now have a dedicated user interface.</p>\n";s:3:"url";s:41:"https://www.drupal.org/blog/drupal-10-2-0";s:13:"date_modified";s:25:"2024-01-25T18:24:28+00:00";s:14:"date_published";s:25:"2023-12-15T18:27:47+00:00";s:10:"_drupalorg";a:2:{s:8:"featured";b:0;s:7:"version";s:5:">=7.0";}}i:3;a:7:{s:2:"id";s:7:"3403229";s:5:"title";s:75:"Drupal 10 will be supported until the release of Drupal 12 in mid-late 2026";s:12:"content_html";s:190:"<p>Announcing a new major release schedule with long term support for Drupal 10 until mid-late 2026. Drupal 11 will be released in 2024 and work on the dedicated branch starts this week.</p>";s:3:"url";s:103:"https://www.drupal.org/blog/drupal-10-will-be-supported-until-the-release-of-drupal-12-in-mid-late-2026";s:13:"date_modified";s:25:"2024-01-25T18:31:05+00:00";s:14:"date_published";s:25:"2023-11-22T07:13:55+00:00";s:10:"_drupalorg";a:2:{s:8:"featured";b:0;s:7:"version";s:5:">=7.0";}}i:5;a:7:{s:2:"id";s:7:"3368367";s:5:"title";s:28:"Drupal 10.1 is now available";s:12:"content_html";s:257:"<p>This first feature release of Drupal 10 is packed with amazing improvements! It makes customizing the look of your site easier, adds support for decoupled navigation, improves content modeling and editing, block management, performance and many more.</p>";s:3:"url";s:41:"https://www.drupal.org/blog/drupal-10-1-0";s:13:"date_modified";s:25:"2023-10-30T16:22:24+00:00";s:14:"date_published";s:25:"2023-06-22T09:11:30+00:00";s:10:"_drupalorg";a:2:{s:8:"featured";b:0;s:7:"version";s:5:">=7.0";}}i:6;a:7:{s:2:"id";s:7:"3347976";s:5:"title";s:37:"Contribute to Drupal and the Open Web";s:12:"content_html";s:146:"<p>Drupal is an open source project. But what does that mean? How can you as a site-owner participate in the project of building a better web?</p>";s:3:"url";s:85:"https://www.drupal.org/about/announcements/blog/contribute-to-drupal-and-the-open-web";s:13:"date_modified";s:25:"2023-03-14T19:43:12+00:00";s:14:"date_published";s:25:"2023-03-14T19:39:44+00:00";s:10:"_drupalorg";a:2:{s:8:"featured";b:0;s:7:"version";s:5:">=7.0";}}i:7;a:7:{s:2:"id";s:7:"3343486";s:5:"title";s:43:"What to expect from the Announcements feed?";s:12:"content_html";s:197:"<p>Drupal is introducing a new project Announcements feature so that you can see news and updates about the Drupal project and community directly in your Drupal dashboard. Learn what to expect.</p>";s:3:"url";s:90:"https://www.drupal.org/about/announcements/blog/what-to-expect-from-the-announcements-feed";s:13:"date_modified";s:25:"2023-02-21T19:45:53+00:00";s:14:"date_published";s:25:"2023-02-21T19:45:53+00:00";s:10:"_drupalorg";a:2:{s:8:"featured";b:0;s:7:"version";s:5:">=7.0";}}i:8;a:7:{s:2:"id";s:7:"3327047";s:5:"title";s:26:"Drupal 10.0.0 is available";s:12:"content_html";s:296:"<p>Thanks to 2129 contributors from 616 organizations resolving 4083 issues in the past two and a half years, Drupal 10.0.0 is available today! This new version sets Drupal up for continued stability and security for the longer term. All new features will be added to Drupal 10 going forward.</p>";s:3:"url";s:41:"https://www.drupal.org/blog/drupal-10-0-0";s:13:"date_modified";s:25:"2023-10-30T16:21:38+00:00";s:14:"date_published";s:25:"2022-12-15T17:43:23+00:00";s:10:"_drupalorg";a:2:{s:8:"featured";b:0;s:7:"version";s:5:">=7.0";}}}', [[timestamp_nextday]]),
('system', 'advisories_response', 'a:0:{}', [[timestamp]]),
('update', 'fetch_failures', 'N;', [[timestamp]]),
('update', 'update_project_data', 'a:1:{s:6:"drupal";a:15:{s:4:"name";s:6:"drupal";s:4:"info";a:6:{s:4:"name";s:13:"Announcements";s:7:"package";s:4:"Core";s:7:"version";s:6:"11.0.1";s:7:"project";s:6:"drupal";s:9:"datestamp";i:1723108508;s:16:"_info_file_ctime";i:[[timestamp]];}s:9:"datestamp";i:1723108508;s:8:"includes";a:44:{s:18:"announcements_feed";s:13:"Announcements";s:14:"automated_cron";s:14:"Automated Cron";s:8:"big_pipe";s:7:"BigPipe";s:5:"block";s:5:"Block";s:13:"block_content";s:13:"Block Content";s:10:"breakpoint";s:10:"Breakpoint";s:9:"ckeditor5";s:10:"CKEditor 5";s:7:"comment";s:7:"Comment";s:6:"config";s:21:"Configuration Manager";s:7:"contact";s:7:"Contact";s:10:"contextual";s:16:"Contextual Links";s:8:"datetime";s:8:"Datetime";s:5:"dblog";s:16:"Database Logging";s:18:"dynamic_page_cache";s:27:"Internal Dynamic Page Cache";s:6:"editor";s:11:"Text Editor";s:5:"field";s:5:"Field";s:8:"field_ui";s:8:"Field UI";s:4:"file";s:4:"File";s:6:"filter";s:6:"Filter";s:4:"help";s:4:"Help";s:7:"history";s:7:"History";s:5:"image";s:5:"Image";s:4:"link";s:4:"Link";s:17:"menu_link_content";s:17:"Custom Menu Links";s:7:"menu_ui";s:7:"Menu UI";s:5:"mysql";s:5:"MySQL";s:4:"node";s:4:"Node";s:7:"options";s:7:"Options";s:10:"page_cache";s:19:"Internal Page Cache";s:4:"path";s:4:"Path";s:10:"path_alias";s:10:"Path alias";s:6:"search";s:6:"Search";s:8:"shortcut";s:8:"Shortcut";s:6:"system";s:6:"System";s:8:"taxonomy";s:8:"Taxonomy";s:4:"text";s:4:"Text";s:7:"toolbar";s:7:"Toolbar";s:6:"update";s:14:"Update Manager";s:4:"user";s:4:"User";s:5:"views";s:5:"Views";s:8:"views_ui";s:8:"Views UI";s:8:"standard";s:8:"Standard";s:5:"claro";s:5:"Claro";s:7:"olivero";s:7:"Olivero";}s:12:"project_type";s:4:"core";s:14:"project_status";b:1;s:16:"existing_version";s:6:"11.0.1";s:14:"existing_major";s:2:"11";s:12:"install_type";s:8:"official";s:5:"title";s:11:"Drupal core";s:4:"link";s:37:"https://www.drupal.org/project/drupal";s:14:"latest_version";s:6:"11.0.1";s:8:"releases";a:1:{s:6:"11.0.1";a:10:{s:4:"name";s:13:"drupal 11.0.1";s:7:"version";s:6:"11.0.1";s:3:"tag";s:6:"11.0.1";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/11.0.1";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-11.0.1.tar.gz";s:4:"date";s:10:"1723108396";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}}s:11:"recommended";s:6:"11.0.1";s:6:"status";i:5;}}', [[timestamp]]),
('update', 'update_project_projects', 'a:1:{s:6:"drupal";a:6:{s:4:"name";s:6:"drupal";s:4:"info";a:6:{s:4:"name";s:13:"Announcements";s:7:"package";s:4:"Core";s:7:"version";s:6:"11.0.1";s:7:"project";s:6:"drupal";s:9:"datestamp";i:1723108508;s:16:"_info_file_ctime";i:[[timestamp]];}s:9:"datestamp";i:1723108508;s:8:"includes";a:44:{s:18:"announcements_feed";s:13:"Announcements";s:14:"automated_cron";s:14:"Automated Cron";s:8:"big_pipe";s:7:"BigPipe";s:5:"block";s:5:"Block";s:13:"block_content";s:13:"Block Content";s:10:"breakpoint";s:10:"Breakpoint";s:9:"ckeditor5";s:10:"CKEditor 5";s:7:"comment";s:7:"Comment";s:6:"config";s:21:"Configuration Manager";s:7:"contact";s:7:"Contact";s:10:"contextual";s:16:"Contextual Links";s:8:"datetime";s:8:"Datetime";s:5:"dblog";s:16:"Database Logging";s:18:"dynamic_page_cache";s:27:"Internal Dynamic Page Cache";s:6:"editor";s:11:"Text Editor";s:5:"field";s:5:"Field";s:8:"field_ui";s:8:"Field UI";s:4:"file";s:4:"File";s:6:"filter";s:6:"Filter";s:4:"help";s:4:"Help";s:7:"history";s:7:"History";s:5:"image";s:5:"Image";s:4:"link";s:4:"Link";s:17:"menu_link_content";s:17:"Custom Menu Links";s:7:"menu_ui";s:7:"Menu UI";s:5:"mysql";s:5:"MySQL";s:4:"node";s:4:"Node";s:7:"options";s:7:"Options";s:10:"page_cache";s:19:"Internal Page Cache";s:4:"path";s:4:"Path";s:10:"path_alias";s:10:"Path alias";s:6:"search";s:6:"Search";s:8:"shortcut";s:8:"Shortcut";s:6:"system";s:6:"System";s:8:"taxonomy";s:8:"Taxonomy";s:4:"text";s:4:"Text";s:7:"toolbar";s:7:"Toolbar";s:6:"update";s:14:"Update Manager";s:4:"user";s:4:"User";s:5:"views";s:5:"Views";s:8:"views_ui";s:8:"Views UI";s:8:"standard";s:8:"Standard";s:5:"claro";s:5:"Claro";s:7:"olivero";s:7:"Olivero";}s:12:"project_type";s:4:"core";s:14:"project_status";b:1;}}', [[timestamp]]);
INSERT INTO `[[dbprefix]]key_value_expire` VALUES
('update_available_releases', 'drupal', 'a:9:{s:5:"title";s:11:"Drupal core";s:10:"short_name";s:6:"drupal";s:4:"type";s:12:"project_core";s:18:"supported_branches";s:23:"10.2.,10.3.,10.4.,11.0.";s:14:"project_status";s:9:"published";s:4:"link";s:37:"https://www.drupal.org/project/drupal";s:5:"terms";s:0:"";s:8:"releases";a:410:{s:6:"11.0.1";a:10:{s:4:"name";s:13:"drupal 11.0.1";s:7:"version";s:6:"11.0.1";s:3:"tag";s:6:"11.0.1";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/11.0.1";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-11.0.1.tar.gz";s:4:"date";s:10:"1723108396";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"11.0.0";a:10:{s:4:"name";s:13:"drupal 11.0.0";s:7:"version";s:6:"11.0.0";s:3:"tag";s:6:"11.0.0";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/11.0.0";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-11.0.0.tar.gz";s:4:"date";s:10:"1722578454";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:10:"11.0.0-rc1";a:10:{s:4:"name";s:17:"drupal 11.0.0-rc1";s:7:"version";s:10:"11.0.0-rc1";s:3:"tag";s:10:"11.0.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/11.0.0-rc1";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-11.0.0-rc1.tar.gz";s:4:"date";s:10:"1720736512";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:12:"11.0.0-beta1";a:10:{s:4:"name";s:19:"drupal 11.0.0-beta1";s:7:"version";s:12:"11.0.0-beta1";s:3:"tag";s:12:"11.0.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/11.0.0-beta1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-11.0.0-beta1.tar.gz";s:4:"date";s:10:"1715953266";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:13:"11.0.0-alpha1";a:10:{s:4:"name";s:20:"drupal 11.0.0-alpha1";s:7:"version";s:13:"11.0.0-alpha1";s:3:"tag";s:13:"11.0.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/11.0.0-alpha1";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-11.0.0-alpha1.tar.gz";s:4:"date";s:10:"1714797816";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"10.3.2";a:10:{s:4:"name";s:13:"drupal 10.3.2";s:7:"version";s:6:"10.3.2";s:3:"tag";s:6:"10.3.2";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.3.2";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.3.2.tar.gz";s:4:"date";s:10:"1723109810";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.3.1";a:10:{s:4:"name";s:13:"drupal 10.3.1";s:7:"version";s:6:"10.3.1";s:3:"tag";s:6:"10.3.1";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.3.1";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.3.1.tar.gz";s:4:"date";s:10:"1720094095";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.3.0";a:10:{s:4:"name";s:13:"drupal 10.3.0";s:7:"version";s:6:"10.3.0";s:3:"tag";s:6:"10.3.0";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.3.0";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.3.0.tar.gz";s:4:"date";s:10:"1718911125";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:10:"10.3.0-rc1";a:10:{s:4:"name";s:17:"drupal 10.3.0-rc1";s:7:"version";s:10:"10.3.0-rc1";s:3:"tag";s:10:"10.3.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.3.0-rc1";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.3.0-rc1.tar.gz";s:4:"date";s:10:"1717621189";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:12:"10.3.0-beta1";a:10:{s:4:"name";s:19:"drupal 10.3.0-beta1";s:7:"version";s:12:"10.3.0-beta1";s:3:"tag";s:12:"10.3.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/10.3.0-beta1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-10.3.0-beta1.tar.gz";s:4:"date";s:10:"1715953149";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:6:"10.2.7";a:10:{s:4:"name";s:13:"drupal 10.2.7";s:7:"version";s:6:"10.2.7";s:3:"tag";s:6:"10.2.7";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.2.7";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.2.7.tar.gz";s:4:"date";s:10:"1717660024";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.2.6";a:10:{s:4:"name";s:13:"drupal 10.2.6";s:7:"version";s:6:"10.2.6";s:3:"tag";s:6:"10.2.6";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.2.6";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.2.6.tar.gz";s:4:"date";s:10:"1714597701";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.2.5";a:10:{s:4:"name";s:13:"drupal 10.2.5";s:7:"version";s:6:"10.2.5";s:3:"tag";s:6:"10.2.5";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.2.5";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.2.5.tar.gz";s:4:"date";s:10:"1712130945";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.2.4";a:10:{s:4:"name";s:13:"drupal 10.2.4";s:7:"version";s:6:"10.2.4";s:3:"tag";s:6:"10.2.4";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.2.4";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.2.4.tar.gz";s:4:"date";s:10:"1709715366";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.2.3";a:10:{s:4:"name";s:13:"drupal 10.2.3";s:7:"version";s:6:"10.2.3";s:3:"tag";s:6:"10.2.3";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.2.3";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.2.3.tar.gz";s:4:"date";s:10:"1707347611";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.2.2";a:10:{s:4:"name";s:13:"drupal 10.2.2";s:7:"version";s:6:"10.2.2";s:3:"tag";s:6:"10.2.2";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.2.2";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.2.2.tar.gz";s:4:"date";s:10:"1705511786";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.2.1";a:10:{s:4:"name";s:13:"drupal 10.2.1";s:7:"version";s:6:"10.2.1";s:3:"tag";s:6:"10.2.1";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.2.1";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.2.1.tar.gz";s:4:"date";s:10:"1704448164";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.2.0";a:10:{s:4:"name";s:13:"drupal 10.2.0";s:7:"version";s:6:"10.2.0";s:3:"tag";s:6:"10.2.0";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.2.0";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.2.0.tar.gz";s:4:"date";s:10:"1702681674";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:10:"10.2.0-rc1";a:10:{s:4:"name";s:17:"drupal 10.2.0-rc1";s:7:"version";s:10:"10.2.0-rc1";s:3:"tag";s:10:"10.2.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.2.0-rc1";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.2.0-rc1.tar.gz";s:4:"date";s:10:"1701450971";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:12:"10.2.0-beta1";a:10:{s:4:"name";s:19:"drupal 10.2.0-beta1";s:7:"version";s:12:"10.2.0-beta1";s:3:"tag";s:12:"10.2.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/10.2.0-beta1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-10.2.0-beta1.tar.gz";s:4:"date";s:10:"1700578716";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:13:"10.2.0-alpha1";a:10:{s:4:"name";s:20:"drupal 10.2.0-alpha1";s:7:"version";s:13:"10.2.0-alpha1";s:3:"tag";s:13:"10.2.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/10.2.0-alpha1";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-10.2.0-alpha1.tar.gz";s:4:"date";s:10:"1699048959";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"10.1.8";a:10:{s:4:"name";s:13:"drupal 10.1.8";s:7:"version";s:6:"10.1.8";s:3:"tag";s:6:"10.1.8";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.1.8";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.1.8.tar.gz";s:4:"date";s:10:"1705512711";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.1.7";a:10:{s:4:"name";s:13:"drupal 10.1.7";s:7:"version";s:6:"10.1.7";s:3:"tag";s:6:"10.1.7";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.1.7";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.1.7.tar.gz";s:4:"date";s:10:"1701857745";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.1.6";a:10:{s:4:"name";s:13:"drupal 10.1.6";s:7:"version";s:6:"10.1.6";s:3:"tag";s:6:"10.1.6";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.1.6";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.1.6.tar.gz";s:4:"date";s:10:"1698841286";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.1.5";a:10:{s:4:"name";s:13:"drupal 10.1.5";s:7:"version";s:6:"10.1.5";s:3:"tag";s:6:"10.1.5";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.1.5";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.1.5.tar.gz";s:4:"date";s:10:"1696456362";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.1.4";a:10:{s:4:"name";s:13:"drupal 10.1.4";s:7:"version";s:6:"10.1.4";s:3:"tag";s:6:"10.1.4";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.1.4";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.1.4.tar.gz";s:4:"date";s:10:"1695227262";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.1.3";a:10:{s:4:"name";s:13:"drupal 10.1.3";s:7:"version";s:6:"10.1.3";s:3:"tag";s:6:"10.1.3";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.1.3";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.1.3.tar.gz";s:4:"date";s:10:"1694101052";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.1.2";a:10:{s:4:"name";s:13:"drupal 10.1.2";s:7:"version";s:6:"10.1.2";s:3:"tag";s:6:"10.1.2";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.1.2";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.1.2.tar.gz";s:4:"date";s:10:"1690972078";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.1.1";a:10:{s:4:"name";s:13:"drupal 10.1.1";s:7:"version";s:6:"10.1.1";s:3:"tag";s:6:"10.1.1";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.1.1";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.1.1.tar.gz";s:4:"date";s:10:"1688632960";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.1.0";a:10:{s:4:"name";s:13:"drupal 10.1.0";s:7:"version";s:6:"10.1.0";s:3:"tag";s:6:"10.1.0";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.1.0";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.1.0.tar.gz";s:4:"date";s:10:"1687424272";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:10:"10.1.0-rc1";a:10:{s:4:"name";s:17:"drupal 10.1.0-rc1";s:7:"version";s:10:"10.1.0-rc1";s:3:"tag";s:10:"10.1.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.1.0-rc1";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.1.0-rc1.tar.gz";s:4:"date";s:10:"1686244833";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:12:"10.1.0-beta1";a:10:{s:4:"name";s:19:"drupal 10.1.0-beta1";s:7:"version";s:12:"10.1.0-beta1";s:3:"tag";s:12:"10.1.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/10.1.0-beta1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-10.1.0-beta1.tar.gz";s:4:"date";s:10:"1684130534";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:13:"10.1.0-alpha1";a:10:{s:4:"name";s:20:"drupal 10.1.0-alpha1";s:7:"version";s:13:"10.1.0-alpha1";s:3:"tag";s:13:"10.1.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/10.1.0-alpha1";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-10.1.0-alpha1.tar.gz";s:4:"date";s:10:"1682694475";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:7:"10.0.11";a:10:{s:4:"name";s:14:"drupal 10.0.11";s:7:"version";s:7:"10.0.11";s:3:"tag";s:7:"10.0.11";s:6:"status";s:9:"published";s:12:"release_link";s:54:"https://www.drupal.org/project/drupal/releases/10.0.11";s:13:"download_link";s:59:"https://ftp.drupal.org/files/projects/drupal-10.0.11.tar.gz";s:4:"date";s:10:"1695228927";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:7:"10.0.10";a:10:{s:4:"name";s:14:"drupal 10.0.10";s:7:"version";s:7:"10.0.10";s:3:"tag";s:7:"10.0.10";s:6:"status";s:9:"published";s:12:"release_link";s:54:"https://www.drupal.org/project/drupal/releases/10.0.10";s:13:"download_link";s:59:"https://ftp.drupal.org/files/projects/drupal-10.0.10.tar.gz";s:4:"date";s:10:"1688549719";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.0.9";a:10:{s:4:"name";s:13:"drupal 10.0.9";s:7:"version";s:6:"10.0.9";s:3:"tag";s:6:"10.0.9";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.0.9";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.0.9.tar.gz";s:4:"date";s:10:"1683108606";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.0.8";a:10:{s:4:"name";s:13:"drupal 10.0.8";s:7:"version";s:6:"10.0.8";s:3:"tag";s:6:"10.0.8";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.0.8";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.0.8.tar.gz";s:4:"date";s:10:"1681921539";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.0.7";a:10:{s:4:"name";s:13:"drupal 10.0.7";s:7:"version";s:6:"10.0.7";s:3:"tag";s:6:"10.0.7";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.0.7";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.0.7.tar.gz";s:4:"date";s:10:"1679678060";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:12:"New features";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.0.6";a:10:{s:4:"name";s:13:"drupal 10.0.6";s:7:"version";s:6:"10.0.6";s:3:"tag";s:6:"10.0.6";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.0.6";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.0.6.tar.gz";s:4:"date";s:10:"1679664982";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.0.5";a:10:{s:4:"name";s:13:"drupal 10.0.5";s:7:"version";s:6:"10.0.5";s:3:"tag";s:6:"10.0.5";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.0.5";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.0.5.tar.gz";s:4:"date";s:10:"1678901067";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.0.4";a:10:{s:4:"name";s:13:"drupal 10.0.4";s:7:"version";s:6:"10.0.4";s:3:"tag";s:6:"10.0.4";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.0.4";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.0.4.tar.gz";s:4:"date";s:10:"1677681486";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.0.3";a:10:{s:4:"name";s:13:"drupal 10.0.3";s:7:"version";s:6:"10.0.3";s:3:"tag";s:6:"10.0.3";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.0.3";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.0.3.tar.gz";s:4:"date";s:10:"1675276709";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.0.2";a:10:{s:4:"name";s:13:"drupal 10.0.2";s:7:"version";s:6:"10.0.2";s:3:"tag";s:6:"10.0.2";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.0.2";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.0.2.tar.gz";s:4:"date";s:10:"1674065542";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.0.1";a:10:{s:4:"name";s:13:"drupal 10.0.1";s:7:"version";s:6:"10.0.1";s:3:"tag";s:6:"10.0.1";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.0.1";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.0.1.tar.gz";s:4:"date";s:10:"1672847780";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"10.0.0";a:10:{s:4:"name";s:13:"drupal 10.0.0";s:7:"version";s:6:"10.0.0";s:3:"tag";s:6:"10.0.0";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/10.0.0";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-10.0.0.tar.gz";s:4:"date";s:10:"1671125939";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:10:"10.0.0-rc3";a:10:{s:4:"name";s:17:"drupal 10.0.0-rc3";s:7:"version";s:10:"10.0.0-rc3";s:3:"tag";s:10:"10.0.0-rc3";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.0.0-rc3";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc3.tar.gz";s:4:"date";s:10:"1670591784";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:10:"10.0.0-rc2";a:10:{s:4:"name";s:17:"drupal 10.0.0-rc2";s:7:"version";s:10:"10.0.0-rc2";s:3:"tag";s:10:"10.0.0-rc2";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.0.0-rc2";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc2.tar.gz";s:4:"date";s:10:"1670320927";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:10:"10.0.0-rc1";a:10:{s:4:"name";s:17:"drupal 10.0.0-rc1";s:7:"version";s:10:"10.0.0-rc1";s:3:"tag";s:10:"10.0.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.0.0-rc1";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc1.tar.gz";s:4:"date";s:10:"1668612993";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:12:"10.0.0-beta2";a:10:{s:4:"name";s:19:"drupal 10.0.0-beta2";s:7:"version";s:12:"10.0.0-beta2";s:3:"tag";s:12:"10.0.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/10.0.0-beta2";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-10.0.0-beta2.tar.gz";s:4:"date";s:10:"1664462663";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"10.0.0-beta1";a:10:{s:4:"name";s:19:"drupal 10.0.0-beta1";s:7:"version";s:12:"10.0.0-beta1";s:3:"tag";s:12:"10.0.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/10.0.0-beta1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-10.0.0-beta1.tar.gz";s:4:"date";s:10:"1663358020";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:13:"10.0.0-alpha7";a:10:{s:4:"name";s:20:"drupal 10.0.0-alpha7";s:7:"version";s:13:"10.0.0-alpha7";s:3:"tag";s:13:"10.0.0-alpha7";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/10.0.0-alpha7";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha7.tar.gz";s:4:"date";s:10:"1659633851";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:13:"10.0.0-alpha6";a:10:{s:4:"name";s:20:"drupal 10.0.0-alpha6";s:7:"version";s:13:"10.0.0-alpha6";s:3:"tag";s:13:"10.0.0-alpha6";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/10.0.0-alpha6";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha6.tar.gz";s:4:"date";s:10:"1657218740";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:13:"10.0.0-alpha5";a:10:{s:4:"name";s:20:"drupal 10.0.0-alpha5";s:7:"version";s:13:"10.0.0-alpha5";s:3:"tag";s:13:"10.0.0-alpha5";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/10.0.0-alpha5";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha5.tar.gz";s:4:"date";s:10:"1654722993";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:13:"10.0.0-alpha4";a:10:{s:4:"name";s:20:"drupal 10.0.0-alpha4";s:7:"version";s:13:"10.0.0-alpha4";s:3:"tag";s:13:"10.0.0-alpha4";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/10.0.0-alpha4";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha4.tar.gz";s:4:"date";s:10:"1651875601";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:13:"10.0.0-alpha3";a:10:{s:4:"name";s:20:"drupal 10.0.0-alpha3";s:7:"version";s:13:"10.0.0-alpha3";s:3:"tag";s:13:"10.0.0-alpha3";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/10.0.0-alpha3";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha3.tar.gz";s:4:"date";s:10:"1649887793";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:13:"10.0.0-alpha2";a:10:{s:4:"name";s:20:"drupal 10.0.0-alpha2";s:7:"version";s:13:"10.0.0-alpha2";s:3:"tag";s:13:"10.0.0-alpha2";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/10.0.0-alpha2";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha2.tar.gz";s:4:"date";s:10:"1645204305";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:13:"10.0.0-alpha1";a:10:{s:4:"name";s:20:"drupal 10.0.0-alpha1";s:7:"version";s:13:"10.0.0-alpha1";s:3:"tag";s:13:"10.0.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/10.0.0-alpha1";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha1.tar.gz";s:4:"date";s:10:"1643404041";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"9.5.11";a:10:{s:4:"name";s:13:"drupal 9.5.11";s:7:"version";s:6:"9.5.11";s:3:"tag";s:6:"9.5.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.5.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.5.11.tar.gz";s:4:"date";s:10:"1695228016";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.5.10";a:10:{s:4:"name";s:13:"drupal 9.5.10";s:7:"version";s:6:"9.5.10";s:3:"tag";s:6:"9.5.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.5.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.5.10.tar.gz";s:4:"date";s:10:"1688550984";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.5.9";a:10:{s:4:"name";s:12:"drupal 9.5.9";s:7:"version";s:5:"9.5.9";s:3:"tag";s:5:"9.5.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.5.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.5.9.tar.gz";s:4:"date";s:10:"1683121532";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.5.8";a:10:{s:4:"name";s:12:"drupal 9.5.8";s:7:"version";s:5:"9.5.8";s:3:"tag";s:5:"9.5.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.5.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.5.8.tar.gz";s:4:"date";s:10:"1681922649";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.5.7";a:10:{s:4:"name";s:12:"drupal 9.5.7";s:7:"version";s:5:"9.5.7";s:3:"tag";s:5:"9.5.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.5.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.5.7.tar.gz";s:4:"date";s:10:"1679677448";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.5.6";a:10:{s:4:"name";s:12:"drupal 9.5.6";s:7:"version";s:5:"9.5.6";s:3:"tag";s:5:"9.5.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.5.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.5.6.tar.gz";s:4:"date";s:10:"1679664389";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.5.5";a:10:{s:4:"name";s:12:"drupal 9.5.5";s:7:"version";s:5:"9.5.5";s:3:"tag";s:5:"9.5.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.5.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.5.5.tar.gz";s:4:"date";s:10:"1678902101";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.5.4";a:10:{s:4:"name";s:12:"drupal 9.5.4";s:7:"version";s:5:"9.5.4";s:3:"tag";s:5:"9.5.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.5.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.5.4.tar.gz";s:4:"date";s:10:"1677680813";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.5.3";a:10:{s:4:"name";s:12:"drupal 9.5.3";s:7:"version";s:5:"9.5.3";s:3:"tag";s:5:"9.5.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.5.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.5.3.tar.gz";s:4:"date";s:10:"1675281829";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.5.2";a:10:{s:4:"name";s:12:"drupal 9.5.2";s:7:"version";s:5:"9.5.2";s:3:"tag";s:5:"9.5.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.5.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.5.2.tar.gz";s:4:"date";s:10:"1674066112";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.5.1";a:10:{s:4:"name";s:12:"drupal 9.5.1";s:7:"version";s:5:"9.5.1";s:3:"tag";s:5:"9.5.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.5.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.5.1.tar.gz";s:4:"date";s:10:"1672849046";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.5.0";a:10:{s:4:"name";s:12:"drupal 9.5.0";s:7:"version";s:5:"9.5.0";s:3:"tag";s:5:"9.5.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.5.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.5.0.tar.gz";s:4:"date";s:10:"1671115839";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"9.5.0-rc2";a:10:{s:4:"name";s:16:"drupal 9.5.0-rc2";s:7:"version";s:9:"9.5.0-rc2";s:3:"tag";s:9:"9.5.0-rc2";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.5.0-rc2";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.5.0-rc2.tar.gz";s:4:"date";s:10:"1670593040";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:9:"9.5.0-rc1";a:10:{s:4:"name";s:16:"drupal 9.5.0-rc1";s:7:"version";s:9:"9.5.0-rc1";s:3:"tag";s:9:"9.5.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.5.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.5.0-rc1.tar.gz";s:4:"date";s:10:"1668611189";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"9.5.0-beta2";a:10:{s:4:"name";s:18:"drupal 9.5.0-beta2";s:7:"version";s:11:"9.5.0-beta2";s:3:"tag";s:11:"9.5.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.5.0-beta2";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.5.0-beta2.tar.gz";s:4:"date";s:10:"1664463958";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"9.5.0-beta1";a:10:{s:4:"name";s:18:"drupal 9.5.0-beta1";s:7:"version";s:11:"9.5.0-beta1";s:3:"tag";s:11:"9.5.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.5.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.5.0-beta1.tar.gz";s:4:"date";s:10:"1663358587";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:6:"9.4.15";a:10:{s:4:"name";s:13:"drupal 9.4.15";s:7:"version";s:6:"9.4.15";s:3:"tag";s:6:"9.4.15";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.4.15";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.4.15.tar.gz";s:4:"date";s:10:"1683122076";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.4.14";a:10:{s:4:"name";s:13:"drupal 9.4.14";s:7:"version";s:6:"9.4.14";s:3:"tag";s:6:"9.4.14";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.4.14";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.4.14.tar.gz";s:4:"date";s:10:"1681922120";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.4.13";a:10:{s:4:"name";s:13:"drupal 9.4.13";s:7:"version";s:6:"9.4.13";s:3:"tag";s:6:"9.4.13";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.4.13";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.4.13.tar.gz";s:4:"date";s:10:"1679665413";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.4.12";a:10:{s:4:"name";s:13:"drupal 9.4.12";s:7:"version";s:6:"9.4.12";s:3:"tag";s:6:"9.4.12";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.4.12";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.4.12.tar.gz";s:4:"date";s:10:"1678901516";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.4.11";a:10:{s:4:"name";s:13:"drupal 9.4.11";s:7:"version";s:6:"9.4.11";s:3:"tag";s:6:"9.4.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.4.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.4.11.tar.gz";s:4:"date";s:10:"1675282255";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.4.10";a:10:{s:4:"name";s:13:"drupal 9.4.10";s:7:"version";s:6:"9.4.10";s:3:"tag";s:6:"9.4.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.4.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.4.10.tar.gz";s:4:"date";s:10:"1674066615";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.4.9";a:10:{s:4:"name";s:12:"drupal 9.4.9";s:7:"version";s:5:"9.4.9";s:3:"tag";s:5:"9.4.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.4.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.4.9.tar.gz";s:4:"date";s:10:"1670421053";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.4.8";a:10:{s:4:"name";s:12:"drupal 9.4.8";s:7:"version";s:5:"9.4.8";s:3:"tag";s:5:"9.4.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.4.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.4.8.tar.gz";s:4:"date";s:10:"1665072393";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.4.7";a:10:{s:4:"name";s:12:"drupal 9.4.7";s:7:"version";s:5:"9.4.7";s:3:"tag";s:5:"9.4.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.4.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.4.7.tar.gz";s:4:"date";s:10:"1664383239";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.4.6";a:10:{s:4:"name";s:12:"drupal 9.4.6";s:7:"version";s:5:"9.4.6";s:3:"tag";s:5:"9.4.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.4.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.4.6.tar.gz";s:4:"date";s:10:"1663681319";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.4.5";a:10:{s:4:"name";s:12:"drupal 9.4.5";s:7:"version";s:5:"9.4.5";s:3:"tag";s:5:"9.4.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.4.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.4.5.tar.gz";s:4:"date";s:10:"1659545453";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.4.4";a:10:{s:4:"name";s:12:"drupal 9.4.4";s:7:"version";s:5:"9.4.4";s:3:"tag";s:5:"9.4.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.4.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.4.4.tar.gz";s:4:"date";s:10:"1659037490";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.4.3";a:10:{s:4:"name";s:12:"drupal 9.4.3";s:7:"version";s:5:"9.4.3";s:3:"tag";s:5:"9.4.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.4.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.4.3.tar.gz";s:4:"date";s:10:"1658333415";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.4.2";a:10:{s:4:"name";s:12:"drupal 9.4.2";s:7:"version";s:5:"9.4.2";s:3:"tag";s:5:"9.4.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.4.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.4.2.tar.gz";s:4:"date";s:10:"1657157309";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.4.1";a:10:{s:4:"name";s:12:"drupal 9.4.1";s:7:"version";s:5:"9.4.1";s:3:"tag";s:5:"9.4.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.4.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.4.1.tar.gz";s:4:"date";s:10:"1655845511";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.4.0";a:10:{s:4:"name";s:12:"drupal 9.4.0";s:7:"version";s:5:"9.4.0";s:3:"tag";s:5:"9.4.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.4.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.4.0.tar.gz";s:4:"date";s:10:"1655311138";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"9.4.0-rc2";a:10:{s:4:"name";s:16:"drupal 9.4.0-rc2";s:7:"version";s:9:"9.4.0-rc2";s:3:"tag";s:9:"9.4.0-rc2";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.4.0-rc2";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.4.0-rc2.tar.gz";s:4:"date";s:10:"1654890055";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:15:"Security update";i:1;s:9:"Bug fixes";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:9:"9.4.0-rc1";a:10:{s:4:"name";s:16:"drupal 9.4.0-rc1";s:7:"version";s:9:"9.4.0-rc1";s:3:"tag";s:9:"9.4.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.4.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.4.0-rc1.tar.gz";s:4:"date";s:10:"1654740019";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"9.4.0-beta1";a:10:{s:4:"name";s:18:"drupal 9.4.0-beta1";s:7:"version";s:11:"9.4.0-beta1";s:3:"tag";s:11:"9.4.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.4.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.4.0-beta1.tar.gz";s:4:"date";s:10:"1653938214";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"9.4.0-alpha1";a:10:{s:4:"name";s:19:"drupal 9.4.0-alpha1";s:7:"version";s:12:"9.4.0-alpha1";s:3:"tag";s:12:"9.4.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/9.4.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-9.4.0-alpha1.tar.gz";s:4:"date";s:10:"1651875606";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"9.3.22";a:10:{s:4:"name";s:13:"drupal 9.3.22";s:7:"version";s:6:"9.3.22";s:3:"tag";s:6:"9.3.22";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.22";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.22.tar.gz";s:4:"date";s:10:"1664382666";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.21";a:10:{s:4:"name";s:13:"drupal 9.3.21";s:7:"version";s:6:"9.3.21";s:3:"tag";s:6:"9.3.21";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.21";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.21.tar.gz";s:4:"date";s:10:"1659544886";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.20";a:10:{s:4:"name";s:13:"drupal 9.3.20";s:7:"version";s:6:"9.3.20";s:3:"tag";s:6:"9.3.20";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.20";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.20.tar.gz";s:4:"date";s:10:"1659037977";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.19";a:10:{s:4:"name";s:13:"drupal 9.3.19";s:7:"version";s:6:"9.3.19";s:3:"tag";s:6:"9.3.19";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.19";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.19.tar.gz";s:4:"date";s:10:"1658333887";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.18";a:10:{s:4:"name";s:13:"drupal 9.3.18";s:7:"version";s:6:"9.3.18";s:3:"tag";s:6:"9.3.18";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.18";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.18.tar.gz";s:4:"date";s:10:"1657238772";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.17";a:10:{s:4:"name";s:13:"drupal 9.3.17";s:7:"version";s:6:"9.3.17";s:3:"tag";s:6:"9.3.17";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.17";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.17.tar.gz";s:4:"date";s:10:"1655846622";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.16";a:10:{s:4:"name";s:13:"drupal 9.3.16";s:7:"version";s:6:"9.3.16";s:3:"tag";s:6:"9.3.16";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.16";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.16.tar.gz";s:4:"date";s:10:"1654888736";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.15";a:10:{s:4:"name";s:13:"drupal 9.3.15";s:7:"version";s:6:"9.3.15";s:3:"tag";s:6:"9.3.15";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.15";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.15.tar.gz";s:4:"date";s:10:"1654098765";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.14";a:10:{s:4:"name";s:13:"drupal 9.3.14";s:7:"version";s:6:"9.3.14";s:3:"tag";s:6:"9.3.14";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.14";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.14.tar.gz";s:4:"date";s:10:"1653506291";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.13";a:10:{s:4:"name";s:13:"drupal 9.3.13";s:7:"version";s:6:"9.3.13";s:3:"tag";s:6:"9.3.13";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.13";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.13.tar.gz";s:4:"date";s:10:"1652261874";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.12";a:10:{s:4:"name";s:13:"drupal 9.3.12";s:7:"version";s:6:"9.3.12";s:3:"tag";s:6:"9.3.12";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.12";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.12.tar.gz";s:4:"date";s:10:"1650467536";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.11";a:10:{s:4:"name";s:13:"drupal 9.3.11";s:7:"version";s:6:"9.3.11";s:3:"tag";s:6:"9.3.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.11.tar.gz";s:4:"date";s:10:"1649897391";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.3.10";a:10:{s:4:"name";s:13:"drupal 9.3.10";s:7:"version";s:6:"9.3.10";s:3:"tag";s:6:"9.3.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.3.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.3.10.tar.gz";s:4:"date";s:10:"1649890098";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.3.9";a:10:{s:4:"name";s:12:"drupal 9.3.9";s:7:"version";s:5:"9.3.9";s:3:"tag";s:5:"9.3.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.3.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.3.9.tar.gz";s:4:"date";s:10:"1647899360";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.3.8";a:10:{s:4:"name";s:12:"drupal 9.3.8";s:7:"version";s:5:"9.3.8";s:3:"tag";s:5:"9.3.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.3.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.3.8.tar.gz";s:4:"date";s:10:"1647446914";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.3.7";a:10:{s:4:"name";s:12:"drupal 9.3.7";s:7:"version";s:5:"9.3.7";s:3:"tag";s:5:"9.3.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.3.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.3.7.tar.gz";s:4:"date";s:10:"1646300599";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.3.6";a:10:{s:4:"name";s:12:"drupal 9.3.6";s:7:"version";s:5:"9.3.6";s:3:"tag";s:5:"9.3.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.3.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.3.6.tar.gz";s:4:"date";s:10:"1645029460";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.3.5";a:10:{s:4:"name";s:12:"drupal 9.3.5";s:7:"version";s:5:"9.3.5";s:3:"tag";s:5:"9.3.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.3.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.3.5.tar.gz";s:4:"date";s:10:"1644011676";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.3.4";a:10:{s:4:"name";s:12:"drupal 9.3.4";s:7:"version";s:5:"9.3.4";s:3:"tag";s:5:"9.3.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.3.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.3.4.tar.gz";s:4:"date";s:10:"1643832805";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.3.3";a:10:{s:4:"name";s:12:"drupal 9.3.3";s:7:"version";s:5:"9.3.3";s:3:"tag";s:5:"9.3.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.3.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.3.3.tar.gz";s:4:"date";s:10:"1642607769";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.3.2";a:10:{s:4:"name";s:12:"drupal 9.3.2";s:7:"version";s:5:"9.3.2";s:3:"tag";s:5:"9.3.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.3.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.3.2.tar.gz";s:4:"date";s:10:"1641351799";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.3.1";a:10:{s:4:"name";s:12:"drupal 9.3.1";s:7:"version";s:5:"9.3.1";s:3:"tag";s:5:"9.3.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.3.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.3.1.tar.gz";s:4:"date";s:10:"1641342679";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.3.0";a:10:{s:4:"name";s:12:"drupal 9.3.0";s:7:"version";s:5:"9.3.0";s:3:"tag";s:5:"9.3.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.3.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.3.0.tar.gz";s:4:"date";s:10:"1639051276";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"9.3.0-rc1";a:10:{s:4:"name";s:16:"drupal 9.3.0-rc1";s:7:"version";s:9:"9.3.0-rc1";s:3:"tag";s:9:"9.3.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.3.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.3.0-rc1.tar.gz";s:4:"date";s:10:"1637959424";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"9.3.0-beta3";a:10:{s:4:"name";s:18:"drupal 9.3.0-beta3";s:7:"version";s:11:"9.3.0-beta3";s:3:"tag";s:11:"9.3.0-beta3";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.3.0-beta3";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta3.tar.gz";s:4:"date";s:10:"1637764182";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"9.3.0-beta2";a:10:{s:4:"name";s:18:"drupal 9.3.0-beta2";s:7:"version";s:11:"9.3.0-beta2";s:3:"tag";s:11:"9.3.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.3.0-beta2";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta2.tar.gz";s:4:"date";s:10:"1637196496";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"9.3.0-beta1";a:10:{s:4:"name";s:18:"drupal 9.3.0-beta1";s:7:"version";s:11:"9.3.0-beta1";s:3:"tag";s:11:"9.3.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.3.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta1.tar.gz";s:4:"date";s:10:"1636746050";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"9.3.0-alpha1";a:10:{s:4:"name";s:19:"drupal 9.3.0-alpha1";s:7:"version";s:12:"9.3.0-alpha1";s:3:"tag";s:12:"9.3.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/9.3.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-9.3.0-alpha1.tar.gz";s:4:"date";s:10:"1635510285";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"9.2.21";a:10:{s:4:"name";s:13:"drupal 9.2.21";s:7:"version";s:6:"9.2.21";s:3:"tag";s:6:"9.2.21";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.21";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.21.tar.gz";s:4:"date";s:10:"1654889475";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.20";a:10:{s:4:"name";s:13:"drupal 9.2.20";s:7:"version";s:6:"9.2.20";s:3:"tag";s:6:"9.2.20";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.20";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.20.tar.gz";s:4:"date";s:10:"1653507225";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.19";a:10:{s:4:"name";s:13:"drupal 9.2.19";s:7:"version";s:6:"9.2.19";s:3:"tag";s:6:"9.2.19";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.19";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.19.tar.gz";s:4:"date";s:10:"1652306637";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.18";a:10:{s:4:"name";s:13:"drupal 9.2.18";s:7:"version";s:6:"9.2.18";s:3:"tag";s:6:"9.2.18";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.18";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.18.tar.gz";s:4:"date";s:10:"1650466972";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.17";a:10:{s:4:"name";s:13:"drupal 9.2.17";s:7:"version";s:6:"9.2.17";s:3:"tag";s:6:"9.2.17";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.17";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.17.tar.gz";s:4:"date";s:10:"1649898006";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.16";a:10:{s:4:"name";s:13:"drupal 9.2.16";s:7:"version";s:6:"9.2.16";s:3:"tag";s:6:"9.2.16";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.16";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.16.tar.gz";s:4:"date";s:10:"1647898826";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.15";a:10:{s:4:"name";s:13:"drupal 9.2.15";s:7:"version";s:6:"9.2.15";s:3:"tag";s:6:"9.2.15";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.15";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.15.tar.gz";s:4:"date";s:10:"1647447411";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.14";a:10:{s:4:"name";s:13:"drupal 9.2.14";s:7:"version";s:6:"9.2.14";s:3:"tag";s:6:"9.2.14";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.14";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.14.tar.gz";s:4:"date";s:10:"1647027629";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.13";a:10:{s:4:"name";s:13:"drupal 9.2.13";s:7:"version";s:6:"9.2.13";s:3:"tag";s:6:"9.2.13";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.13";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.13.tar.gz";s:4:"date";s:10:"1645029955";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.12";a:10:{s:4:"name";s:13:"drupal 9.2.12";s:7:"version";s:6:"9.2.12";s:3:"tag";s:6:"9.2.12";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.12";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.12.tar.gz";s:4:"date";s:10:"1644012448";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.11";a:10:{s:4:"name";s:13:"drupal 9.2.11";s:7:"version";s:6:"9.2.11";s:3:"tag";s:6:"9.2.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.11.tar.gz";s:4:"date";s:10:"1642608353";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.2.10";a:10:{s:4:"name";s:13:"drupal 9.2.10";s:7:"version";s:6:"9.2.10";s:3:"tag";s:6:"9.2.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.2.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.2.10.tar.gz";s:4:"date";s:10:"1637765544";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.2.9";a:10:{s:4:"name";s:12:"drupal 9.2.9";s:7:"version";s:5:"9.2.9";s:3:"tag";s:5:"9.2.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.2.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.2.9.tar.gz";s:4:"date";s:10:"1637184936";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.2.8";a:10:{s:4:"name";s:12:"drupal 9.2.8";s:7:"version";s:5:"9.2.8";s:3:"tag";s:5:"9.2.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.2.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.2.8.tar.gz";s:4:"date";s:10:"1635961216";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.2.7";a:10:{s:4:"name";s:12:"drupal 9.2.7";s:7:"version";s:5:"9.2.7";s:3:"tag";s:5:"9.2.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.2.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.2.7.tar.gz";s:4:"date";s:10:"1633544267";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.2.6";a:10:{s:4:"name";s:12:"drupal 9.2.6";s:7:"version";s:5:"9.2.6";s:3:"tag";s:5:"9.2.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.2.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.2.6.tar.gz";s:4:"date";s:10:"1631721555";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.2.5";a:10:{s:4:"name";s:12:"drupal 9.2.5";s:7:"version";s:5:"9.2.5";s:3:"tag";s:5:"9.2.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.2.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.2.5.tar.gz";s:4:"date";s:10:"1630534729";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.2.4";a:10:{s:4:"name";s:12:"drupal 9.2.4";s:7:"version";s:5:"9.2.4";s:3:"tag";s:5:"9.2.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.2.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.2.4.tar.gz";s:4:"date";s:10:"1628791178";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.2.3";a:10:{s:4:"name";s:12:"drupal 9.2.3";s:7:"version";s:5:"9.2.3";s:3:"tag";s:5:"9.2.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.2.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.2.3.tar.gz";s:4:"date";s:10:"1627997922";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.2.2";a:10:{s:4:"name";s:12:"drupal 9.2.2";s:7:"version";s:5:"9.2.2";s:3:"tag";s:5:"9.2.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.2.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.2.2.tar.gz";s:4:"date";s:10:"1626882385";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.2.1";a:10:{s:4:"name";s:12:"drupal 9.2.1";s:7:"version";s:5:"9.2.1";s:3:"tag";s:5:"9.2.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.2.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.2.1.tar.gz";s:4:"date";s:10:"1625664286";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.2.0";a:10:{s:4:"name";s:12:"drupal 9.2.0";s:7:"version";s:5:"9.2.0";s:3:"tag";s:5:"9.2.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.2.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.2.0.tar.gz";s:4:"date";s:10:"1623847798";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"9.2.0-rc1";a:10:{s:4:"name";s:16:"drupal 9.2.0-rc1";s:7:"version";s:9:"9.2.0-rc1";s:3:"tag";s:9:"9.2.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.2.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.2.0-rc1.tar.gz";s:4:"date";s:10:"1623080867";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"9.2.0-beta3";a:10:{s:4:"name";s:18:"drupal 9.2.0-beta3";s:7:"version";s:11:"9.2.0-beta3";s:3:"tag";s:11:"9.2.0-beta3";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.2.0-beta3";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta3.tar.gz";s:4:"date";s:10:"1622207568";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"9.2.0-beta2";a:10:{s:4:"name";s:18:"drupal 9.2.0-beta2";s:7:"version";s:11:"9.2.0-beta2";s:3:"tag";s:11:"9.2.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.2.0-beta2";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta2.tar.gz";s:4:"date";s:10:"1622068611";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:4:{i:0;s:15:"Security update";i:1;s:9:"Bug fixes";i:2;s:12:"New features";i:3;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"9.2.0-beta1";a:10:{s:4:"name";s:18:"drupal 9.2.0-beta1";s:7:"version";s:11:"9.2.0-beta1";s:3:"tag";s:11:"9.2.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.2.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta1.tar.gz";s:4:"date";s:10:"1621506248";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"9.2.0-alpha1";a:10:{s:4:"name";s:19:"drupal 9.2.0-alpha1";s:7:"version";s:12:"9.2.0-alpha1";s:3:"tag";s:12:"9.2.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/9.2.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-9.2.0-alpha1.tar.gz";s:4:"date";s:10:"1620291652";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"9.1.15";a:10:{s:4:"name";s:13:"drupal 9.1.15";s:7:"version";s:6:"9.1.15";s:3:"tag";s:6:"9.1.15";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.1.15";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.1.15.tar.gz";s:4:"date";s:10:"1637766681";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.1.14";a:10:{s:4:"name";s:13:"drupal 9.1.14";s:7:"version";s:6:"9.1.14";s:3:"tag";s:6:"9.1.14";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.1.14";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.1.14.tar.gz";s:4:"date";s:10:"1637185450";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.1.13";a:10:{s:4:"name";s:13:"drupal 9.1.13";s:7:"version";s:6:"9.1.13";s:3:"tag";s:6:"9.1.13";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.1.13";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.1.13.tar.gz";s:4:"date";s:10:"1631722011";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.1.12";a:10:{s:4:"name";s:13:"drupal 9.1.12";s:7:"version";s:6:"9.1.12";s:3:"tag";s:6:"9.1.12";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.1.12";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.1.12.tar.gz";s:4:"date";s:10:"1628791786";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.1.11";a:10:{s:4:"name";s:13:"drupal 9.1.11";s:7:"version";s:6:"9.1.11";s:3:"tag";s:6:"9.1.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.1.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.1.11.tar.gz";s:4:"date";s:10:"1626882849";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.1.10";a:10:{s:4:"name";s:13:"drupal 9.1.10";s:7:"version";s:6:"9.1.10";s:3:"tag";s:6:"9.1.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.1.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.1.10.tar.gz";s:4:"date";s:10:"1622828120";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.1.9";a:10:{s:4:"name";s:12:"drupal 9.1.9";s:7:"version";s:5:"9.1.9";s:3:"tag";s:5:"9.1.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.1.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.1.9.tar.gz";s:4:"date";s:10:"1622056478";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.1.8";a:10:{s:4:"name";s:12:"drupal 9.1.8";s:7:"version";s:5:"9.1.8";s:3:"tag";s:5:"9.1.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.1.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.1.8.tar.gz";s:4:"date";s:10:"1620214182";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.1.7";a:10:{s:4:"name";s:12:"drupal 9.1.7";s:7:"version";s:5:"9.1.7";s:3:"tag";s:5:"9.1.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.1.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.1.7.tar.gz";s:4:"date";s:10:"1619022156";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.1.6";a:10:{s:4:"name";s:12:"drupal 9.1.6";s:7:"version";s:5:"9.1.6";s:3:"tag";s:5:"9.1.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.1.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.1.6.tar.gz";s:4:"date";s:10:"1617795446";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.1.5";a:10:{s:4:"name";s:12:"drupal 9.1.5";s:7:"version";s:5:"9.1.5";s:3:"tag";s:5:"9.1.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.1.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.1.5.tar.gz";s:4:"date";s:10:"1614869503";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.1.4";a:10:{s:4:"name";s:12:"drupal 9.1.4";s:7:"version";s:5:"9.1.4";s:3:"tag";s:5:"9.1.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.1.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.1.4.tar.gz";s:4:"date";s:10:"1612380948";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.1.3";a:10:{s:4:"name";s:12:"drupal 9.1.3";s:7:"version";s:5:"9.1.3";s:3:"tag";s:5:"9.1.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.1.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.1.3.tar.gz";s:4:"date";s:10:"1611161215";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.1.2";a:10:{s:4:"name";s:12:"drupal 9.1.2";s:7:"version";s:5:"9.1.2";s:3:"tag";s:5:"9.1.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.1.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.1.2.tar.gz";s:4:"date";s:10:"1609984407";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.1.1";a:10:{s:4:"name";s:12:"drupal 9.1.1";s:7:"version";s:5:"9.1.1";s:3:"tag";s:5:"9.1.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.1.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.1.1.tar.gz";s:4:"date";s:10:"1609979034";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.1.0";a:10:{s:4:"name";s:12:"drupal 9.1.0";s:7:"version";s:5:"9.1.0";s:3:"tag";s:5:"9.1.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.1.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.1.0.tar.gz";s:4:"date";s:10:"1606933254";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"9.1.0-rc3";a:10:{s:4:"name";s:16:"drupal 9.1.0-rc3";s:7:"version";s:9:"9.1.0-rc3";s:3:"tag";s:9:"9.1.0-rc3";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.1.0-rc3";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc3.tar.gz";s:4:"date";s:10:"1606357271";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:9:"9.1.0-rc2";a:10:{s:4:"name";s:16:"drupal 9.1.0-rc2";s:7:"version";s:9:"9.1.0-rc2";s:3:"tag";s:9:"9.1.0-rc2";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.1.0-rc2";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc2.tar.gz";s:4:"date";s:10:"1606332982";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:9:"9.1.0-rc1";a:10:{s:4:"name";s:16:"drupal 9.1.0-rc1";s:7:"version";s:9:"9.1.0-rc1";s:3:"tag";s:9:"9.1.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.1.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc1.tar.gz";s:4:"date";s:10:"1605722782";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:4:{i:0;s:15:"Security update";i:1;s:9:"Bug fixes";i:2;s:12:"New features";i:3;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"9.1.0-beta1";a:10:{s:4:"name";s:18:"drupal 9.1.0-beta1";s:7:"version";s:11:"9.1.0-beta1";s:3:"tag";s:11:"9.1.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.1.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.1.0-beta1.tar.gz";s:4:"date";s:10:"1604672644";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"9.1.0-alpha1";a:10:{s:4:"name";s:19:"drupal 9.1.0-alpha1";s:7:"version";s:12:"9.1.0-alpha1";s:3:"tag";s:12:"9.1.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/9.1.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-9.1.0-alpha1.tar.gz";s:4:"date";s:10:"1603466665";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"9.0.14";a:10:{s:4:"name";s:13:"drupal 9.0.14";s:7:"version";s:6:"9.0.14";s:3:"tag";s:6:"9.0.14";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.0.14";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.0.14.tar.gz";s:4:"date";s:10:"1622055778";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.0.13";a:10:{s:4:"name";s:13:"drupal 9.0.13";s:7:"version";s:6:"9.0.13";s:3:"tag";s:6:"9.0.13";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.0.13";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.0.13.tar.gz";s:4:"date";s:10:"1620218506";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.0.12";a:10:{s:4:"name";s:13:"drupal 9.0.12";s:7:"version";s:6:"9.0.12";s:3:"tag";s:6:"9.0.12";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.0.12";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.0.12.tar.gz";s:4:"date";s:10:"1619020951";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.0.11";a:10:{s:4:"name";s:13:"drupal 9.0.11";s:7:"version";s:6:"9.0.11";s:3:"tag";s:6:"9.0.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.0.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.0.11.tar.gz";s:4:"date";s:10:"1611161749";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"9.0.10";a:10:{s:4:"name";s:13:"drupal 9.0.10";s:7:"version";s:6:"9.0.10";s:3:"tag";s:6:"9.0.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/9.0.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-9.0.10.tar.gz";s:4:"date";s:10:"1607029536";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.0.9";a:10:{s:4:"name";s:12:"drupal 9.0.9";s:7:"version";s:5:"9.0.9";s:3:"tag";s:5:"9.0.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.0.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.0.9.tar.gz";s:4:"date";s:10:"1606359757";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.0.8";a:10:{s:4:"name";s:12:"drupal 9.0.8";s:7:"version";s:5:"9.0.8";s:3:"tag";s:5:"9.0.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.0.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.0.8.tar.gz";s:4:"date";s:10:"1605720638";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.0.7";a:10:{s:4:"name";s:12:"drupal 9.0.7";s:7:"version";s:5:"9.0.7";s:3:"tag";s:5:"9.0.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.0.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.0.7.tar.gz";s:4:"date";s:10:"1602100055";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.0.6";a:10:{s:4:"name";s:12:"drupal 9.0.6";s:7:"version";s:5:"9.0.6";s:3:"tag";s:5:"9.0.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.0.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.0.6.tar.gz";s:4:"date";s:10:"1600275813";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.0.5";a:10:{s:4:"name";s:12:"drupal 9.0.5";s:7:"version";s:5:"9.0.5";s:3:"tag";s:5:"9.0.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.0.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.0.5.tar.gz";s:4:"date";s:10:"1599167739";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.0.4";a:10:{s:4:"name";s:12:"drupal 9.0.4";s:7:"version";s:5:"9.0.4";s:3:"tag";s:5:"9.0.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.0.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.0.4.tar.gz";s:4:"date";s:10:"1599046734";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.0.3";a:10:{s:4:"name";s:12:"drupal 9.0.3";s:7:"version";s:5:"9.0.3";s:3:"tag";s:5:"9.0.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.0.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.0.3.tar.gz";s:4:"date";s:10:"1596664575";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.0.2";a:10:{s:4:"name";s:12:"drupal 9.0.2";s:7:"version";s:5:"9.0.2";s:3:"tag";s:5:"9.0.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.0.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.0.2.tar.gz";s:4:"date";s:10:"1594237418";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.0.1";a:10:{s:4:"name";s:12:"drupal 9.0.1";s:7:"version";s:5:"9.0.1";s:3:"tag";s:5:"9.0.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.0.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.0.1.tar.gz";s:4:"date";s:10:"1592417721";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"9.0.0";a:10:{s:4:"name";s:12:"drupal 9.0.0";s:7:"version";s:5:"9.0.0";s:3:"tag";s:5:"9.0.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/9.0.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-9.0.0.tar.gz";s:4:"date";s:10:"1591221685";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"9.0.0-rc1";a:10:{s:4:"name";s:16:"drupal 9.0.0-rc1";s:7:"version";s:9:"9.0.0-rc1";s:3:"tag";s:9:"9.0.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.0.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.0.0-rc1.tar.gz";s:4:"date";s:10:"1590187579";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"9.0.0-beta3";a:10:{s:4:"name";s:18:"drupal 9.0.0-beta3";s:7:"version";s:11:"9.0.0-beta3";s:3:"tag";s:11:"9.0.0-beta3";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.0.0-beta3";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta3.tar.gz";s:4:"date";s:10:"1589587936";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"9.0.0-beta2";a:10:{s:4:"name";s:18:"drupal 9.0.0-beta2";s:7:"version";s:11:"9.0.0-beta2";s:3:"tag";s:11:"9.0.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.0.0-beta2";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta2.tar.gz";s:4:"date";s:10:"1585597395";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:15:"Security update";i:1;s:9:"Bug fixes";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"9.0.0-beta1";a:10:{s:4:"name";s:18:"drupal 9.0.0-beta1";s:7:"version";s:11:"9.0.0-beta1";s:3:"tag";s:11:"9.0.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/9.0.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta1.tar.gz";s:4:"date";s:10:"1584734060";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"9.0.0-alpha2";a:10:{s:4:"name";s:19:"drupal 9.0.0-alpha2";s:7:"version";s:12:"9.0.0-alpha2";s:3:"tag";s:12:"9.0.0-alpha2";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/9.0.0-alpha2";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-9.0.0-alpha2.tar.gz";s:4:"date";s:10:"1583349043";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:12:"9.0.0-alpha1";a:10:{s:4:"name";s:19:"drupal 9.0.0-alpha1";s:7:"version";s:12:"9.0.0-alpha1";s:3:"tag";s:12:"9.0.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/9.0.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-9.0.0-alpha1.tar.gz";s:4:"date";s:10:"1581447927";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"8.9.20";a:10:{s:4:"name";s:13:"drupal 8.9.20";s:7:"version";s:6:"8.9.20";s:3:"tag";s:6:"8.9.20";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.20";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.20.tar.gz";s:4:"date";s:10:"1637185966";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.9.19";a:10:{s:4:"name";s:13:"drupal 8.9.19";s:7:"version";s:6:"8.9.19";s:3:"tag";s:6:"8.9.19";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.19";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.19.tar.gz";s:4:"date";s:10:"1631722431";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.9.18";a:10:{s:4:"name";s:13:"drupal 8.9.18";s:7:"version";s:6:"8.9.18";s:3:"tag";s:6:"8.9.18";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.18";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.18.tar.gz";s:4:"date";s:10:"1628792296";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.9.17";a:10:{s:4:"name";s:13:"drupal 8.9.17";s:7:"version";s:6:"8.9.17";s:3:"tag";s:6:"8.9.17";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.17";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.17.tar.gz";s:4:"date";s:10:"1626883324";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.9.16";a:10:{s:4:"name";s:13:"drupal 8.9.16";s:7:"version";s:6:"8.9.16";s:3:"tag";s:6:"8.9.16";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.16";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.16.tar.gz";s:4:"date";s:10:"1622058087";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.9.15";a:10:{s:4:"name";s:13:"drupal 8.9.15";s:7:"version";s:6:"8.9.15";s:3:"tag";s:6:"8.9.15";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.15";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.15.tar.gz";s:4:"date";s:10:"1620216983";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.9.14";a:10:{s:4:"name";s:13:"drupal 8.9.14";s:7:"version";s:6:"8.9.14";s:3:"tag";s:6:"8.9.14";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.14";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.14.tar.gz";s:4:"date";s:10:"1619021518";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.9.13";a:10:{s:4:"name";s:13:"drupal 8.9.13";s:7:"version";s:6:"8.9.13";s:3:"tag";s:6:"8.9.13";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.13";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.13.tar.gz";s:4:"date";s:10:"1611162272";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.9.12";a:10:{s:4:"name";s:13:"drupal 8.9.12";s:7:"version";s:6:"8.9.12";s:3:"tag";s:6:"8.9.12";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.12";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.12.tar.gz";s:4:"date";s:10:"1609977009";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.9.11";a:10:{s:4:"name";s:13:"drupal 8.9.11";s:7:"version";s:6:"8.9.11";s:3:"tag";s:6:"8.9.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.11.tar.gz";s:4:"date";s:10:"1607030087";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.9.10";a:10:{s:4:"name";s:13:"drupal 8.9.10";s:7:"version";s:6:"8.9.10";s:3:"tag";s:6:"8.9.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.9.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.9.10.tar.gz";s:4:"date";s:10:"1606360301";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.9.9";a:10:{s:4:"name";s:12:"drupal 8.9.9";s:7:"version";s:5:"8.9.9";s:3:"tag";s:5:"8.9.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.9.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.9.9.tar.gz";s:4:"date";s:10:"1605721120";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.9.8";a:10:{s:4:"name";s:12:"drupal 8.9.8";s:7:"version";s:5:"8.9.8";s:3:"tag";s:5:"8.9.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.9.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.9.8.tar.gz";s:4:"date";s:10:"1604595269";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.9.7";a:10:{s:4:"name";s:12:"drupal 8.9.7";s:7:"version";s:5:"8.9.7";s:3:"tag";s:5:"8.9.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.9.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.9.7.tar.gz";s:4:"date";s:10:"1602100507";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.9.6";a:10:{s:4:"name";s:12:"drupal 8.9.6";s:7:"version";s:5:"8.9.6";s:3:"tag";s:5:"8.9.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.9.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.9.6.tar.gz";s:4:"date";s:10:"1600276267";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.9.5";a:10:{s:4:"name";s:12:"drupal 8.9.5";s:7:"version";s:5:"8.9.5";s:3:"tag";s:5:"8.9.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.9.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.9.5.tar.gz";s:4:"date";s:10:"1599168205";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.9.4";a:10:{s:4:"name";s:12:"drupal 8.9.4";s:7:"version";s:5:"8.9.4";s:3:"tag";s:5:"8.9.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.9.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.9.4.tar.gz";s:4:"date";s:10:"1599047691";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.9.3";a:10:{s:4:"name";s:12:"drupal 8.9.3";s:7:"version";s:5:"8.9.3";s:3:"tag";s:5:"8.9.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.9.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.9.3.tar.gz";s:4:"date";s:10:"1596665051";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.9.2";a:10:{s:4:"name";s:12:"drupal 8.9.2";s:7:"version";s:5:"8.9.2";s:3:"tag";s:5:"8.9.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.9.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.9.2.tar.gz";s:4:"date";s:10:"1594237961";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.9.1";a:10:{s:4:"name";s:12:"drupal 8.9.1";s:7:"version";s:5:"8.9.1";s:3:"tag";s:5:"8.9.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.9.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.9.1.tar.gz";s:4:"date";s:10:"1592418237";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.9.0";a:10:{s:4:"name";s:12:"drupal 8.9.0";s:7:"version";s:5:"8.9.0";s:3:"tag";s:5:"8.9.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.9.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.9.0.tar.gz";s:4:"date";s:10:"1591204117";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"8.9.0-rc1";a:10:{s:4:"name";s:16:"drupal 8.9.0-rc1";s:7:"version";s:9:"8.9.0-rc1";s:3:"tag";s:9:"8.9.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.9.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.9.0-rc1.tar.gz";s:4:"date";s:10:"1590189096";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"8.9.0-beta3";a:10:{s:4:"name";s:18:"drupal 8.9.0-beta3";s:7:"version";s:11:"8.9.0-beta3";s:3:"tag";s:11:"8.9.0-beta3";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.9.0-beta3";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta3.tar.gz";s:4:"date";s:10:"1589746375";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.9.0-beta2";a:10:{s:4:"name";s:18:"drupal 8.9.0-beta2";s:7:"version";s:11:"8.9.0-beta2";s:3:"tag";s:11:"8.9.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.9.0-beta2";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta2.tar.gz";s:4:"date";s:10:"1585863226";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.9.0-beta1";a:10:{s:4:"name";s:18:"drupal 8.9.0-beta1";s:7:"version";s:11:"8.9.0-beta1";s:3:"tag";s:11:"8.9.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.9.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta1.tar.gz";s:4:"date";s:10:"1585263710";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:6:"8.8.12";a:10:{s:4:"name";s:13:"drupal 8.8.12";s:7:"version";s:6:"8.8.12";s:3:"tag";s:6:"8.8.12";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.8.12";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.8.12.tar.gz";s:4:"date";s:10:"1606360866";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.8.11";a:10:{s:4:"name";s:13:"drupal 8.8.11";s:7:"version";s:6:"8.8.11";s:3:"tag";s:6:"8.8.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.8.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.8.11.tar.gz";s:4:"date";s:10:"1605721628";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.8.10";a:10:{s:4:"name";s:13:"drupal 8.8.10";s:7:"version";s:6:"8.8.10";s:3:"tag";s:6:"8.8.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.8.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.8.10.tar.gz";s:4:"date";s:10:"1600276704";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.8.9";a:10:{s:4:"name";s:12:"drupal 8.8.9";s:7:"version";s:5:"8.8.9";s:3:"tag";s:5:"8.8.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.8.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.8.9.tar.gz";s:4:"date";s:10:"1599168716";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.8.8";a:10:{s:4:"name";s:12:"drupal 8.8.8";s:7:"version";s:5:"8.8.8";s:3:"tag";s:5:"8.8.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.8.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.8.8.tar.gz";s:4:"date";s:10:"1592418750";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.8.7";a:10:{s:4:"name";s:12:"drupal 8.8.7";s:7:"version";s:5:"8.8.7";s:3:"tag";s:5:"8.8.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.8.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.8.7.tar.gz";s:4:"date";s:10:"1591203837";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.8.6";a:10:{s:4:"name";s:12:"drupal 8.8.6";s:7:"version";s:5:"8.8.6";s:3:"tag";s:5:"8.8.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.8.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.8.6.tar.gz";s:4:"date";s:10:"1589989060";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.8.5";a:10:{s:4:"name";s:12:"drupal 8.8.5";s:7:"version";s:5:"8.8.5";s:3:"tag";s:5:"8.8.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.8.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.8.5.tar.gz";s:4:"date";s:10:"1585861530";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.8.4";a:10:{s:4:"name";s:12:"drupal 8.8.4";s:7:"version";s:5:"8.8.4";s:3:"tag";s:5:"8.8.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.8.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.8.4.tar.gz";s:4:"date";s:10:"1584560524";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.8.3";a:10:{s:4:"name";s:12:"drupal 8.8.3";s:7:"version";s:5:"8.8.3";s:3:"tag";s:5:"8.8.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.8.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.8.3.tar.gz";s:4:"date";s:10:"1583347094";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.8.2";a:10:{s:4:"name";s:12:"drupal 8.8.2";s:7:"version";s:5:"8.8.2";s:3:"tag";s:5:"8.8.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.8.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.8.2.tar.gz";s:4:"date";s:10:"1580598849";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.8.1";a:10:{s:4:"name";s:12:"drupal 8.8.1";s:7:"version";s:5:"8.8.1";s:3:"tag";s:5:"8.8.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.8.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.8.1.tar.gz";s:4:"date";s:10:"1576695785";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.8.0";a:10:{s:4:"name";s:12:"drupal 8.8.0";s:7:"version";s:5:"8.8.0";s:3:"tag";s:5:"8.8.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.8.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.8.0.tar.gz";s:4:"date";s:10:"1575450481";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"8.8.0-rc1";a:10:{s:4:"name";s:16:"drupal 8.8.0-rc1";s:7:"version";s:9:"8.8.0-rc1";s:3:"tag";s:9:"8.8.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.8.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.8.0-rc1.tar.gz";s:4:"date";s:10:"1574462580";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"8.8.0-beta1";a:10:{s:4:"name";s:18:"drupal 8.8.0-beta1";s:7:"version";s:11:"8.8.0-beta1";s:3:"tag";s:11:"8.8.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.8.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.8.0-beta1.tar.gz";s:4:"date";s:10:"1573256280";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.8.0-alpha1";a:10:{s:4:"name";s:19:"drupal 8.8.0-alpha1";s:7:"version";s:12:"8.8.0-alpha1";s:3:"tag";s:12:"8.8.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.8.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.8.0-alpha1.tar.gz";s:4:"date";s:10:"1571355784";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"8.7.14";a:10:{s:4:"name";s:13:"drupal 8.7.14";s:7:"version";s:6:"8.7.14";s:3:"tag";s:6:"8.7.14";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.7.14";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.7.14.tar.gz";s:4:"date";s:10:"1589988665";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.7.13";a:10:{s:4:"name";s:13:"drupal 8.7.13";s:7:"version";s:6:"8.7.13";s:3:"tag";s:6:"8.7.13";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.7.13";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.7.13.tar.gz";s:4:"date";s:10:"1585861883";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.7.12";a:10:{s:4:"name";s:13:"drupal 8.7.12";s:7:"version";s:6:"8.7.12";s:3:"tag";s:6:"8.7.12";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.7.12";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.7.12.tar.gz";s:4:"date";s:10:"1584552250";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.7.11";a:10:{s:4:"name";s:13:"drupal 8.7.11";s:7:"version";s:6:"8.7.11";s:3:"tag";s:6:"8.7.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.7.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.7.11.tar.gz";s:4:"date";s:10:"1576695785";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.7.10";a:10:{s:4:"name";s:13:"drupal 8.7.10";s:7:"version";s:6:"8.7.10";s:3:"tag";s:6:"8.7.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.7.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.7.10.tar.gz";s:4:"date";s:10:"1573687985";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.7.9";a:10:{s:4:"name";s:12:"drupal 8.7.9";s:7:"version";s:5:"8.7.9";s:3:"tag";s:5:"8.7.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.7.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.7.9.tar.gz";s:4:"date";s:10:"1573063387";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.7.8";a:10:{s:4:"name";s:12:"drupal 8.7.8";s:7:"version";s:5:"8.7.8";s:3:"tag";s:5:"8.7.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.7.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.7.8.tar.gz";s:4:"date";s:10:"1570044484";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.7.7";a:10:{s:4:"name";s:12:"drupal 8.7.7";s:7:"version";s:5:"8.7.7";s:3:"tag";s:5:"8.7.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.7.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.7.7.tar.gz";s:4:"date";s:10:"1567593185";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.7.6";a:10:{s:4:"name";s:12:"drupal 8.7.6";s:7:"version";s:5:"8.7.6";s:3:"tag";s:5:"8.7.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.7.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.7.6.tar.gz";s:4:"date";s:10:"1565206385";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.7.5";a:10:{s:4:"name";s:12:"drupal 8.7.5";s:7:"version";s:5:"8.7.5";s:3:"tag";s:5:"8.7.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.7.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.7.5.tar.gz";s:4:"date";s:10:"1563380885";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.7.4";a:10:{s:4:"name";s:12:"drupal 8.7.4";s:7:"version";s:5:"8.7.4";s:3:"tag";s:5:"8.7.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.7.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.7.4.tar.gz";s:4:"date";s:10:"1562225587";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.7.3";a:10:{s:4:"name";s:12:"drupal 8.7.3";s:7:"version";s:5:"8.7.3";s:3:"tag";s:5:"8.7.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.7.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.7.3.tar.gz";s:4:"date";s:10:"1559762581";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.7.2";a:10:{s:4:"name";s:12:"drupal 8.7.2";s:7:"version";s:5:"8.7.2";s:3:"tag";s:5:"8.7.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.7.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.7.2.tar.gz";s:4:"date";s:10:"1558597086";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.7.1";a:10:{s:4:"name";s:12:"drupal 8.7.1";s:7:"version";s:5:"8.7.1";s:3:"tag";s:5:"8.7.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.7.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.7.1.tar.gz";s:4:"date";s:10:"1557335588";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.7.0";a:10:{s:4:"name";s:12:"drupal 8.7.0";s:7:"version";s:5:"8.7.0";s:3:"tag";s:5:"8.7.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.7.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.7.0.tar.gz";s:4:"date";s:10:"1556737085";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"8.7.0-rc1";a:10:{s:4:"name";s:16:"drupal 8.7.0-rc1";s:7:"version";s:9:"8.7.0-rc1";s:3:"tag";s:9:"8.7.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.7.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.7.0-rc1.tar.gz";s:4:"date";s:10:"1555603385";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:4:{i:0;s:15:"Security update";i:1;s:9:"Bug fixes";i:2;s:12:"New features";i:3;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"8.7.0-beta2";a:10:{s:4:"name";s:18:"drupal 8.7.0-beta2";s:7:"version";s:11:"8.7.0-beta2";s:3:"tag";s:11:"8.7.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.7.0-beta2";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.7.0-beta2.tar.gz";s:4:"date";s:10:"1554684784";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.7.0-beta1";a:10:{s:4:"name";s:18:"drupal 8.7.0-beta1";s:7:"version";s:11:"8.7.0-beta1";s:3:"tag";s:11:"8.7.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.7.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.7.0-beta1.tar.gz";s:4:"date";s:10:"1553881681";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.7.0-alpha2";a:10:{s:4:"name";s:19:"drupal 8.7.0-alpha2";s:7:"version";s:12:"8.7.0-alpha2";s:3:"tag";s:12:"8.7.0-alpha2";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.7.0-alpha2";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.7.0-alpha2.tar.gz";s:4:"date";s:10:"1553106180";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:12:"8.7.0-alpha1";a:10:{s:4:"name";s:19:"drupal 8.7.0-alpha1";s:7:"version";s:12:"8.7.0-alpha1";s:3:"tag";s:12:"8.7.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.7.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.7.0-alpha1.tar.gz";s:4:"date";s:10:"1552602484";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"8.6.18";a:10:{s:4:"name";s:13:"drupal 8.6.18";s:7:"version";s:6:"8.6.18";s:3:"tag";s:6:"8.6.18";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.6.18";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.6.18.tar.gz";s:4:"date";s:10:"1573687985";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.6.17";a:10:{s:4:"name";s:13:"drupal 8.6.17";s:7:"version";s:6:"8.6.17";s:3:"tag";s:6:"8.6.17";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.6.17";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.6.17.tar.gz";s:4:"date";s:10:"1560756785";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.6.16";a:10:{s:4:"name";s:13:"drupal 8.6.16";s:7:"version";s:6:"8.6.16";s:3:"tag";s:6:"8.6.16";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.6.16";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.6.16.tar.gz";s:4:"date";s:10:"1557335588";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.6.15";a:10:{s:4:"name";s:13:"drupal 8.6.15";s:7:"version";s:6:"8.6.15";s:3:"tag";s:6:"8.6.15";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.6.15";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.6.15.tar.gz";s:4:"date";s:10:"1555533181";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.6.14";a:10:{s:4:"name";s:13:"drupal 8.6.14";s:7:"version";s:6:"8.6.14";s:3:"tag";s:6:"8.6.14";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.6.14";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.6.14.tar.gz";s:4:"date";s:10:"1554688384";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.6.13";a:10:{s:4:"name";s:13:"drupal 8.6.13";s:7:"version";s:6:"8.6.13";s:3:"tag";s:6:"8.6.13";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.6.13";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.6.13.tar.gz";s:4:"date";s:10:"1553099584";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.6.12";a:10:{s:4:"name";s:13:"drupal 8.6.12";s:7:"version";s:6:"8.6.12";s:3:"tag";s:6:"8.6.12";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.6.12";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.6.12.tar.gz";s:4:"date";s:10:"1552601584";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.6.11";a:10:{s:4:"name";s:13:"drupal 8.6.11";s:7:"version";s:6:"8.6.11";s:3:"tag";s:6:"8.6.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.6.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.6.11.tar.gz";s:4:"date";s:10:"1552511584";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.6.10";a:10:{s:4:"name";s:13:"drupal 8.6.10";s:7:"version";s:6:"8.6.10";s:3:"tag";s:6:"8.6.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.6.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.6.10.tar.gz";s:4:"date";s:10:"1550691784";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.6.9";a:10:{s:4:"name";s:12:"drupal 8.6.9";s:7:"version";s:5:"8.6.9";s:3:"tag";s:5:"8.6.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.6.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.6.9.tar.gz";s:4:"date";s:10:"1549628580";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.6.8";a:10:{s:4:"name";s:12:"drupal 8.6.8";s:7:"version";s:5:"8.6.8";s:3:"tag";s:5:"8.6.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.6.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.6.8.tar.gz";s:4:"date";s:10:"1549466580";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.6.7";a:10:{s:4:"name";s:12:"drupal 8.6.7";s:7:"version";s:5:"8.6.7";s:3:"tag";s:5:"8.6.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.6.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.6.7.tar.gz";s:4:"date";s:10:"1547682180";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.6.6";a:10:{s:4:"name";s:12:"drupal 8.6.6";s:7:"version";s:5:"8.6.6";s:3:"tag";s:5:"8.6.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.6.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.6.6.tar.gz";s:4:"date";s:10:"1547663557";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.6.5";a:10:{s:4:"name";s:12:"drupal 8.6.5";s:7:"version";s:5:"8.6.5";s:3:"tag";s:5:"8.6.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.6.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.6.5.tar.gz";s:4:"date";s:10:"1546467485";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.6.4";a:10:{s:4:"name";s:12:"drupal 8.6.4";s:7:"version";s:5:"8.6.4";s:3:"tag";s:5:"8.6.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.6.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.6.4.tar.gz";s:4:"date";s:10:"1544011681";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.6.3";a:10:{s:4:"name";s:12:"drupal 8.6.3";s:7:"version";s:5:"8.6.3";s:3:"tag";s:5:"8.6.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.6.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.6.3.tar.gz";s:4:"date";s:10:"1541602684";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.6.2";a:10:{s:4:"name";s:12:"drupal 8.6.2";s:7:"version";s:5:"8.6.2";s:3:"tag";s:5:"8.6.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.6.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.6.2.tar.gz";s:4:"date";s:10:"1539816180";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.6.1";a:10:{s:4:"name";s:12:"drupal 8.6.1";s:7:"version";s:5:"8.6.1";s:3:"tag";s:5:"8.6.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.6.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.6.1.tar.gz";s:4:"date";s:10:"1536585780";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.6.0";a:10:{s:4:"name";s:12:"drupal 8.6.0";s:7:"version";s:5:"8.6.0";s:3:"tag";s:5:"8.6.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.6.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.6.0.tar.gz";s:4:"date";s:10:"1536186480";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"8.6.0-rc1";a:10:{s:4:"name";s:16:"drupal 8.6.0-rc1";s:7:"version";s:9:"8.6.0-rc1";s:3:"tag";s:9:"8.6.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.6.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.6.0-rc1.tar.gz";s:4:"date";s:10:"1534532580";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"8.6.0-beta2";a:10:{s:4:"name";s:18:"drupal 8.6.0-beta2";s:7:"version";s:11:"8.6.0-beta2";s:3:"tag";s:11:"8.6.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.6.0-beta2";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.6.0-beta2.tar.gz";s:4:"date";s:10:"1533298080";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.6.0-beta1";a:10:{s:4:"name";s:18:"drupal 8.6.0-beta1";s:7:"version";s:11:"8.6.0-beta1";s:3:"tag";s:11:"8.6.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.6.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.6.0-beta1.tar.gz";s:4:"date";s:10:"1533270485";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.6.0-alpha1";a:10:{s:4:"name";s:19:"drupal 8.6.0-alpha1";s:7:"version";s:12:"8.6.0-alpha1";s:3:"tag";s:12:"8.6.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.6.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.6.0-alpha1.tar.gz";s:4:"date";s:10:"1532033881";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:6:"8.5.15";a:10:{s:4:"name";s:13:"drupal 8.5.15";s:7:"version";s:6:"8.5.15";s:3:"tag";s:6:"8.5.15";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.5.15";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.5.15.tar.gz";s:4:"date";s:10:"1555533181";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.5.14";a:10:{s:4:"name";s:13:"drupal 8.5.14";s:7:"version";s:6:"8.5.14";s:3:"tag";s:6:"8.5.14";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.5.14";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.5.14.tar.gz";s:4:"date";s:10:"1553099584";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.5.13";a:10:{s:4:"name";s:13:"drupal 8.5.13";s:7:"version";s:6:"8.5.13";s:3:"tag";s:6:"8.5.13";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.5.13";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.5.13.tar.gz";s:4:"date";s:10:"1552601584";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.5.12";a:10:{s:4:"name";s:13:"drupal 8.5.12";s:7:"version";s:6:"8.5.12";s:3:"tag";s:6:"8.5.12";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.5.12";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.5.12.tar.gz";s:4:"date";s:10:"1552511584";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.5.11";a:10:{s:4:"name";s:13:"drupal 8.5.11";s:7:"version";s:6:"8.5.11";s:3:"tag";s:6:"8.5.11";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.5.11";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.5.11.tar.gz";s:4:"date";s:10:"1550691784";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:6:"8.5.10";a:10:{s:4:"name";s:13:"drupal 8.5.10";s:7:"version";s:6:"8.5.10";s:3:"tag";s:6:"8.5.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.5.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.5.10.tar.gz";s:4:"date";s:10:"1547682180";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.5.9";a:10:{s:4:"name";s:12:"drupal 8.5.9";s:7:"version";s:5:"8.5.9";s:3:"tag";s:5:"8.5.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.5.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.5.9.tar.gz";s:4:"date";s:10:"1547663557";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.5.8";a:10:{s:4:"name";s:12:"drupal 8.5.8";s:7:"version";s:5:"8.5.8";s:3:"tag";s:5:"8.5.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.5.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.5.8.tar.gz";s:4:"date";s:10:"1539816180";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.5.7";a:10:{s:4:"name";s:12:"drupal 8.5.7";s:7:"version";s:5:"8.5.7";s:3:"tag";s:5:"8.5.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.5.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.5.7.tar.gz";s:4:"date";s:10:"1536187080";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.5.6";a:10:{s:4:"name";s:12:"drupal 8.5.6";s:7:"version";s:5:"8.5.6";s:3:"tag";s:5:"8.5.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.5.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.5.6.tar.gz";s:4:"date";s:10:"1533156780";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.5.5";a:10:{s:4:"name";s:12:"drupal 8.5.5";s:7:"version";s:5:"8.5.5";s:3:"tag";s:5:"8.5.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.5.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.5.5.tar.gz";s:4:"date";s:10:"1530738820";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.5.4";a:10:{s:4:"name";s:12:"drupal 8.5.4";s:7:"version";s:5:"8.5.4";s:3:"tag";s:5:"8.5.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.5.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.5.4.tar.gz";s:4:"date";s:10:"1528319584";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.5.3";a:10:{s:4:"name";s:12:"drupal 8.5.3";s:7:"version";s:5:"8.5.3";s:3:"tag";s:5:"8.5.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.5.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.5.3.tar.gz";s:4:"date";s:10:"1524672780";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.5.2";a:10:{s:4:"name";s:12:"drupal 8.5.2";s:7:"version";s:5:"8.5.2";s:3:"tag";s:5:"8.5.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.5.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.5.2.tar.gz";s:4:"date";s:10:"1524073147";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.5.1";a:10:{s:4:"name";s:12:"drupal 8.5.1";s:7:"version";s:5:"8.5.1";s:3:"tag";s:5:"8.5.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.5.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.5.1.tar.gz";s:4:"date";s:10:"1522263480";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.5.0";a:10:{s:4:"name";s:12:"drupal 8.5.0";s:7:"version";s:5:"8.5.0";s:3:"tag";s:5:"8.5.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.5.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.5.0.tar.gz";s:4:"date";s:10:"1520457780";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"8.5.0-rc1";a:10:{s:4:"name";s:16:"drupal 8.5.0-rc1";s:7:"version";s:9:"8.5.0-rc1";s:3:"tag";s:9:"8.5.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.5.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.5.0-rc1.tar.gz";s:4:"date";s:10:"1519234680";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:4:{i:0;s:8:"Insecure";i:1;s:15:"Security update";i:2;s:9:"Bug fixes";i:3;s:12:"New features";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"8.5.0-beta1";a:10:{s:4:"name";s:18:"drupal 8.5.0-beta1";s:7:"version";s:11:"8.5.0-beta1";s:3:"tag";s:11:"8.5.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.5.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.5.0-beta1.tar.gz";s:4:"date";s:10:"1518211380";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.5.0-alpha1";a:10:{s:4:"name";s:19:"drupal 8.5.0-alpha1";s:7:"version";s:12:"8.5.0-alpha1";s:3:"tag";s:12:"8.5.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.5.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.5.0-alpha1.tar.gz";s:4:"date";s:10:"1516320484";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:5:"8.4.8";a:10:{s:4:"name";s:12:"drupal 8.4.8";s:7:"version";s:5:"8.4.8";s:3:"tag";s:5:"8.4.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.4.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.4.8.tar.gz";s:4:"date";s:10:"1524672780";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.4.7";a:10:{s:4:"name";s:12:"drupal 8.4.7";s:7:"version";s:5:"8.4.7";s:3:"tag";s:5:"8.4.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.4.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.4.7.tar.gz";s:4:"date";s:10:"1524073147";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.4.6";a:10:{s:4:"name";s:12:"drupal 8.4.6";s:7:"version";s:5:"8.4.6";s:3:"tag";s:5:"8.4.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.4.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.4.6.tar.gz";s:4:"date";s:10:"1522263480";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.4.5";a:10:{s:4:"name";s:12:"drupal 8.4.5";s:7:"version";s:5:"8.4.5";s:3:"tag";s:5:"8.4.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.4.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.4.5.tar.gz";s:4:"date";s:10:"1519234680";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.4.4";a:10:{s:4:"name";s:12:"drupal 8.4.4";s:7:"version";s:5:"8.4.4";s:3:"tag";s:5:"8.4.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.4.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.4.4.tar.gz";s:4:"date";s:10:"1515021185";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.4.3";a:10:{s:4:"name";s:12:"drupal 8.4.3";s:7:"version";s:5:"8.4.3";s:3:"tag";s:5:"8.4.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.4.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.4.3.tar.gz";s:4:"date";s:10:"1512600784";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.4.2";a:10:{s:4:"name";s:12:"drupal 8.4.2";s:7:"version";s:5:"8.4.2";s:3:"tag";s:5:"8.4.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.4.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.4.2.tar.gz";s:4:"date";s:10:"1509719885";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.4.1";a:10:{s:4:"name";s:12:"drupal 8.4.1";s:7:"version";s:5:"8.4.1";s:3:"tag";s:5:"8.4.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.4.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.4.1.tar.gz";s:4:"date";s:10:"1509562384";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.4.0";a:10:{s:4:"name";s:12:"drupal 8.4.0";s:7:"version";s:5:"8.4.0";s:3:"tag";s:5:"8.4.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.4.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.4.0.tar.gz";s:4:"date";s:10:"1507146244";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"8.4.0-rc2";a:10:{s:4:"name";s:16:"drupal 8.4.0-rc2";s:7:"version";s:9:"8.4.0-rc2";s:3:"tag";s:9:"8.4.0-rc2";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.4.0-rc2";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.4.0-rc2.tar.gz";s:4:"date";s:10:"1505911444";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:9:"8.4.0-rc1";a:10:{s:4:"name";s:16:"drupal 8.4.0-rc1";s:7:"version";s:9:"8.4.0-rc1";s:3:"tag";s:9:"8.4.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.4.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.4.0-rc1.tar.gz";s:4:"date";s:10:"1504733043";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"8.4.0-beta1";a:10:{s:4:"name";s:18:"drupal 8.4.0-beta1";s:7:"version";s:11:"8.4.0-beta1";s:3:"tag";s:11:"8.4.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.4.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.4.0-beta1.tar.gz";s:4:"date";s:10:"1502992144";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.4.0-alpha1";a:10:{s:4:"name";s:19:"drupal 8.4.0-alpha1";s:7:"version";s:12:"8.4.0-alpha1";s:3:"tag";s:12:"8.4.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.4.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.4.0-alpha1.tar.gz";s:4:"date";s:10:"1501790944";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:5:"8.3.9";a:10:{s:4:"name";s:12:"drupal 8.3.9";s:7:"version";s:5:"8.3.9";s:3:"tag";s:5:"8.3.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.3.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.3.9.tar.gz";s:4:"date";s:10:"1522263480";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.3.8";a:10:{s:4:"name";s:12:"drupal 8.3.8";s:7:"version";s:5:"8.3.8";s:3:"tag";s:5:"8.3.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.3.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.3.8.tar.gz";s:4:"date";s:10:"1520881985";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:15:"Security update";i:2;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.3.7";a:10:{s:4:"name";s:12:"drupal 8.3.7";s:7:"version";s:5:"8.3.7";s:3:"tag";s:5:"8.3.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.3.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.3.7.tar.gz";s:4:"date";s:10:"1502903903";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.3.6";a:10:{s:4:"name";s:12:"drupal 8.3.6";s:7:"version";s:5:"8.3.6";s:3:"tag";s:5:"8.3.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.3.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.3.6.tar.gz";s:4:"date";s:10:"1501688043";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.3.5";a:10:{s:4:"name";s:12:"drupal 8.3.5";s:7:"version";s:5:"8.3.5";s:3:"tag";s:5:"8.3.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.3.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.3.5.tar.gz";s:4:"date";s:10:"1499274843";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.3.4";a:10:{s:4:"name";s:12:"drupal 8.3.4";s:7:"version";s:5:"8.3.4";s:3:"tag";s:5:"8.3.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.3.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.3.4.tar.gz";s:4:"date";s:10:"1498069442";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.3.3";a:10:{s:4:"name";s:12:"drupal 8.3.3";s:7:"version";s:5:"8.3.3";s:3:"tag";s:5:"8.3.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.3.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.3.3.tar.gz";s:4:"date";s:10:"1496858041";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.3.2";a:10:{s:4:"name";s:12:"drupal 8.3.2";s:7:"version";s:5:"8.3.2";s:3:"tag";s:5:"8.3.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.3.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.3.2.tar.gz";s:4:"date";s:10:"1493834585";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.3.1";a:10:{s:4:"name";s:12:"drupal 8.3.1";s:7:"version";s:5:"8.3.1";s:3:"tag";s:5:"8.3.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.3.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.3.1.tar.gz";s:4:"date";s:10:"1492622946";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.3.0";a:10:{s:4:"name";s:12:"drupal 8.3.0";s:7:"version";s:5:"8.3.0";s:3:"tag";s:5:"8.3.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.3.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.3.0.tar.gz";s:4:"date";s:10:"1491439084";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"8.3.0-rc2";a:10:{s:4:"name";s:16:"drupal 8.3.0-rc2";s:7:"version";s:9:"8.3.0-rc2";s:3:"tag";s:9:"8.3.0-rc2";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.3.0-rc2";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.3.0-rc2.tar.gz";s:4:"date";s:10:"1489613583";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:9:"8.3.0-rc1";a:10:{s:4:"name";s:16:"drupal 8.3.0-rc1";s:7:"version";s:9:"8.3.0-rc1";s:3:"tag";s:9:"8.3.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.3.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.3.0-rc1.tar.gz";s:4:"date";s:10:"1488383284";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"8.3.0-beta1";a:10:{s:4:"name";s:18:"drupal 8.3.0-beta1";s:7:"version";s:11:"8.3.0-beta1";s:3:"tag";s:11:"8.3.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.3.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.3.0-beta1.tar.gz";s:4:"date";s:10:"1487175783";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.3.0-alpha1";a:10:{s:4:"name";s:19:"drupal 8.3.0-alpha1";s:7:"version";s:12:"8.3.0-alpha1";s:3:"tag";s:12:"8.3.0-alpha1";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.3.0-alpha1";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.3.0-alpha1.tar.gz";s:4:"date";s:10:"1485968583";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:5:"8.2.8";a:10:{s:4:"name";s:12:"drupal 8.2.8";s:7:"version";s:5:"8.2.8";s:3:"tag";s:5:"8.2.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.2.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.2.8.tar.gz";s:4:"date";s:10:"1492622852";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.2.7";a:10:{s:4:"name";s:12:"drupal 8.2.7";s:7:"version";s:5:"8.2.7";s:3:"tag";s:5:"8.2.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.2.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.2.7.tar.gz";s:4:"date";s:10:"1489609638";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.2.6";a:10:{s:4:"name";s:12:"drupal 8.2.6";s:7:"version";s:5:"8.2.6";s:3:"tag";s:5:"8.2.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.2.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.2.6.tar.gz";s:4:"date";s:10:"1485975485";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.2.5";a:10:{s:4:"name";s:12:"drupal 8.2.5";s:7:"version";s:5:"8.2.5";s:3:"tag";s:5:"8.2.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.2.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.2.5.tar.gz";s:4:"date";s:10:"1483529942";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.2.4";a:10:{s:4:"name";s:12:"drupal 8.2.4";s:7:"version";s:5:"8.2.4";s:3:"tag";s:5:"8.2.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.2.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.2.4.tar.gz";s:4:"date";s:10:"1481136784";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.2.3";a:10:{s:4:"name";s:12:"drupal 8.2.3";s:7:"version";s:5:"8.2.3";s:3:"tag";s:5:"8.2.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.2.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.2.3.tar.gz";s:4:"date";s:10:"1479322439";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.2.2";a:10:{s:4:"name";s:12:"drupal 8.2.2";s:7:"version";s:5:"8.2.2";s:3:"tag";s:5:"8.2.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.2.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.2.2.tar.gz";s:4:"date";s:10:"1478106542";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.2.1";a:10:{s:4:"name";s:12:"drupal 8.2.1";s:7:"version";s:5:"8.2.1";s:3:"tag";s:5:"8.2.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.2.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.2.1.tar.gz";s:4:"date";s:10:"1476181439";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.2.0";a:10:{s:4:"name";s:12:"drupal 8.2.0";s:7:"version";s:5:"8.2.0";s:3:"tag";s:5:"8.2.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.2.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.2.0.tar.gz";s:4:"date";s:10:"1475660639";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"8.2.0-rc2";a:10:{s:4:"name";s:16:"drupal 8.2.0-rc2";s:7:"version";s:9:"8.2.0-rc2";s:3:"tag";s:9:"8.2.0-rc2";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.2.0-rc2";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.2.0-rc2.tar.gz";s:4:"date";s:10:"1474484358";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:9:"8.2.0-rc1";a:10:{s:4:"name";s:16:"drupal 8.2.0-rc1";s:7:"version";s:9:"8.2.0-rc1";s:3:"tag";s:9:"8.2.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.2.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.2.0-rc1.tar.gz";s:4:"date";s:10:"1473285089";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"8.2.0-beta3";a:10:{s:4:"name";s:18:"drupal 8.2.0-beta3";s:7:"version";s:11:"8.2.0-beta3";s:3:"tag";s:11:"8.2.0-beta3";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.2.0-beta3";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta3.tar.gz";s:4:"date";s:10:"1472222475";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.2.0-beta2";a:10:{s:4:"name";s:18:"drupal 8.2.0-beta2";s:7:"version";s:11:"8.2.0-beta2";s:3:"tag";s:11:"8.2.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.2.0-beta2";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta2.tar.gz";s:4:"date";s:10:"1471710839";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.2.0-beta1";a:10:{s:4:"name";s:18:"drupal 8.2.0-beta1";s:7:"version";s:11:"8.2.0-beta1";s:3:"tag";s:11:"8.2.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.2.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta1.tar.gz";s:4:"date";s:10:"1470230639";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:6:"8.1.10";a:10:{s:4:"name";s:13:"drupal 8.1.10";s:7:"version";s:6:"8.1.10";s:3:"tag";s:6:"8.1.10";s:6:"status";s:9:"published";s:12:"release_link";s:53:"https://www.drupal.org/project/drupal/releases/8.1.10";s:13:"download_link";s:58:"https://ftp.drupal.org/files/projects/drupal-8.1.10.tar.gz";s:4:"date";s:10:"1474478939";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.1.9";a:10:{s:4:"name";s:12:"drupal 8.1.9";s:7:"version";s:5:"8.1.9";s:3:"tag";s:5:"8.1.9";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.1.9";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.1.9.tar.gz";s:4:"date";s:10:"1473276313";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.1.8";a:10:{s:4:"name";s:12:"drupal 8.1.8";s:7:"version";s:5:"8.1.8";s:3:"tag";s:5:"8.1.8";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.1.8";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.1.8.tar.gz";s:4:"date";s:10:"1470233647";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.1.7";a:10:{s:4:"name";s:12:"drupal 8.1.7";s:7:"version";s:5:"8.1.7";s:3:"tag";s:5:"8.1.7";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.1.7";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.1.7.tar.gz";s:4:"date";s:10:"1468855358";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.1.6";a:10:{s:4:"name";s:12:"drupal 8.1.6";s:7:"version";s:5:"8.1.6";s:3:"tag";s:5:"8.1.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.1.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.1.6.tar.gz";s:4:"date";s:10:"1468242539";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.1.5";a:10:{s:4:"name";s:12:"drupal 8.1.5";s:7:"version";s:5:"8.1.5";s:3:"tag";s:5:"8.1.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.1.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.1.5.tar.gz";s:4:"date";s:10:"1467884639";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.1.4";a:10:{s:4:"name";s:12:"drupal 8.1.4";s:7:"version";s:5:"8.1.4";s:3:"tag";s:5:"8.1.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.1.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.1.4.tar.gz";s:4:"date";s:10:"1467810839";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.1.3";a:10:{s:4:"name";s:12:"drupal 8.1.3";s:7:"version";s:5:"8.1.3";s:3:"tag";s:5:"8.1.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.1.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.1.3.tar.gz";s:4:"date";s:10:"1466021480";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:15:"Security update";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.1.2";a:10:{s:4:"name";s:12:"drupal 8.1.2";s:7:"version";s:5:"8.1.2";s:3:"tag";s:5:"8.1.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.1.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.1.2.tar.gz";s:4:"date";s:10:"1464824339";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.1.1";a:10:{s:4:"name";s:12:"drupal 8.1.1";s:7:"version";s:5:"8.1.1";s:3:"tag";s:5:"8.1.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.1.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.1.1.tar.gz";s:4:"date";s:10:"1462361039";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.1.0";a:10:{s:4:"name";s:12:"drupal 8.1.0";s:7:"version";s:5:"8.1.0";s:3:"tag";s:5:"8.1.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.1.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.1.0.tar.gz";s:4:"date";s:10:"1461118190";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"8.1.0-rc1";a:10:{s:4:"name";s:16:"drupal 8.1.0-rc1";s:7:"version";s:9:"8.1.0-rc1";s:3:"tag";s:9:"8.1.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.1.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.1.0-rc1.tar.gz";s:4:"date";s:10:"1459976639";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:11:"8.1.0-beta2";a:10:{s:4:"name";s:18:"drupal 8.1.0-beta2";s:7:"version";s:11:"8.1.0-beta2";s:3:"tag";s:11:"8.1.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.1.0-beta2";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.1.0-beta2.tar.gz";s:4:"date";s:10:"1458699840";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.1.0-beta1";a:10:{s:4:"name";s:18:"drupal 8.1.0-beta1";s:7:"version";s:11:"8.1.0-beta1";s:3:"tag";s:11:"8.1.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.1.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.1.0-beta1.tar.gz";s:4:"date";s:10:"1456975758";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";i:2;s:12:"New features";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:5:"8.0.6";a:10:{s:4:"name";s:12:"drupal 8.0.6";s:7:"version";s:5:"8.0.6";s:3:"tag";s:5:"8.0.6";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.0.6";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.0.6.tar.gz";s:4:"date";s:10:"1459900439";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.0.5";a:10:{s:4:"name";s:12:"drupal 8.0.5";s:7:"version";s:5:"8.0.5";s:3:"tag";s:5:"8.0.5";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.0.5";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.0.5.tar.gz";s:4:"date";s:10:"1456914839";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.0.4";a:10:{s:4:"name";s:12:"drupal 8.0.4";s:7:"version";s:5:"8.0.4";s:3:"tag";s:5:"8.0.4";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.0.4";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.0.4.tar.gz";s:4:"date";s:10:"1456341749";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.0.3";a:10:{s:4:"name";s:12:"drupal 8.0.3";s:7:"version";s:5:"8.0.3";s:3:"tag";s:5:"8.0.3";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.0.3";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.0.3.tar.gz";s:4:"date";s:10:"1454489043";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.0.2";a:10:{s:4:"name";s:12:"drupal 8.0.2";s:7:"version";s:5:"8.0.2";s:3:"tag";s:5:"8.0.2";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.0.2";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.0.2.tar.gz";s:4:"date";s:10:"1452119939";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.0.1";a:10:{s:4:"name";s:12:"drupal 8.0.1";s:7:"version";s:5:"8.0.1";s:3:"tag";s:5:"8.0.1";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.0.1";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.0.1.tar.gz";s:4:"date";s:10:"1449066839";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:5:"8.0.0";a:10:{s:4:"name";s:12:"drupal 8.0.0";s:7:"version";s:5:"8.0.0";s:3:"tag";s:5:"8.0.0";s:6:"status";s:9:"published";s:12:"release_link";s:52:"https://www.drupal.org/project/drupal/releases/8.0.0";s:13:"download_link";s:57:"https://ftp.drupal.org/files/projects/drupal-8.0.0.tar.gz";s:4:"date";s:10:"1447941840";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:44:"Covered by Drupal''s security advisory policy";}s:9:"8.0.0-rc4";a:10:{s:4:"name";s:16:"drupal 8.0.0-rc4";s:7:"version";s:9:"8.0.0-rc4";s:3:"tag";s:9:"8.0.0-rc4";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.0.0-rc4";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc4.tar.gz";s:4:"date";s:10:"1447413840";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:9:"8.0.0-rc3";a:10:{s:4:"name";s:16:"drupal 8.0.0-rc3";s:7:"version";s:9:"8.0.0-rc3";s:3:"tag";s:9:"8.0.0-rc3";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.0.0-rc3";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc3.tar.gz";s:4:"date";s:10:"1446633239";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:9:"8.0.0-rc2";a:10:{s:4:"name";s:16:"drupal 8.0.0-rc2";s:7:"version";s:9:"8.0.0-rc2";s:3:"tag";s:9:"8.0.0-rc2";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.0.0-rc2";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc2.tar.gz";s:4:"date";s:10:"1445468639";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:9:"8.0.0-rc1";a:10:{s:4:"name";s:16:"drupal 8.0.0-rc1";s:7:"version";s:9:"8.0.0-rc1";s:3:"tag";s:9:"8.0.0-rc1";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.0.0-rc1";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc1.tar.gz";s:4:"date";s:10:"1444253039";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:58:"RC releases are not covered by Drupal security advisories.";}s:12:"8.0.0-beta16";a:10:{s:4:"name";s:19:"drupal 8.0.0-beta16";s:7:"version";s:12:"8.0.0-beta16";s:3:"tag";s:12:"8.0.0-beta16";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.0.0-beta16";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta16.tar.gz";s:4:"date";s:10:"1443746640";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:9:"Bug fixes";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.0.0-beta15";a:10:{s:4:"name";s:19:"drupal 8.0.0-beta15";s:7:"version";s:12:"8.0.0-beta15";s:3:"tag";s:12:"8.0.0-beta15";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.0.0-beta15";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta15.tar.gz";s:4:"date";s:10:"1441357140";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.0.0-beta14";a:10:{s:4:"name";s:19:"drupal 8.0.0-beta14";s:7:"version";s:12:"8.0.0-beta14";s:3:"tag";s:12:"8.0.0-beta14";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.0.0-beta14";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta14.tar.gz";s:4:"date";s:10:"1438593539";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.0.0-beta13";a:10:{s:4:"name";s:19:"drupal 8.0.0-beta13";s:7:"version";s:12:"8.0.0-beta13";s:3:"tag";s:12:"8.0.0-beta13";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.0.0-beta13";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta13.tar.gz";s:4:"date";s:10:"1438194539";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.0.0-beta12";a:10:{s:4:"name";s:19:"drupal 8.0.0-beta12";s:7:"version";s:12:"8.0.0-beta12";s:3:"tag";s:12:"8.0.0-beta12";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.0.0-beta12";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta12.tar.gz";s:4:"date";s:10:"1435601583";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.0.0-beta11";a:10:{s:4:"name";s:19:"drupal 8.0.0-beta11";s:7:"version";s:12:"8.0.0-beta11";s:3:"tag";s:12:"8.0.0-beta11";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.0.0-beta11";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta11.tar.gz";s:4:"date";s:10:"1432758481";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:12:"8.0.0-beta10";a:10:{s:4:"name";s:19:"drupal 8.0.0-beta10";s:7:"version";s:12:"8.0.0-beta10";s:3:"tag";s:12:"8.0.0-beta10";s:6:"status";s:9:"published";s:12:"release_link";s:59:"https://www.drupal.org/project/drupal/releases/8.0.0-beta10";s:13:"download_link";s:64:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta10.tar.gz";s:4:"date";s:10:"1430314681";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.0.0-beta9";a:10:{s:4:"name";s:18:"drupal 8.0.0-beta9";s:7:"version";s:11:"8.0.0-beta9";s:3:"tag";s:11:"8.0.0-beta9";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0.0-beta9";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta9.tar.gz";s:4:"date";s:10:"1427299981";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.0.0-beta7";a:10:{s:4:"name";s:18:"drupal 8.0.0-beta7";s:7:"version";s:11:"8.0.0-beta7";s:3:"tag";s:11:"8.0.0-beta7";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0.0-beta7";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta7.tar.gz";s:4:"date";s:10:"1424875381";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.0.0-beta6";a:10:{s:4:"name";s:18:"drupal 8.0.0-beta6";s:7:"version";s:11:"8.0.0-beta6";s:3:"tag";s:11:"8.0.0-beta6";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0.0-beta6";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta6.tar.gz";s:4:"date";s:10:"1422443800";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.0.0-beta4";a:10:{s:4:"name";s:18:"drupal 8.0.0-beta4";s:7:"version";s:11:"8.0.0-beta4";s:3:"tag";s:11:"8.0.0-beta4";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0.0-beta4";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta4.tar.gz";s:4:"date";s:10:"1418825280";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.0.0-beta3";a:10:{s:4:"name";s:18:"drupal 8.0.0-beta3";s:7:"version";s:11:"8.0.0-beta3";s:3:"tag";s:11:"8.0.0-beta3";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0.0-beta3";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta3.tar.gz";s:4:"date";s:10:"1415797380";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.0.0-beta2";a:10:{s:4:"name";s:18:"drupal 8.0.0-beta2";s:7:"version";s:11:"8.0.0-beta2";s:3:"tag";s:11:"8.0.0-beta2";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0.0-beta2";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta2.tar.gz";s:4:"date";s:10:"1413394161";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:8:"Insecure";i:1;s:15:"Security update";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:11:"8.0.0-beta1";a:10:{s:4:"name";s:18:"drupal 8.0.0-beta1";s:7:"version";s:11:"8.0.0-beta1";s:3:"tag";s:11:"8.0.0-beta1";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0.0-beta1";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta1.tar.gz";s:4:"date";s:10:"1412147030";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:60:"Beta releases are not covered by Drupal security advisories.";}s:13:"8.0.0-alpha15";a:10:{s:4:"name";s:20:"drupal 8.0.0-alpha15";s:7:"version";s:13:"8.0.0-alpha15";s:3:"tag";s:13:"8.0.0-alpha15";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/8.0.0-alpha15";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-8.0.0-alpha15.tar.gz";s:4:"date";s:10:"1411139628";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:13:"8.0.0-alpha14";a:10:{s:4:"name";s:20:"drupal 8.0.0-alpha14";s:7:"version";s:13:"8.0.0-alpha14";s:3:"tag";s:13:"8.0.0-alpha14";s:6:"status";s:9:"published";s:12:"release_link";s:60:"https://www.drupal.org/project/drupal/releases/8.0.0-alpha14";s:13:"download_link";s:65:"https://ftp.drupal.org/files/projects/drupal-8.0.0-alpha14.tar.gz";s:4:"date";s:10:"1407344628";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:11:"8.0-alpha13";a:10:{s:4:"name";s:18:"drupal 8.0-alpha13";s:7:"version";s:11:"8.0-alpha13";s:3:"tag";s:11:"8.0-alpha13";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0-alpha13";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha13.tar.gz";s:4:"date";s:10:"1404296627";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:11:"8.0-alpha12";a:10:{s:4:"name";s:18:"drupal 8.0-alpha12";s:7:"version";s:11:"8.0-alpha12";s:3:"tag";s:11:"8.0-alpha12";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0-alpha12";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha12.tar.gz";s:4:"date";s:10:"1401293627";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:11:"8.0-alpha11";a:10:{s:4:"name";s:18:"drupal 8.0-alpha11";s:7:"version";s:11:"8.0-alpha11";s:3:"tag";s:11:"8.0-alpha11";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0-alpha11";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha11.tar.gz";s:4:"date";s:10:"1398249227";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:11:"8.0-alpha10";a:10:{s:4:"name";s:18:"drupal 8.0-alpha10";s:7:"version";s:11:"8.0-alpha10";s:3:"tag";s:11:"8.0-alpha10";s:6:"status";s:9:"published";s:12:"release_link";s:58:"https://www.drupal.org/project/drupal/releases/8.0-alpha10";s:13:"download_link";s:63:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha10.tar.gz";s:4:"date";s:10:"1395231556";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:10:"8.0-alpha9";a:10:{s:4:"name";s:17:"drupal 8.0-alpha9";s:7:"version";s:10:"8.0-alpha9";s:3:"tag";s:10:"8.0-alpha9";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/8.0-alpha9";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha9.tar.gz";s:4:"date";s:10:"1392806005";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:12:"New features";i:1;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:10:"8.0-alpha8";a:10:{s:4:"name";s:17:"drupal 8.0-alpha8";s:7:"version";s:10:"8.0-alpha8";s:3:"tag";s:10:"8.0-alpha8";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/8.0-alpha8";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha8.tar.gz";s:4:"date";s:10:"1390393105";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:10:"8.0-alpha7";a:10:{s:4:"name";s:17:"drupal 8.0-alpha7";s:7:"version";s:10:"8.0-alpha7";s:3:"tag";s:10:"8.0-alpha7";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/8.0-alpha7";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha7.tar.gz";s:4:"date";s:10:"1387399705";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:10:"8.0-alpha6";a:10:{s:4:"name";s:17:"drupal 8.0-alpha6";s:7:"version";s:10:"8.0-alpha6";s:3:"tag";s:10:"8.0-alpha6";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/8.0-alpha6";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha6.tar.gz";s:4:"date";s:10:"1385153305";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:10:"8.0-alpha5";a:10:{s:4:"name";s:17:"drupal 8.0-alpha5";s:7:"version";s:10:"8.0-alpha5";s:3:"tag";s:10:"8.0-alpha5";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/8.0-alpha5";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha5.tar.gz";s:4:"date";s:10:"1384850305";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:10:"8.0-alpha4";a:10:{s:4:"name";s:17:"drupal 8.0-alpha4";s:7:"version";s:10:"8.0-alpha4";s:3:"tag";s:10:"8.0-alpha4";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/8.0-alpha4";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha4.tar.gz";s:4:"date";s:10:"1382092313";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:12:"New features";i:1;s:9:"Bug fixes";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:10:"8.0-alpha3";a:10:{s:4:"name";s:17:"drupal 8.0-alpha3";s:7:"version";s:10:"8.0-alpha3";s:3:"tag";s:10:"8.0-alpha3";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/8.0-alpha3";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha3.tar.gz";s:4:"date";s:10:"1378303307";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:3:{i:0;s:12:"New features";i:1;s:9:"Bug fixes";i:2;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:10:"8.0-alpha2";a:10:{s:4:"name";s:17:"drupal 8.0-alpha2";s:7:"version";s:10:"8.0-alpha2";s:3:"tag";s:10:"8.0-alpha2";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/8.0-alpha2";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-8.0-alpha2.tar.gz";s:4:"date";s:10:"1372069563";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:1:{i:0;s:8:"Insecure";}}s:8:"security";s:61:"Alpha releases are not covered by Drupal security advisories.";}s:10:"11.0.x-dev";a:10:{s:4:"name";s:17:"drupal 11.0.x-dev";s:7:"version";s:10:"11.0.x-dev";s:3:"tag";s:6:"11.0.x";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/11.0.x-dev";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-11.0.x-dev.tar.gz";s:4:"date";s:10:"1723116703";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:8:"11.x-dev";a:10:{s:4:"name";s:15:"drupal 11.x-dev";s:7:"version";s:8:"11.x-dev";s:3:"tag";s:4:"11.x";s:6:"status";s:9:"published";s:12:"release_link";s:55:"https://www.drupal.org/project/drupal/releases/11.x-dev";s:13:"download_link";s:60:"https://ftp.drupal.org/files/projects/drupal-11.x-dev.tar.gz";s:4:"date";s:10:"1723126816";s:5:"files";s:0:"";s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";s:5:"terms";a:0:{}}s:10:"10.4.x-dev";a:10:{s:4:"name";s:17:"drupal 10.4.x-dev";s:7:"version";s:10:"10.4.x-dev";s:3:"tag";s:6:"10.4.x";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.4.x-dev";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.4.x-dev.tar.gz";s:4:"date";s:10:"1723116287";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:10:"10.3.x-dev";a:10:{s:4:"name";s:17:"drupal 10.3.x-dev";s:7:"version";s:10:"10.3.x-dev";s:3:"tag";s:6:"10.3.x";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.3.x-dev";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.3.x-dev.tar.gz";s:4:"date";s:10:"1723115775";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:10:"10.2.x-dev";a:10:{s:4:"name";s:17:"drupal 10.2.x-dev";s:7:"version";s:10:"10.2.x-dev";s:3:"tag";s:6:"10.2.x";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.2.x-dev";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.2.x-dev.tar.gz";s:4:"date";s:10:"1717659333";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:10:"10.1.x-dev";a:10:{s:4:"name";s:17:"drupal 10.1.x-dev";s:7:"version";s:10:"10.1.x-dev";s:3:"tag";s:6:"10.1.x";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.1.x-dev";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.1.x-dev.tar.gz";s:4:"date";s:10:"1713001795";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:10:"10.0.x-dev";a:10:{s:4:"name";s:17:"drupal 10.0.x-dev";s:7:"version";s:10:"10.0.x-dev";s:3:"tag";s:6:"10.0.x";s:6:"status";s:9:"published";s:12:"release_link";s:57:"https://www.drupal.org/project/drupal/releases/10.0.x-dev";s:13:"download_link";s:62:"https://ftp.drupal.org/files/projects/drupal-10.0.x-dev.tar.gz";s:4:"date";s:10:"1696930730";s:5:"files";s:0:"";s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";s:5:"terms";a:0:{}}s:9:"9.5.x-dev";a:10:{s:4:"name";s:16:"drupal 9.5.x-dev";s:7:"version";s:9:"9.5.x-dev";s:3:"tag";s:5:"9.5.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.5.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.5.x-dev.tar.gz";s:4:"date";s:10:"1701801362";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:9:"9.4.x-dev";a:10:{s:4:"name";s:16:"drupal 9.4.x-dev";s:7:"version";s:9:"9.4.x-dev";s:3:"tag";s:5:"9.4.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.4.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.4.x-dev.tar.gz";s:4:"date";s:10:"1683123227";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:9:"9.3.x-dev";a:10:{s:4:"name";s:16:"drupal 9.3.x-dev";s:7:"version";s:9:"9.3.x-dev";s:3:"tag";s:5:"9.3.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.3.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.3.x-dev.tar.gz";s:4:"date";s:10:"1664385919";s:5:"files";s:0:"";s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";s:5:"terms";a:0:{}}s:9:"9.2.x-dev";a:10:{s:4:"name";s:16:"drupal 9.2.x-dev";s:7:"version";s:9:"9.2.x-dev";s:3:"tag";s:5:"9.2.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.2.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.2.x-dev.tar.gz";s:4:"date";s:10:"1654891907";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:9:"9.1.x-dev";a:10:{s:4:"name";s:16:"drupal 9.1.x-dev";s:7:"version";s:9:"9.1.x-dev";s:3:"tag";s:5:"9.1.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.1.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.1.x-dev.tar.gz";s:4:"date";s:10:"1637766277";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:9:"9.0.x-dev";a:10:{s:4:"name";s:16:"drupal 9.0.x-dev";s:7:"version";s:9:"9.0.x-dev";s:3:"tag";s:5:"9.0.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/9.0.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-9.0.x-dev.tar.gz";s:4:"date";s:10:"1622063424";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:9:"8.9.x-dev";a:10:{s:4:"name";s:16:"drupal 8.9.x-dev";s:7:"version";s:9:"8.9.x-dev";s:3:"tag";s:5:"8.9.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.9.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.9.x-dev.tar.gz";s:4:"date";s:10:"1637188625";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:9:"8.8.x-dev";a:10:{s:4:"name";s:16:"drupal 8.8.x-dev";s:7:"version";s:9:"8.8.x-dev";s:3:"tag";s:5:"8.8.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.8.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.8.x-dev.tar.gz";s:4:"date";s:10:"1606364994";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:9:"8.7.x-dev";a:10:{s:4:"name";s:16:"drupal 8.7.x-dev";s:7:"version";s:9:"8.7.x-dev";s:3:"tag";s:5:"8.7.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.7.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.7.x-dev.tar.gz";s:4:"date";s:10:"1589987612";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:9:"8.6.x-dev";a:10:{s:4:"name";s:16:"drupal 8.6.x-dev";s:7:"version";s:9:"8.6.x-dev";s:3:"tag";s:5:"8.6.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.6.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.6.x-dev.tar.gz";s:4:"date";s:10:"1573687985";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}s:9:"8.5.x-dev";a:10:{s:4:"name";s:16:"drupal 8.5.x-dev";s:7:"version";s:9:"8.5.x-dev";s:3:"tag";s:5:"8.5.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.5.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.5.x-dev.tar.gz";s:4:"date";s:10:"1555533181";s:5:"files";s:0:"";s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";s:5:"terms";a:0:{}}s:9:"8.4.x-dev";a:10:{s:4:"name";s:16:"drupal 8.4.x-dev";s:7:"version";s:9:"8.4.x-dev";s:3:"tag";s:5:"8.4.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.4.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.4.x-dev.tar.gz";s:4:"date";s:10:"1533047880";s:5:"files";s:0:"";s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";s:5:"terms";a:0:{}}s:9:"8.3.x-dev";a:10:{s:4:"name";s:16:"drupal 8.3.x-dev";s:7:"version";s:9:"8.3.x-dev";s:3:"tag";s:5:"8.3.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.3.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.3.x-dev.tar.gz";s:4:"date";s:10:"1522263480";s:5:"files";s:0:"";s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";s:5:"terms";a:0:{}}s:9:"8.2.x-dev";a:10:{s:4:"name";s:16:"drupal 8.2.x-dev";s:7:"version";s:9:"8.2.x-dev";s:3:"tag";s:5:"8.2.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.2.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.2.x-dev.tar.gz";s:4:"date";s:10:"1492624982";s:5:"files";s:0:"";s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";s:5:"terms";a:0:{}}s:9:"8.1.x-dev";a:10:{s:4:"name";s:16:"drupal 8.1.x-dev";s:7:"version";s:9:"8.1.x-dev";s:3:"tag";s:5:"8.1.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.1.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.1.x-dev.tar.gz";s:4:"date";s:10:"1474478393";s:5:"files";s:0:"";s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";s:5:"terms";a:0:{}}s:9:"8.0.x-dev";a:10:{s:4:"name";s:16:"drupal 8.0.x-dev";s:7:"version";s:9:"8.0.x-dev";s:3:"tag";s:5:"8.0.x";s:6:"status";s:9:"published";s:12:"release_link";s:56:"https://www.drupal.org/project/drupal/releases/8.0.x-dev";s:13:"download_link";s:61:"https://ftp.drupal.org/files/projects/drupal-8.0.x-dev.tar.gz";s:4:"date";s:10:"1459900439";s:5:"files";s:0:"";s:5:"terms";a:1:{s:12:"Release type";a:2:{i:0;s:9:"Bug fixes";i:1;s:12:"New features";}}s:8:"security";s:59:"Dev releases are not covered by Drupal security advisories.";}}s:10:"last_fetch";i:[[timestamp]];}', [[timestamp_nextday]]);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]menu_link_content`
--

CREATE TABLE `[[dbprefix]]menu_link_content` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `menu_link_content_field__uuid__value` (`uuid`),
  UNIQUE KEY `menu_link_content__revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The base table for menu_link_content entities.' AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]menu_link_content_data`
--

CREATE TABLE `[[dbprefix]]menu_link_content_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `enabled` tinyint NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `menu_name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `external` tinyint DEFAULT NULL,
  `rediscover` tinyint DEFAULT NULL,
  `weight` int DEFAULT NULL,
  `expanded` tinyint DEFAULT NULL,
  `parent` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `menu_link_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `menu_link_content__revision_id` (`revision_id`),
  KEY `menu_link_content_field__link__uri` (`link__uri`(30)),
  KEY `menu_link_content__enabled_bundle` (`enabled`,`bundle`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The data table for menu_link_content entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]menu_link_content_field_revision`
--

CREATE TABLE `[[dbprefix]]menu_link_content_field_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `enabled` tinyint NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `external` tinyint DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `menu_link_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `menu_link_content_field__link__uri` (`link__uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The revision data table for menu_link_content entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]menu_link_content_revision`
--

CREATE TABLE `[[dbprefix]]menu_link_content_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `menu_link_content__id` (`id`),
  KEY `menu_link_content__ef029a1897` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The revision table for menu_link_content entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]menu_tree`
--

CREATE TABLE `[[dbprefix]]menu_tree` (
  `menu_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The menu name. All links with the same menu name (such as ''tools'') are part of the same menu.',
  `mlid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'The menu link ID (mlid) is the integer primary key.',
  `id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'Unique machine name: the plugin ID.',
  `parent` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The plugin ID for the parent of this link.',
  `route_name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The machine name of a defined Symfony Route this menu link represents.',
  `route_param_key` varchar(255) DEFAULT NULL COMMENT 'An encoded string of route parameters for loading by route.',
  `route_parameters` longblob COMMENT 'Serialized array of route parameters of this menu link.',
  `url` varchar(255) NOT NULL DEFAULT '' COMMENT 'The external path this link points to (when not using a route).',
  `title` longblob COMMENT 'The serialized title for the link. May be a TranslatableMarkup.',
  `description` longblob COMMENT 'The serialized description of this link - used for admin pages and title attribute. May be a TranslatableMarkup.',
  `class` text COMMENT 'The class for this link plugin.',
  `options` longblob COMMENT 'A serialized array of URL options, such as a query string or HTML attributes.',
  `provider` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'system' COMMENT 'The name of the module that generated this link.',
  `enabled` smallint NOT NULL DEFAULT '1' COMMENT 'A flag for whether the link should be rendered in menus. (0 = a disabled menu link that may be shown on admin screens, 1 = a normal, visible link)',
  `discovered` smallint NOT NULL DEFAULT '0' COMMENT 'A flag for whether the link was discovered, so can be purged on rebuild',
  `expanded` smallint NOT NULL DEFAULT '0' COMMENT 'Flag for whether this link should be rendered as expanded in menus - expanded links always have their child links displayed, instead of only when the link is in the active trail (1 = expanded, 0 = not expanded)',
  `weight` int NOT NULL DEFAULT '0' COMMENT 'Link weight among links in the same menu at the same depth.',
  `metadata` longblob COMMENT 'A serialized array of data that may be used by the plugin instance.',
  `has_children` smallint NOT NULL DEFAULT '0' COMMENT 'Flag indicating whether any enabled links have this link as a parent (1 = enabled children exist, 0 = no enabled children).',
  `depth` smallint NOT NULL DEFAULT '0' COMMENT 'The depth relative to the top level. A link with empty parent will have depth == 1.',
  `p1` int unsigned NOT NULL DEFAULT '0' COMMENT 'The first mlid in the materialized path. If N = depth, then pN must equal the mlid. If depth > 1 then p(N-1) must equal the parent link mlid. All pX where X > depth must equal zero. The columns p1 .. p9 are also called the parents.',
  `p2` int unsigned NOT NULL DEFAULT '0' COMMENT 'The second mlid in the materialized path. See p1.',
  `p3` int unsigned NOT NULL DEFAULT '0' COMMENT 'The third mlid in the materialized path. See p1.',
  `p4` int unsigned NOT NULL DEFAULT '0' COMMENT 'The fourth mlid in the materialized path. See p1.',
  `p5` int unsigned NOT NULL DEFAULT '0' COMMENT 'The fifth mlid in the materialized path. See p1.',
  `p6` int unsigned NOT NULL DEFAULT '0' COMMENT 'The sixth mlid in the materialized path. See p1.',
  `p7` int unsigned NOT NULL DEFAULT '0' COMMENT 'The seventh mlid in the materialized path. See p1.',
  `p8` int unsigned NOT NULL DEFAULT '0' COMMENT 'The eighth mlid in the materialized path. See p1.',
  `p9` int unsigned NOT NULL DEFAULT '0' COMMENT 'The ninth mlid in the materialized path. See p1.',
  `form_class` varchar(255) DEFAULT NULL COMMENT 'meh',
  PRIMARY KEY (`mlid`),
  UNIQUE KEY `id` (`id`),
  KEY `menu_parents` (`menu_name`,`p1`,`p2`,`p3`,`p4`,`p5`,`p6`,`p7`,`p8`,`p9`),
  KEY `menu_parent_expand_child` (`menu_name`,`expanded`,`has_children`,`parent`(16)),
  KEY `route_values` (`route_name`(32),`route_param_key`(16))
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COMMENT='Contains the menu tree hierarchy.' AUTO_INCREMENT=67 ;

--
-- Dumping data for table `[[dbprefix]]menu_tree`
--

INSERT INTO `[[dbprefix]]menu_tree` VALUES
('footer', 1, 'contact.site_page', '', 'contact.site_page', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Contact";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 's:0:"";', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'contact', 1, 1, 0, 0, 'a:0:{}', 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('tools', 2, 'filter.tips_all', '', 'filter.tips_all', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Compose tips";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 's:0:"";', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'filter', 0, 1, 0, 0, 'a:0:{}', 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('tools', 3, 'node.add_page', '', 'node.add_page', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Add content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 's:0:"";', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'node', 1, 1, 0, 0, 'a:0:{}', 0, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('tools', 4, 'search.view', '', 'search.view', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"Search";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 's:0:"";', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'search', 0, 1, 0, 0, 'a:0:{}', 0, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('main', 5, 'standard.front_page', '', '<front>', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Home";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 's:0:"";', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'standard', 1, 1, 0, 0, 'a:0:{}', 0, 1, 5, 0, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 6, 'system.admin', '', 'system.admin', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"Administration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 's:0:"";', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, 9, 'a:0:{}', 1, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 7, 'announcements_feed.announcement', 'system.admin', 'announcements_feed.announcement', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Announcements";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:49:"Displays announcements from the Drupal community.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'announcements_feed', 1, 1, 0, 10, 'a:0:{}', 0, 2, 6, 7, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 8, 'help.main', 'system.admin', 'help.main', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Help";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:48:"Reference for usage, configuration, and modules.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'help', 1, 1, 0, 9, 'a:0:{}', 0, 2, 6, 8, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 9, 'system.admin_content', 'system.admin', 'system.admin_content', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Content";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:24:"Find and manage content.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -10, 'a:0:{}', 1, 2, 6, 9, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 10, 'comment.admin', 'system.admin_content', 'comment.admin', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Comments";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:59:"List and edit site comments and the comment approval queue.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'comment', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 9, 10, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 11, 'system.admin_structure', 'system.admin', 'system.admin_structure', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Structure";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:45:"Administer blocks, content types, menus, etc.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -8, 'a:0:{}', 1, 2, 6, 11, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 12, 'block.admin_display', 'system.admin_structure', 'block.admin_display', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Block layout";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:79:"Configure what block content appears in your site''s sidebars and other regions.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'block', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 11, 12, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 13, 'entity.block_content_type.collection', 'system.admin_structure', 'entity.block_content_type.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Block types";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:78:"Create and manage fields, forms, and display settings for your content blocks.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'block_content', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 11, 13, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 14, 'entity.comment_type.collection', 'system.admin_structure', 'entity.comment_type.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Comment types";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:46:"Manage form and displays settings of comments.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'comment', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 11, 14, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 15, 'entity.contact_form.collection', 'system.admin_structure', 'entity.contact_form.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Contact forms";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:32:"Create and manage contact forms.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'contact', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 11, 15, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 16, 'field_ui.display_mode', 'system.admin_structure', 'field_ui.display_mode', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Display modes";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:65:"Configure what displays are available for your content and forms.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'field_ui', 1, 1, 0, 0, 'a:0:{}', 1, 3, 6, 11, 16, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 17, 'entity.entity_view_mode.collection', 'field_ui.display_mode', 'entity.entity_view_mode.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"View modes";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:25:"Manage custom view modes.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'field_ui', 1, 1, 0, 0, 'a:0:{}', 0, 4, 6, 11, 16, 17, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 18, 'entity.entity_form_mode.collection', 'field_ui.display_mode', 'entity.entity_form_mode.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"Form modes";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:25:"Manage custom form modes.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'field_ui', 1, 1, 0, 0, 'a:0:{}', 0, 4, 6, 11, 16, 18, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 19, 'entity.menu.collection', 'system.admin_structure', 'entity.menu.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Menus";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:28:"Manage menus and menu links.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'menu_ui', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 11, 19, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 20, 'entity.node_type.collection', 'system.admin_structure', 'entity.node_type.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Content types";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:71:"Create and manage fields, forms, and display settings for your content.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'node', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 11, 20, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 21, 'entity.taxonomy_vocabulary.collection', 'system.admin_structure', 'entity.taxonomy_vocabulary.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Taxonomy";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:67:"Manage tagging, categorization, and classification of your content.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'taxonomy', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 11, 21, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 22, 'entity.view.collection', 'system.admin_structure', 'entity.view.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Views";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:35:"Manage customized lists of content.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'views_ui', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 11, 22, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 23, 'system.themes_page', 'system.admin', 'system.themes_page', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"Appearance";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:28:"Select and configure themes.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -6, 'a:0:{}', 0, 2, 6, 23, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 24, 'system.modules_list', 'system.admin', 'system.modules_list', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"Extend";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:53:"Add and install modules to extend site functionality.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -2, 'a:0:{}', 0, 2, 6, 24, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 25, 'system.admin_config', 'system.admin', 'system.admin_config', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Configuration";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:20:"Administer settings.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, 0, 'a:0:{}', 1, 2, 6, 25, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 26, 'system.admin_config_media', 'system.admin_config', 'system.admin_config_media', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:5:"Media";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 's:0:"";', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -10, 'a:0:{}', 1, 3, 6, 25, 26, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 27, 'entity.image_style.collection', 'system.admin_config_media', 'entity.image_style.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Image styles";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:78:"Configure styles that can be used for resizing or adjusting images on display.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'image', 1, 1, 0, 0, 'a:0:{}', 0, 4, 6, 25, 26, 27, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 28, 'system.file_system_settings', 'system.admin_config_media', 'system.file_system_settings', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"File system";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:67:"Configure the location of uploaded files and how they are accessed.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, 0, 'a:0:{}', 0, 4, 6, 25, 26, 28, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 29, 'system.image_toolkit_settings', 'system.admin_config_media', 'system.image_toolkit_settings', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Image toolkit";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:74:"Choose which image toolkit to use if you have installed optional toolkits.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, 20, 'a:0:{}', 0, 4, 6, 25, 26, 29, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 30, 'system.admin_config_services', 'system.admin_config', 'system.admin_config_services', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Web services";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 's:0:"";', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, 0, 'a:0:{}', 1, 3, 6, 25, 30, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 31, 'system.rss_feeds_settings', 'system.admin_config_services', 'system.rss_feeds_settings', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"RSS publishing";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:115:"Configure the site description, the number of items per feed, and whether feeds should be titles/teasers/full-text.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, 0, 'a:0:{}', 0, 4, 6, 25, 30, 31, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 32, 'system.linkset_settings', 'system.admin_config_services', 'system.linkset_settings', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:21:"Menu Linkset Settings";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:43:"Enable or disable the menu linkset endpoint";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, 10, 'a:0:{}', 0, 4, 6, 25, 30, 32, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 33, 'system.admin_config_development', 'system.admin_config', 'system.admin_config_development', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Development";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:36:"Configure and use development tools.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -10, 'a:0:{}', 1, 3, 6, 25, 33, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 34, 'config.sync', 'system.admin_config_development', 'config.sync', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:29:"Configuration synchronization";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:37:"Import and export your configuration.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'config', 1, 1, 0, 0, 'a:0:{}', 0, 4, 6, 25, 33, 34, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 35, 'system.site_maintenance_mode', 'system.admin_config_development', 'system.site_maintenance_mode', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Maintenance mode";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:62:"Take the site offline for updates and other maintenance tasks.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -10, 'a:0:{}', 0, 4, 6, 25, 33, 35, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 36, 'system.performance_settings', 'system.admin_config_development', 'system.performance_settings', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"Performance";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:45:"Configure caching and bandwidth optimization.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -20, 'a:0:{}', 0, 4, 6, 25, 33, 36, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 37, 'system.development_settings', 'system.admin_config_development', 'system.development_settings', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:20:"Development settings";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:36:"Configure theme development settings";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -19, 'a:0:{}', 0, 4, 6, 25, 33, 37, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 38, 'system.logging_settings', 'system.admin_config_development', 'system.logging_settings', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:18:"Logging and errors";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:61:"Configure the display of error messages and database logging.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -15, 'a:0:{}', 0, 4, 6, 25, 33, 38, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 39, 'system.admin_config_regional', 'system.admin_config', 'system.admin_config_regional', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Region and language";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:59:"Configure regional settings, localization, and translation.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -5, 'a:0:{}', 1, 3, 6, 25, 39, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 40, 'system.regional_settings', 'system.admin_config_regional', 'system.regional_settings', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:17:"Regional settings";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:43:"Configure the locale and timezone settings.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -20, 'a:0:{}', 0, 4, 6, 25, 39, 40, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 41, 'entity.date_format.collection', 'system.admin_config_regional', 'entity.date_format.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:21:"Date and time formats";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:44:"Configure how dates and times are displayed.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -9, 'a:0:{}', 0, 4, 6, 25, 39, 41, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 42, 'system.admin_config_search', 'system.admin_config', 'system.admin_config_search', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Search and metadata";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:64:"Configure site search, metadata, and search engine optimization.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -10, 'a:0:{}', 1, 3, 6, 25, 42, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 43, 'entity.path_alias.collection', 'system.admin_config_search', 'entity.path_alias.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:11:"URL aliases";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:34:"Add custom URLs to existing paths.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'path', 1, 1, 0, -5, 'a:0:{}', 0, 4, 6, 25, 42, 43, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 44, 'entity.search_page.collection', 'system.admin_config_search', 'entity.search_page.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:12:"Search pages";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:51:"Configure search pages and search indexing options.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'search', 1, 1, 0, -10, 'a:0:{}', 0, 4, 6, 25, 42, 44, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 45, 'system.admin_config_system', 'system.admin_config', 'system.admin_config_system', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"System";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:49:"Configure basic site settings, actions, and cron.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -20, 'a:0:{}', 1, 3, 6, 25, 45, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 46, 'system.site_information_settings', 'system.admin_config_system', 'system.site_information_settings', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Basic site settings";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:77:"Change site name, email address, slogan, default front page, and error pages.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -20, 'a:0:{}', 0, 4, 6, 25, 45, 46, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 47, 'system.cron_settings', 'system.admin_config_system', 'system.cron_settings', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:4:"Cron";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:40:"Manage automatic site maintenance tasks.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, 20, 'a:0:{}', 0, 4, 6, 25, 45, 47, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 48, 'system.admin_config_ui', 'system.admin_config', 'system.admin_config_ui', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:14:"User interface";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:44:"Configure the administrative user interface.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -15, 'a:0:{}', 1, 3, 6, 25, 48, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 49, 'entity.shortcut_set.collection', 'system.admin_config_ui', 'entity.shortcut_set.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:9:"Shortcuts";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:29:"Add and modify shortcut sets.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'shortcut', 1, 1, 0, 0, 'a:0:{}', 0, 4, 6, 25, 48, 49, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 50, 'system.admin_config_workflow', 'system.admin_config', 'system.admin_config_workflow', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:8:"Workflow";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:28:"Manage the content workflow.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, 5, 'a:0:{}', 0, 3, 6, 25, 50, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 51, 'system.admin_config_content', 'system.admin_config', 'system.admin_config_content', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:17:"Content authoring";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:43:"Configure content formatting and authoring.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -15, 'a:0:{}', 1, 3, 6, 25, 51, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 52, 'filter.admin_overview', 'system.admin_config_content', 'filter.admin_overview', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:24:"Text formats and editors";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:78:"Select and configure text editors, and how content is filtered when displayed.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'filter', 1, 1, 0, 0, 'a:0:{}', 0, 4, 6, 25, 51, 52, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 53, 'user.admin_index', 'system.admin_config', 'user.admin_index', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"People";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:24:"Configure user accounts.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'user', 1, 1, 0, -20, 'a:0:{}', 1, 3, 6, 25, 53, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 54, 'entity.user.admin_form', 'user.admin_index', 'entity.user.admin_form', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:16:"Account settings";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:105:"Configure default user account settings, including fields, registration requirements, and email messages.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'user', 1, 1, 0, -10, 'a:0:{}', 0, 4, 6, 25, 53, 54, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 55, 'system.admin_reports', 'system.admin', 'system.admin_reports', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:7:"Reports";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:34:"View reports, updates, and errors.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, 5, 'a:0:{}', 1, 2, 6, 55, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 56, 'dblog.overview', 'system.admin_reports', 'dblog.overview', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:19:"Recent log messages";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:43:"View events that have recently been logged.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'dblog', 1, 1, 0, -1, 'a:0:{}', 0, 3, 6, 55, 56, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 57, 'dblog.page_not_found', 'system.admin_reports', 'dblog.page_not_found', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:27:"Top ''page not found'' errors";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:36:"View ''page not found'' errors (404s).";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'dblog', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 55, 57, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 58, 'dblog.access_denied', 'system.admin_reports', 'dblog.access_denied', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:26:"Top ''access denied'' errors";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:35:"View ''access denied'' errors (403s).";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'dblog', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 55, 58, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 59, 'entity.field_storage_config.collection', 'system.admin_reports', 'entity.field_storage_config.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"Field list";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:39:"Overview of fields on all entity types.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'field_ui', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 55, 59, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 60, 'system.status', 'system.admin_reports', 'system.status', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Status report";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:48:"Get a status report about your site''s operation.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'system', 1, 1, 0, -60, 'a:0:{}', 0, 3, 6, 55, 60, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 61, 'views_ui.reports_plugins', 'system.admin_reports', 'views_ui.reports_plugins', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:13:"Views plugins";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:38:"Overview of plugins used in all views.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'views_ui', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 55, 61, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 62, 'dblog.search', 'system.admin_reports', 'dblog.search', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:18:"Top search phrases";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:33:"View most popular search phrases.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', '', 1, 1, 0, 0, 'a:0:{}', 0, 3, 6, 55, 62, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 63, 'entity.user.collection', 'system.admin', 'entity.user.collection', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:6:"People";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:45:"Manage user accounts, roles, and permissions.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'user', 1, 1, 0, 4, 'a:0:{}', 0, 2, 6, 63, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('account', 64, 'user.page', '', 'user.page', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:10:"My account";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 's:0:"";', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'user', 1, 1, 0, -10, 'a:0:{}', 0, 1, 64, 0, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('account', 65, 'user.logout', '', '', '', 'a:0:{}', '', 's:0:"";', 's:0:"";', 'Drupal\\user\\Plugin\\Menu\\LoginLogoutMenuLink', 'a:0:{}', 'user', 1, 1, 0, 10, 'a:0:{}', 0, 1, 65, 0, 0, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin', 66, 'update.status', 'system.admin_reports', 'update.status', '', 'a:0:{}', '', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:17:"Available updates";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'O:48:"Drupal\\Core\\StringTranslation\\TranslatableMarkup":3:{s:9:"\0*\0string";s:82:"Get a status report about available updates for your installed modules and themes.";s:12:"\0*\0arguments";a:0:{}s:10:"\0*\0options";a:0:{}}', 'Drupal\\Core\\Menu\\MenuLinkDefault', 'a:0:{}', 'update', 1, 1, 0, -50, 'a:0:{}', 0, 3, 6, 55, 66, 0, 0, 0, 0, 0, 0, 'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node`
--

CREATE TABLE `[[dbprefix]]node` (
  `nid` int unsigned NOT NULL AUTO_INCREMENT,
  `vid` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`nid`),
  UNIQUE KEY `node_field__uuid__value` (`uuid`),
  UNIQUE KEY `node__vid` (`vid`),
  KEY `node_field__type__target_id` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The base table for node entities.' AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node_access`
--

CREATE TABLE `[[dbprefix]]node_access` (
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "[[dbprefix]]node".nid this record affects.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "[[dbprefix]]language".langcode of this node.',
  `fallback` tinyint unsigned NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether this record should be used as a fallback if a language condition is not provided.',
  `gid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The grant ID a user must possess in the specified realm to gain this row''s privileges on the node.',
  `realm` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The realm in which the user must possess the grant ID. Modules can define one or more realms by implementing hook_node_grants().',
  `grant_view` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can view this node.',
  `grant_update` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can edit this node.',
  `grant_delete` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can delete this node.',
  PRIMARY KEY (`nid`,`gid`,`realm`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Identifies which realm/grant pairs a user must possess in…';

--
-- Dumping data for table `[[dbprefix]]node_access`
--

INSERT INTO `[[dbprefix]]node_access` VALUES
(0, '', 1, 0, 'all', 1, 0, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node_field_data`
--

CREATE TABLE `[[dbprefix]]node_field_data` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `title` varchar(255) NOT NULL,
  `created` int NOT NULL,
  `changed` int NOT NULL,
  `promote` tinyint NOT NULL,
  `sticky` tinyint NOT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`nid`,`langcode`),
  KEY `node__id__default_langcode__langcode` (`nid`,`default_langcode`,`langcode`),
  KEY `node__vid` (`vid`),
  KEY `node_field__type__target_id` (`type`),
  KEY `node_field__uid__target_id` (`uid`),
  KEY `node_field__created` (`created`),
  KEY `node_field__changed` (`changed`),
  KEY `node__status_type` (`status`,`type`,`nid`),
  KEY `node__frontpage` (`promote`,`status`,`sticky`,`created`),
  KEY `node__title_type` (`title`(191),`type`(4))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The data table for node entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node_field_revision`
--

CREATE TABLE `[[dbprefix]]node_field_revision` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `title` varchar(255) DEFAULT NULL,
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `promote` tinyint DEFAULT NULL,
  `sticky` tinyint DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`,`langcode`),
  KEY `node__id__default_langcode__langcode` (`nid`,`default_langcode`,`langcode`),
  KEY `node_field__uid__target_id` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The revision data table for node entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node_revision`
--

CREATE TABLE `[[dbprefix]]node_revision` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_timestamp` int DEFAULT NULL,
  `revision_log` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`),
  KEY `node__nid` (`nid`),
  KEY `node_field__langcode` (`langcode`),
  KEY `node_field__revision_uid__target_id` (`revision_uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The revision table for node entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node_revision__body`
--

CREATE TABLE `[[dbprefix]]node_revision__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Revision archive storage for node field body.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node_revision__comment`
--

CREATE TABLE `[[dbprefix]]node_revision__comment` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `comment_status` int NOT NULL DEFAULT '0' COMMENT 'Whether comments are allowed on this entity: 0 = no, 1 = closed (read only), 2 = open (read/write).',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Revision archive storage for node field comment.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node_revision__field_image`
--

CREATE TABLE `[[dbprefix]]node_revision__field_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_image_target_id` (`field_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Revision archive storage for node field field_image.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node_revision__field_tags`
--

CREATE TABLE `[[dbprefix]]node_revision__field_tags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_tags_target_id` (`field_tags_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Revision archive storage for node field field_tags.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node__body`
--

CREATE TABLE `[[dbprefix]]node__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Data storage for node field body.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node__comment`
--

CREATE TABLE `[[dbprefix]]node__comment` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `comment_status` int NOT NULL DEFAULT '0' COMMENT 'Whether comments are allowed on this entity: 0 = no, 1 = closed (read only), 2 = open (read/write).',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Data storage for node field comment.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node__field_image`
--

CREATE TABLE `[[dbprefix]]node__field_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_image_target_id` (`field_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Data storage for node field field_image.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]node__field_tags`
--

CREATE TABLE `[[dbprefix]]node__field_tags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_tags_target_id` (`field_tags_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Data storage for node field field_tags.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]path_alias`
--

CREATE TABLE `[[dbprefix]]path_alias` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` varchar(255) DEFAULT NULL,
  `alias` varchar(255) DEFAULT NULL,
  `status` tinyint NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `path_alias_field__uuid__value` (`uuid`),
  UNIQUE KEY `path_alias__revision_id` (`revision_id`),
  KEY `path_alias__alias_langcode_id_status` (`alias`(191),`langcode`,`id`,`status`),
  KEY `path_alias__path_langcode_id_status` (`path`(191),`langcode`,`id`,`status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The base table for path_alias entities.' AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]path_alias_revision`
--

CREATE TABLE `[[dbprefix]]path_alias_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` varchar(255) DEFAULT NULL,
  `alias` varchar(255) DEFAULT NULL,
  `status` tinyint NOT NULL,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `path_alias__id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The revision table for path_alias entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]queue`
--

CREATE TABLE `[[dbprefix]]queue` (
  `item_id` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique item ID.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The queue name.',
  `data` longblob COMMENT 'The arbitrary data for the item.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp when the claim lease expires on the item.',
  `created` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp when the item was created.',
  PRIMARY KEY (`item_id`),
  KEY `name_created` (`name`,`created`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COMMENT='Stores items in queues.' AUTO_INCREMENT=40 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]router`
--

CREATE TABLE `[[dbprefix]]router` (
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Machine name of this route',
  `path` varchar(255) NOT NULL DEFAULT '' COMMENT 'The path for this URI',
  `pattern_outline` varchar(255) NOT NULL DEFAULT '' COMMENT 'The pattern',
  `fit` int NOT NULL DEFAULT '0' COMMENT 'A numeric representation of how specific the path is.',
  `route` longblob COMMENT 'A serialized Route object',
  `number_parts` smallint NOT NULL DEFAULT '0' COMMENT 'Number of parts in this router path.',
  PRIMARY KEY (`name`),
  KEY `pattern_outline_parts` (`pattern_outline`(191),`number_parts`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Maps paths to various callbacks (access, page and title)';

--
-- Dumping data for table `[[dbprefix]]router`
--

INSERT INTO `[[dbprefix]]router` VALUES
('<button>', '/', '/', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:1:"/";s:4:"host";s:0:"";s:8:"defaults";a:0:{}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:8:"_no_path";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:8:"{^/$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:1:"/";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:1:"/";s:8:"numParts";i:1;}}', 1),
('<current>', '/<current>', '/<current>', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:10:"/<current>";s:4:"host";s:0:"";s:8:"defaults";a:0:{}s:12:"requirements";a:0:{}s:7:"options";a:2:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:19:"{^/\\<current\\>$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:10:"/<current>";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:10:"/<current>";s:8:"numParts";i:1;}}', 1),
('<front>', '/', '/', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:1:"/";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:6:"_title";s:4:"Home";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:8:"{^/$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:1:"/";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:1:"/";s:8:"numParts";i:1;}}', 1),
('<nolink>', '/', '/', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:1:"/";s:4:"host";s:0:"";s:8:"defaults";a:0:{}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:8:"_no_path";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:8:"{^/$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:1:"/";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:1:"/";s:8:"numParts";i:1;}}', 1),
('<none>', '/', '/', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:1:"/";s:4:"host";s:0:"";s:8:"defaults";a:0:{}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:8:"_no_path";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:8:"{^/$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:1:"/";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:1:"/";s:8:"numParts";i:1;}}', 1),
('announcements_feed.announcement', '/admin/announcements_feed', '/admin/announcements_feed', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/admin/announcements_feed";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:74:"\\Drupal\\announcements_feed\\Controller\\AnnounceController::getAnnouncements";s:6:"_title";s:23:"Community announcements";}s:12:"requirements";a:1:{s:11:"_permission";s:20:"access announcements";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/admin/announcements_feed$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/announcements_feed";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:25:"/admin/announcements_feed";s:8:"numParts";i:2;}}', 2),
('big_pipe.nojs', '/big_pipe/no-js', '/big_pipe/no-js', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:15:"/big_pipe/no-js";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:59:"\\Drupal\\big_pipe\\Controller\\BigPipeController:setNoJsCookie";s:6:"_title";s:19:"BigPipe no-JS check";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:8:"no_cache";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:23:"{^/big_pipe/no\\-js$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:15:"/big_pipe/no-js";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:15:"/big_pipe/no-js";s:8:"numParts";i:2;}}', 2),
('block.admin_add', '/admin/structure/block/add/{plugin_id}/{theme}', '/admin/structure/block/add/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:46:"/admin/structure/block/add/{plugin_id}/{theme}";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:66:"\\Drupal\\block\\Controller\\BlockAddController::blockAddConfigureForm";s:5:"theme";N;s:6:"_title";s:15:"Configure block";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"administer blocks";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:9:"plugin_id";i:1;s:5:"theme";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:78:"{^/admin/structure/block/add/(?P<plugin_id>[^/]++)(?:/(?P<theme>[^/]++))?$}sDu";s:11:"path_tokens";a:3:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"theme";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"plugin_id";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/structure/block/add";}}s:9:"path_vars";a:2:{i:0;s:9:"plugin_id";i:1;s:5:"theme";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:28:"/admin/structure/block/add/%";s:8:"numParts";i:6;}}', 6),
('block.admin_demo', '/admin/structure/block/demo/{theme}', '/admin/structure/block/demo/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:35:"/admin/structure/block/demo/{theme}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:46:"\\Drupal\\block\\Controller\\BlockController::demo";s:15:"_title_callback";s:21:"theme_handler:getName";}s:12:"requirements";a:2:{s:13:"_access_theme";s:4:"TRUE";s:11:"_permission";s:17:"administer blocks";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:0;s:4:"utf8";b:1;s:14:"_access_checks";a:2:{i:0;s:18:"access_check.theme";i:1;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"theme";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:52:"{^/admin/structure/block/demo/(?P<theme>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"theme";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/structure/block/demo";}}s:9:"path_vars";a:1:{i:0;s:5:"theme";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:29:"/admin/structure/block/demo/%";s:8:"numParts";i:5;}}', 5),
('block.admin_display', '/admin/structure/block', '/admin/structure/block', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/admin/structure/block";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:53:"\\Drupal\\block\\Controller\\BlockListController::listing";s:6:"_title";s:12:"Block layout";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"administer blocks";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:29:"{^/admin/structure/block$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/block";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:22:"/admin/structure/block";s:8:"numParts";i:3;}}', 3),
('block.admin_display_theme', '/admin/structure/block/list/{theme}', '/admin/structure/block/list/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:35:"/admin/structure/block/list/{theme}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:53:"\\Drupal\\block\\Controller\\BlockListController::listing";s:6:"_title";s:12:"Block layout";}s:12:"requirements";a:2:{s:13:"_access_theme";s:4:"TRUE";s:11:"_permission";s:17:"administer blocks";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:18:"access_check.theme";i:1;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"theme";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:52:"{^/admin/structure/block/list/(?P<theme>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"theme";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/structure/block/list";}}s:9:"path_vars";a:1:{i:0;s:5:"theme";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:29:"/admin/structure/block/list/%";s:8:"numParts";i:5;}}', 5),
('block.admin_library', '/admin/structure/block/library/{theme}', '/admin/structure/block/library/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:38:"/admin/structure/block/library/{theme}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:59:"\\Drupal\\block\\Controller\\BlockLibraryController::listBlocks";s:6:"_title";s:11:"Place block";}s:12:"requirements";a:2:{s:13:"_access_theme";s:4:"TRUE";s:11:"_permission";s:17:"administer blocks";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:18:"access_check.theme";i:1;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"theme";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:55:"{^/admin/structure/block/library/(?P<theme>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"theme";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:30:"/admin/structure/block/library";}}s:9:"path_vars";a:1:{i:0;s:5:"theme";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:32:"/admin/structure/block/library/%";s:8:"numParts";i:5;}}', 5),
('block.category_autocomplete', '/block-category/autocomplete', '/block-category/autocomplete', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:28:"/block-category/autocomplete";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:69:"\\Drupal\\block\\Controller\\CategoryAutocompleteController::autocomplete";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"administer blocks";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/block\\-category/autocomplete$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:28:"/block-category/autocomplete";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:28:"/block-category/autocomplete";s:8:"numParts";i:2;}}', 2),
('block_content.add_form', '/block/add/{block_content_type}', '/block/add/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:31:"/block/add/{block_content_type}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:64:"\\Drupal\\block_content\\Controller\\BlockContentController::addForm";s:15:"_title_callback";s:72:"\\Drupal\\block_content\\Controller\\BlockContentController::getAddFormTitle";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:34:"block_content:{block_content_type}";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:18:"block_content_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:48:"{^/block/add/(?P<block_content_type>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:10:"/block/add";}}s:9:"path_vars";a:1:{i:0;s:18:"block_content_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:12:"/block/add/%";s:8:"numParts";i:3;}}', 3),
('block_content.add_page', '/block/add', '/block/add', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:10:"/block/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:60:"\\Drupal\\block_content\\Controller\\BlockContentController::add";s:6:"_title";s:17:"Add content block";}s:12:"requirements";a:1:{s:25:"_entity_create_any_access";s:13:"block_content";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:30:"access_check.entity_create_any";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:17:"{^/block/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:10:"/block/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:10:"/block/add";s:8:"numParts";i:2;}}', 2),
('block_content.type_add', '/admin/structure/block-content/add', '/admin/structure/block-content/add', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:34:"/admin/structure/block-content/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:22:"block_content_type.add";s:6:"_title";s:3:"Add";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:18:"block_content_type";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:42:"{^/admin/structure/block\\-content/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:34:"/admin/structure/block-content/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:34:"/admin/structure/block-content/add";s:8:"numParts";i:4;}}', 4),
('ckeditor5.media_entity_metadata', '/ckeditor5/{editor}/media-entity-metadata', '/ckeditor5/%/media-entity-metadata', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:41:"/ckeditor5/{editor}/media-entity-metadata";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:74:"\\Drupal\\ckeditor5\\Controller\\CKEditor5MediaController::mediaEntityMetadata";}s:12:"requirements";a:3:{s:14:"_entity_access";s:10:"editor.use";s:14:"_custom_access";s:61:"\\Drupal\\ckeditor5\\Controller\\CKEditor5MediaController::access";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:6:"editor";a:2:{s:4:"type";s:13:"entity:editor";s:9:"converter";s:21:"paramconverter.entity";}}s:4:"utf8";b:1;s:14:"_access_checks";a:3:{i:0;s:19:"access_check.entity";i:1;s:19:"access_check.custom";i:2;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:1:{i:0;s:3:"GET";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:6:"editor";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:60:"{^/ckeditor5/(?P<editor>[^/]++)/media\\-entity\\-metadata$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/media-entity-metadata";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:6:"editor";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:10:"/ckeditor5";}}s:9:"path_vars";a:1:{i:0;s:6:"editor";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:34:"/ckeditor5/%/media-entity-metadata";s:8:"numParts";i:3;}}', 3),
('ckeditor5.upload_image', '/ckeditor5/upload-image/{editor}', '/ckeditor5/upload-image/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:32:"/ckeditor5/upload-image/{editor}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:61:"\\Drupal\\ckeditor5\\Controller\\CKEditor5ImageController::upload";}s:12:"requirements";a:3:{s:14:"_entity_access";s:10:"editor.use";s:14:"_custom_access";s:79:"\\Drupal\\ckeditor5\\Controller\\CKEditor5ImageController::imageUploadEnabledAccess";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:6:"editor";a:2:{s:4:"type";s:13:"entity:editor";s:9:"converter";s:21:"paramconverter.entity";}}s:4:"utf8";b:1;s:14:"_access_checks";a:3:{i:0;s:19:"access_check.entity";i:1;s:19:"access_check.custom";i:2;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:1:{i:0;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:6:"editor";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:50:"{^/ckeditor5/upload\\-image/(?P<editor>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:6:"editor";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:23:"/ckeditor5/upload-image";}}s:9:"path_vars";a:1:{i:0;s:6:"editor";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:25:"/ckeditor5/upload-image/%";s:8:"numParts";i:3;}}', 3),
('comment.admin', '/admin/content/comment', '/admin/content/comment', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/admin/content/comment";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:7:"comment";s:10:"display_id";s:14:"page_published";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:19:"administer comments";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:29:"{^/admin/content/comment$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/content/comment";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:22:"/admin/content/comment";s:8:"numParts";i:3;}}', 3),
('comment.admin_approval', '/admin/content/comment/approval', '/admin/content/comment/approval', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:31:"/admin/content/comment/approval";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:7:"comment";s:10:"display_id";s:15:"page_unapproved";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:19:"administer comments";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/admin/content/comment/approval$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/content/comment/approval";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:31:"/admin/content/comment/approval";s:8:"numParts";i:4;}}', 4),
('comment.approve', '/comment/{comment}/approve', '/comment/%/approve', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:26:"/comment/{comment}/approve";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:6:"_title";s:7:"Approve";s:11:"_controller";s:60:"\\Drupal\\comment\\Controller\\CommentController::commentApprove";s:11:"entity_type";s:7:"comment";}s:12:"requirements";a:3:{s:14:"_entity_access";s:15:"comment.approve";s:11:"_csrf_token";s:4:"TRUE";s:7:"comment";s:3:"\\d+";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:7:"comment";a:2:{s:4:"type";s:14:"entity:comment";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:7:"comment";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:40:"{^/comment/(?P<comment>\\d+)/approve$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/approve";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:7:"comment";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:8:"/comment";}}s:9:"path_vars";a:1:{i:0;s:7:"comment";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:18:"/comment/%/approve";s:8:"numParts";i:3;}}', 3),
('comment.multiple_delete_confirm', '/admin/content/comment/delete', '/admin/content/comment/delete', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:29:"/admin/content/comment/delete";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:6:"_title";s:6:"Delete";s:5:"_form";s:42:"\\Drupal\\comment\\Form\\ConfirmDeleteMultiple";s:14:"entity_type_id";s:7:"comment";}s:12:"requirements";a:1:{s:30:"_entity_delete_multiple_access";s:7:"comment";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:35:"access_check.entity_delete_multiple";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/content/comment/delete$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/content/comment/delete";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:29:"/admin/content/comment/delete";s:8:"numParts";i:4;}}', 4),
('comment.new_comments_node_links', '/comments/render_new_comments_node_links', '/comments/render_new_comments_node_links', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:40:"/comments/render_new_comments_node_links";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:72:"\\Drupal\\comment\\Controller\\CommentController::renderNewCommentsNodeLinks";}s:12:"requirements";a:1:{s:11:"_permission";s:14:"access content";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:47:"{^/comments/render_new_comments_node_links$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:40:"/comments/render_new_comments_node_links";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:40:"/comments/render_new_comments_node_links";s:8:"numParts";i:2;}}', 2),
('comment.node_redirect', '/comment/{node}/reply', '/comment/%/reply', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:21:"/comment/{node}/reply";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:58:"\\Drupal\\comment\\Controller\\CommentController::redirectNode";}s:12:"requirements";a:3:{s:14:"_entity_access";s:9:"node.view";s:20:"_module_dependencies";s:4:"node";s:4:"node";s:3:"\\d+";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"node";a:2:{s:4:"type";s:11:"entity:node";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"node";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:35:"{^/comment/(?P<node>\\d+)/reply$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:6:"/reply";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"node";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:8:"/comment";}}s:9:"path_vars";a:1:{i:0;s:4:"node";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:16:"/comment/%/reply";s:8:"numParts";i:3;}}', 3),
('comment.reply', '/comment/reply/{entity_type}/{entity}/{field_name}/{pid}', '/comment/reply/%/%/%', 24, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:56:"/comment/reply/{entity_type}/{entity}/{field_name}/{pid}";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:58:"\\Drupal\\comment\\Controller\\CommentController::getReplyForm";s:6:"_title";s:15:"Add new comment";s:3:"pid";N;}s:12:"requirements";a:1:{s:14:"_custom_access";s:61:"\\Drupal\\comment\\Controller\\CommentController::replyFormAccess";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:6:"entity";a:2:{s:4:"type";s:20:"entity:{entity_type}";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.custom";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:4:{i:0;s:11:"entity_type";i:1;s:6:"entity";i:2;s:10:"field_name";i:3;s:3:"pid";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:108:"{^/comment/reply/(?P<entity_type>[^/]++)/(?P<entity>[^/]++)/(?P<field_name>[^/]++)(?:/(?P<pid>[^/]++))?$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:3:"pid";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"field_name";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:6:"entity";i:4;b:1;}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"entity_type";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:14:"/comment/reply";}}s:9:"path_vars";a:4:{i:0;s:11:"entity_type";i:1;s:6:"entity";i:2;s:10:"field_name";i:3;s:3:"pid";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:24;s:14:"patternOutline";s:20:"/comment/reply/%/%/%";s:8:"numParts";i:6;}}', 6),
('config.diff', '/admin/config/development/configuration/sync/diff/{source_name}/{target_name}', '/admin/config/development/configuration/sync/diff/%', 126, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:77:"/admin/config/development/configuration/sync/diff/{source_name}/{target_name}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:48:"\\Drupal\\config\\Controller\\ConfigController::diff";s:11:"target_name";N;}s:12:"requirements";a:1:{s:11:"_permission";s:25:"synchronize configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:11:"source_name";i:1;s:11:"target_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:109:"{^/admin/config/development/configuration/sync/diff/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu";s:11:"path_tokens";a:3:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"target_name";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"source_name";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:49:"/admin/config/development/configuration/sync/diff";}}s:9:"path_vars";a:2:{i:0;s:11:"source_name";i:1;s:11:"target_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:126;s:14:"patternOutline";s:51:"/admin/config/development/configuration/sync/diff/%";s:8:"numParts";i:8;}}', 8),
('config.diff_collection', '/admin/config/development/configuration/sync/diff_collection/{collection}/{source_name}/{target_name}', '/admin/config/development/configuration/sync/diff_collection/%/%', 252, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:101:"/admin/config/development/configuration/sync/diff_collection/{collection}/{source_name}/{target_name}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:48:"\\Drupal\\config\\Controller\\ConfigController::diff";s:11:"target_name";N;}s:12:"requirements";a:1:{s:11:"_permission";s:25:"synchronize configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:10:"collection";i:1;s:11:"source_name";i:2;s:11:"target_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:143:"{^/admin/config/development/configuration/sync/diff_collection/(?P<collection>[^/]++)/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"target_name";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"source_name";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"collection";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:60:"/admin/config/development/configuration/sync/diff_collection";}}s:9:"path_vars";a:3:{i:0;s:10:"collection";i:1;s:11:"source_name";i:2;s:11:"target_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:252;s:14:"patternOutline";s:64:"/admin/config/development/configuration/sync/diff_collection/%/%";s:8:"numParts";i:9;}}', 9),
('config.export_download', '/admin/config/development/configuration/full/export-download', '/admin/config/development/configuration/full/export-download', 63, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:60:"/admin/config/development/configuration/full/export-download";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:58:"\\Drupal\\config\\Controller\\ConfigController::downloadExport";}s:12:"requirements";a:1:{s:11:"_permission";s:20:"export configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:68:"{^/admin/config/development/configuration/full/export\\-download$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:60:"/admin/config/development/configuration/full/export-download";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:63;s:14:"patternOutline";s:60:"/admin/config/development/configuration/full/export-download";s:8:"numParts";i:6;}}', 6),
('config.export_full', '/admin/config/development/configuration/full/export', '/admin/config/development/configuration/full/export', 63, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:51:"/admin/config/development/configuration/full/export";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:36:"\\Drupal\\config\\Form\\ConfigExportForm";s:6:"_title";s:6:"Export";}s:12:"requirements";a:1:{s:11:"_permission";s:20:"export configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:58:"{^/admin/config/development/configuration/full/export$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:51:"/admin/config/development/configuration/full/export";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:63;s:14:"patternOutline";s:51:"/admin/config/development/configuration/full/export";s:8:"numParts";i:6;}}', 6),
('config.export_single', '/admin/config/development/configuration/single/export/{config_type}/{config_name}', '/admin/config/development/configuration/single/export', 63, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:81:"/admin/config/development/configuration/single/export/{config_type}/{config_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:6:"_title";s:13:"Single export";s:5:"_form";s:42:"\\Drupal\\config\\Form\\ConfigSingleExportForm";s:11:"config_type";N;s:11:"config_name";N;}s:12:"requirements";a:1:{s:11:"_permission";s:20:"export configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:11:"config_type";i:1;s:11:"config_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:118:"{^/admin/config/development/configuration/single/export(?:/(?P<config_type>[^/]++)(?:/(?P<config_name>[^/]++))?)?$}sDu";s:11:"path_tokens";a:3:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"config_name";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"config_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:53:"/admin/config/development/configuration/single/export";}}s:9:"path_vars";a:2:{i:0;s:11:"config_type";i:1;s:11:"config_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:63;s:14:"patternOutline";s:53:"/admin/config/development/configuration/single/export";s:8:"numParts";i:8;}}', 8),
('config.import_full', '/admin/config/development/configuration/full/import', '/admin/config/development/configuration/full/import', 63, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:51:"/admin/config/development/configuration/full/import";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:36:"\\Drupal\\config\\Form\\ConfigImportForm";s:6:"_title";s:6:"Import";}s:12:"requirements";a:1:{s:11:"_permission";s:20:"import configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:58:"{^/admin/config/development/configuration/full/import$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:51:"/admin/config/development/configuration/full/import";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:63;s:14:"patternOutline";s:51:"/admin/config/development/configuration/full/import";s:8:"numParts";i:6;}}', 6),
('config.import_single', '/admin/config/development/configuration/single/import', '/admin/config/development/configuration/single/import', 63, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/admin/config/development/configuration/single/import";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:13:"Single import";s:5:"_form";s:42:"\\Drupal\\config\\Form\\ConfigSingleImportForm";}s:12:"requirements";a:1:{s:11:"_permission";s:20:"import configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:60:"{^/admin/config/development/configuration/single/import$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:53:"/admin/config/development/configuration/single/import";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:63;s:14:"patternOutline";s:53:"/admin/config/development/configuration/single/import";s:8:"numParts";i:6;}}', 6),
('config.sync', '/admin/config/development/configuration', '/admin/config/development/configuration', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:39:"/admin/config/development/configuration";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:30:"\\Drupal\\config\\Form\\ConfigSync";s:6:"_title";s:11:"Synchronize";}s:12:"requirements";a:1:{s:11:"_permission";s:25:"synchronize configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:46:"{^/admin/config/development/configuration$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/config/development/configuration";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:39:"/admin/config/development/configuration";s:8:"numParts";i:4;}}', 4),
('contact.form_add', '/admin/structure/contact/add', '/admin/structure/contact/add', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:28:"/admin/structure/contact/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:16:"contact_form.add";s:6:"_title";s:16:"Add contact form";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer contact forms";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:35:"{^/admin/structure/contact/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:28:"/admin/structure/contact/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:28:"/admin/structure/contact/add";s:8:"numParts";i:4;}}', 4),
('contact.site_page', '/contact', '/contact', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:8:"/contact";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:6:"_title";s:7:"Contact";s:11:"_controller";s:61:"\\Drupal\\contact\\Controller\\ContactController::contactSitePage";s:12:"contact_form";N;}s:12:"requirements";a:1:{s:11:"_permission";s:29:"access site-wide contact form";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:15:"{^/contact$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/contact";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:8:"/contact";s:8:"numParts";i:1;}}', 1),
('contextual.render', '/contextual/render', '/contextual/render', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:18:"/contextual/render";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:47:"\\Drupal\\contextual\\ContextualController::render";}s:12:"requirements";a:1:{s:11:"_permission";s:23:"access contextual links";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:25:"{^/contextual/render$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:18:"/contextual/render";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:18:"/contextual/render";s:8:"numParts";i:2;}}', 2),
('dblog.access_denied', '/admin/reports/access-denied', '/admin/reports/access-denied', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:28:"/admin/reports/access-denied";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:6:"_title";s:26:"Top ''access denied'' errors";s:11:"_controller";s:56:"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages";s:4:"type";s:13:"access denied";}s:12:"requirements";a:1:{s:11:"_permission";s:19:"access site reports";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/reports/access\\-denied$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:28:"/admin/reports/access-denied";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:28:"/admin/reports/access-denied";s:8:"numParts";i:3;}}', 3),
('dblog.confirm', '/admin/reports/dblog/confirm', '/admin/reports/dblog/confirm', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:28:"/admin/reports/dblog/confirm";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:43:"\\Drupal\\dblog\\Form\\DblogClearLogConfirmForm";s:6:"_title";s:34:"Confirm delete recent log messages";}s:12:"requirements";a:1:{s:11:"_permission";s:19:"access site reports";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:35:"{^/admin/reports/dblog/confirm$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:28:"/admin/reports/dblog/confirm";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:28:"/admin/reports/dblog/confirm";s:8:"numParts";i:4;}}', 4),
('dblog.event', '/admin/reports/dblog/event/{event_id}', '/admin/reports/dblog/event/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:37:"/admin/reports/dblog/event/{event_id}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:54:"\\Drupal\\dblog\\Controller\\DbLogController::eventDetails";s:6:"_title";s:7:"Details";}s:12:"requirements";a:1:{s:11:"_permission";s:19:"access site reports";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:8:"event_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:54:"{^/admin/reports/dblog/event/(?P<event_id>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:8:"event_id";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/reports/dblog/event";}}s:9:"path_vars";a:1:{i:0;s:8:"event_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:28:"/admin/reports/dblog/event/%";s:8:"numParts";i:5;}}', 5);
INSERT INTO `[[dbprefix]]router` VALUES
('dblog.overview', '/admin/reports/dblog', '/admin/reports/dblog', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/admin/reports/dblog";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:8:"watchdog";s:10:"display_id";s:4:"page";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:19:"access site reports";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/admin/reports/dblog$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/reports/dblog";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/admin/reports/dblog";s:8:"numParts";i:3;}}', 3),
('dblog.page_not_found', '/admin/reports/page-not-found', '/admin/reports/page-not-found', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:29:"/admin/reports/page-not-found";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:6:"_title";s:27:"Top ''page not found'' errors";s:11:"_controller";s:56:"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages";s:4:"type";s:14:"page not found";}s:12:"requirements";a:1:{s:11:"_permission";s:19:"access site reports";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/admin/reports/page\\-not\\-found$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/reports/page-not-found";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:29:"/admin/reports/page-not-found";s:8:"numParts";i:3;}}', 3),
('dblog.search', '/admin/reports/search', '/admin/reports/search', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:21:"/admin/reports/search";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:56:"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages";s:6:"_title";s:18:"Top search phrases";s:4:"type";s:6:"search";}s:12:"requirements";a:2:{s:20:"_module_dependencies";s:6:"search";s:11:"_permission";s:19:"access site reports";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:28:"{^/admin/reports/search$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:21:"/admin/reports/search";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:21:"/admin/reports/search";s:8:"numParts";i:3;}}', 3),
('editor.filter_xss', '/editor/filter_xss/{filter_format}', '/editor/filter_xss/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:34:"/editor/filter_xss/{filter_format}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:42:"\\Drupal\\editor\\EditorController::filterXss";}s:12:"requirements";a:1:{s:14:"_entity_access";s:17:"filter_format.use";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"filter_format";a:2:{s:4:"type";s:20:"entity:filter_format";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"filter_format";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:51:"{^/editor/filter_xss/(?P<filter_format>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"filter_format";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:18:"/editor/filter_xss";}}s:9:"path_vars";a:1:{i:0;s:13:"filter_format";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:20:"/editor/filter_xss/%";s:8:"numParts";i:3;}}', 3),
('entity.block.delete_form', '/admin/structure/block/manage/{block}/delete', '/admin/structure/block/manage/%/delete', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:44:"/admin/structure/block/manage/{block}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:12:"block.delete";s:6:"_title";s:12:"Remove block";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"administer blocks";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:5:"block";a:2:{s:4:"type";s:12:"entity:block";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"block";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:61:"{^/admin/structure/block/manage/(?P<block>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"block";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/block/manage";}}s:9:"path_vars";a:1:{i:0;s:5:"block";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:38:"/admin/structure/block/manage/%/delete";s:8:"numParts";i:6;}}', 6),
('entity.block.disable', '/admin/structure/block/manage/{block}/disable', '/admin/structure/block/manage/%/disable', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:45:"/admin/structure/block/manage/{block}/disable";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:58:"\\Drupal\\block\\Controller\\BlockController::performOperation";s:2:"op";s:7:"disable";}s:12:"requirements";a:2:{s:14:"_entity_access";s:13:"block.disable";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:5:"block";a:2:{s:4:"type";s:12:"entity:block";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"block";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:62:"{^/admin/structure/block/manage/(?P<block>[^/]++)/disable$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/disable";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"block";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/block/manage";}}s:9:"path_vars";a:1:{i:0;s:5:"block";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:39:"/admin/structure/block/manage/%/disable";s:8:"numParts";i:6;}}', 6),
('entity.block.edit_form', '/admin/structure/block/manage/{block}', '/admin/structure/block/manage/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:37:"/admin/structure/block/manage/{block}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:13:"block.default";s:6:"_title";s:15:"Configure block";}s:12:"requirements";a:1:{s:14:"_entity_access";s:12:"block.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:5:"block";a:2:{s:4:"type";s:12:"entity:block";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"block";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:54:"{^/admin/structure/block/manage/(?P<block>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"block";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/block/manage";}}s:9:"path_vars";a:1:{i:0;s:5:"block";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:31:"/admin/structure/block/manage/%";s:8:"numParts";i:5;}}', 5),
('entity.block.enable', '/admin/structure/block/manage/{block}/enable', '/admin/structure/block/manage/%/enable', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:44:"/admin/structure/block/manage/{block}/enable";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:58:"\\Drupal\\block\\Controller\\BlockController::performOperation";s:2:"op";s:6:"enable";}s:12:"requirements";a:2:{s:14:"_entity_access";s:12:"block.enable";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:5:"block";a:2:{s:4:"type";s:12:"entity:block";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"block";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:61:"{^/admin/structure/block/manage/(?P<block>[^/]++)/enable$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/enable";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"block";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/block/manage";}}s:9:"path_vars";a:1:{i:0;s:5:"block";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:38:"/admin/structure/block/manage/%/enable";s:8:"numParts";i:6;}}', 6),
('entity.block_content.canonical', '/admin/content/block/{block_content}', '/admin/content/block/%', 14, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:36:"/admin/content/block/{block_content}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:18:"block_content.edit";s:15:"_title_callback";s:54:"\\Drupal\\Core\\Entity\\Controller\\EntityController::title";}s:12:"requirements";a:2:{s:14:"_entity_access";s:20:"block_content.update";s:13:"block_content";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"block_content";a:2:{s:4:"type";s:20:"entity:block_content";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"block_content";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:50:"{^/admin/content/block/(?P<block_content>\\d+)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:13:"block_content";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/content/block";}}s:9:"path_vars";a:1:{i:0;s:13:"block_content";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:14;s:14:"patternOutline";s:22:"/admin/content/block/%";s:8:"numParts";i:4;}}', 4),
('entity.block_content.collection', '/admin/content/block', '/admin/content/block', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/admin/content/block";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:13:"block_content";s:10:"display_id";s:6:"page_1";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:20:"access block library";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/admin/content/block$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/content/block";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/admin/content/block";s:8:"numParts";i:3;}}', 3),
('entity.block_content.delete_form', '/admin/content/block/{block_content}/delete', '/admin/content/block/%/delete', 29, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:43:"/admin/content/block/{block_content}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:20:"block_content.delete";s:6:"_title";s:6:"Delete";}s:12:"requirements";a:2:{s:14:"_entity_access";s:20:"block_content.delete";s:13:"block_content";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"block_content";a:2:{s:4:"type";s:20:"entity:block_content";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"block_content";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:57:"{^/admin/content/block/(?P<block_content>\\d+)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:13:"block_content";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/content/block";}}s:9:"path_vars";a:1:{i:0;s:13:"block_content";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:29;s:14:"patternOutline";s:29:"/admin/content/block/%/delete";s:8:"numParts";i:5;}}', 5),
('entity.block_content.edit_form', '/admin/content/block/{block_content}', '/admin/content/block/%', 14, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:36:"/admin/content/block/{block_content}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:12:"_entity_form";s:18:"block_content.edit";}s:12:"requirements";a:2:{s:14:"_entity_access";s:20:"block_content.update";s:13:"block_content";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"block_content";a:2:{s:4:"type";s:20:"entity:block_content";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"block_content";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:50:"{^/admin/content/block/(?P<block_content>\\d+)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:13:"block_content";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/content/block";}}s:9:"path_vars";a:1:{i:0;s:13:"block_content";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:14;s:14:"patternOutline";s:22:"/admin/content/block/%";s:8:"numParts";i:4;}}', 4),
('entity.block_content.field_ui_fields', '/admin/structure/block-content/manage/{block_content_type}/fields', '/admin/structure/block-content/manage/%/fields', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:65:"/admin/structure/block-content/manage/{block_content_type}/fields";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:62:"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing";s:6:"_title";s:13:"Manage fields";s:14:"entity_type_id";s:13:"block_content";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:31:"administer block_content fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:18:"block_content_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:83:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:1:{i:0;s:18:"block_content_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:46:"/admin/structure/block-content/manage/%/fields";s:8:"numParts";i:6;}}', 6),
('entity.block_content.revision_delete_form', '/admin/content/block/{block_content}/revision/{block_content_revision}/delete', '/admin/content/block/%/revision/%/delete', 117, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:77:"/admin/content/block/{block_content}/revision/{block_content_revision}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:29:"block_content.revision-delete";s:6:"_title";s:15:"Delete revision";}s:12:"requirements";a:1:{s:14:"_entity_access";s:38:"block_content_revision.delete revision";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:2:{s:13:"block_content";a:2:{s:4:"type";s:20:"entity:block_content";s:9:"converter";s:21:"paramconverter.entity";}s:22:"block_content_revision";a:2:{s:4:"type";s:29:"entity_revision:block_content";s:9:"converter";s:30:"paramconverter.entity_revision";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:13:"block_content";i:1;s:22:"block_content_revision";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:104:"{^/admin/content/block/(?P<block_content>[^/]++)/revision/(?P<block_content_revision>[^/]++)/delete$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:22:"block_content_revision";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:9:"/revision";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"block_content";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/content/block";}}s:9:"path_vars";a:2:{i:0;s:13:"block_content";i:1;s:22:"block_content_revision";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:117;s:14:"patternOutline";s:40:"/admin/content/block/%/revision/%/delete";s:8:"numParts";i:7;}}', 7),
('entity.block_content.revision_revert_form', '/admin/content/block/{block_content}/revision/{block_content_revision}/revert', '/admin/content/block/%/revision/%/revert', 117, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:77:"/admin/content/block/{block_content}/revision/{block_content_revision}/revert";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:29:"block_content.revision-revert";s:6:"_title";s:15:"Revert revision";}s:12:"requirements";a:1:{s:14:"_entity_access";s:29:"block_content_revision.revert";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:2:{s:13:"block_content";a:2:{s:4:"type";s:20:"entity:block_content";s:9:"converter";s:21:"paramconverter.entity";}s:22:"block_content_revision";a:2:{s:4:"type";s:29:"entity_revision:block_content";s:9:"converter";s:30:"paramconverter.entity_revision";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:13:"block_content";i:1;s:22:"block_content_revision";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:104:"{^/admin/content/block/(?P<block_content>[^/]++)/revision/(?P<block_content_revision>[^/]++)/revert$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/revert";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:22:"block_content_revision";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:9:"/revision";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"block_content";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/content/block";}}s:9:"path_vars";a:2:{i:0;s:13:"block_content";i:1;s:22:"block_content_revision";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:117;s:14:"patternOutline";s:40:"/admin/content/block/%/revision/%/revert";s:8:"numParts";i:7;}}', 7),
('entity.block_content.version_history', '/admin/content/block/{block_content}/revisions', '/admin/content/block/%/revisions', 29, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:46:"/admin/content/block/{block_content}/revisions";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:54:"Drupal\\Core\\Entity\\Controller\\VersionHistoryController";s:6:"_title";s:9:"Revisions";}s:12:"requirements";a:1:{s:14:"_entity_access";s:32:"block_content.view all revisions";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:14:"entity_type_id";s:13:"block_content";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:13:"block_content";a:2:{s:4:"type";s:20:"entity:block_content";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"block_content";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:63:"{^/admin/content/block/(?P<block_content>[^/]++)/revisions$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:10:"/revisions";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"block_content";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/content/block";}}s:9:"path_vars";a:1:{i:0;s:13:"block_content";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:29;s:14:"patternOutline";s:32:"/admin/content/block/%/revisions";s:8:"numParts";i:5;}}', 5),
('entity.block_content_type.collection', '/admin/structure/block-content', '/admin/structure/block-content', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:30:"/admin/structure/block-content";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_list";s:18:"block_content_type";s:6:"_title";s:11:"Block types";s:16:"_title_arguments";a:0:{}s:14:"_title_context";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer block types";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/admin/structure/block\\-content$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:30:"/admin/structure/block-content";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:30:"/admin/structure/block-content";s:8:"numParts";i:3;}}', 3),
('entity.block_content_type.delete_form', '/admin/structure/block-content/manage/{block_content_type}/delete', '/admin/structure/block-content/manage/%/delete', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:65:"/admin/structure/block-content/manage/{block_content_type}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:25:"block_content_type.delete";s:15:"_title_callback";s:60:"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle";}s:12:"requirements";a:1:{s:14:"_entity_access";s:25:"block_content_type.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:18:"block_content_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:83:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:1:{i:0;s:18:"block_content_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:46:"/admin/structure/block-content/manage/%/delete";s:8:"numParts";i:6;}}', 6),
('entity.block_content_type.edit_form', '/admin/structure/block-content/manage/{block_content_type}', '/admin/structure/block-content/manage/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:58:"/admin/structure/block-content/manage/{block_content_type}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:23:"block_content_type.edit";s:15:"_title_callback";s:58:"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle";}s:12:"requirements";a:1:{s:14:"_entity_access";s:25:"block_content_type.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:18:"block_content_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:76:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:1:{i:0;s:18:"block_content_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:39:"/admin/structure/block-content/manage/%";s:8:"numParts";i:5;}}', 5),
('entity.block_content_type.entity_permissions_form', '/admin/structure/block-content/manage/{block_content_type}/permissions', '/admin/structure/block-content/manage/%/permissions', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:70:"/admin/structure/block-content/manage/{block_content_type}/permissions";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:6:"_title";s:18:"Manage permissions";s:5:"_form";s:38:"Drupal\\user\\Form\\EntityPermissionsForm";s:14:"entity_type_id";s:13:"block_content";s:18:"bundle_entity_type";s:18:"block_content_type";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer permissions";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:9:"_field_ui";b:1;s:10:"parameters";a:1:{s:18:"block_content_type";a:3:{s:4:"type";s:25:"entity:block_content_type";s:21:"with_config_overrides";b:1;s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:18:"block_content_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:88:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/permissions$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/permissions";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:1:{i:0;s:18:"block_content_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:51:"/admin/structure/block-content/manage/%/permissions";s:8:"numParts";i:6;}}', 6),
('entity.comment.canonical', '/comment/{comment}', '/comment/%', 2, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:18:"/comment/{comment}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:15:"_title_callback";s:67:"\\Drupal\\comment\\Controller\\CommentController::commentPermalinkTitle";s:11:"_controller";s:62:"\\Drupal\\comment\\Controller\\CommentController::commentPermalink";}s:12:"requirements";a:2:{s:14:"_entity_access";s:12:"comment.view";s:7:"comment";s:3:"\\d+";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:7:"comment";a:2:{s:4:"type";s:14:"entity:comment";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:7:"comment";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/comment/(?P<comment>\\d+)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:7:"comment";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:8:"/comment";}}s:9:"path_vars";a:1:{i:0;s:7:"comment";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:2;s:14:"patternOutline";s:10:"/comment/%";s:8:"numParts";i:2;}}', 2),
('entity.comment.delete_form', '/comment/{comment}/delete', '/comment/%/delete', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/comment/{comment}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:6:"Delete";s:12:"_entity_form";s:14:"comment.delete";}s:12:"requirements";a:2:{s:14:"_entity_access";s:14:"comment.delete";s:7:"comment";s:3:"\\d+";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:7:"comment";a:2:{s:4:"type";s:14:"entity:comment";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:7:"comment";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:39:"{^/comment/(?P<comment>\\d+)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:7:"comment";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:8:"/comment";}}s:9:"path_vars";a:1:{i:0;s:7:"comment";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:17:"/comment/%/delete";s:8:"numParts";i:3;}}', 3),
('entity.comment.delete_multiple_form', '/admin/content/comment/delete', '/admin/content/comment/delete', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:29:"/admin/content/comment/delete";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:6:"_title";s:6:"Delete";s:5:"_form";s:42:"\\Drupal\\comment\\Form\\ConfirmDeleteMultiple";s:14:"entity_type_id";s:7:"comment";}s:12:"requirements";a:1:{s:30:"_entity_delete_multiple_access";s:7:"comment";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:35:"access_check.entity_delete_multiple";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/content/comment/delete$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/content/comment/delete";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:29:"/admin/content/comment/delete";s:8:"numParts";i:4;}}', 4),
('entity.comment.edit_form', '/comment/{comment}/edit', '/comment/%/edit', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:23:"/comment/{comment}/edit";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:4:"Edit";s:12:"_entity_form";s:15:"comment.default";}s:12:"requirements";a:2:{s:14:"_entity_access";s:14:"comment.update";s:7:"comment";s:3:"\\d+";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:7:"comment";a:2:{s:4:"type";s:14:"entity:comment";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:7:"comment";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:37:"{^/comment/(?P<comment>\\d+)/edit$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/edit";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:7:"comment";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:8:"/comment";}}s:9:"path_vars";a:1:{i:0;s:7:"comment";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:15:"/comment/%/edit";s:8:"numParts";i:3;}}', 3),
('entity.comment.field_ui_fields', '/admin/structure/comment/manage/{comment_type}/fields', '/admin/structure/comment/manage/%/fields', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/admin/structure/comment/manage/{comment_type}/fields";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:62:"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing";s:6:"_title";s:13:"Manage fields";s:14:"entity_type_id";s:7:"comment";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:25:"administer comment fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"comment_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:70:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"comment_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:40:"/admin/structure/comment/manage/%/fields";s:8:"numParts";i:6;}}', 6),
('entity.comment_type.add_form', '/admin/structure/comment/types/add', '/admin/structure/comment/types/add', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:34:"/admin/structure/comment/types/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:16:"comment_type.add";s:6:"_title";s:16:"Add comment type";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer comment types";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:41:"{^/admin/structure/comment/types/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:34:"/admin/structure/comment/types/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:34:"/admin/structure/comment/types/add";s:8:"numParts";i:5;}}', 5),
('entity.comment_type.collection', '/admin/structure/comment', '/admin/structure/comment', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:24:"/admin/structure/comment";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:12:"comment_type";s:6:"_title";s:13:"Comment types";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer comment types";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:31:"{^/admin/structure/comment$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:24:"/admin/structure/comment";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:24:"/admin/structure/comment";s:8:"numParts";i:3;}}', 3),
('entity.comment_type.delete_form', '/admin/structure/comment/manage/{comment_type}/delete', '/admin/structure/comment/manage/%/delete', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/admin/structure/comment/manage/{comment_type}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:19:"comment_type.delete";s:6:"_title";s:6:"Delete";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"comment_type.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"comment_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:70:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"comment_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:40:"/admin/structure/comment/manage/%/delete";s:8:"numParts";i:6;}}', 6),
('entity.comment_type.edit_form', '/admin/structure/comment/manage/{comment_type}', '/admin/structure/comment/manage/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:46:"/admin/structure/comment/manage/{comment_type}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:17:"comment_type.edit";s:15:"_title_callback";s:54:"\\Drupal\\Core\\Entity\\Controller\\EntityController::title";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"comment_type.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"comment_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:63:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"comment_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:33:"/admin/structure/comment/manage/%";s:8:"numParts";i:5;}}', 5),
('entity.comment_type.entity_permissions_form', '/admin/structure/comment/manage/{comment_type}/permissions', '/admin/structure/comment/manage/%/permissions', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:58:"/admin/structure/comment/manage/{comment_type}/permissions";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:6:"_title";s:18:"Manage permissions";s:5:"_form";s:38:"Drupal\\user\\Form\\EntityPermissionsForm";s:14:"entity_type_id";s:7:"comment";s:18:"bundle_entity_type";s:12:"comment_type";}s:12:"requirements";a:2:{s:11:"_permission";s:22:"administer permissions";s:14:"_custom_access";s:47:"\\Drupal\\user\\Form\\EntityPermissionsForm::access";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:9:"_field_ui";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:3:{s:4:"type";s:19:"entity:comment_type";s:21:"with_config_overrides";b:1;s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:19:"access_check.custom";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"comment_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:75:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/permissions$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/permissions";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"comment_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:45:"/admin/structure/comment/manage/%/permissions";s:8:"numParts";i:6;}}', 6),
('entity.contact_form.canonical', '/contact/{contact_form}', '/contact/%', 2, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:23:"/contact/{contact_form}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:7:"Contact";s:11:"_controller";s:61:"\\Drupal\\contact\\Controller\\ContactController::contactSitePage";}s:12:"requirements";a:1:{s:14:"_entity_access";s:17:"contact_form.view";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"contact_form";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:40:"{^/contact/(?P<contact_form>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:8:"/contact";}}s:9:"path_vars";a:1:{i:0;s:12:"contact_form";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:2;s:14:"patternOutline";s:10:"/contact/%";s:8:"numParts";i:2;}}', 2),
('entity.contact_form.collection', '/admin/structure/contact', '/admin/structure/contact', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:24:"/admin/structure/contact";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:12:"contact_form";s:6:"_title";s:13:"Contact forms";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer contact forms";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:31:"{^/admin/structure/contact$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:24:"/admin/structure/contact";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:24:"/admin/structure/contact";s:8:"numParts";i:3;}}', 3),
('entity.contact_form.delete_form', '/admin/structure/contact/manage/{contact_form}/delete', '/admin/structure/contact/manage/%/delete', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/admin/structure/contact/manage/{contact_form}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:19:"contact_form.delete";s:6:"_title";s:6:"Delete";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"contact_form.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"contact_form";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:70:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"contact_form";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:40:"/admin/structure/contact/manage/%/delete";s:8:"numParts";i:6;}}', 6);
INSERT INTO `[[dbprefix]]router` VALUES
('entity.contact_form.edit_form', '/admin/structure/contact/manage/{contact_form}', '/admin/structure/contact/manage/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:46:"/admin/structure/contact/manage/{contact_form}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:17:"contact_form.edit";s:6:"_title";s:17:"Edit contact form";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"contact_form.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"contact_form";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:63:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"contact_form";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:33:"/admin/structure/contact/manage/%";s:8:"numParts";i:5;}}', 5),
('entity.contact_form.entity_permissions_form', '/admin/structure/contact/manage/{contact_form}/permissions', '/admin/structure/contact/manage/%/permissions', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:58:"/admin/structure/contact/manage/{contact_form}/permissions";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:6:"_title";s:18:"Manage permissions";s:5:"_form";s:38:"Drupal\\user\\Form\\EntityPermissionsForm";s:14:"entity_type_id";s:15:"contact_message";s:18:"bundle_entity_type";s:12:"contact_form";}s:12:"requirements";a:2:{s:11:"_permission";s:22:"administer permissions";s:14:"_custom_access";s:47:"\\Drupal\\user\\Form\\EntityPermissionsForm::access";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:9:"_field_ui";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:3:{s:4:"type";s:19:"entity:contact_form";s:21:"with_config_overrides";b:1;s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:19:"access_check.custom";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"contact_form";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:75:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/permissions$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/permissions";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"contact_form";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:45:"/admin/structure/contact/manage/%/permissions";s:8:"numParts";i:6;}}', 6),
('entity.contact_message.field_ui_fields', '/admin/structure/contact/manage/{contact_form}/fields', '/admin/structure/contact/manage/%/fields', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/admin/structure/contact/manage/{contact_form}/fields";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:62:"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing";s:6:"_title";s:13:"Manage fields";s:14:"entity_type_id";s:15:"contact_message";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:33:"administer contact_message fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"contact_form";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:70:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"contact_form";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:40:"/admin/structure/contact/manage/%/fields";s:8:"numParts";i:6;}}', 6),
('entity.date_format.collection', '/admin/config/regional/date-time', '/admin/config/regional/date-time', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:32:"/admin/config/regional/date-time";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:11:"date_format";s:6:"_title";s:21:"Date and time formats";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:40:"{^/admin/config/regional/date\\-time$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/config/regional/date-time";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:32:"/admin/config/regional/date-time";s:8:"numParts";i:4;}}', 4),
('entity.date_format.delete_form', '/admin/config/regional/date-time/formats/manage/{date_format}/delete', '/admin/config/regional/date-time/formats/manage/%/delete', 253, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:68:"/admin/config/regional/date-time/formats/manage/{date_format}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:18:"date_format.delete";s:6:"_title";s:18:"Delete date format";}s:12:"requirements";a:1:{s:14:"_entity_access";s:18:"date_format.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"date_format";a:2:{s:4:"type";s:18:"entity:date_format";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:11:"date_format";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:86:"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"date_format";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:47:"/admin/config/regional/date-time/formats/manage";}}s:9:"path_vars";a:1:{i:0;s:11:"date_format";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:253;s:14:"patternOutline";s:56:"/admin/config/regional/date-time/formats/manage/%/delete";s:8:"numParts";i:8;}}', 8),
('entity.date_format.edit_form', '/admin/config/regional/date-time/formats/manage/{date_format}', '/admin/config/regional/date-time/formats/manage/%', 126, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:61:"/admin/config/regional/date-time/formats/manage/{date_format}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:16:"date_format.edit";s:6:"_title";s:16:"Edit date format";}s:12:"requirements";a:1:{s:14:"_entity_access";s:18:"date_format.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"date_format";a:2:{s:4:"type";s:18:"entity:date_format";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:11:"date_format";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:79:"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"date_format";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:47:"/admin/config/regional/date-time/formats/manage";}}s:9:"path_vars";a:1:{i:0;s:11:"date_format";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:126;s:14:"patternOutline";s:49:"/admin/config/regional/date-time/formats/manage/%";s:8:"numParts";i:7;}}', 7),
('entity.entity_form_display.block_content.default', '/admin/structure/block-content/manage/{block_content_type}/form-display', '/admin/structure/block-content/manage/%/form-display', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:71:"/admin/structure/block-content/manage/{block_content_type}/form-display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"form_mode_name";s:7:"default";s:14:"entity_type_id";s:13:"block_content";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:37:"administer block_content form display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:18:"block_content_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:90:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/form-display";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:1:{i:0;s:18:"block_content_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:52:"/admin/structure/block-content/manage/%/form-display";s:8:"numParts";i:6;}}', 6),
('entity.entity_form_display.block_content.form_mode', '/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}', '/admin/structure/block-content/manage/%/form-display/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:88:"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"entity_type_id";s:13:"block_content";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:37:"administer block_content form display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:18:"block_content_type";i:1;s:14:"form_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:117:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"form_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:13:"/form-display";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:2:{i:0;s:18:"block_content_type";i:1;s:14:"form_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:54:"/admin/structure/block-content/manage/%/form-display/%";s:8:"numParts";i:7;}}', 7),
('entity.entity_form_display.comment.default', '/admin/structure/comment/manage/{comment_type}/form-display', '/admin/structure/comment/manage/%/form-display', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:59:"/admin/structure/comment/manage/{comment_type}/form-display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"form_mode_name";s:7:"default";s:14:"entity_type_id";s:7:"comment";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:31:"administer comment form display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"comment_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:77:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/form-display";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"comment_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:46:"/admin/structure/comment/manage/%/form-display";s:8:"numParts";i:6;}}', 6),
('entity.entity_form_display.comment.form_mode', '/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}', '/admin/structure/comment/manage/%/form-display/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:76:"/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"entity_type_id";s:7:"comment";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:31:"administer comment form display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:12:"comment_type";i:1;s:14:"form_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:104:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"form_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:13:"/form-display";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:2:{i:0;s:12:"comment_type";i:1;s:14:"form_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:48:"/admin/structure/comment/manage/%/form-display/%";s:8:"numParts";i:7;}}', 7),
('entity.entity_form_display.contact_message.default', '/admin/structure/contact/manage/{contact_form}/form-display', '/admin/structure/contact/manage/%/form-display', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:59:"/admin/structure/contact/manage/{contact_form}/form-display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"form_mode_name";s:7:"default";s:14:"entity_type_id";s:15:"contact_message";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:39:"administer contact_message form display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"contact_form";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:77:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/form-display";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"contact_form";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:46:"/admin/structure/contact/manage/%/form-display";s:8:"numParts";i:6;}}', 6),
('entity.entity_form_display.contact_message.form_mode', '/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}', '/admin/structure/contact/manage/%/form-display/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:76:"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"entity_type_id";s:15:"contact_message";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:39:"administer contact_message form display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:12:"contact_form";i:1;s:14:"form_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:104:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"form_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:13:"/form-display";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:2:{i:0;s:12:"contact_form";i:1;s:14:"form_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:48:"/admin/structure/contact/manage/%/form-display/%";s:8:"numParts";i:7;}}', 7),
('entity.entity_form_display.node.default', '/admin/structure/types/manage/{node_type}/form-display', '/admin/structure/types/manage/%/form-display', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:54:"/admin/structure/types/manage/{node_type}/form-display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"form_mode_name";s:7:"default";s:14:"entity_type_id";s:4:"node";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:28:"administer node form display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"node_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:72:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/form-display";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:1:{i:0;s:9:"node_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:44:"/admin/structure/types/manage/%/form-display";s:8:"numParts";i:6;}}', 6),
('entity.entity_form_display.node.form_mode', '/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}', '/admin/structure/types/manage/%/form-display/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:71:"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"entity_type_id";s:4:"node";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:28:"administer node form display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:9:"node_type";i:1;s:14:"form_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:99:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"form_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:13:"/form-display";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:2:{i:0;s:9:"node_type";i:1;s:14:"form_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:46:"/admin/structure/types/manage/%/form-display/%";s:8:"numParts";i:7;}}', 7),
('entity.entity_form_display.taxonomy_term.default', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display', '/admin/structure/taxonomy/manage/%/overview/form-display', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:76:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"form_mode_name";s:7:"default";s:14:"entity_type_id";s:13:"taxonomy_term";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:37:"administer taxonomy_term form display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:94:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/overview/form-display";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:56:"/admin/structure/taxonomy/manage/%/overview/form-display";s:8:"numParts";i:7;}}', 7),
('entity.entity_form_display.taxonomy_term.form_mode', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}', '/admin/structure/taxonomy/manage/%/overview/form-display/%', 246, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:93:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"entity_type_id";s:13:"taxonomy_term";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:37:"administer taxonomy_term form display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:19:"taxonomy_vocabulary";i:1;s:14:"form_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:121:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"form_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:22:"/overview/form-display";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:2:{i:0;s:19:"taxonomy_vocabulary";i:1;s:14:"form_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:246;s:14:"patternOutline";s:58:"/admin/structure/taxonomy/manage/%/overview/form-display/%";s:8:"numParts";i:8;}}', 8),
('entity.entity_form_display.user.default', '/admin/config/people/accounts/form-display', '/admin/config/people/accounts/form-display', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:42:"/admin/config/people/accounts/form-display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"form_mode_name";s:7:"default";s:14:"entity_type_id";s:4:"user";s:6:"bundle";s:4:"user";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:28:"administer user form display";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:50:"{^/admin/config/people/accounts/form\\-display$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/config/people/accounts/form-display";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:42:"/admin/config/people/accounts/form-display";s:8:"numParts";i:5;}}', 5),
('entity.entity_form_display.user.form_mode', '/admin/config/people/accounts/form-display/{form_mode_name}', '/admin/config/people/accounts/form-display/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:59:"/admin/config/people/accounts/form-display/{form_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_form_display.edit";s:6:"_title";s:19:"Manage form display";s:14:"entity_type_id";s:4:"user";s:6:"bundle";s:4:"user";}s:12:"requirements";a:1:{s:26:"_field_ui_form_mode_access";s:28:"administer user form display";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.form_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:14:"form_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:77:"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"form_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/config/people/accounts/form-display";}}s:9:"path_vars";a:1:{i:0;s:14:"form_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:44:"/admin/config/people/accounts/form-display/%";s:8:"numParts";i:6;}}', 6),
('entity.entity_form_mode.add_form', '/admin/structure/display-modes/form/add/{entity_type_id}', '/admin/structure/display-modes/form/add/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:56:"/admin/structure/display-modes/form/add/{entity_type_id}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:20:"entity_form_mode.add";s:6:"_title";s:13:"Add form mode";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer display modes";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:14:"entity_type_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:74:"{^/admin/structure/display\\-modes/form/add/(?P<entity_type_id>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"entity_type_id";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/structure/display-modes/form/add";}}s:9:"path_vars";a:1:{i:0;s:14:"entity_type_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:41:"/admin/structure/display-modes/form/add/%";s:8:"numParts";i:6;}}', 6),
('entity.entity_form_mode.collection', '/admin/structure/display-modes/form', '/admin/structure/display-modes/form', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:35:"/admin/structure/display-modes/form";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:16:"entity_form_mode";s:6:"_title";s:10:"Form modes";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer display modes";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:43:"{^/admin/structure/display\\-modes/form$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:35:"/admin/structure/display-modes/form";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:35:"/admin/structure/display-modes/form";s:8:"numParts";i:4;}}', 4),
('entity.entity_form_mode.delete_form', '/admin/structure/display-modes/form/manage/{entity_form_mode}/delete', '/admin/structure/display-modes/form/manage/%/delete', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:68:"/admin/structure/display-modes/form/manage/{entity_form_mode}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:23:"entity_form_mode.delete";s:6:"_title";s:16:"Delete form mode";}s:12:"requirements";a:1:{s:14:"_entity_access";s:23:"entity_form_mode.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:16:"entity_form_mode";a:2:{s:4:"type";s:23:"entity:entity_form_mode";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:16:"entity_form_mode";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:86:"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:16:"entity_form_mode";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/structure/display-modes/form/manage";}}s:9:"path_vars";a:1:{i:0;s:16:"entity_form_mode";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:51:"/admin/structure/display-modes/form/manage/%/delete";s:8:"numParts";i:7;}}', 7),
('entity.entity_form_mode.edit_form', '/admin/structure/display-modes/form/manage/{entity_form_mode}', '/admin/structure/display-modes/form/manage/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:61:"/admin/structure/display-modes/form/manage/{entity_form_mode}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:21:"entity_form_mode.edit";s:6:"_title";s:14:"Edit form mode";}s:12:"requirements";a:1:{s:14:"_entity_access";s:23:"entity_form_mode.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:16:"entity_form_mode";a:2:{s:4:"type";s:23:"entity:entity_form_mode";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:16:"entity_form_mode";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:79:"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:16:"entity_form_mode";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/structure/display-modes/form/manage";}}s:9:"path_vars";a:1:{i:0;s:16:"entity_form_mode";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:44:"/admin/structure/display-modes/form/manage/%";s:8:"numParts";i:6;}}', 6),
('entity.entity_view_display.block_content.default', '/admin/structure/block-content/manage/{block_content_type}/display', '/admin/structure/block-content/manage/%/display', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:66:"/admin/structure/block-content/manage/{block_content_type}/display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"view_mode_name";s:7:"default";s:14:"entity_type_id";s:13:"block_content";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:32:"administer block_content display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:18:"block_content_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:84:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/display";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:1:{i:0;s:18:"block_content_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:47:"/admin/structure/block-content/manage/%/display";s:8:"numParts";i:6;}}', 6),
('entity.entity_view_display.block_content.view_mode', '/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}', '/admin/structure/block-content/manage/%/display/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:83:"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"entity_type_id";s:13:"block_content";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:32:"administer block_content display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:18:"block_content_type";i:1;s:14:"view_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:111:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"view_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:8:"/display";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:2:{i:0;s:18:"block_content_type";i:1;s:14:"view_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:49:"/admin/structure/block-content/manage/%/display/%";s:8:"numParts";i:7;}}', 7),
('entity.entity_view_display.comment.default', '/admin/structure/comment/manage/{comment_type}/display', '/admin/structure/comment/manage/%/display', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:54:"/admin/structure/comment/manage/{comment_type}/display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"view_mode_name";s:7:"default";s:14:"entity_type_id";s:7:"comment";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:26:"administer comment display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"comment_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:71:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/display";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"comment_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:41:"/admin/structure/comment/manage/%/display";s:8:"numParts";i:6;}}', 6),
('entity.entity_view_display.comment.view_mode', '/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}', '/admin/structure/comment/manage/%/display/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:71:"/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"entity_type_id";s:7:"comment";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:26:"administer comment display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:12:"comment_type";i:1;s:14:"view_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:98:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"view_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:8:"/display";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:2:{i:0;s:12:"comment_type";i:1;s:14:"view_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:43:"/admin/structure/comment/manage/%/display/%";s:8:"numParts";i:7;}}', 7),
('entity.entity_view_display.contact_message.default', '/admin/structure/contact/manage/{contact_form}/display', '/admin/structure/contact/manage/%/display', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:54:"/admin/structure/contact/manage/{contact_form}/display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"view_mode_name";s:7:"default";s:14:"entity_type_id";s:15:"contact_message";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:34:"administer contact_message display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"contact_form";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:71:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/display";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"contact_form";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:41:"/admin/structure/contact/manage/%/display";s:8:"numParts";i:6;}}', 6),
('entity.entity_view_display.contact_message.view_mode', '/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}', '/admin/structure/contact/manage/%/display/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:71:"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"entity_type_id";s:15:"contact_message";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:34:"administer contact_message display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:12:"contact_form";i:1;s:14:"view_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:98:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"view_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:8:"/display";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:2:{i:0;s:12:"contact_form";i:1;s:14:"view_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:43:"/admin/structure/contact/manage/%/display/%";s:8:"numParts";i:7;}}', 7),
('entity.entity_view_display.node.default', '/admin/structure/types/manage/{node_type}/display', '/admin/structure/types/manage/%/display', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:49:"/admin/structure/types/manage/{node_type}/display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"view_mode_name";s:7:"default";s:14:"entity_type_id";s:4:"node";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:23:"administer node display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"node_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:66:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/display";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:1:{i:0;s:9:"node_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:39:"/admin/structure/types/manage/%/display";s:8:"numParts";i:6;}}', 6);
INSERT INTO `[[dbprefix]]router` VALUES
('entity.entity_view_display.node.view_mode', '/admin/structure/types/manage/{node_type}/display/{view_mode_name}', '/admin/structure/types/manage/%/display/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:66:"/admin/structure/types/manage/{node_type}/display/{view_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"entity_type_id";s:4:"node";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:23:"administer node display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:9:"node_type";i:1;s:14:"view_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:93:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"view_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:8:"/display";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:2:{i:0;s:9:"node_type";i:1;s:14:"view_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:41:"/admin/structure/types/manage/%/display/%";s:8:"numParts";i:7;}}', 7),
('entity.entity_view_display.taxonomy_term.default', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display', '/admin/structure/taxonomy/manage/%/overview/display', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:71:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"view_mode_name";s:7:"default";s:14:"entity_type_id";s:13:"taxonomy_term";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:32:"administer taxonomy_term display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:88:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:17:"/overview/display";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:51:"/admin/structure/taxonomy/manage/%/overview/display";s:8:"numParts";i:7;}}', 7),
('entity.entity_view_display.taxonomy_term.view_mode', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}', '/admin/structure/taxonomy/manage/%/overview/display/%', 246, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:88:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"entity_type_id";s:13:"taxonomy_term";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:32:"administer taxonomy_term display";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:19:"taxonomy_vocabulary";i:1;s:14:"view_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:115:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"view_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:17:"/overview/display";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:2:{i:0;s:19:"taxonomy_vocabulary";i:1;s:14:"view_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:246;s:14:"patternOutline";s:53:"/admin/structure/taxonomy/manage/%/overview/display/%";s:8:"numParts";i:8;}}', 8),
('entity.entity_view_display.user.default', '/admin/config/people/accounts/display', '/admin/config/people/accounts/display', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:37:"/admin/config/people/accounts/display";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"view_mode_name";s:7:"default";s:14:"entity_type_id";s:4:"user";s:6:"bundle";s:4:"user";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:23:"administer user display";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:44:"{^/admin/config/people/accounts/display$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/config/people/accounts/display";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:37:"/admin/config/people/accounts/display";s:8:"numParts";i:5;}}', 5),
('entity.entity_view_display.user.view_mode', '/admin/config/people/accounts/display/{view_mode_name}', '/admin/config/people/accounts/display/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:54:"/admin/config/people/accounts/display/{view_mode_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:24:"entity_view_display.edit";s:6:"_title";s:14:"Manage display";s:14:"entity_type_id";s:4:"user";s:6:"bundle";s:4:"user";}s:12:"requirements";a:1:{s:26:"_field_ui_view_mode_access";s:23:"administer user display";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:31:"access_check.field_ui.view_mode";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:14:"view_mode_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:71:"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"view_mode_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/config/people/accounts/display";}}s:9:"path_vars";a:1:{i:0;s:14:"view_mode_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:39:"/admin/config/people/accounts/display/%";s:8:"numParts";i:6;}}', 6),
('entity.entity_view_mode.add_form', '/admin/structure/display-modes/view/add/{entity_type_id}', '/admin/structure/display-modes/view/add/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:56:"/admin/structure/display-modes/view/add/{entity_type_id}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:20:"entity_view_mode.add";s:6:"_title";s:13:"Add view mode";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer display modes";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:14:"entity_type_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:74:"{^/admin/structure/display\\-modes/view/add/(?P<entity_type_id>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"entity_type_id";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/structure/display-modes/view/add";}}s:9:"path_vars";a:1:{i:0;s:14:"entity_type_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:41:"/admin/structure/display-modes/view/add/%";s:8:"numParts";i:6;}}', 6),
('entity.entity_view_mode.collection', '/admin/structure/display-modes/view', '/admin/structure/display-modes/view', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:35:"/admin/structure/display-modes/view";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:16:"entity_view_mode";s:6:"_title";s:10:"View modes";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer display modes";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:43:"{^/admin/structure/display\\-modes/view$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:35:"/admin/structure/display-modes/view";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:35:"/admin/structure/display-modes/view";s:8:"numParts";i:4;}}', 4),
('entity.entity_view_mode.delete_form', '/admin/structure/display-modes/view/manage/{entity_view_mode}/delete', '/admin/structure/display-modes/view/manage/%/delete', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:68:"/admin/structure/display-modes/view/manage/{entity_view_mode}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:23:"entity_view_mode.delete";s:6:"_title";s:16:"Delete view mode";}s:12:"requirements";a:1:{s:14:"_entity_access";s:23:"entity_view_mode.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:16:"entity_view_mode";a:2:{s:4:"type";s:23:"entity:entity_view_mode";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:16:"entity_view_mode";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:86:"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:16:"entity_view_mode";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/structure/display-modes/view/manage";}}s:9:"path_vars";a:1:{i:0;s:16:"entity_view_mode";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:51:"/admin/structure/display-modes/view/manage/%/delete";s:8:"numParts";i:7;}}', 7),
('entity.entity_view_mode.edit_form', '/admin/structure/display-modes/view/manage/{entity_view_mode}', '/admin/structure/display-modes/view/manage/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:61:"/admin/structure/display-modes/view/manage/{entity_view_mode}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:21:"entity_view_mode.edit";s:6:"_title";s:14:"Edit view mode";}s:12:"requirements";a:1:{s:14:"_entity_access";s:23:"entity_view_mode.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:16:"entity_view_mode";a:2:{s:4:"type";s:23:"entity:entity_view_mode";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:16:"entity_view_mode";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:79:"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:16:"entity_view_mode";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/structure/display-modes/view/manage";}}s:9:"path_vars";a:1:{i:0;s:16:"entity_view_mode";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:44:"/admin/structure/display-modes/view/manage/%";s:8:"numParts";i:6;}}', 6),
('entity.field_config.block_content_field_delete_form', '/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/delete', '/admin/structure/block-content/manage/%/fields/%/delete', 245, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:87:"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/delete";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:12:"_entity_form";s:19:"field_config.delete";s:14:"entity_type_id";s:13:"block_content";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.delete";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:2:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:18:"block_content_type";i:1;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:115:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:2:{i:0;s:18:"block_content_type";i:1;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:245;s:14:"patternOutline";s:55:"/admin/structure/block-content/manage/%/fields/%/delete";s:8:"numParts";i:8;}}', 8),
('entity.field_config.block_content_field_edit_form', '/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}', '/admin/structure/block-content/manage/%/fields/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:80:"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:17:"field_config.edit";s:15:"_title_callback";s:51:"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle";s:14:"entity_type_id";s:13:"block_content";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.update";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:2:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:18:"block_content_type";i:1;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:108:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:2:{i:0;s:18:"block_content_type";i:1;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:48:"/admin/structure/block-content/manage/%/fields/%";s:8:"numParts";i:7;}}', 7),
('entity.field_config.comment_field_delete_form', '/admin/structure/comment/manage/{comment_type}/fields/{field_config}/delete', '/admin/structure/comment/manage/%/fields/%/delete', 245, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:75:"/admin/structure/comment/manage/{comment_type}/fields/{field_config}/delete";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:12:"_entity_form";s:19:"field_config.delete";s:14:"entity_type_id";s:7:"comment";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.delete";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:2:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:12:"comment_type";i:1;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:102:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:2:{i:0;s:12:"comment_type";i:1;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:245;s:14:"patternOutline";s:49:"/admin/structure/comment/manage/%/fields/%/delete";s:8:"numParts";i:8;}}', 8),
('entity.field_config.comment_field_edit_form', '/admin/structure/comment/manage/{comment_type}/fields/{field_config}', '/admin/structure/comment/manage/%/fields/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:68:"/admin/structure/comment/manage/{comment_type}/fields/{field_config}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:17:"field_config.edit";s:15:"_title_callback";s:51:"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle";s:14:"entity_type_id";s:7:"comment";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.update";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:2:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:12:"comment_type";i:1;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:95:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:2:{i:0;s:12:"comment_type";i:1;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:42:"/admin/structure/comment/manage/%/fields/%";s:8:"numParts";i:7;}}', 7),
('entity.field_config.contact_message_field_delete_form', '/admin/structure/contact/manage/{contact_form}/fields/{field_config}/delete', '/admin/structure/contact/manage/%/fields/%/delete', 245, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:75:"/admin/structure/contact/manage/{contact_form}/fields/{field_config}/delete";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:12:"_entity_form";s:19:"field_config.delete";s:14:"entity_type_id";s:15:"contact_message";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.delete";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:2:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:12:"contact_form";i:1;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:102:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:2:{i:0;s:12:"contact_form";i:1;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:245;s:14:"patternOutline";s:49:"/admin/structure/contact/manage/%/fields/%/delete";s:8:"numParts";i:8;}}', 8),
('entity.field_config.contact_message_field_edit_form', '/admin/structure/contact/manage/{contact_form}/fields/{field_config}', '/admin/structure/contact/manage/%/fields/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:68:"/admin/structure/contact/manage/{contact_form}/fields/{field_config}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:17:"field_config.edit";s:15:"_title_callback";s:51:"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle";s:14:"entity_type_id";s:15:"contact_message";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.update";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:2:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:12:"contact_form";i:1;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:95:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:2:{i:0;s:12:"contact_form";i:1;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:42:"/admin/structure/contact/manage/%/fields/%";s:8:"numParts";i:7;}}', 7),
('entity.field_config.node_field_delete_form', '/admin/structure/types/manage/{node_type}/fields/{field_config}/delete', '/admin/structure/types/manage/%/fields/%/delete', 245, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:70:"/admin/structure/types/manage/{node_type}/fields/{field_config}/delete";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:12:"_entity_form";s:19:"field_config.delete";s:14:"entity_type_id";s:4:"node";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.delete";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:2:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:9:"node_type";i:1;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:97:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:2:{i:0;s:9:"node_type";i:1;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:245;s:14:"patternOutline";s:47:"/admin/structure/types/manage/%/fields/%/delete";s:8:"numParts";i:8;}}', 8),
('entity.field_config.node_field_edit_form', '/admin/structure/types/manage/{node_type}/fields/{field_config}', '/admin/structure/types/manage/%/fields/%', 122, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:63:"/admin/structure/types/manage/{node_type}/fields/{field_config}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:17:"field_config.edit";s:15:"_title_callback";s:51:"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle";s:14:"entity_type_id";s:4:"node";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.update";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:2:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:9:"node_type";i:1;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:90:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:2:{i:0;s:9:"node_type";i:1;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:122;s:14:"patternOutline";s:40:"/admin/structure/types/manage/%/fields/%";s:8:"numParts";i:7;}}', 7),
('entity.field_config.taxonomy_term_field_delete_form', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/delete', '/admin/structure/taxonomy/manage/%/overview/fields/%/delete', 493, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:92:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/delete";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:12:"_entity_form";s:19:"field_config.delete";s:14:"entity_type_id";s:13:"taxonomy_term";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.delete";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:2:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:19:"taxonomy_vocabulary";i:1;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:119:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)/delete$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:16:"/overview/fields";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:2:{i:0;s:19:"taxonomy_vocabulary";i:1;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:493;s:14:"patternOutline";s:59:"/admin/structure/taxonomy/manage/%/overview/fields/%/delete";s:8:"numParts";i:9;}}', 9),
('entity.field_config.taxonomy_term_field_edit_form', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}', '/admin/structure/taxonomy/manage/%/overview/fields/%', 246, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:85:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:17:"field_config.edit";s:15:"_title_callback";s:51:"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle";s:14:"entity_type_id";s:13:"taxonomy_term";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.update";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:2:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:19:"taxonomy_vocabulary";i:1;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:112:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:16:"/overview/fields";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:2:{i:0;s:19:"taxonomy_vocabulary";i:1;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:246;s:14:"patternOutline";s:52:"/admin/structure/taxonomy/manage/%/overview/fields/%";s:8:"numParts";i:8;}}', 8),
('entity.field_config.user_field_delete_form', '/admin/config/people/accounts/fields/{field_config}/delete', '/admin/config/people/accounts/fields/%/delete', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:58:"/admin/config/people/accounts/fields/{field_config}/delete";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:12:"_entity_form";s:19:"field_config.delete";s:14:"entity_type_id";s:4:"user";s:6:"bundle";s:4:"user";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.delete";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:9:"_field_ui";b:1;s:10:"parameters";a:1:{s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:75:"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:36:"/admin/config/people/accounts/fields";}}s:9:"path_vars";a:1:{i:0;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:45:"/admin/config/people/accounts/fields/%/delete";s:8:"numParts";i:7;}}', 7),
('entity.field_config.user_field_edit_form', '/admin/config/people/accounts/fields/{field_config}', '/admin/config/people/accounts/fields/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:51:"/admin/config/people/accounts/fields/{field_config}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_form";s:17:"field_config.edit";s:15:"_title_callback";s:51:"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle";s:14:"entity_type_id";s:4:"user";s:6:"bundle";s:4:"user";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"field_config.update";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:9:"_field_ui";b:1;s:10:"parameters";a:1:{s:12:"field_config";a:2:{s:4:"type";s:19:"entity:field_config";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"field_config";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:68:"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"field_config";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:36:"/admin/config/people/accounts/fields";}}s:9:"path_vars";a:1:{i:0;s:12:"field_config";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:38:"/admin/config/people/accounts/fields/%";s:8:"numParts";i:6;}}', 6),
('entity.field_storage_config.collection', '/admin/reports/fields', '/admin/reports/fields', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:21:"/admin/reports/fields";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:20:"field_storage_config";s:6:"_title";s:10:"Field list";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer content types";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:28:"{^/admin/reports/fields$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:21:"/admin/reports/fields";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:21:"/admin/reports/fields";s:8:"numParts";i:3;}}', 3),
('entity.file.delete_form', '/file/{file}/delete', '/file/%/delete', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:19:"/file/{file}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:11:"file.delete";s:6:"_title";s:6:"Delete";}s:12:"requirements";a:2:{s:4:"file";s:3:"\\d+";s:14:"_entity_access";s:11:"file.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:4:"file";a:2:{s:4:"type";s:11:"entity:file";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"file";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:33:"{^/file/(?P<file>\\d+)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"file";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:5:"/file";}}s:9:"path_vars";a:1:{i:0;s:4:"file";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:14:"/file/%/delete";s:8:"numParts";i:3;}}', 3),
('entity.filter_format.disable', '/admin/config/content/formats/manage/{filter_format}/disable', '/admin/config/content/formats/manage/%/disable', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:60:"/admin/config/content/formats/manage/{filter_format}/disable";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:21:"filter_format.disable";s:6:"_title";s:19:"Disable text format";}s:12:"requirements";a:1:{s:14:"_entity_access";s:21:"filter_format.disable";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"filter_format";a:2:{s:4:"type";s:20:"entity:filter_format";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"filter_format";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:77:"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/disable$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/disable";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"filter_format";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:36:"/admin/config/content/formats/manage";}}s:9:"path_vars";a:1:{i:0;s:13:"filter_format";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:46:"/admin/config/content/formats/manage/%/disable";s:8:"numParts";i:7;}}', 7),
('entity.filter_format.edit_form', '/admin/config/content/formats/manage/{filter_format}', '/admin/config/content/formats/manage/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:52:"/admin/config/content/formats/manage/{filter_format}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:18:"filter_format.edit";s:15:"_title_callback";s:52:"\\Drupal\\filter\\Controller\\FilterController::getLabel";}s:12:"requirements";a:1:{s:14:"_entity_access";s:20:"filter_format.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"filter_format";a:2:{s:4:"type";s:20:"entity:filter_format";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"filter_format";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:69:"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"filter_format";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:36:"/admin/config/content/formats/manage";}}s:9:"path_vars";a:1:{i:0;s:13:"filter_format";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:38:"/admin/config/content/formats/manage/%";s:8:"numParts";i:6;}}', 6),
('entity.image_style.collection', '/admin/config/media/image-styles', '/admin/config/media/image-styles', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:32:"/admin/config/media/image-styles";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:11:"image_style";s:6:"_title";s:12:"Image styles";}s:12:"requirements";a:1:{s:11:"_permission";s:23:"administer image styles";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:40:"{^/admin/config/media/image\\-styles$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/config/media/image-styles";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:32:"/admin/config/media/image-styles";s:8:"numParts";i:4;}}', 4),
('entity.image_style.delete_form', '/admin/config/media/image-styles/manage/{image_style}/delete', '/admin/config/media/image-styles/manage/%/delete', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:60:"/admin/config/media/image-styles/manage/{image_style}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:18:"image_style.delete";s:6:"_title";s:6:"Delete";}s:12:"requirements";a:1:{s:14:"_entity_access";s:18:"image_style.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"image_style";a:2:{s:4:"type";s:18:"entity:image_style";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:11:"image_style";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:78:"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"image_style";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/config/media/image-styles/manage";}}s:9:"path_vars";a:1:{i:0;s:11:"image_style";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:48:"/admin/config/media/image-styles/manage/%/delete";s:8:"numParts";i:7;}}', 7),
('entity.image_style.edit_form', '/admin/config/media/image-styles/manage/{image_style}', '/admin/config/media/image-styles/manage/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/admin/config/media/image-styles/manage/{image_style}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:16:"image_style.edit";s:6:"_title";s:10:"Edit style";}s:12:"requirements";a:1:{s:11:"_permission";s:23:"administer image styles";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"image_style";a:2:{s:4:"type";s:18:"entity:image_style";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:11:"image_style";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:71:"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"image_style";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/config/media/image-styles/manage";}}s:9:"path_vars";a:1:{i:0;s:11:"image_style";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:41:"/admin/config/media/image-styles/manage/%";s:8:"numParts";i:6;}}', 6),
('entity.image_style.flush_form', '/admin/config/media/image-styles/manage/{image_style}/flush', '/admin/config/media/image-styles/manage/%/flush', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:59:"/admin/config/media/image-styles/manage/{image_style}/flush";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:17:"image_style.flush";s:6:"_title";s:5:"Flush";}s:12:"requirements";a:1:{s:11:"_permission";s:23:"administer image styles";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"image_style";a:2:{s:4:"type";s:18:"entity:image_style";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:11:"image_style";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:77:"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/flush$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:6:"/flush";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"image_style";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/config/media/image-styles/manage";}}s:9:"path_vars";a:1:{i:0;s:11:"image_style";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:47:"/admin/config/media/image-styles/manage/%/flush";s:8:"numParts";i:7;}}', 7);
INSERT INTO `[[dbprefix]]router` VALUES
('entity.menu.add_form', '/admin/structure/menu/add', '/admin/structure/menu/add', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/admin/structure/menu/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:8:"menu.add";s:6:"_title";s:8:"Add menu";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:4:"menu";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/admin/structure/menu/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/structure/menu/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:25:"/admin/structure/menu/add";s:8:"numParts";i:4;}}', 4),
('entity.menu.add_link_form', '/admin/structure/menu/manage/{menu}/add', '/admin/structure/menu/manage/%/add', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:39:"/admin/structure/menu/manage/{menu}/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:60:"\\Drupal\\menu_link_content\\Controller\\MenuController::addLink";s:6:"_title";s:13:"Add menu link";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:17:"menu_link_content";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"menu";a:2:{s:4:"type";s:11:"entity:menu";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"menu";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:56:"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/add$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:4:"/add";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"menu";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:28:"/admin/structure/menu/manage";}}s:9:"path_vars";a:1:{i:0;s:4:"menu";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:34:"/admin/structure/menu/manage/%/add";s:8:"numParts";i:6;}}', 6),
('entity.menu.collection', '/admin/structure/menu', '/admin/structure/menu', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:21:"/admin/structure/menu";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:4:"menu";s:6:"_title";s:5:"Menus";}s:12:"requirements";a:1:{s:11:"_permission";s:15:"administer menu";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:28:"{^/admin/structure/menu$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:21:"/admin/structure/menu";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:21:"/admin/structure/menu";s:8:"numParts";i:3;}}', 3),
('entity.menu.delete_form', '/admin/structure/menu/manage/{menu}/delete', '/admin/structure/menu/manage/%/delete', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:42:"/admin/structure/menu/manage/{menu}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:11:"menu.delete";s:6:"_title";s:11:"Delete menu";}s:12:"requirements";a:1:{s:14:"_entity_access";s:11:"menu.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"menu";a:2:{s:4:"type";s:11:"entity:menu";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"menu";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:59:"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"menu";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:28:"/admin/structure/menu/manage";}}s:9:"path_vars";a:1:{i:0;s:4:"menu";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:37:"/admin/structure/menu/manage/%/delete";s:8:"numParts";i:6;}}', 6),
('entity.menu.edit_form', '/admin/structure/menu/manage/{menu}', '/admin/structure/menu/manage/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:35:"/admin/structure/menu/manage/{menu}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:9:"menu.edit";s:15:"_title_callback";s:52:"\\Drupal\\menu_ui\\Controller\\MenuController::menuTitle";}s:12:"requirements";a:1:{s:14:"_entity_access";s:11:"menu.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"menu";a:2:{s:4:"type";s:11:"entity:menu";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"menu";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:52:"{^/admin/structure/menu/manage/(?P<menu>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"menu";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:28:"/admin/structure/menu/manage";}}s:9:"path_vars";a:1:{i:0;s:4:"menu";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:30:"/admin/structure/menu/manage/%";s:8:"numParts";i:5;}}', 5),
('entity.menu_link_content.canonical', '/admin/structure/menu/item/{menu_link_content}/edit', '/admin/structure/menu/item/%/edit', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:51:"/admin/structure/menu/item/{menu_link_content}/edit";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:25:"menu_link_content.default";s:6:"_title";s:14:"Edit menu link";}s:12:"requirements";a:1:{s:14:"_entity_access";s:24:"menu_link_content.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:17:"menu_link_content";a:2:{s:4:"type";s:24:"entity:menu_link_content";s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:17:"menu_link_content";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:68:"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/edit";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:17:"menu_link_content";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/structure/menu/item";}}s:9:"path_vars";a:1:{i:0;s:17:"menu_link_content";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:33:"/admin/structure/menu/item/%/edit";s:8:"numParts";i:6;}}', 6),
('entity.menu_link_content.delete_form', '/admin/structure/menu/item/{menu_link_content}/delete', '/admin/structure/menu/item/%/delete', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/admin/structure/menu/item/{menu_link_content}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:24:"menu_link_content.delete";s:6:"_title";s:16:"Delete menu link";}s:12:"requirements";a:1:{s:14:"_entity_access";s:24:"menu_link_content.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:17:"menu_link_content";a:2:{s:4:"type";s:24:"entity:menu_link_content";s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:17:"menu_link_content";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:70:"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:17:"menu_link_content";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/structure/menu/item";}}s:9:"path_vars";a:1:{i:0;s:17:"menu_link_content";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:35:"/admin/structure/menu/item/%/delete";s:8:"numParts";i:6;}}', 6),
('entity.menu_link_content.edit_form', '/admin/structure/menu/item/{menu_link_content}/edit', '/admin/structure/menu/item/%/edit', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:51:"/admin/structure/menu/item/{menu_link_content}/edit";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:25:"menu_link_content.default";s:6:"_title";s:14:"Edit menu link";}s:12:"requirements";a:1:{s:14:"_entity_access";s:24:"menu_link_content.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:17:"menu_link_content";a:2:{s:4:"type";s:24:"entity:menu_link_content";s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:17:"menu_link_content";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:68:"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/edit";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:17:"menu_link_content";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/structure/menu/item";}}s:9:"path_vars";a:1:{i:0;s:17:"menu_link_content";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:33:"/admin/structure/menu/item/%/edit";s:8:"numParts";i:6;}}', 6),
('entity.node.canonical', '/node/{node}', '/node/%', 2, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:12:"/node/{node}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:48:"\\Drupal\\node\\Controller\\NodeViewController::view";s:15:"_title_callback";s:49:"\\Drupal\\node\\Controller\\NodeViewController::title";}s:12:"requirements";a:2:{s:4:"node";s:3:"\\d+";s:14:"_entity_access";s:9:"node.view";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"node";a:2:{s:4:"type";s:11:"entity:node";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"node";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:26:"{^/node/(?P<node>\\d+)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"node";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:5:"/node";}}s:9:"path_vars";a:1:{i:0;s:4:"node";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:2;s:14:"patternOutline";s:7:"/node/%";s:8:"numParts";i:2;}}', 2),
('entity.node.delete_form', '/node/{node}/delete', '/node/%/delete', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:19:"/node/{node}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:11:"node.delete";s:6:"_title";s:6:"Delete";}s:12:"requirements";a:2:{s:4:"node";s:3:"\\d+";s:14:"_entity_access";s:11:"node.delete";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:21:"_node_operation_route";b:1;s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:4:"node";a:2:{s:4:"type";s:11:"entity:node";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"node";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:33:"{^/node/(?P<node>\\d+)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"node";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:5:"/node";}}s:9:"path_vars";a:1:{i:0;s:4:"node";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:14:"/node/%/delete";s:8:"numParts";i:3;}}', 3),
('entity.node.delete_multiple_form', '/admin/content/node/delete', '/admin/content/node/delete', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:26:"/admin/content/node/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:32:"\\Drupal\\node\\Form\\DeleteMultiple";s:14:"entity_type_id";s:4:"node";}s:12:"requirements";a:1:{s:30:"_entity_delete_multiple_access";s:4:"node";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:35:"access_check.entity_delete_multiple";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:33:"{^/admin/content/node/delete$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/content/node/delete";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:26:"/admin/content/node/delete";s:8:"numParts";i:4;}}', 4),
('entity.node.edit_form', '/node/{node}/edit', '/node/%/edit', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:17:"/node/{node}/edit";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:12:"_entity_form";s:9:"node.edit";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"node.update";s:4:"node";s:3:"\\d+";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:21:"_node_operation_route";b:1;s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:4:"node";a:2:{s:4:"type";s:11:"entity:node";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"node";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:31:"{^/node/(?P<node>\\d+)/edit$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/edit";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"node";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:5:"/node";}}s:9:"path_vars";a:1:{i:0;s:4:"node";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:12:"/node/%/edit";s:8:"numParts";i:3;}}', 3),
('entity.node.field_ui_fields', '/admin/structure/types/manage/{node_type}/fields', '/admin/structure/types/manage/%/fields', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:48:"/admin/structure/types/manage/{node_type}/fields";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:62:"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing";s:6:"_title";s:13:"Manage fields";s:14:"entity_type_id";s:4:"node";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer node fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"node_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:65:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/fields";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:1:{i:0;s:9:"node_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:38:"/admin/structure/types/manage/%/fields";s:8:"numParts";i:6;}}', 6),
('entity.node.preview', '/node/preview/{node_preview}/{view_mode_id}', '/node/preview/%/%', 12, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:43:"/node/preview/{node_preview}/{view_mode_id}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:51:"\\Drupal\\node\\Controller\\NodePreviewController::view";s:15:"_title_callback";s:52:"\\Drupal\\node\\Controller\\NodePreviewController::title";}s:12:"requirements";a:1:{s:20:"_node_preview_access";s:14:"{node_preview}";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:12:"node_preview";a:2:{s:4:"type";s:12:"node_preview";s:9:"converter";s:42:"drupal.proxy_original_service.node_preview";}}s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:25:"access_check.node.preview";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:12:"node_preview";i:1;s:12:"view_mode_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:70:"{^/node/preview/(?P<node_preview>[^/]++)/(?P<view_mode_id>[^/]++)$}sDu";s:11:"path_tokens";a:3:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"view_mode_id";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"node_preview";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:13:"/node/preview";}}s:9:"path_vars";a:2:{i:0;s:12:"node_preview";i:1;s:12:"view_mode_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:12;s:14:"patternOutline";s:17:"/node/preview/%/%";s:8:"numParts";i:4;}}', 4),
('entity.node.revision', '/node/{node}/revisions/{node_revision}/view', '/node/%/revisions/%/view', 21, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:43:"/node/{node}/revisions/{node_revision}/view";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:52:"\\Drupal\\node\\Controller\\NodeController::revisionShow";s:15:"_title_callback";s:57:"\\Drupal\\node\\Controller\\NodeController::revisionPageTitle";}s:12:"requirements";a:2:{s:14:"_entity_access";s:27:"node_revision.view revision";s:4:"node";s:3:"\\d+";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:2:{s:4:"node";a:2:{s:4:"type";s:11:"entity:node";s:9:"converter";s:21:"paramconverter.entity";}s:13:"node_revision";a:2:{s:4:"type";s:20:"entity_revision:node";s:9:"converter";s:30:"paramconverter.entity_revision";}}s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:4:"node";i:1;s:13:"node_revision";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:67:"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/view$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/view";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"node_revision";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:10:"/revisions";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"node";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:5:"/node";}}s:9:"path_vars";a:2:{i:0;s:4:"node";i:1;s:13:"node_revision";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:21;s:14:"patternOutline";s:24:"/node/%/revisions/%/view";s:8:"numParts";i:5;}}', 5),
('entity.node.version_history', '/node/{node}/revisions', '/node/%/revisions', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/node/{node}/revisions";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:9:"Revisions";s:11:"_controller";s:56:"\\Drupal\\node\\Controller\\NodeController::revisionOverview";}s:12:"requirements";a:2:{s:14:"_entity_access";s:23:"node.view all revisions";s:4:"node";s:3:"\\d+";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:21:"_node_operation_route";b:1;s:10:"parameters";a:1:{s:4:"node";a:2:{s:4:"type";s:11:"entity:node";s:9:"converter";s:21:"paramconverter.entity";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"node";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/node/(?P<node>\\d+)/revisions$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:10:"/revisions";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"node";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:5:"/node";}}s:9:"path_vars";a:1:{i:0;s:4:"node";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:17:"/node/%/revisions";s:8:"numParts";i:3;}}', 3),
('entity.node_type.collection', '/admin/structure/types', '/admin/structure/types', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/admin/structure/types";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:9:"node_type";s:6:"_title";s:13:"Content types";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer content types";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:29:"{^/admin/structure/types$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/types";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:22:"/admin/structure/types";s:8:"numParts";i:3;}}', 3),
('entity.node_type.delete_form', '/admin/structure/types/manage/{node_type}/delete', '/admin/structure/types/manage/%/delete', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:48:"/admin/structure/types/manage/{node_type}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:16:"node_type.delete";s:6:"_title";s:6:"Delete";}s:12:"requirements";a:1:{s:14:"_entity_access";s:16:"node_type.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"node_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:65:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:1:{i:0;s:9:"node_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:38:"/admin/structure/types/manage/%/delete";s:8:"numParts";i:6;}}', 6),
('entity.node_type.edit_form', '/admin/structure/types/manage/{node_type}', '/admin/structure/types/manage/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:41:"/admin/structure/types/manage/{node_type}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:14:"node_type.edit";s:15:"_title_callback";s:54:"\\Drupal\\Core\\Entity\\Controller\\EntityController::title";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer content types";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"node_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:58:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:1:{i:0;s:9:"node_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:31:"/admin/structure/types/manage/%";s:8:"numParts";i:5;}}', 5),
('entity.node_type.entity_permissions_form', '/admin/structure/types/manage/{node_type}/permissions', '/admin/structure/types/manage/%/permissions', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/admin/structure/types/manage/{node_type}/permissions";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:6:"_title";s:18:"Manage permissions";s:5:"_form";s:38:"Drupal\\user\\Form\\EntityPermissionsForm";s:14:"entity_type_id";s:4:"node";s:18:"bundle_entity_type";s:9:"node_type";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer permissions";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:9:"_field_ui";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:3:{s:4:"type";s:16:"entity:node_type";s:21:"with_config_overrides";b:1;s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"node_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:70:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/permissions$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/permissions";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:1:{i:0;s:9:"node_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:43:"/admin/structure/types/manage/%/permissions";s:8:"numParts";i:6;}}', 6),
('entity.path_alias.add_form', '/admin/config/search/path/add', '/admin/config/search/path/add', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:29:"/admin/config/search/path/add";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:12:"_entity_form";s:18:"path_alias.default";s:14:"entity_type_id";s:10:"path_alias";s:15:"_title_callback";s:56:"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:10:"path_alias";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/config/search/path/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/config/search/path/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:29:"/admin/config/search/path/add";s:8:"numParts";i:5;}}', 5),
('entity.path_alias.collection', '/admin/config/search/path', '/admin/config/search/path', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/admin/config/search/path";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_list";s:10:"path_alias";s:6:"_title";s:11:"URL aliases";s:16:"_title_arguments";a:0:{}s:14:"_title_context";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer url aliases";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/admin/config/search/path$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/config/search/path";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:25:"/admin/config/search/path";s:8:"numParts";i:4;}}', 4),
('entity.path_alias.delete_form', '/admin/config/search/path/delete/{path_alias}', '/admin/config/search/path/delete/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:45:"/admin/config/search/path/delete/{path_alias}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:17:"path_alias.delete";s:15:"_title_callback";s:60:"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle";}s:12:"requirements";a:2:{s:14:"_entity_access";s:17:"path_alias.delete";s:10:"path_alias";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:10:"path_alias";a:2:{s:4:"type";s:17:"entity:path_alias";s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:10:"path_alias";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:59:"{^/admin/config/search/path/delete/(?P<path_alias>\\d+)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:10:"path_alias";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/config/search/path/delete";}}s:9:"path_vars";a:1:{i:0;s:10:"path_alias";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:34:"/admin/config/search/path/delete/%";s:8:"numParts";i:6;}}', 6),
('entity.path_alias.edit_form', '/admin/config/search/path/edit/{path_alias}', '/admin/config/search/path/edit/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:43:"/admin/config/search/path/edit/{path_alias}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:18:"path_alias.default";s:15:"_title_callback";s:58:"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle";}s:12:"requirements";a:2:{s:14:"_entity_access";s:17:"path_alias.update";s:10:"path_alias";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:10:"path_alias";a:2:{s:4:"type";s:17:"entity:path_alias";s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:10:"path_alias";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:57:"{^/admin/config/search/path/edit/(?P<path_alias>\\d+)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:10:"path_alias";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:30:"/admin/config/search/path/edit";}}s:9:"path_vars";a:1:{i:0;s:10:"path_alias";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:32:"/admin/config/search/path/edit/%";s:8:"numParts";i:6;}}', 6),
('entity.search_page.collection', '/admin/config/search/pages', '/admin/config/search/pages', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:26:"/admin/config/search/pages";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:11:"search_page";s:6:"_title";s:12:"Search pages";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"administer search";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:33:"{^/admin/config/search/pages$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/config/search/pages";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:26:"/admin/config/search/pages";s:8:"numParts";i:4;}}', 4),
('entity.search_page.delete_form', '/admin/config/search/pages/manage/{search_page}/delete', '/admin/config/search/pages/manage/%/delete', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:54:"/admin/config/search/pages/manage/{search_page}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:18:"search_page.delete";s:6:"_title";s:6:"Delete";}s:12:"requirements";a:1:{s:14:"_entity_access";s:18:"search_page.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"search_page";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:11:"search_page";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:71:"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"search_page";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:33:"/admin/config/search/pages/manage";}}s:9:"path_vars";a:1:{i:0;s:11:"search_page";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:42:"/admin/config/search/pages/manage/%/delete";s:8:"numParts";i:7;}}', 7),
('entity.search_page.disable', '/admin/config/search/pages/manage/{search_page}/disable', '/admin/config/search/pages/manage/%/disable', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:55:"/admin/config/search/pages/manage/{search_page}/disable";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:60:"\\Drupal\\search\\Controller\\SearchController::performOperation";s:2:"op";s:7:"disable";}s:12:"requirements";a:2:{s:14:"_entity_access";s:19:"search_page.disable";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"search_page";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:11:"search_page";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:72:"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/disable$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/disable";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"search_page";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:33:"/admin/config/search/pages/manage";}}s:9:"path_vars";a:1:{i:0;s:11:"search_page";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:43:"/admin/config/search/pages/manage/%/disable";s:8:"numParts";i:7;}}', 7),
('entity.search_page.edit_form', '/admin/config/search/pages/manage/{search_page}', '/admin/config/search/pages/manage/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:47:"/admin/config/search/pages/manage/{search_page}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:16:"search_page.edit";s:15:"_title_callback";s:53:"\\Drupal\\search\\Controller\\SearchController::editTitle";}s:12:"requirements";a:1:{s:14:"_entity_access";s:18:"search_page.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"search_page";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:11:"search_page";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:64:"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"search_page";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:33:"/admin/config/search/pages/manage";}}s:9:"path_vars";a:1:{i:0;s:11:"search_page";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:35:"/admin/config/search/pages/manage/%";s:8:"numParts";i:6;}}', 6),
('entity.search_page.enable', '/admin/config/search/pages/manage/{search_page}/enable', '/admin/config/search/pages/manage/%/enable', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:54:"/admin/config/search/pages/manage/{search_page}/enable";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:60:"\\Drupal\\search\\Controller\\SearchController::performOperation";s:2:"op";s:6:"enable";}s:12:"requirements";a:2:{s:14:"_entity_access";s:18:"search_page.update";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"search_page";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:11:"search_page";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:71:"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/enable$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/enable";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"search_page";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:33:"/admin/config/search/pages/manage";}}s:9:"path_vars";a:1:{i:0;s:11:"search_page";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:42:"/admin/config/search/pages/manage/%/enable";s:8:"numParts";i:7;}}', 7),
('entity.search_page.set_default', '/admin/config/search/pages/manage/{search_page}/set-default', '/admin/config/search/pages/manage/%/set-default', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:59:"/admin/config/search/pages/manage/{search_page}/set-default";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:56:"\\Drupal\\search\\Controller\\SearchController::setAsDefault";}s:12:"requirements";a:2:{s:14:"_entity_access";s:18:"search_page.update";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"search_page";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:11:"search_page";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:77:"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/set\\-default$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/set-default";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"search_page";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:33:"/admin/config/search/pages/manage";}}s:9:"path_vars";a:1:{i:0;s:11:"search_page";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:47:"/admin/config/search/pages/manage/%/set-default";s:8:"numParts";i:7;}}', 7),
('entity.shortcut.canonical', '/admin/config/user-interface/shortcut/link/{shortcut}', '/admin/config/user-interface/shortcut/link/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/admin/config/user-interface/shortcut/link/{shortcut}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:16:"shortcut.default";s:6:"_title";s:4:"Edit";}s:12:"requirements";a:2:{s:14:"_entity_access";s:15:"shortcut.update";s:8:"shortcut";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:8:"shortcut";a:2:{s:4:"type";s:15:"entity:shortcut";s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:8:"shortcut";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:68:"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:8:"shortcut";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/config/user-interface/shortcut/link";}}s:9:"path_vars";a:1:{i:0;s:8:"shortcut";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:44:"/admin/config/user-interface/shortcut/link/%";s:8:"numParts";i:6;}}', 6),
('entity.shortcut.delete_form', '/admin/config/user-interface/shortcut/link/{shortcut}/delete', '/admin/config/user-interface/shortcut/link/%/delete', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:60:"/admin/config/user-interface/shortcut/link/{shortcut}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:15:"shortcut.delete";s:6:"_title";s:6:"Delete";}s:12:"requirements";a:2:{s:14:"_entity_access";s:15:"shortcut.delete";s:8:"shortcut";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:8:"shortcut";a:2:{s:4:"type";s:15:"entity:shortcut";s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:8:"shortcut";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:75:"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:8:"shortcut";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/config/user-interface/shortcut/link";}}s:9:"path_vars";a:1:{i:0;s:8:"shortcut";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:51:"/admin/config/user-interface/shortcut/link/%/delete";s:8:"numParts";i:7;}}', 7),
('entity.shortcut.edit_form', '/admin/config/user-interface/shortcut/link/{shortcut}', '/admin/config/user-interface/shortcut/link/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/admin/config/user-interface/shortcut/link/{shortcut}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:16:"shortcut.default";s:6:"_title";s:4:"Edit";}s:12:"requirements";a:2:{s:14:"_entity_access";s:15:"shortcut.update";s:8:"shortcut";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:8:"shortcut";a:2:{s:4:"type";s:15:"entity:shortcut";s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:8:"shortcut";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:68:"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:8:"shortcut";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/config/user-interface/shortcut/link";}}s:9:"path_vars";a:1:{i:0;s:8:"shortcut";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:44:"/admin/config/user-interface/shortcut/link/%";s:8:"numParts";i:6;}}', 6),
('entity.shortcut.link_delete_inline', '/admin/config/user-interface/shortcut/link/{shortcut}/delete-inline', '/admin/config/user-interface/shortcut/link/%/delete-inline', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:67:"/admin/config/user-interface/shortcut/link/{shortcut}/delete-inline";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:72:"\\Drupal\\shortcut\\Controller\\ShortcutController::deleteShortcutLinkInline";}s:12:"requirements";a:3:{s:14:"_entity_access";s:15:"shortcut.delete";s:11:"_csrf_token";s:4:"TRUE";s:8:"shortcut";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:8:"shortcut";a:2:{s:4:"type";s:15:"entity:shortcut";s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:8:"shortcut";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:83:"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/delete\\-inline$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:14:"/delete-inline";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:8:"shortcut";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/config/user-interface/shortcut/link";}}s:9:"path_vars";a:1:{i:0;s:8:"shortcut";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:58:"/admin/config/user-interface/shortcut/link/%/delete-inline";s:8:"numParts";i:7;}}', 7);
INSERT INTO `[[dbprefix]]router` VALUES
('entity.shortcut_set.collection', '/admin/config/user-interface/shortcut', '/admin/config/user-interface/shortcut', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:37:"/admin/config/user-interface/shortcut";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:12:"shortcut_set";s:6:"_title";s:9:"Shortcuts";}s:12:"requirements";a:1:{s:11:"_permission";s:20:"administer shortcuts";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:45:"{^/admin/config/user\\-interface/shortcut$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/config/user-interface/shortcut";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:37:"/admin/config/user-interface/shortcut";s:8:"numParts";i:4;}}', 4),
('entity.shortcut_set.customize_form', '/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize', '/admin/config/user-interface/shortcut/manage/%/customize', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:69:"/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:22:"shortcut_set.customize";s:6:"_title";s:10:"List links";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"shortcut_set.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"shortcut_set";a:2:{s:4:"type";s:19:"entity:shortcut_set";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"shortcut_set";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:87:"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/customize$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:10:"/customize";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"shortcut_set";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:44:"/admin/config/user-interface/shortcut/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"shortcut_set";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:56:"/admin/config/user-interface/shortcut/manage/%/customize";s:8:"numParts";i:7;}}', 7),
('entity.shortcut_set.delete_form', '/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete', '/admin/config/user-interface/shortcut/manage/%/delete', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:66:"/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:19:"shortcut_set.delete";s:6:"_title";s:19:"Delete shortcut set";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"shortcut_set.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"shortcut_set";a:2:{s:4:"type";s:19:"entity:shortcut_set";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"shortcut_set";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:84:"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"shortcut_set";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:44:"/admin/config/user-interface/shortcut/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"shortcut_set";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:53:"/admin/config/user-interface/shortcut/manage/%/delete";s:8:"numParts";i:7;}}', 7),
('entity.shortcut_set.edit_form', '/admin/config/user-interface/shortcut/manage/{shortcut_set}', '/admin/config/user-interface/shortcut/manage/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:59:"/admin/config/user-interface/shortcut/manage/{shortcut_set}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:17:"shortcut_set.edit";s:6:"_title";s:17:"Edit shortcut set";}s:12:"requirements";a:1:{s:14:"_entity_access";s:19:"shortcut_set.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"shortcut_set";a:2:{s:4:"type";s:19:"entity:shortcut_set";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"shortcut_set";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:77:"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"shortcut_set";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:44:"/admin/config/user-interface/shortcut/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"shortcut_set";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:46:"/admin/config/user-interface/shortcut/manage/%";s:8:"numParts";i:6;}}', 6),
('entity.taxonomy_term.add_form', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/add', '/admin/structure/taxonomy/manage/%/add', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:58:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:55:"\\Drupal\\taxonomy\\Controller\\TaxonomyController::addForm";s:6:"_title";s:8:"Add term";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:35:"taxonomy_term:{taxonomy_vocabulary}";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:75:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/add$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:4:"/add";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:38:"/admin/structure/taxonomy/manage/%/add";s:8:"numParts";i:6;}}', 6),
('entity.taxonomy_term.canonical', '/taxonomy/term/{taxonomy_term}', '/taxonomy/term/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:30:"/taxonomy/term/{taxonomy_term}";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:57:"\\Drupal\\taxonomy\\Controller\\TaxonomyController::termTitle";s:7:"view_id";s:13:"taxonomy_term";s:10:"display_id";s:6:"page_1";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:14:"access content";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:1:{s:5:"arg_0";s:13:"taxonomy_term";}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"taxonomy_term";a:2:{s:4:"type";s:20:"entity:taxonomy_term";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"taxonomy_term";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:47:"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"taxonomy_term";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:14:"/taxonomy/term";}}s:9:"path_vars";a:1:{i:0;s:13:"taxonomy_term";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:16:"/taxonomy/term/%";s:8:"numParts";i:3;}}', 3),
('entity.taxonomy_term.delete_form', '/taxonomy/term/{taxonomy_term}/delete', '/taxonomy/term/%/delete', 13, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:37:"/taxonomy/term/{taxonomy_term}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:20:"taxonomy_term.delete";s:6:"_title";s:11:"Delete term";}s:12:"requirements";a:2:{s:14:"_entity_access";s:20:"taxonomy_term.delete";s:13:"taxonomy_term";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"taxonomy_term";a:2:{s:4:"type";s:20:"entity:taxonomy_term";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"taxonomy_term";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:51:"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:13:"taxonomy_term";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:14:"/taxonomy/term";}}s:9:"path_vars";a:1:{i:0;s:13:"taxonomy_term";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:13;s:14:"patternOutline";s:23:"/taxonomy/term/%/delete";s:8:"numParts";i:4;}}', 4),
('entity.taxonomy_term.edit_form', '/taxonomy/term/{taxonomy_term}/edit', '/taxonomy/term/%/edit', 13, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:35:"/taxonomy/term/{taxonomy_term}/edit";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:21:"taxonomy_term.default";s:6:"_title";s:9:"Edit term";}s:12:"requirements";a:2:{s:14:"_entity_access";s:20:"taxonomy_term.update";s:13:"taxonomy_term";s:3:"\\d+";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"taxonomy_term";a:2:{s:4:"type";s:20:"entity:taxonomy_term";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"taxonomy_term";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:49:"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/edit$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/edit";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:13:"taxonomy_term";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:14:"/taxonomy/term";}}s:9:"path_vars";a:1:{i:0;s:13:"taxonomy_term";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:13;s:14:"patternOutline";s:21:"/taxonomy/term/%/edit";s:8:"numParts";i:4;}}', 4),
('entity.taxonomy_term.field_ui_fields', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields', '/admin/structure/taxonomy/manage/%/overview/fields', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:70:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:62:"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing";s:6:"_title";s:13:"Manage fields";s:14:"entity_type_id";s:13:"taxonomy_term";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:31:"administer taxonomy_term fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:87:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:16:"/overview/fields";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:50:"/admin/structure/taxonomy/manage/%/overview/fields";s:8:"numParts";i:7;}}', 7),
('entity.taxonomy_term.revision', '/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view', '/taxonomy/term/%/revision/%/view', 53, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:69:"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:58:"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController";s:15:"_title_callback";s:65:"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController::title";}s:12:"requirements";a:1:{s:14:"_entity_access";s:36:"taxonomy_term_revision.view revision";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:2:{s:13:"taxonomy_term";a:2:{s:4:"type";s:20:"entity:taxonomy_term";s:9:"converter";s:21:"paramconverter.entity";}s:22:"taxonomy_term_revision";a:2:{s:4:"type";s:29:"entity_revision:taxonomy_term";s:9:"converter";s:30:"paramconverter.entity_revision";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:13:"taxonomy_term";i:1;s:22:"taxonomy_term_revision";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:96:"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/view$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/view";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:22:"taxonomy_term_revision";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:9:"/revision";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"taxonomy_term";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:14:"/taxonomy/term";}}s:9:"path_vars";a:2:{i:0;s:13:"taxonomy_term";i:1;s:22:"taxonomy_term_revision";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:53;s:14:"patternOutline";s:32:"/taxonomy/term/%/revision/%/view";s:8:"numParts";i:6;}}', 6),
('entity.taxonomy_term.revision_delete_form', '/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete', '/taxonomy/term/%/revision/%/delete', 53, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:71:"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:29:"taxonomy_term.revision-delete";s:6:"_title";s:15:"Delete revision";}s:12:"requirements";a:1:{s:14:"_entity_access";s:38:"taxonomy_term_revision.delete revision";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:2:{s:13:"taxonomy_term";a:2:{s:4:"type";s:20:"entity:taxonomy_term";s:9:"converter";s:21:"paramconverter.entity";}s:22:"taxonomy_term_revision";a:2:{s:4:"type";s:29:"entity_revision:taxonomy_term";s:9:"converter";s:30:"paramconverter.entity_revision";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:13:"taxonomy_term";i:1;s:22:"taxonomy_term_revision";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:98:"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/delete$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:22:"taxonomy_term_revision";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:9:"/revision";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"taxonomy_term";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:14:"/taxonomy/term";}}s:9:"path_vars";a:2:{i:0;s:13:"taxonomy_term";i:1;s:22:"taxonomy_term_revision";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:53;s:14:"patternOutline";s:34:"/taxonomy/term/%/revision/%/delete";s:8:"numParts";i:6;}}', 6),
('entity.taxonomy_term.revision_revert_form', '/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert', '/taxonomy/term/%/revision/%/revert', 53, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:71:"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:29:"taxonomy_term.revision-revert";s:6:"_title";s:15:"Revert revision";}s:12:"requirements";a:1:{s:14:"_entity_access";s:29:"taxonomy_term_revision.revert";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:2:{s:13:"taxonomy_term";a:2:{s:4:"type";s:20:"entity:taxonomy_term";s:9:"converter";s:21:"paramconverter.entity";}s:22:"taxonomy_term_revision";a:2:{s:4:"type";s:29:"entity_revision:taxonomy_term";s:9:"converter";s:30:"paramconverter.entity_revision";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:13:"taxonomy_term";i:1;s:22:"taxonomy_term_revision";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:98:"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/revert$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/revert";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:22:"taxonomy_term_revision";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:9:"/revision";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"taxonomy_term";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:14:"/taxonomy/term";}}s:9:"path_vars";a:2:{i:0;s:13:"taxonomy_term";i:1;s:22:"taxonomy_term_revision";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:53;s:14:"patternOutline";s:34:"/taxonomy/term/%/revision/%/revert";s:8:"numParts";i:6;}}', 6),
('entity.taxonomy_term.version_history', '/taxonomy/term/{taxonomy_term}/revisions', '/taxonomy/term/%/revisions', 13, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:40:"/taxonomy/term/{taxonomy_term}/revisions";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:54:"Drupal\\Core\\Entity\\Controller\\VersionHistoryController";s:6:"_title";s:9:"Revisions";}s:12:"requirements";a:1:{s:14:"_entity_access";s:32:"taxonomy_term.view all revisions";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:14:"entity_type_id";s:13:"taxonomy_term";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:13:"taxonomy_term";a:2:{s:4:"type";s:20:"entity:taxonomy_term";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"taxonomy_term";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:57:"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revisions$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:10:"/revisions";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"taxonomy_term";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:14:"/taxonomy/term";}}s:9:"path_vars";a:1:{i:0;s:13:"taxonomy_term";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:13;s:14:"patternOutline";s:26:"/taxonomy/term/%/revisions";s:8:"numParts";i:4;}}', 4),
('entity.taxonomy_vocabulary.add_form', '/admin/structure/taxonomy/add', '/admin/structure/taxonomy/add', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:29:"/admin/structure/taxonomy/add";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:12:"_entity_form";s:27:"taxonomy_vocabulary.default";s:14:"entity_type_id";s:19:"taxonomy_vocabulary";s:15:"_title_callback";s:56:"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:19:"taxonomy_vocabulary";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/structure/taxonomy/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/taxonomy/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:29:"/admin/structure/taxonomy/add";s:8:"numParts";i:4;}}', 4),
('entity.taxonomy_vocabulary.collection', '/admin/structure/taxonomy', '/admin/structure/taxonomy', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/admin/structure/taxonomy";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:12:"_entity_list";s:19:"taxonomy_vocabulary";s:6:"_title";s:8:"Taxonomy";s:16:"_title_arguments";a:0:{}s:14:"_title_context";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:44:"administer taxonomy+access taxonomy overview";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/admin/structure/taxonomy$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/structure/taxonomy";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:25:"/admin/structure/taxonomy";s:8:"numParts";i:3;}}', 3),
('entity.taxonomy_vocabulary.delete_form', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete', '/admin/structure/taxonomy/manage/%/delete', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:61:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:26:"taxonomy_vocabulary.delete";s:15:"_title_callback";s:60:"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle";}s:12:"requirements";a:1:{s:14:"_entity_access";s:26:"taxonomy_vocabulary.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:78:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:41:"/admin/structure/taxonomy/manage/%/delete";s:8:"numParts";i:6;}}', 6),
('entity.taxonomy_vocabulary.edit_form', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}', '/admin/structure/taxonomy/manage/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:54:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:27:"taxonomy_vocabulary.default";s:15:"_title_callback";s:58:"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle";}s:12:"requirements";a:1:{s:14:"_entity_access";s:26:"taxonomy_vocabulary.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:71:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:34:"/admin/structure/taxonomy/manage/%";s:8:"numParts";i:5;}}', 5),
('entity.taxonomy_vocabulary.entity_permissions_form', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions', '/admin/structure/taxonomy/manage/%/overview/permissions', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:75:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:6:"_title";s:18:"Manage permissions";s:5:"_form";s:38:"Drupal\\user\\Form\\EntityPermissionsForm";s:14:"entity_type_id";s:13:"taxonomy_term";s:18:"bundle_entity_type";s:19:"taxonomy_vocabulary";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer permissions";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:9:"_field_ui";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:3:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:21:"with_config_overrides";b:1;s:9:"converter";s:21:"paramconverter.entity";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:92:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/permissions$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:21:"/overview/permissions";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:55:"/admin/structure/taxonomy/manage/%/overview/permissions";s:8:"numParts";i:7;}}', 7),
('entity.taxonomy_vocabulary.overview_form', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview', '/admin/structure/taxonomy/manage/%/overview', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:63:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:15:"_title_callback";s:54:"\\Drupal\\Core\\Entity\\Controller\\EntityController::title";s:5:"_form";s:34:"Drupal\\taxonomy\\Form\\OverviewTerms";}s:12:"requirements";a:1:{s:14:"_entity_access";s:44:"taxonomy_vocabulary.access taxonomy overview";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:3:{s:21:"with_config_overrides";b:1;s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:80:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:9:"/overview";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:43:"/admin/structure/taxonomy/manage/%/overview";s:8:"numParts";i:6;}}', 6),
('entity.taxonomy_vocabulary.reset_form', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset', '/admin/structure/taxonomy/manage/%/reset', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:60:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:25:"taxonomy_vocabulary.reset";s:6:"_title";s:5:"Reset";}s:12:"requirements";a:1:{s:14:"_entity_access";s:37:"taxonomy_vocabulary.reset all weights";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:3:{s:21:"with_config_overrides";b:1;s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:77:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/reset$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:6:"/reset";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:40:"/admin/structure/taxonomy/manage/%/reset";s:8:"numParts";i:6;}}', 6),
('entity.user.admin_form', '/admin/config/people/accounts', '/admin/config/people/accounts', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:29:"/admin/config/people/accounts";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:32:"\\Drupal\\user\\AccountSettingsForm";s:6:"_title";s:16:"Account settings";}s:12:"requirements";a:1:{s:11:"_permission";s:27:"administer account settings";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/config/people/accounts$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/config/people/accounts";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:29:"/admin/config/people/accounts";s:8:"numParts";i:4;}}', 4),
('entity.user.cancel_form', '/user/{user}/cancel', '/user/%/cancel', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:19:"/user/{user}/cancel";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:14:"Cancel account";s:12:"_entity_form";s:11:"user.cancel";}s:12:"requirements";a:2:{s:4:"user";s:3:"\\d+";s:14:"_entity_access";s:11:"user.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:4:"user";a:2:{s:4:"type";s:11:"entity:user";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"user";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:33:"{^/user/(?P<user>\\d+)/cancel$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/cancel";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"user";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:5:"/user";}}s:9:"path_vars";a:1:{i:0;s:4:"user";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:14:"/user/%/cancel";s:8:"numParts";i:3;}}', 3),
('entity.user.canonical', '/user/{user}', '/user/%', 2, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:12:"/user/{user}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_view";s:9:"user.full";s:15:"_title_callback";s:48:"Drupal\\user\\Controller\\UserController::userTitle";}s:12:"requirements";a:2:{s:4:"user";s:3:"\\d+";s:14:"_entity_access";s:9:"user.view";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"user";a:2:{s:4:"type";s:11:"entity:user";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"user";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:26:"{^/user/(?P<user>\\d+)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"user";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:5:"/user";}}s:9:"path_vars";a:1:{i:0;s:4:"user";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:2;s:14:"patternOutline";s:7:"/user/%";s:8:"numParts";i:2;}}', 2),
('entity.user.collection', '/admin/people', '/admin/people', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:13:"/admin/people";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:17:"user_admin_people";s:10:"display_id";s:6:"page_1";s:30:"_view_display_show_admin_links";b:0;}s:12:"requirements";a:2:{s:11:"_permission";s:16:"administer users";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:0;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:20:"{^/admin/people$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/admin/people";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:13:"/admin/people";s:8:"numParts";i:2;}}', 2),
('entity.user.contact_form', '/user/{user}/contact', '/user/%/contact', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/user/{user}/contact";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:7:"Contact";s:11:"_controller";s:65:"\\Drupal\\contact\\Controller\\ContactController::contactPersonalPage";}s:12:"requirements";a:2:{s:28:"_access_contact_personal_tab";s:4:"TRUE";s:4:"user";s:3:"\\d+";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"user";a:2:{s:4:"type";s:11:"entity:user";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:29:"access_check.contact_personal";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"user";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:34:"{^/user/(?P<user>\\d+)/contact$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/contact";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"user";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:5:"/user";}}s:9:"path_vars";a:1:{i:0;s:4:"user";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:15:"/user/%/contact";s:8:"numParts";i:3;}}', 3),
('entity.user.edit_form', '/user/{user}/edit', '/user/%/edit', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:17:"/user/{user}/edit";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:12:"user.default";s:15:"_title_callback";s:48:"Drupal\\user\\Controller\\UserController::userTitle";}s:12:"requirements";a:2:{s:4:"user";s:3:"\\d+";s:14:"_entity_access";s:11:"user.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:4:"user";a:2:{s:4:"type";s:11:"entity:user";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"user";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:31:"{^/user/(?P<user>\\d+)/edit$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/edit";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"user";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:5:"/user";}}s:9:"path_vars";a:1:{i:0;s:4:"user";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:12:"/user/%/edit";s:8:"numParts";i:3;}}', 3),
('entity.user.field_ui_fields', '/admin/config/people/accounts/fields', '/admin/config/people/accounts/fields', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:36:"/admin/config/people/accounts/fields";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:62:"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing";s:6:"_title";s:13:"Manage fields";s:14:"entity_type_id";s:4:"user";s:6:"bundle";s:4:"user";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer user fields";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:43:"{^/admin/config/people/accounts/fields$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:36:"/admin/config/people/accounts/fields";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:36:"/admin/config/people/accounts/fields";s:8:"numParts";i:5;}}', 5),
('entity.user_role.collection', '/admin/people/roles', '/admin/people/roles', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:19:"/admin/people/roles";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:9:"user_role";s:6:"_title";s:5:"Roles";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer permissions";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:26:"{^/admin/people/roles$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:19:"/admin/people/roles";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:19:"/admin/people/roles";s:8:"numParts";i:3;}}', 3),
('entity.user_role.delete_form', '/admin/people/roles/manage/{user_role}/delete', '/admin/people/roles/manage/%/delete', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:45:"/admin/people/roles/manage/{user_role}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:16:"user_role.delete";s:6:"_title";s:11:"Delete role";}s:12:"requirements";a:1:{s:14:"_entity_access";s:16:"user_role.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"user_role";a:2:{s:4:"type";s:16:"entity:user_role";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"user_role";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:62:"{^/admin/people/roles/manage/(?P<user_role>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"user_role";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/people/roles/manage";}}s:9:"path_vars";a:1:{i:0;s:9:"user_role";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:35:"/admin/people/roles/manage/%/delete";s:8:"numParts";i:6;}}', 6),
('entity.user_role.edit_form', '/admin/people/roles/manage/{user_role}', '/admin/people/roles/manage/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:38:"/admin/people/roles/manage/{user_role}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:17:"user_role.default";s:6:"_title";s:9:"Edit role";}s:12:"requirements";a:1:{s:14:"_entity_access";s:16:"user_role.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"user_role";a:2:{s:4:"type";s:16:"entity:user_role";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"user_role";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:55:"{^/admin/people/roles/manage/(?P<user_role>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"user_role";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/people/roles/manage";}}s:9:"path_vars";a:1:{i:0;s:9:"user_role";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:28:"/admin/people/roles/manage/%";s:8:"numParts";i:5;}}', 5),
('entity.user_role.edit_permissions_form', '/admin/people/permissions/{user_role}', '/admin/people/permissions/%', 14, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:37:"/admin/people/permissions/{user_role}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:49:"\\Drupal\\user\\Form\\UserPermissionsRoleSpecificForm";s:6:"_title";s:9:"Edit role";}s:12:"requirements";a:1:{s:14:"_entity_access";s:16:"user_role.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"user_role";a:2:{s:4:"type";s:16:"entity:user_role";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"user_role";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:54:"{^/admin/people/permissions/(?P<user_role>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"user_role";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/people/permissions";}}s:9:"path_vars";a:1:{i:0;s:9:"user_role";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:14;s:14:"patternOutline";s:27:"/admin/people/permissions/%";s:8:"numParts";i:4;}}', 4),
('entity.view.break_lock_form', '/admin/structure/views/view/{view}/break-lock', '/admin/structure/views/view/%/break-lock', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:45:"/admin/structure/views/view/{view}/break-lock";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:15:"view.break_lock";s:6:"_title";s:10:"Break lock";}s:12:"requirements";a:1:{s:14:"_entity_access";s:15:"view.break-lock";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"view";a:2:{s:4:"type";s:11:"entity:view";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"view";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:63:"{^/admin/structure/views/view/(?P<view>[^/]++)/break\\-lock$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:11:"/break-lock";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/structure/views/view";}}s:9:"path_vars";a:1:{i:0;s:4:"view";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:40:"/admin/structure/views/view/%/break-lock";s:8:"numParts";i:6;}}', 6),
('entity.view.collection', '/admin/structure/views', '/admin/structure/views', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/admin/structure/views";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:4:"view";s:6:"_title";s:5:"Views";}s:12:"requirements";a:1:{s:11:"_permission";s:16:"administer views";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:29:"{^/admin/structure/views$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:22:"/admin/structure/views";s:8:"numParts";i:3;}}', 3);
INSERT INTO `[[dbprefix]]router` VALUES
('entity.view.delete_form', '/admin/structure/views/view/{view}/delete', '/admin/structure/views/view/%/delete', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:41:"/admin/structure/views/view/{view}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:11:"view.delete";s:6:"_title";s:11:"Delete view";}s:12:"requirements";a:1:{s:14:"_entity_access";s:11:"view.delete";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"view";a:2:{s:4:"type";s:11:"entity:view";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"view";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:58:"{^/admin/structure/views/view/(?P<view>[^/]++)/delete$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/structure/views/view";}}s:9:"path_vars";a:1:{i:0;s:4:"view";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:36:"/admin/structure/views/view/%/delete";s:8:"numParts";i:6;}}', 6),
('entity.view.disable', '/admin/structure/views/view/{view}/disable', '/admin/structure/views/view/%/disable', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:42:"/admin/structure/views/view/{view}/disable";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:60:"\\Drupal\\views_ui\\Controller\\ViewsUIController::ajaxOperation";s:2:"op";s:7:"disable";}s:12:"requirements";a:2:{s:14:"_entity_access";s:12:"view.disable";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"view";a:2:{s:4:"type";s:11:"entity:view";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"view";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:59:"{^/admin/structure/views/view/(?P<view>[^/]++)/disable$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/disable";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/structure/views/view";}}s:9:"path_vars";a:1:{i:0;s:4:"view";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:37:"/admin/structure/views/view/%/disable";s:8:"numParts";i:6;}}', 6),
('entity.view.duplicate_form', '/admin/structure/views/view/{view}/duplicate', '/admin/structure/views/view/%/duplicate', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:44:"/admin/structure/views/view/{view}/duplicate";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:14:"view.duplicate";s:6:"_title";s:14:"Duplicate view";}s:12:"requirements";a:1:{s:14:"_entity_access";s:14:"view.duplicate";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"view";a:2:{s:4:"type";s:11:"entity:view";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"view";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:61:"{^/admin/structure/views/view/(?P<view>[^/]++)/duplicate$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:10:"/duplicate";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/structure/views/view";}}s:9:"path_vars";a:1:{i:0;s:4:"view";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:39:"/admin/structure/views/view/%/duplicate";s:8:"numParts";i:6;}}', 6),
('entity.view.edit_display_form', '/admin/structure/views/view/{view}/edit/{display_id}', '/admin/structure/views/view/%/edit', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:52:"/admin/structure/views/view/{view}/edit/{display_id}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:51:"\\Drupal\\views_ui\\Controller\\ViewsUIController::edit";s:10:"display_id";N;}s:12:"requirements";a:1:{s:14:"_entity_access";s:11:"view.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:4:"view";i:1;s:10:"display_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:84:"{^/admin/structure/views/view/(?P<view>[^/]++)/edit(?:/(?P<display_id>[^/]++))?$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:5:"/edit";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/structure/views/view";}}s:9:"path_vars";a:2:{i:0;s:4:"view";i:1;s:10:"display_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:34:"/admin/structure/views/view/%/edit";s:8:"numParts";i:7;}}', 7),
('entity.view.edit_form', '/admin/structure/views/view/{view}', '/admin/structure/views/view/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:34:"/admin/structure/views/view/{view}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:51:"\\Drupal\\views_ui\\Controller\\ViewsUIController::edit";}s:12:"requirements";a:1:{s:14:"_entity_access";s:11:"view.update";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"view";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:51:"{^/admin/structure/views/view/(?P<view>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/structure/views/view";}}s:9:"path_vars";a:1:{i:0;s:4:"view";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:29:"/admin/structure/views/view/%";s:8:"numParts";i:5;}}', 5),
('entity.view.enable', '/admin/structure/views/view/{view}/enable', '/admin/structure/views/view/%/enable', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:41:"/admin/structure/views/view/{view}/enable";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:60:"\\Drupal\\views_ui\\Controller\\ViewsUIController::ajaxOperation";s:2:"op";s:6:"enable";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.enable";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"view";a:2:{s:4:"type";s:11:"entity:view";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"view";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:58:"{^/admin/structure/views/view/(?P<view>[^/]++)/enable$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/enable";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/structure/views/view";}}s:9:"path_vars";a:1:{i:0;s:4:"view";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:36:"/admin/structure/views/view/%/enable";s:8:"numParts";i:6;}}', 6),
('entity.view.preview_form', '/admin/structure/views/view/{view}/preview/{display_id}', '/admin/structure/views/view/%/preview', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:55:"/admin/structure/views/view/{view}/preview/{display_id}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:12:"view.preview";s:10:"display_id";N;}s:12:"requirements";a:1:{s:11:"_permission";s:16:"administer views";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:4:"view";i:1;s:10:"display_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:87:"{^/admin/structure/views/view/(?P<view>[^/]++)/preview(?:/(?P<display_id>[^/]++))?$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:8:"/preview";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/structure/views/view";}}s:9:"path_vars";a:2:{i:0;s:4:"view";i:1;s:10:"display_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:37:"/admin/structure/views/view/%/preview";s:8:"numParts";i:7;}}', 7),
('field_ui.display_mode', '/admin/structure/display-modes', '/admin/structure/display-modes', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:30:"/admin/structure/display-modes";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:13:"Display modes";}s:12:"requirements";a:2:{s:11:"_permission";s:24:"administer display modes";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/admin/structure/display\\-modes$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:30:"/admin/structure/display-modes";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:30:"/admin/structure/display-modes";s:8:"numParts";i:3;}}', 3),
('field_ui.entity_form_mode_add', '/admin/structure/display-modes/form/add', '/admin/structure/display-modes/form/add', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:39:"/admin/structure/display-modes/form/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:78:"\\Drupal\\field_ui\\Controller\\EntityDisplayModeController::formModeTypeSelection";s:6:"_title";s:28:"Choose form mode entity type";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer display modes";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:47:"{^/admin/structure/display\\-modes/form/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/structure/display-modes/form/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:39:"/admin/structure/display-modes/form/add";s:8:"numParts";i:5;}}', 5),
('field_ui.entity_view_mode_add', '/admin/structure/display-modes/view/add', '/admin/structure/display-modes/view/add', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:39:"/admin/structure/display-modes/view/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:78:"\\Drupal\\field_ui\\Controller\\EntityDisplayModeController::viewModeTypeSelection";s:6:"_title";s:28:"Choose view mode entity type";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer display modes";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:47:"{^/admin/structure/display\\-modes/view/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/structure/display-modes/view/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:39:"/admin/structure/display-modes/view/add";s:8:"numParts";i:5;}}', 5),
('field_ui.field_add_block_content', '/admin/structure/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}', '/admin/structure/block-content/manage/%/add-field/%/%', 244, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:95:"/admin/structure/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:80:"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:13:"block_content";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:31:"administer block_content fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:18:"block_content_type";i:1;s:11:"entity_type";i:2;s:10:"field_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:134:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"field_name";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"entity_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:10:"/add-field";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:3:{i:0;s:18:"block_content_type";i:1;s:11:"entity_type";i:2;s:10:"field_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:244;s:14:"patternOutline";s:53:"/admin/structure/block-content/manage/%/add-field/%/%";s:8:"numParts";i:8;}}', 8),
('field_ui.field_add_comment', '/admin/structure/comment/manage/{comment_type}/add-field/{entity_type}/{field_name}', '/admin/structure/comment/manage/%/add-field/%/%', 244, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:83:"/admin/structure/comment/manage/{comment_type}/add-field/{entity_type}/{field_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:80:"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:7:"comment";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:25:"administer comment fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:12:"comment_type";i:1;s:11:"entity_type";i:2;s:10:"field_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:121:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"field_name";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"entity_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:10:"/add-field";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:3:{i:0;s:12:"comment_type";i:1;s:11:"entity_type";i:2;s:10:"field_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:244;s:14:"patternOutline";s:47:"/admin/structure/comment/manage/%/add-field/%/%";s:8:"numParts";i:8;}}', 8),
('field_ui.field_add_contact_message', '/admin/structure/contact/manage/{contact_form}/add-field/{entity_type}/{field_name}', '/admin/structure/contact/manage/%/add-field/%/%', 244, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:83:"/admin/structure/contact/manage/{contact_form}/add-field/{entity_type}/{field_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:80:"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:15:"contact_message";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:33:"administer contact_message fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:12:"contact_form";i:1;s:11:"entity_type";i:2;s:10:"field_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:121:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"field_name";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"entity_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:10:"/add-field";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:3:{i:0;s:12:"contact_form";i:1;s:11:"entity_type";i:2;s:10:"field_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:244;s:14:"patternOutline";s:47:"/admin/structure/contact/manage/%/add-field/%/%";s:8:"numParts";i:8;}}', 8),
('field_ui.field_add_node', '/admin/structure/types/manage/{node_type}/add-field/{entity_type}/{field_name}', '/admin/structure/types/manage/%/add-field/%/%', 244, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:78:"/admin/structure/types/manage/{node_type}/add-field/{entity_type}/{field_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:80:"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:4:"node";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer node fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:9:"node_type";i:1;s:11:"entity_type";i:2;s:10:"field_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:116:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"field_name";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"entity_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:10:"/add-field";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:3:{i:0;s:9:"node_type";i:1;s:11:"entity_type";i:2;s:10:"field_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:244;s:14:"patternOutline";s:45:"/admin/structure/types/manage/%/add-field/%/%";s:8:"numParts";i:8;}}', 8),
('field_ui.field_add_taxonomy_term', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/add-field/{entity_type}/{field_name}', '/admin/structure/taxonomy/manage/%/overview/add-field/%/%', 492, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:100:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/add-field/{entity_type}/{field_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:80:"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:13:"taxonomy_term";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:31:"administer taxonomy_term fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:19:"taxonomy_vocabulary";i:1;s:11:"entity_type";i:2;s:10:"field_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:138:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"field_name";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"entity_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:19:"/overview/add-field";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:3:{i:0;s:19:"taxonomy_vocabulary";i:1;s:11:"entity_type";i:2;s:10:"field_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:492;s:14:"patternOutline";s:57:"/admin/structure/taxonomy/manage/%/overview/add-field/%/%";s:8:"numParts";i:9;}}', 9),
('field_ui.field_add_user', '/admin/config/people/accounts/add-field/{entity_type}/{field_name}', '/admin/config/people/accounts/add-field/%/%', 124, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:66:"/admin/config/people/accounts/add-field/{entity_type}/{field_name}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:80:"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:4:"user";s:6:"bundle";s:4:"user";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer user fields";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:11:"entity_type";i:1;s:10:"field_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:94:"{^/admin/config/people/accounts/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu";s:11:"path_tokens";a:3:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"field_name";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"entity_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/config/people/accounts/add-field";}}s:9:"path_vars";a:2:{i:0;s:11:"entity_type";i:1;s:10:"field_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:124;s:14:"patternOutline";s:43:"/admin/config/people/accounts/add-field/%/%";s:8:"numParts";i:7;}}', 7),
('field_ui.field_storage_config_add_block_content', '/admin/structure/block-content/manage/{block_content_type}/fields/add-field', '/admin/structure/block-content/manage/%/fields/add-field', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:75:"/admin/structure/block-content/manage/{block_content_type}/fields/add-field";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:41:"\\Drupal\\field_ui\\Form\\FieldStorageAddForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:13:"block_content";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:31:"administer block_content fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:18:"block_content_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:94:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/add\\-field$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:17:"/fields/add-field";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:1:{i:0;s:18:"block_content_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:56:"/admin/structure/block-content/manage/%/fields/add-field";s:8:"numParts";i:7;}}', 7),
('field_ui.field_storage_config_add_comment', '/admin/structure/comment/manage/{comment_type}/fields/add-field', '/admin/structure/comment/manage/%/fields/add-field', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:63:"/admin/structure/comment/manage/{comment_type}/fields/add-field";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:41:"\\Drupal\\field_ui\\Form\\FieldStorageAddForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:7:"comment";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:25:"administer comment fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"comment_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:81:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/add\\-field$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:17:"/fields/add-field";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"comment_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:50:"/admin/structure/comment/manage/%/fields/add-field";s:8:"numParts";i:7;}}', 7),
('field_ui.field_storage_config_add_contact_message', '/admin/structure/contact/manage/{contact_form}/fields/add-field', '/admin/structure/contact/manage/%/fields/add-field', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:63:"/admin/structure/contact/manage/{contact_form}/fields/add-field";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:41:"\\Drupal\\field_ui\\Form\\FieldStorageAddForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:15:"contact_message";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:33:"administer contact_message fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"contact_form";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:81:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/add\\-field$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:17:"/fields/add-field";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"contact_form";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:50:"/admin/structure/contact/manage/%/fields/add-field";s:8:"numParts";i:7;}}', 7),
('field_ui.field_storage_config_add_node', '/admin/structure/types/manage/{node_type}/fields/add-field', '/admin/structure/types/manage/%/fields/add-field', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:58:"/admin/structure/types/manage/{node_type}/fields/add-field";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:41:"\\Drupal\\field_ui\\Form\\FieldStorageAddForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:4:"node";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer node fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"node_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:76:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/add\\-field$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:17:"/fields/add-field";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:1:{i:0;s:9:"node_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:48:"/admin/structure/types/manage/%/fields/add-field";s:8:"numParts";i:7;}}', 7),
('field_ui.field_storage_config_add_taxonomy_term', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/add-field', '/admin/structure/taxonomy/manage/%/overview/fields/add-field', 247, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:80:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/add-field";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:41:"\\Drupal\\field_ui\\Form\\FieldStorageAddForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:13:"taxonomy_term";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:11:"_permission";s:31:"administer taxonomy_term fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:98:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/add\\-field$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:26:"/overview/fields/add-field";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:247;s:14:"patternOutline";s:60:"/admin/structure/taxonomy/manage/%/overview/fields/add-field";s:8:"numParts";i:8;}}', 8),
('field_ui.field_storage_config_add_user', '/admin/config/people/accounts/fields/add-field', '/admin/config/people/accounts/fields/add-field', 63, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:46:"/admin/config/people/accounts/fields/add-field";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:41:"\\Drupal\\field_ui\\Form\\FieldStorageAddForm";s:6:"_title";s:9:"Add field";s:14:"entity_type_id";s:4:"user";s:6:"bundle";s:4:"user";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer user fields";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:54:"{^/admin/config/people/accounts/fields/add\\-field$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:46:"/admin/config/people/accounts/fields/add-field";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:63;s:14:"patternOutline";s:46:"/admin/config/people/accounts/fields/add-field";s:8:"numParts";i:6;}}', 6),
('field_ui.field_storage_config_reuse_block_content', '/admin/structure/block-content/manage/{block_content_type}/fields/reuse', '/admin/structure/block-content/manage/%/fields/reuse', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:71:"/admin/structure/block-content/manage/{block_content_type}/fields/reuse";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:43:"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm";s:6:"_title";s:24:"Re-use an existing field";s:14:"entity_type_id";s:13:"block_content";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:28:"_field_ui_field_reuse_access";s:31:"administer block_content fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:18:"block_content_type";a:2:{s:4:"type";s:25:"entity:block_content_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:33:"access_check.field_ui.field_reuse";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:18:"block_content_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:89:"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/reuse$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/fields/reuse";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:18:"block_content_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/structure/block-content/manage";}}s:9:"path_vars";a:1:{i:0;s:18:"block_content_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:52:"/admin/structure/block-content/manage/%/fields/reuse";s:8:"numParts";i:7;}}', 7),
('field_ui.field_storage_config_reuse_comment', '/admin/structure/comment/manage/{comment_type}/fields/reuse', '/admin/structure/comment/manage/%/fields/reuse', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:59:"/admin/structure/comment/manage/{comment_type}/fields/reuse";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:43:"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm";s:6:"_title";s:24:"Re-use an existing field";s:14:"entity_type_id";s:7:"comment";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:28:"_field_ui_field_reuse_access";s:25:"administer comment fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"comment_type";a:2:{s:4:"type";s:19:"entity:comment_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:33:"access_check.field_ui.field_reuse";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"comment_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:76:"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/reuse$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/fields/reuse";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"comment_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/comment/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"comment_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:46:"/admin/structure/comment/manage/%/fields/reuse";s:8:"numParts";i:7;}}', 7),
('field_ui.field_storage_config_reuse_contact_message', '/admin/structure/contact/manage/{contact_form}/fields/reuse', '/admin/structure/contact/manage/%/fields/reuse', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:59:"/admin/structure/contact/manage/{contact_form}/fields/reuse";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:43:"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm";s:6:"_title";s:24:"Re-use an existing field";s:14:"entity_type_id";s:15:"contact_message";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:28:"_field_ui_field_reuse_access";s:33:"administer contact_message fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"contact_form";a:2:{s:4:"type";s:19:"entity:contact_form";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:33:"access_check.field_ui.field_reuse";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"contact_form";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:76:"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/reuse$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/fields/reuse";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"contact_form";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/contact/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"contact_form";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:46:"/admin/structure/contact/manage/%/fields/reuse";s:8:"numParts";i:7;}}', 7),
('field_ui.field_storage_config_reuse_node', '/admin/structure/types/manage/{node_type}/fields/reuse', '/admin/structure/types/manage/%/fields/reuse', 123, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:54:"/admin/structure/types/manage/{node_type}/fields/reuse";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:43:"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm";s:6:"_title";s:24:"Re-use an existing field";s:14:"entity_type_id";s:4:"node";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:28:"_field_ui_field_reuse_access";s:22:"administer node fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:2:{s:4:"type";s:16:"entity:node_type";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:33:"access_check.field_ui.field_reuse";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"node_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:71:"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/reuse$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/fields/reuse";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/types/manage";}}s:9:"path_vars";a:1:{i:0;s:9:"node_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:123;s:14:"patternOutline";s:44:"/admin/structure/types/manage/%/fields/reuse";s:8:"numParts";i:7;}}', 7),
('field_ui.field_storage_config_reuse_taxonomy_term', '/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/reuse', '/admin/structure/taxonomy/manage/%/overview/fields/reuse', 247, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:76:"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/reuse";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:43:"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm";s:6:"_title";s:24:"Re-use an existing field";s:14:"entity_type_id";s:13:"taxonomy_term";s:6:"bundle";s:0:"";}s:12:"requirements";a:1:{s:28:"_field_ui_field_reuse_access";s:31:"administer taxonomy_term fields";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:10:"parameters";a:1:{s:19:"taxonomy_vocabulary";a:2:{s:4:"type";s:26:"entity:taxonomy_vocabulary";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:9:"_field_ui";b:1;s:14:"_access_checks";a:1:{i:0;s:33:"access_check.field_ui.field_reuse";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:93:"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/reuse$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/overview/fields/reuse";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:19:"taxonomy_vocabulary";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/structure/taxonomy/manage";}}s:9:"path_vars";a:1:{i:0;s:19:"taxonomy_vocabulary";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:247;s:14:"patternOutline";s:56:"/admin/structure/taxonomy/manage/%/overview/fields/reuse";s:8:"numParts";i:8;}}', 8),
('field_ui.field_storage_config_reuse_user', '/admin/config/people/accounts/fields/reuse', '/admin/config/people/accounts/fields/reuse', 63, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:42:"/admin/config/people/accounts/fields/reuse";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:5:"_form";s:43:"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm";s:6:"_title";s:24:"Re-use an existing field";s:14:"entity_type_id";s:4:"user";s:6:"bundle";s:4:"user";}s:12:"requirements";a:1:{s:28:"_field_ui_field_reuse_access";s:22:"administer user fields";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:9:"_field_ui";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:33:"access_check.field_ui.field_reuse";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:49:"{^/admin/config/people/accounts/fields/reuse$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:42:"/admin/config/people/accounts/fields/reuse";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:63;s:14:"patternOutline";s:42:"/admin/config/people/accounts/fields/reuse";s:8:"numParts";i:6;}}', 6),
('file.ajax_progress', '/file/progress/{key}', '/file/progress/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/file/progress/{key}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:58:"\\Drupal\\file\\Controller\\FileWidgetAjaxController::progress";}s:12:"requirements";a:1:{s:11:"_permission";s:14:"access content";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:3:"key";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:37:"{^/file/progress/(?P<key>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:3:"key";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:14:"/file/progress";}}s:9:"path_vars";a:1:{i:0;s:3:"key";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:16:"/file/progress/%";s:8:"numParts";i:3;}}', 3),
('filter.admin_overview', '/admin/config/content/formats', '/admin/config/content/formats', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:29:"/admin/config/content/formats";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_list";s:13:"filter_format";s:6:"_title";s:24:"Text formats and editors";}s:12:"requirements";a:1:{s:11:"_permission";s:18:"administer filters";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/config/content/formats$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/config/content/formats";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:29:"/admin/config/content/formats";s:8:"numParts";i:4;}}', 4);
INSERT INTO `[[dbprefix]]router` VALUES
('filter.format_add', '/admin/config/content/formats/add', '/admin/config/content/formats/add', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:33:"/admin/config/content/formats/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:17:"filter_format.add";s:6:"_title";s:15:"Add text format";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:13:"filter_format";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:40:"{^/admin/config/content/formats/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:33:"/admin/config/content/formats/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:33:"/admin/config/content/formats/add";s:8:"numParts";i:5;}}', 5),
('filter.tips', '/filter/tips/{filter_format}', '/filter/tips/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:28:"/filter/tips/{filter_format}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:54:"\\Drupal\\filter\\Controller\\FilterController::filterTips";s:6:"_title";s:12:"Compose tips";}s:12:"requirements";a:1:{s:14:"_entity_access";s:17:"filter_format.use";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"filter_format";a:2:{s:4:"type";s:20:"entity:filter_format";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:13:"filter_format";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:45:"{^/filter/tips/(?P<filter_format>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"filter_format";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:12:"/filter/tips";}}s:9:"path_vars";a:1:{i:0;s:13:"filter_format";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:14:"/filter/tips/%";s:8:"numParts";i:3;}}', 3),
('filter.tips_all', '/filter/tips', '/filter/tips', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:12:"/filter/tips";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:54:"\\Drupal\\filter\\Controller\\FilterController::filterTips";s:6:"_title";s:12:"Compose tips";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:13:"filter_format";a:2:{s:4:"type";s:20:"entity:filter_format";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:19:"{^/filter/tips$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/filter/tips";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:12:"/filter/tips";s:8:"numParts";i:2;}}', 2),
('help.help_topic', '/admin/help/topic/{id}', '/admin/help/topic/%', 14, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/admin/help/topic/{id}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:64:"\\Drupal\\help\\Controller\\HelpTopicPluginController::viewHelpTopic";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"access help pages";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:2:"id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:39:"{^/admin/help/topic/(?P<id>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:2:"id";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:17:"/admin/help/topic";}}s:9:"path_vars";a:1:{i:0;s:2:"id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:14;s:14:"patternOutline";s:19:"/admin/help/topic/%";s:8:"numParts";i:4;}}', 4),
('help.main', '/admin/help', '/admin/help', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:11:"/admin/help";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:48:"\\Drupal\\help\\Controller\\HelpController::helpMain";s:6:"_title";s:4:"Help";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"access help pages";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:18:"{^/admin/help$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:11:"/admin/help";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:11:"/admin/help";s:8:"numParts";i:2;}}', 2),
('help.page', '/admin/help/{name}', '/admin/help/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:18:"/admin/help/{name}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:48:"\\Drupal\\help\\Controller\\HelpController::helpPage";s:6:"_title";s:4:"Help";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"access help pages";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:35:"{^/admin/help/(?P<name>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:11:"/admin/help";}}s:9:"path_vars";a:1:{i:0;s:4:"name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:13:"/admin/help/%";s:8:"numParts";i:3;}}', 3),
('history.get_last_node_view', '/history/get_node_read_timestamps', '/history/get_node_read_timestamps', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:33:"/history/get_node_read_timestamps";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:67:"\\Drupal\\history\\Controller\\HistoryController::getNodeReadTimestamps";}s:12:"requirements";a:1:{s:11:"_permission";s:14:"access content";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:40:"{^/history/get_node_read_timestamps$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:33:"/history/get_node_read_timestamps";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:33:"/history/get_node_read_timestamps";s:8:"numParts";i:2;}}', 2),
('history.read_node', '/history/{node}/read', '/history/%/read', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/history/{node}/read";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:54:"\\Drupal\\history\\Controller\\HistoryController::readNode";}s:12:"requirements";a:2:{s:14:"_entity_access";s:9:"node.view";s:4:"node";s:3:"\\d+";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"node";a:2:{s:4:"type";s:11:"entity:node";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"node";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:34:"{^/history/(?P<node>\\d+)/read$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/read";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"node";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:8:"/history";}}s:9:"path_vars";a:1:{i:0;s:4:"node";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:15:"/history/%/read";s:8:"numParts";i:3;}}', 3),
('image.effect_add_form', '/admin/config/media/image-styles/manage/{image_style}/add/{image_effect}', '/admin/config/media/image-styles/manage/%/add/%', 250, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:72:"/admin/config/media/image-styles/manage/{image_style}/add/{image_effect}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:37:"\\Drupal\\image\\Form\\ImageEffectAddForm";s:6:"_title";s:16:"Add image effect";}s:12:"requirements";a:1:{s:11:"_permission";s:23:"administer image styles";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"image_style";a:2:{s:4:"type";s:18:"entity:image_style";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:11:"image_style";i:1;s:12:"image_effect";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:100:"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/add/(?P<image_effect>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"image_effect";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:4:"/add";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"image_style";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/config/media/image-styles/manage";}}s:9:"path_vars";a:2:{i:0;s:11:"image_style";i:1;s:12:"image_effect";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:250;s:14:"patternOutline";s:47:"/admin/config/media/image-styles/manage/%/add/%";s:8:"numParts";i:8;}}', 8),
('image.effect_delete', '/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}/delete', '/admin/config/media/image-styles/manage/%/effects/%/delete', 501, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:83:"/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:40:"\\Drupal\\image\\Form\\ImageEffectDeleteForm";s:6:"_title";s:19:"Delete image effect";}s:12:"requirements";a:1:{s:11:"_permission";s:23:"administer image styles";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"image_style";a:2:{s:4:"type";s:18:"entity:image_style";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:11:"image_style";i:1;s:12:"image_effect";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:111:"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/effects/(?P<image_effect>[^/]++)/delete$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"image_effect";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:8:"/effects";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"image_style";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/config/media/image-styles/manage";}}s:9:"path_vars";a:2:{i:0;s:11:"image_style";i:1;s:12:"image_effect";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:501;s:14:"patternOutline";s:58:"/admin/config/media/image-styles/manage/%/effects/%/delete";s:8:"numParts";i:9;}}', 9),
('image.effect_edit_form', '/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}', '/admin/config/media/image-styles/manage/%/effects/%', 250, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:76:"/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:38:"\\Drupal\\image\\Form\\ImageEffectEditForm";s:6:"_title";s:17:"Edit image effect";}s:12:"requirements";a:1:{s:11:"_permission";s:23:"administer image styles";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"image_style";a:2:{s:4:"type";s:18:"entity:image_style";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:11:"image_style";i:1;s:12:"image_effect";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:104:"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/effects/(?P<image_effect>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"image_effect";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:8:"/effects";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"image_style";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:39:"/admin/config/media/image-styles/manage";}}s:9:"path_vars";a:2:{i:0;s:11:"image_style";i:1;s:12:"image_effect";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:250;s:14:"patternOutline";s:51:"/admin/config/media/image-styles/manage/%/effects/%";s:8:"numParts";i:8;}}', 8),
('image.style_add', '/admin/config/media/image-styles/add', '/admin/config/media/image-styles/add', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:36:"/admin/config/media/image-styles/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:15:"image_style.add";s:6:"_title";s:15:"Add image style";}s:12:"requirements";a:1:{s:11:"_permission";s:23:"administer image styles";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:44:"{^/admin/config/media/image\\-styles/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:36:"/admin/config/media/image-styles/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:36:"/admin/config/media/image-styles/add";s:8:"numParts";i:5;}}', 5),
('image.style_private', '/system/files/styles/{image_style}/{scheme}', '/system/files/styles/%/%', 28, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:43:"/system/files/styles/{image_style}/{scheme}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:62:"\\Drupal\\image\\Controller\\ImageStyleDownloadController::deliver";s:26:"required_derivative_scheme";s:7:"private";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:11:"image_style";a:2:{s:4:"type";s:18:"entity:image_style";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:11:"image_style";i:1;s:6:"scheme";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:70:"{^/system/files/styles/(?P<image_style>[^/]++)/(?P<scheme>[^/]++)$}sDu";s:11:"path_tokens";a:3:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:6:"scheme";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"image_style";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:20:"/system/files/styles";}}s:9:"path_vars";a:2:{i:0;s:11:"image_style";i:1;s:6:"scheme";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:28;s:14:"patternOutline";s:24:"/system/files/styles/%/%";s:8:"numParts";i:5;}}', 5),
('image.style_public', '/sites/default/files/styles/{image_style}/{scheme}', '/sites/default/files/styles/%/%', 60, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:50:"/sites/default/files/styles/{image_style}/{scheme}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:61:"Drupal\\image\\Controller\\ImageStyleDownloadController::deliver";s:26:"required_derivative_scheme";s:6:"public";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:11:"image_style";a:2:{s:4:"type";s:18:"entity:image_style";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:11:"image_style";i:1;s:6:"scheme";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:77:"{^/sites/default/files/styles/(?P<image_style>[^/]++)/(?P<scheme>[^/]++)$}sDu";s:11:"path_tokens";a:3:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:6:"scheme";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"image_style";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:27:"/sites/default/files/styles";}}s:9:"path_vars";a:2:{i:0;s:11:"image_style";i:1;s:6:"scheme";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:60;s:14:"patternOutline";s:31:"/sites/default/files/styles/%/%";s:8:"numParts";i:6;}}', 6),
('menu_ui.link_edit', '/admin/structure/menu/link/{menu_link_plugin}/edit', '/admin/structure/menu/link/%/edit', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:50:"/admin/structure/menu/link/{menu_link_plugin}/edit";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:37:"\\Drupal\\menu_ui\\Form\\MenuLinkEditForm";s:6:"_title";s:14:"Edit menu link";}s:12:"requirements";a:1:{s:11:"_permission";s:15:"administer menu";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:16:"menu_link_plugin";a:2:{s:4:"type";s:16:"menu_link_plugin";s:9:"converter";s:54:"drupal.proxy_original_service.paramconverter.menu_link";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:16:"menu_link_plugin";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:67:"{^/admin/structure/menu/link/(?P<menu_link_plugin>[^/]++)/edit$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/edit";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:16:"menu_link_plugin";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/structure/menu/link";}}s:9:"path_vars";a:1:{i:0;s:16:"menu_link_plugin";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:33:"/admin/structure/menu/link/%/edit";s:8:"numParts";i:6;}}', 6),
('menu_ui.link_reset', '/admin/structure/menu/link/{menu_link_plugin}/reset', '/admin/structure/menu/link/%/reset', 61, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:51:"/admin/structure/menu/link/{menu_link_plugin}/reset";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:38:"\\Drupal\\menu_ui\\Form\\MenuLinkResetForm";s:6:"_title";s:15:"Reset menu link";}s:12:"requirements";a:2:{s:11:"_permission";s:15:"administer menu";s:14:"_custom_access";s:56:"\\Drupal\\menu_ui\\Form\\MenuLinkResetForm::linkIsResettable";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:16:"menu_link_plugin";a:2:{s:4:"type";s:16:"menu_link_plugin";s:9:"converter";s:54:"drupal.proxy_original_service.paramconverter.menu_link";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:19:"access_check.custom";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:16:"menu_link_plugin";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:68:"{^/admin/structure/menu/link/(?P<menu_link_plugin>[^/]++)/reset$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:6:"/reset";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:16:"menu_link_plugin";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/structure/menu/link";}}s:9:"path_vars";a:1:{i:0;s:16:"menu_link_plugin";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:61;s:14:"patternOutline";s:34:"/admin/structure/menu/link/%/reset";s:8:"numParts";i:6;}}', 6),
('menu_ui.parent_options_js', '/admin/structure/menu/parents', '/admin/structure/menu/parents', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:29:"/admin/structure/menu/parents";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:59:"\\Drupal\\menu_ui\\Controller\\MenuController::getParentOptions";}s:12:"requirements";a:1:{s:11:"_permission";s:15:"administer menu";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/structure/menu/parents$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/structure/menu/parents";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:29:"/admin/structure/menu/parents";s:8:"numParts";i:4;}}', 4),
('node.add', '/node/add/{node_type}', '/node/add/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:21:"/node/add/{node_type}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:12:"node.default";s:15:"_title_callback";s:52:"\\Drupal\\node\\Controller\\NodeController::addPageTitle";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:16:"node:{node_type}";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:21:"_node_operation_route";b:1;s:10:"parameters";a:1:{s:9:"node_type";a:3:{s:4:"type";s:16:"entity:node_type";s:21:"with_config_overrides";b:1;s:9:"converter";s:21:"paramconverter.entity";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"node_type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/node/add/(?P<node_type>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"node_type";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:9:"/node/add";}}s:9:"path_vars";a:1:{i:0;s:9:"node_type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:11:"/node/add/%";s:8:"numParts";i:3;}}', 3),
('node.add_page', '/node/add', '/node/add', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:9:"/node/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:11:"Add content";s:11:"_controller";s:47:"\\Drupal\\node\\Controller\\NodeController::addPage";}s:12:"requirements";a:1:{s:25:"_entity_create_any_access";s:4:"node";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:21:"_node_operation_route";b:1;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:30:"access_check.entity_create_any";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:16:"{^/node/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:9:"/node/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:9:"/node/add";s:8:"numParts";i:2;}}', 2),
('node.configure_rebuild_confirm', '/admin/reports/status/rebuild', '/admin/reports/status/rebuild', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:29:"/admin/reports/status/rebuild";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:5:"_form";s:40:"\\Drupal\\node\\Form\\RebuildPermissionsForm";}s:12:"requirements";a:1:{s:11:"_permission";s:16:"administer nodes";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/reports/status/rebuild$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/reports/status/rebuild";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:29:"/admin/reports/status/rebuild";s:8:"numParts";i:4;}}', 4),
('node.multiple_delete_confirm', '/admin/content/node/delete', '/admin/content/node/delete', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:26:"/admin/content/node/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:32:"\\Drupal\\node\\Form\\DeleteMultiple";s:14:"entity_type_id";s:4:"node";}s:12:"requirements";a:1:{s:30:"_entity_delete_multiple_access";s:4:"node";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:35:"access_check.entity_delete_multiple";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:33:"{^/admin/content/node/delete$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/content/node/delete";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:26:"/admin/content/node/delete";s:8:"numParts";i:4;}}', 4),
('node.revision_delete_confirm', '/node/{node}/revisions/{node_revision}/delete', '/node/%/revisions/%/delete', 21, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:45:"/node/{node}/revisions/{node_revision}/delete";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:40:"\\Drupal\\node\\Form\\NodeRevisionDeleteForm";s:6:"_title";s:23:"Delete earlier revision";}s:12:"requirements";a:2:{s:14:"_entity_access";s:29:"node_revision.delete revision";s:4:"node";s:3:"\\d+";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:21:"_node_operation_route";b:1;s:10:"parameters";a:2:{s:4:"node";a:2:{s:4:"type";s:11:"entity:node";s:9:"converter";s:21:"paramconverter.entity";}s:13:"node_revision";a:2:{s:4:"type";s:20:"entity_revision:node";s:9:"converter";s:30:"paramconverter.entity_revision";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:4:"node";i:1;s:13:"node_revision";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:69:"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/delete$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/delete";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"node_revision";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:10:"/revisions";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"node";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:5:"/node";}}s:9:"path_vars";a:2:{i:0;s:4:"node";i:1;s:13:"node_revision";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:21;s:14:"patternOutline";s:26:"/node/%/revisions/%/delete";s:8:"numParts";i:5;}}', 5),
('node.revision_revert_confirm', '/node/{node}/revisions/{node_revision}/revert', '/node/%/revisions/%/revert', 21, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:45:"/node/{node}/revisions/{node_revision}/revert";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:40:"\\Drupal\\node\\Form\\NodeRevisionRevertForm";s:6:"_title";s:26:"Revert to earlier revision";}s:12:"requirements";a:2:{s:14:"_entity_access";s:29:"node_revision.revert revision";s:4:"node";s:3:"\\d+";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:21:"_node_operation_route";b:1;s:10:"parameters";a:2:{s:4:"node";a:2:{s:4:"type";s:11:"entity:node";s:9:"converter";s:21:"paramconverter.entity";}s:13:"node_revision";a:2:{s:4:"type";s:20:"entity_revision:node";s:9:"converter";s:30:"paramconverter.entity_revision";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:2:{i:0;s:4:"node";i:1;s:13:"node_revision";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:69:"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/revert$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/revert";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"node_revision";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:10:"/revisions";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"node";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:5:"/node";}}s:9:"path_vars";a:2:{i:0;s:4:"node";i:1;s:13:"node_revision";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:21;s:14:"patternOutline";s:26:"/node/%/revisions/%/revert";s:8:"numParts";i:5;}}', 5),
('node.revision_revert_translation_confirm', '/node/{node}/revisions/{node_revision}/revert/{langcode}', '/node/%/revisions/%/revert/%', 42, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:56:"/node/{node}/revisions/{node_revision}/revert/{langcode}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:51:"\\Drupal\\node\\Form\\NodeRevisionRevertTranslationForm";s:6:"_title";s:43:"Revert to earlier revision of a translation";}s:12:"requirements";a:2:{s:14:"_entity_access";s:29:"node_revision.revert revision";s:4:"node";s:3:"\\d+";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:21:"_node_operation_route";b:1;s:10:"parameters";a:2:{s:4:"node";a:2:{s:4:"type";s:11:"entity:node";s:9:"converter";s:21:"paramconverter.entity";}s:13:"node_revision";a:2:{s:4:"type";s:20:"entity_revision:node";s:9:"converter";s:30:"paramconverter.entity_revision";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:4:"node";i:1;s:13:"node_revision";i:2;s:8:"langcode";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:90:"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/revert/(?P<langcode>[^/]++)$}sDu";s:11:"path_tokens";a:6:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:8:"langcode";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:7:"/revert";}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:13:"node_revision";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:10:"/revisions";}i:4;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"node";i:4;b:1;}i:5;a:2:{i:0;s:4:"text";i:1;s:5:"/node";}}s:9:"path_vars";a:3:{i:0;s:4:"node";i:1;s:13:"node_revision";i:2;s:8:"langcode";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:42;s:14:"patternOutline";s:28:"/node/%/revisions/%/revert/%";s:8:"numParts";i:6;}}', 6),
('node.type_add', '/admin/structure/types/add', '/admin/structure/types/add', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:26:"/admin/structure/types/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:13:"node_type.add";s:6:"_title";s:16:"Add content type";}s:12:"requirements";a:1:{s:11:"_permission";s:24:"administer content types";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:33:"{^/admin/structure/types/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/structure/types/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:26:"/admin/structure/types/add";s:8:"numParts";i:4;}}', 4),
('search.add_type', '/admin/config/search/pages/add/{search_plugin_id}', '/admin/config/search/pages/add/%', 62, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:49:"/admin/config/search/pages/add/{search_plugin_id}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:15:"search_page.add";s:6:"_title";s:19:"Add new search page";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:11:"search_page";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:16:"search_plugin_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:66:"{^/admin/config/search/pages/add/(?P<search_plugin_id>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:16:"search_plugin_id";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:30:"/admin/config/search/pages/add";}}s:9:"path_vars";a:1:{i:0;s:16:"search_plugin_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:62;s:14:"patternOutline";s:32:"/admin/config/search/pages/add/%";s:8:"numParts";i:6;}}', 6),
('search.help_help_search', '/search/help/help', '/search/help/help', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:17:"/search/help/help";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:53:"Drupal\\search\\Controller\\SearchController::searchHelp";s:6:"_title";s:15:"About searching";s:6:"entity";s:11:"help_search";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"entity.view";s:11:"_permission";s:14:"search content";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:6:"entity";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:24:"{^/search/help/help$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:17:"/search/help/help";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:17:"/search/help/help";s:8:"numParts";i:3;}}', 3),
('search.help_node_search', '/search/node/help', '/search/node/help', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:17:"/search/node/help";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:53:"Drupal\\search\\Controller\\SearchController::searchHelp";s:6:"_title";s:15:"About searching";s:6:"entity";s:11:"node_search";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"entity.view";s:11:"_permission";s:14:"search content";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:6:"entity";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:24:"{^/search/node/help$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:17:"/search/node/help";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:17:"/search/node/help";s:8:"numParts";i:3;}}', 3),
('search.help_user_search', '/search/user/help', '/search/user/help', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:17:"/search/user/help";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:53:"Drupal\\search\\Controller\\SearchController::searchHelp";s:6:"_title";s:15:"About searching";s:6:"entity";s:11:"user_search";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"entity.view";s:11:"_permission";s:14:"search content";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:6:"entity";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:24:"{^/search/user/help$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:17:"/search/user/help";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:17:"/search/user/help";s:8:"numParts";i:3;}}', 3),
('search.reindex_confirm', '/admin/config/search/pages/reindex', '/admin/config/search/pages/reindex', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:34:"/admin/config/search/pages/reindex";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:34:"\\Drupal\\search\\Form\\ReindexConfirm";s:6:"_title";s:11:"Clear index";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"administer search";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:41:"{^/admin/config/search/pages/reindex$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:34:"/admin/config/search/pages/reindex";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:34:"/admin/config/search/pages/reindex";s:8:"numParts";i:5;}}', 5),
('search.view', '/search', '/search', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:7:"/search";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:61:"Drupal\\search\\Controller\\SearchController::redirectSearchPage";s:6:"_title";s:6:"Search";s:6:"entity";s:11:"node_search";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"entity.view";s:11:"_permission";s:14:"search content";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:6:"entity";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:14:"{^/search$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:7:"/search";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:7:"/search";s:8:"numParts";i:1;}}', 1),
('search.view_help_search', '/search/help', '/search/help', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:12:"/search/help";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:47:"Drupal\\search\\Controller\\SearchController::view";s:6:"_title";s:6:"Search";s:6:"entity";s:11:"help_search";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"entity.view";s:11:"_permission";s:14:"search content";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:6:"entity";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:19:"{^/search/help$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/search/help";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:12:"/search/help";s:8:"numParts";i:2;}}', 2),
('search.view_node_search', '/search/node', '/search/node', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:12:"/search/node";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:47:"Drupal\\search\\Controller\\SearchController::view";s:6:"_title";s:6:"Search";s:6:"entity";s:11:"node_search";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"entity.view";s:11:"_permission";s:14:"search content";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:6:"entity";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:19:"{^/search/node$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/search/node";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:12:"/search/node";s:8:"numParts";i:2;}}', 2),
('search.view_user_search', '/search/user', '/search/user', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:12:"/search/user";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:47:"Drupal\\search\\Controller\\SearchController::view";s:6:"_title";s:6:"Search";s:6:"entity";s:11:"user_search";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"entity.view";s:11:"_permission";s:14:"search content";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:6:"entity";a:2:{s:4:"type";s:18:"entity:search_page";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:23:"access_check.permission";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:19:"{^/search/user$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/search/user";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:12:"/search/user";s:8:"numParts";i:2;}}', 2),
('shortcut.link_add', '/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link', '/admin/config/user-interface/shortcut/manage/%/add-link', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:68:"/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:55:"\\Drupal\\shortcut\\Controller\\ShortcutController::addForm";s:6:"_title";s:8:"Add link";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:23:"shortcut:{shortcut_set}";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"shortcut_set";a:2:{s:4:"type";s:19:"entity:shortcut_set";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"shortcut_set";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:87:"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/add\\-link$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:9:"/add-link";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"shortcut_set";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:44:"/admin/config/user-interface/shortcut/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"shortcut_set";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:55:"/admin/config/user-interface/shortcut/manage/%/add-link";s:8:"numParts";i:7;}}', 7),
('shortcut.link_add_inline', '/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link-inline', '/admin/config/user-interface/shortcut/manage/%/add-link-inline', 125, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:75:"/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link-inline";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:72:"\\Drupal\\shortcut\\Controller\\ShortcutSetController::addShortcutLinkInline";}s:12:"requirements";a:2:{s:14:"_entity_access";s:19:"shortcut_set.update";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:12:"shortcut_set";a:2:{s:4:"type";s:19:"entity:shortcut_set";s:9:"converter";s:63:"drupal.proxy_original_service.paramconverter.configentity_admin";}}s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:19:"access_check.entity";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:12:"shortcut_set";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:95:"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/add\\-link\\-inline$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:16:"/add-link-inline";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:12:"shortcut_set";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:44:"/admin/config/user-interface/shortcut/manage";}}s:9:"path_vars";a:1:{i:0;s:12:"shortcut_set";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:125;s:14:"patternOutline";s:62:"/admin/config/user-interface/shortcut/manage/%/add-link-inline";s:8:"numParts";i:7;}}', 7);
INSERT INTO `[[dbprefix]]router` VALUES
('shortcut.set_add', '/admin/config/user-interface/shortcut/add-set', '/admin/config/user-interface/shortcut/add-set', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:45:"/admin/config/user-interface/shortcut/add-set";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:16:"shortcut_set.add";s:6:"_title";s:16:"Add shortcut set";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:12:"shortcut_set";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:54:"{^/admin/config/user\\-interface/shortcut/add\\-set$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:45:"/admin/config/user-interface/shortcut/add-set";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:45:"/admin/config/user-interface/shortcut/add-set";s:8:"numParts";i:5;}}', 5),
('shortcut.set_switch', '/user/{user}/shortcuts', '/user/%/shortcuts', 5, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/user/{user}/shortcuts";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:39:"\\Drupal\\shortcut\\Form\\SwitchShortcutSet";s:6:"_title";s:9:"Shortcuts";}s:12:"requirements";a:1:{s:14:"_custom_access";s:52:"\\Drupal\\shortcut\\Form\\SwitchShortcutSet::checkAccess";}s:7:"options";a:6:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"user";s:3:"\\d+";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"user";a:2:{s:4:"type";s:11:"entity:user";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.custom";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"user";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:39:"{^/user/(?P<user>[^/]++)/shortcuts$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:10:"/shortcuts";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"user";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:5:"/user";}}s:9:"path_vars";a:1:{i:0;s:4:"user";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:5;s:14:"patternOutline";s:17:"/user/%/shortcuts";s:8:"numParts";i:3;}}', 3),
('system.401', '/system/401', '/system/401', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:11:"/system/401";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:49:"\\Drupal\\system\\Controller\\Http4xxController:on401";s:6:"_title";s:12:"Unauthorized";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:18:"{^/system/401$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:11:"/system/401";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:11:"/system/401";s:8:"numParts";i:2;}}', 2),
('system.403', '/system/403', '/system/403', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:11:"/system/403";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:49:"\\Drupal\\system\\Controller\\Http4xxController:on403";s:6:"_title";s:13:"Access denied";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:18:"{^/system/403$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:11:"/system/403";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:11:"/system/403";s:8:"numParts";i:2;}}', 2),
('system.404', '/system/404', '/system/404', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:11:"/system/404";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:49:"\\Drupal\\system\\Controller\\Http4xxController:on404";s:6:"_title";s:14:"Page not found";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:18:"{^/system/404$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:11:"/system/404";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:11:"/system/404";s:8:"numParts";i:2;}}', 2),
('system.4xx', '/system/4xx', '/system/4xx', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:11:"/system/4xx";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:49:"\\Drupal\\system\\Controller\\Http4xxController:on4xx";s:6:"_title";s:12:"Client error";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:18:"{^/system/4xx$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:11:"/system/4xx";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:11:"/system/4xx";s:8:"numParts";i:2;}}', 2),
('system.admin', '/admin', '/admin', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:6:"/admin";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:14:"Administration";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:13:"{^/admin$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:6:"/admin";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:6:"/admin";s:8:"numParts";i:1;}}', 1),
('system.admin_compact_page', '/admin/compact/{mode}', '/admin/compact', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:21:"/admin/compact/{mode}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:55:"\\Drupal\\system\\Controller\\SystemController::compactPage";s:4:"mode";s:3:"off";}s:12:"requirements";a:1:{s:11:"_permission";s:27:"access administration pages";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"mode";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:43:"{^/admin/compact(?:/(?P<mode>[^/]++))?$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"mode";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:14:"/admin/compact";}}s:9:"path_vars";a:1:{i:0;s:4:"mode";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:14:"/admin/compact";s:8:"numParts";i:3;}}', 3),
('system.admin_config', '/admin/config', '/admin/config', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:13:"/admin/config";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:11:"_controller";s:52:"\\Drupal\\system\\Controller\\SystemController::overview";s:7:"link_id";s:19:"system.admin_config";s:6:"_title";s:13:"Configuration";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:27:"_access_admin_overview_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:32:"access_check.admin_overview_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:20:"{^/admin/config$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/admin/config";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:13:"/admin/config";s:8:"numParts";i:2;}}', 2),
('system.admin_config_content', '/admin/config/content', '/admin/config/content', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:21:"/admin/config/content";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:17:"Content authoring";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:28:"{^/admin/config/content$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:21:"/admin/config/content";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:21:"/admin/config/content";s:8:"numParts";i:3;}}', 3),
('system.admin_config_development', '/admin/config/development', '/admin/config/development', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/admin/config/development";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:11:"Development";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/admin/config/development$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/config/development";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:25:"/admin/config/development";s:8:"numParts";i:3;}}', 3),
('system.admin_config_media', '/admin/config/media', '/admin/config/media', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:19:"/admin/config/media";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:5:"Media";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:26:"{^/admin/config/media$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:19:"/admin/config/media";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:19:"/admin/config/media";s:8:"numParts";i:3;}}', 3),
('system.admin_config_regional', '/admin/config/regional', '/admin/config/regional', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/admin/config/regional";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:19:"Region and language";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:29:"{^/admin/config/regional$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/config/regional";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:22:"/admin/config/regional";s:8:"numParts";i:3;}}', 3),
('system.admin_config_search', '/admin/config/search', '/admin/config/search', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/admin/config/search";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:19:"Search and metadata";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/admin/config/search$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/config/search";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/admin/config/search";s:8:"numParts";i:3;}}', 3),
('system.admin_config_services', '/admin/config/services', '/admin/config/services', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/admin/config/services";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:12:"Web services";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:29:"{^/admin/config/services$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/config/services";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:22:"/admin/config/services";s:8:"numParts";i:3;}}', 3),
('system.admin_config_system', '/admin/config/system', '/admin/config/system', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/admin/config/system";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:6:"System";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/admin/config/system$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/config/system";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/admin/config/system";s:8:"numParts";i:3;}}', 3),
('system.admin_config_ui', '/admin/config/user-interface', '/admin/config/user-interface', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:28:"/admin/config/user-interface";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:14:"User interface";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/config/user\\-interface$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:28:"/admin/config/user-interface";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:28:"/admin/config/user-interface";s:8:"numParts";i:3;}}', 3),
('system.admin_config_workflow', '/admin/config/workflow', '/admin/config/workflow', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/admin/config/workflow";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:8:"Workflow";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:29:"{^/admin/config/workflow$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/config/workflow";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:22:"/admin/config/workflow";s:8:"numParts";i:3;}}', 3),
('system.admin_content', '/admin/content', '/admin/content', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:14:"/admin/content";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:7:"content";s:10:"display_id";s:6:"page_1";s:30:"_view_display_show_admin_links";b:0;}s:12:"requirements";a:2:{s:11:"_permission";s:23:"access content overview";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:0;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:0:{}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:21:"{^/admin/content$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:14:"/admin/content";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:14:"/admin/content";s:8:"numParts";i:2;}}', 2),
('system.admin_index', '/admin/index', '/admin/index', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:12:"/admin/index";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:48:"\\Drupal\\system\\Controller\\AdminController::index";s:6:"_title";s:14:"Administration";}s:12:"requirements";a:1:{s:11:"_permission";s:27:"access administration pages";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:19:"{^/admin/index$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/admin/index";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:12:"/admin/index";s:8:"numParts";i:2;}}', 2),
('system.admin_reports', '/admin/reports', '/admin/reports', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:14:"/admin/reports";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:7:"Reports";}s:12:"requirements";a:2:{s:11:"_permission";s:19:"access site reports";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:21:"{^/admin/reports$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:14:"/admin/reports";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:14:"/admin/reports";s:8:"numParts";i:2;}}', 2),
('system.admin_structure', '/admin/structure', '/admin/structure', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:16:"/admin/structure";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:9:"Structure";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:23:"{^/admin/structure$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:16:"/admin/structure";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:16:"/admin/structure";s:8:"numParts";i:2;}}', 2),
('system.batch_page.html', '/batch', '/batch', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:6:"/batch";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:52:"\\Drupal\\system\\Controller\\BatchController::batchPage";s:15:"_title_callback";s:57:"\\Drupal\\system\\Controller\\BatchController::batchPageTitle";}s:12:"requirements";a:2:{s:7:"_access";s:4:"TRUE";s:7:"_format";s:4:"html";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:12:"_no_big_pipe";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:13:"{^/batch$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:6:"/batch";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:6:"/batch";s:8:"numParts";i:1;}}', 1),
('system.batch_page.json', '/batch', '/batch', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:6:"/batch";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:52:"\\Drupal\\system\\Controller\\BatchController::batchPage";}s:12:"requirements";a:2:{s:7:"_access";s:4:"TRUE";s:7:"_format";s:4:"json";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:13:"{^/batch$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:6:"/batch";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:6:"/batch";s:8:"numParts";i:1;}}', 1),
('system.cron', '/cron/{key}', '/cron/%', 2, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:11:"/cron/{key}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:34:"\\Drupal\\system\\CronController::run";}s:12:"requirements";a:1:{s:19:"_access_system_cron";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:8:"no_cache";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:17:"access_check.cron";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:3:"key";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:28:"{^/cron/(?P<key>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:3:"key";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:5:"/cron";}}s:9:"path_vars";a:1:{i:0;s:3:"key";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:2;s:14:"patternOutline";s:7:"/cron/%";s:8:"numParts";i:2;}}', 2),
('system.cron_settings', '/admin/config/system/cron', '/admin/config/system/cron', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/admin/config/system/cron";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:28:"\\Drupal\\system\\Form\\CronForm";s:6:"_title";s:4:"Cron";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/admin/config/system/cron$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/config/system/cron";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:25:"/admin/config/system/cron";s:8:"numParts";i:4;}}', 4),
('system.csrftoken', '/session/token', '/session/token', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:14:"/session/token";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:56:"\\Drupal\\system\\Controller\\CsrfTokenController::csrfToken";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:21:"{^/session/token$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:14:"/session/token";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:14:"/session/token";s:8:"numParts";i:2;}}', 2),
('system.css_asset', '/sites/default/files/css/{file_name}', '/sites/default/files/css/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:36:"/sites/default/files/css/{file_name}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:52:"Drupal\\system\\Controller\\CssAssetController::deliver";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"file_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:53:"{^/sites/default/files/css/(?P<file_name>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"file_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:24:"/sites/default/files/css";}}s:9:"path_vars";a:1:{i:0;s:9:"file_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:26:"/sites/default/files/css/%";s:8:"numParts";i:5;}}', 5),
('system.date_format_add', '/admin/config/regional/date-time/formats/add', '/admin/config/regional/date-time/formats/add', 63, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:44:"/admin/config/regional/date-time/formats/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:15:"date_format.add";s:6:"_title";s:15:"Add date format";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:52:"{^/admin/config/regional/date\\-time/formats/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:44:"/admin/config/regional/date-time/formats/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:63;s:14:"patternOutline";s:44:"/admin/config/regional/date-time/formats/add";s:8:"numParts";i:6;}}', 6),
('system.db_update', '/update.php/{op}', '/update.php', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:16:"/update.php/{op}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:2:"op";s:4:"info";}s:12:"requirements";a:1:{s:21:"_access_system_update";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:19:"default_url_options";a:1:{s:15:"path_processing";b:0;}s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:22:"access_check.db_update";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:2:"op";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:39:"{^/update\\.php(?:/(?P<op>[^/]++))?$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:2:"op";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:11:"/update.php";}}s:9:"path_vars";a:1:{i:0;s:2:"op";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:11:"/update.php";s:8:"numParts";i:2;}}', 2),
('system.development_settings', '/admin/config/development/settings', '/admin/config/development/settings', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:34:"/admin/config/development/settings";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:43:"\\Drupal\\system\\Form\\DevelopmentSettingsForm";s:6:"_title";s:20:"Development settings";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:41:"{^/admin/config/development/settings$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:34:"/admin/config/development/settings";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:34:"/admin/config/development/settings";s:8:"numParts";i:4;}}', 4),
('system.entity_autocomplete', '/entity_reference_autocomplete/{target_type}/{selection_handler}/{selection_settings_key}', '/entity_reference_autocomplete/%/%/%', 8, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:89:"/entity_reference_autocomplete/{target_type}/{selection_handler}/{selection_settings_key}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:74:"\\Drupal\\system\\Controller\\EntityAutocompleteController::handleAutocomplete";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:11:"target_type";i:1;s:17:"selection_handler";i:2;s:22:"selection_settings_key";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:126:"{^/entity_reference_autocomplete/(?P<target_type>[^/]++)/(?P<selection_handler>[^/]++)/(?P<selection_settings_key>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:22:"selection_settings_key";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:17:"selection_handler";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"target_type";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:30:"/entity_reference_autocomplete";}}s:9:"path_vars";a:3:{i:0;s:11:"target_type";i:1;s:17:"selection_handler";i:2;s:22:"selection_settings_key";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:8;s:14:"patternOutline";s:36:"/entity_reference_autocomplete/%/%/%";s:8:"numParts";i:4;}}', 4),
('system.files', '/system/files/{scheme}', '/system/files', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/system/files/{scheme}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:47:"\\Drupal\\system\\FileDownloadController::download";s:6:"scheme";s:7:"private";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:6:"scheme";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:44:"{^/system/files(?:/(?P<scheme>[^/]++))?$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:6:"scheme";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:13:"/system/files";}}s:9:"path_vars";a:1:{i:0;s:6:"scheme";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:13:"/system/files";s:8:"numParts";i:3;}}', 3),
('system.file_system_settings', '/admin/config/media/file-system', '/admin/config/media/file-system', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:31:"/admin/config/media/file-system";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:34:"\\Drupal\\system\\Form\\FileSystemForm";s:6:"_title";s:11:"File system";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:39:"{^/admin/config/media/file\\-system$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/config/media/file-system";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:31:"/admin/config/media/file-system";s:8:"numParts";i:4;}}', 4),
('system.image_toolkit_settings', '/admin/config/media/image-toolkit', '/admin/config/media/image-toolkit', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:33:"/admin/config/media/image-toolkit";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:36:"\\Drupal\\system\\Form\\ImageToolkitForm";s:6:"_title";s:13:"Image toolkit";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:41:"{^/admin/config/media/image\\-toolkit$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:33:"/admin/config/media/image-toolkit";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:33:"/admin/config/media/image-toolkit";s:8:"numParts";i:4;}}', 4),
('system.js_asset', '/sites/default/files/js/{file_name}', '/sites/default/files/js/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:35:"/sites/default/files/js/{file_name}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:51:"Drupal\\system\\Controller\\JsAssetController::deliver";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}s:4:"utf8";b:1;}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:9:"file_name";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:52:"{^/sites/default/files/js/(?P<file_name>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"file_name";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:23:"/sites/default/files/js";}}s:9:"path_vars";a:1:{i:0;s:9:"file_name";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:25:"/sites/default/files/js/%";s:8:"numParts";i:5;}}', 5),
('system.linkset_settings', '/admin/config/services/linkset', '/admin/config/services/linkset', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:30:"/admin/config/services/linkset";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:21:"Menu Linkset Settings";s:5:"_form";s:42:"Drupal\\system\\Form\\MenuLinksetSettingsForm";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:37:"{^/admin/config/services/linkset$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:30:"/admin/config/services/linkset";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:30:"/admin/config/services/linkset";s:8:"numParts";i:4;}}', 4),
('system.logging_settings', '/admin/config/development/logging', '/admin/config/development/logging', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:33:"/admin/config/development/logging";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:31:"\\Drupal\\system\\Form\\LoggingForm";s:6:"_title";s:18:"Logging and errors";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:40:"{^/admin/config/development/logging$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:33:"/admin/config/development/logging";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:33:"/admin/config/development/logging";s:8:"numParts";i:4;}}', 4),
('system.modules_list', '/admin/modules', '/admin/modules', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:14:"/admin/modules";s:4:"host";s:0:"";s:8:"defaults";a:3:{s:6:"_title";s:6:"Extend";s:14:"_title_context";s:15:"With components";s:5:"_form";s:35:"\\Drupal\\system\\Form\\ModulesListForm";}s:12:"requirements";a:1:{s:11:"_permission";s:18:"administer modules";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_no_big_pipe";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:21:"{^/admin/modules$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:14:"/admin/modules";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:14:"/admin/modules";s:8:"numParts";i:2;}}', 2),
('system.modules_list_confirm', '/admin/modules/list/confirm', '/admin/modules/list/confirm', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:27:"/admin/modules/list/confirm";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:42:"\\Drupal\\system\\Form\\ModulesListConfirmForm";s:6:"_title";s:39:"Some required modules must be installed";}s:12:"requirements";a:1:{s:11:"_permission";s:18:"administer modules";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:34:"{^/admin/modules/list/confirm$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/modules/list/confirm";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:27:"/admin/modules/list/confirm";s:8:"numParts";i:4;}}', 4),
('system.modules_list_non_stable_confirm', '/admin/modules/list/confirm-non-stable', '/admin/modules/list/confirm-non-stable', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:38:"/admin/modules/list/confirm-non-stable";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:51:"\\Drupal\\system\\Form\\ModulesListNonStableConfirmForm";s:6:"_title";s:18:"Non-stable modules";}s:12:"requirements";a:1:{s:11:"_permission";s:18:"administer modules";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:47:"{^/admin/modules/list/confirm\\-non\\-stable$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:38:"/admin/modules/list/confirm-non-stable";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:38:"/admin/modules/list/confirm-non-stable";s:8:"numParts";i:4;}}', 4),
('system.modules_uninstall', '/admin/modules/uninstall', '/admin/modules/uninstall', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:24:"/admin/modules/uninstall";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:40:"\\Drupal\\system\\Form\\ModulesUninstallForm";s:6:"_title";s:9:"Uninstall";}s:12:"requirements";a:1:{s:11:"_permission";s:18:"administer modules";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:31:"{^/admin/modules/uninstall$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:24:"/admin/modules/uninstall";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:24:"/admin/modules/uninstall";s:8:"numParts";i:3;}}', 3);
INSERT INTO `[[dbprefix]]router` VALUES
('system.modules_uninstall_confirm', '/admin/modules/uninstall/confirm', '/admin/modules/uninstall/confirm', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:32:"/admin/modules/uninstall/confirm";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:47:"\\Drupal\\system\\Form\\ModulesUninstallConfirmForm";s:6:"_title";s:17:"Confirm uninstall";}s:12:"requirements";a:1:{s:11:"_permission";s:18:"administer modules";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:39:"{^/admin/modules/uninstall/confirm$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/modules/uninstall/confirm";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:32:"/admin/modules/uninstall/confirm";s:8:"numParts";i:4;}}', 4),
('system.performance_settings', '/admin/config/development/performance', '/admin/config/development/performance', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:37:"/admin/config/development/performance";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:54:"\\Drupal\\system\\Controller\\PerformanceController::build";s:6:"_title";s:11:"Performance";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:44:"{^/admin/config/development/performance$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/config/development/performance";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:37:"/admin/config/development/performance";s:8:"numParts";i:4;}}', 4),
('system.php', '/admin/reports/status/php', '/admin/reports/status/php', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/admin/reports/status/php";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:51:"\\Drupal\\system\\Controller\\SystemInfoController::php";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:12:"_admin_route";b:0;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/admin/reports/status/php$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/reports/status/php";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:25:"/admin/reports/status/php";s:8:"numParts";i:4;}}', 4),
('system.prepare_modules_entity_uninstall', '/admin/modules/uninstall/entity/{entity_type_id}', '/admin/modules/uninstall/entity/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:48:"/admin/modules/uninstall/entity/{entity_type_id}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:53:"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm";s:15:"_title_callback";s:64:"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm::formTitle";}s:12:"requirements";a:2:{s:11:"_permission";s:18:"administer modules";s:14:"_custom_access";s:66:"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm::checkAccess";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:19:"access_check.custom";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:14:"entity_type_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:65:"{^/admin/modules/uninstall/entity/(?P<entity_type_id>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:14:"entity_type_id";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/modules/uninstall/entity";}}s:9:"path_vars";a:1:{i:0;s:14:"entity_type_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:33:"/admin/modules/uninstall/entity/%";s:8:"numParts";i:5;}}', 5),
('system.private_file_download', '/system/files/{filepath}', '/system/files/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:24:"/system/files/{filepath}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:47:"\\Drupal\\system\\FileDownloadController::download";}s:12:"requirements";a:2:{s:8:"filepath";s:2:".+";s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:8:"filepath";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:37:"{^/system/files/(?P<filepath>.+)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:2:".+";i:3;s:8:"filepath";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:13:"/system/files";}}s:9:"path_vars";a:1:{i:0;s:8:"filepath";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:15:"/system/files/%";s:8:"numParts";i:3;}}', 3),
('system.regional_settings', '/admin/config/regional/settings', '/admin/config/regional/settings', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:31:"/admin/config/regional/settings";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:32:"\\Drupal\\system\\Form\\RegionalForm";s:6:"_title";s:17:"Regional settings";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/admin/config/regional/settings$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/config/regional/settings";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:31:"/admin/config/regional/settings";s:8:"numParts";i:4;}}', 4),
('system.rss_feeds_settings', '/admin/config/services/rss-publishing', '/admin/config/services/rss-publishing', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:37:"/admin/config/services/rss-publishing";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:32:"\\Drupal\\system\\Form\\RssFeedsForm";s:6:"_title";s:14:"RSS publishing";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:45:"{^/admin/config/services/rss\\-publishing$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/config/services/rss-publishing";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:37:"/admin/config/services/rss-publishing";s:8:"numParts";i:4;}}', 4),
('system.run_cron', '/admin/reports/status/run-cron', '/admin/reports/status/run-cron', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:30:"/admin/reports/status/run-cron";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:42:"\\Drupal\\system\\CronController::runManually";}s:12:"requirements";a:2:{s:11:"_permission";s:29:"administer site configuration";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:8:"no_cache";b:1;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/admin/reports/status/run\\-cron$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:30:"/admin/reports/status/run-cron";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:30:"/admin/reports/status/run-cron";s:8:"numParts";i:4;}}', 4),
('system.site_information_settings', '/admin/config/system/site-information', '/admin/config/system/site-information', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:37:"/admin/config/system/site-information";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:39:"\\Drupal\\system\\Form\\SiteInformationForm";s:6:"_title";s:19:"Basic site settings";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:45:"{^/admin/config/system/site\\-information$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/config/system/site-information";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:37:"/admin/config/system/site-information";s:8:"numParts";i:4;}}', 4),
('system.site_maintenance_mode', '/admin/config/development/maintenance', '/admin/config/development/maintenance', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:37:"/admin/config/development/maintenance";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:43:"\\Drupal\\system\\Form\\SiteMaintenanceModeForm";s:6:"_title";s:16:"Maintenance mode";}s:12:"requirements";a:1:{s:11:"_permission";s:57:"administer site configuration+administer software updates";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:44:"{^/admin/config/development/maintenance$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:37:"/admin/config/development/maintenance";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:37:"/admin/config/development/maintenance";s:8:"numParts";i:4;}}', 4),
('system.status', '/admin/reports/status', '/admin/reports/status', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:21:"/admin/reports/status";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:54:"\\Drupal\\system\\Controller\\SystemInfoController::status";s:6:"_title";s:13:"Status report";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:28:"{^/admin/reports/status$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:21:"/admin/reports/status";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:21:"/admin/reports/status";s:8:"numParts";i:3;}}', 3),
('system.temporary', '/system/temporary', '/system/temporary', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:17:"/system/temporary";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:47:"\\Drupal\\system\\FileDownloadController::download";s:6:"scheme";s:9:"temporary";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:24:"{^/system/temporary$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:17:"/system/temporary";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:17:"/system/temporary";s:8:"numParts";i:2;}}', 2),
('system.themes_page', '/admin/appearance', '/admin/appearance', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:17:"/admin/appearance";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:10:"Appearance";s:11:"_controller";s:54:"\\Drupal\\system\\Controller\\SystemController::themesPage";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"administer themes";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:24:"{^/admin/appearance$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:17:"/admin/appearance";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:17:"/admin/appearance";s:8:"numParts";i:2;}}', 2),
('system.theme_install', '/admin/appearance/install', '/admin/appearance/install', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/admin/appearance/install";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:50:"\\Drupal\\system\\Controller\\ThemeController::install";}s:12:"requirements";a:2:{s:11:"_permission";s:17:"administer themes";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/admin/appearance/install$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/appearance/install";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:25:"/admin/appearance/install";s:8:"numParts";i:3;}}', 3),
('system.theme_settings', '/admin/appearance/settings', '/admin/appearance/settings', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:26:"/admin/appearance/settings";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:37:"\\Drupal\\system\\Form\\ThemeSettingsForm";s:6:"_title";s:19:"Appearance settings";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"administer themes";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:33:"{^/admin/appearance/settings$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/appearance/settings";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:26:"/admin/appearance/settings";s:8:"numParts";i:3;}}', 3),
('system.theme_settings_theme', '/admin/appearance/settings/{theme}', '/admin/appearance/settings/%', 14, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:34:"/admin/appearance/settings/{theme}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:37:"\\Drupal\\system\\Form\\ThemeSettingsForm";s:15:"_title_callback";s:21:"theme_handler:getName";}s:12:"requirements";a:1:{s:11:"_permission";s:17:"administer themes";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"theme";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:51:"{^/admin/appearance/settings/(?P<theme>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"theme";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/appearance/settings";}}s:9:"path_vars";a:1:{i:0;s:5:"theme";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:14;s:14:"patternOutline";s:28:"/admin/appearance/settings/%";s:8:"numParts";i:4;}}', 4),
('system.theme_set_default', '/admin/appearance/default', '/admin/appearance/default', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/admin/appearance/default";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:20:"Set as default theme";s:11:"_controller";s:58:"\\Drupal\\system\\Controller\\ThemeController::setDefaultTheme";}s:12:"requirements";a:2:{s:11:"_permission";s:17:"administer themes";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/admin/appearance/default$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/appearance/default";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:25:"/admin/appearance/default";s:8:"numParts";i:3;}}', 3),
('system.theme_uninstall', '/admin/appearance/uninstall', '/admin/appearance/uninstall', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:27:"/admin/appearance/uninstall";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:52:"\\Drupal\\system\\Controller\\ThemeController::uninstall";}s:12:"requirements";a:2:{s:11:"_permission";s:17:"administer themes";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:34:"{^/admin/appearance/uninstall$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/appearance/uninstall";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:27:"/admin/appearance/uninstall";s:8:"numParts";i:3;}}', 3),
('system.timezone', '/system/timezone/{abbreviation}/{offset}/{is_daylight_saving_time}', '/system/timezone', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:66:"/system/timezone/{abbreviation}/{offset}/{is_daylight_saving_time}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:11:"_controller";s:57:"\\Drupal\\system\\Controller\\TimezoneController::getTimezone";s:12:"abbreviation";s:0:"";s:6:"offset";i:-1;s:23:"is_daylight_saving_time";N;}s:12:"requirements";a:4:{s:7:"_access";s:4:"TRUE";s:12:"abbreviation";s:14:"0|([A-Z]{3,5})";s:6:"offset";s:6:"\\-?\\d+";s:23:"is_daylight_saving_time";s:7:"\\-1|0|1";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:12:"abbreviation";i:1;s:6:"offset";i:2;s:23:"is_daylight_saving_time";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:129:"{^/system/timezone(?:/(?P<abbreviation>0|(?:[A-Z]{3,5}))(?:/(?P<offset>\\-?\\d+)(?:/(?P<is_daylight_saving_time>\\-1|0|1))?)?)?$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:7:"\\-1|0|1";i:3;s:23:"is_daylight_saving_time";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"\\-?\\d+";i:3;s:6:"offset";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:16:"0|(?:[A-Z]{3,5})";i:3;s:12:"abbreviation";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:16:"/system/timezone";}}s:9:"path_vars";a:3:{i:0;s:12:"abbreviation";i:1;s:6:"offset";i:2;s:23:"is_daylight_saving_time";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:16:"/system/timezone";s:8:"numParts";i:5;}}', 5),
('toolbar.subtrees', '/toolbar/subtrees/{hash}', '/toolbar/subtrees/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:24:"/toolbar/subtrees/{hash}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:58:"\\Drupal\\toolbar\\Controller\\ToolbarController::subtreesAjax";}s:12:"requirements";a:1:{s:14:"_custom_access";s:64:"\\Drupal\\toolbar\\Controller\\ToolbarController::checkSubTreeAccess";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.custom";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:4:"hash";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:41:"{^/toolbar/subtrees/(?P<hash>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"hash";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:17:"/toolbar/subtrees";}}s:9:"path_vars";a:1:{i:0;s:4:"hash";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:19:"/toolbar/subtrees/%";s:8:"numParts";i:3;}}', 3),
('update.confirmation_page', '/admin/update/ready', '/admin/update/ready', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:19:"/admin/update/ready";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:31:"\\Drupal\\update\\Form\\UpdateReady";s:6:"_title";s:15:"Ready to update";}s:12:"requirements";a:1:{s:11:"_permission";s:27:"administer software updates";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:26:"{^/admin/update/ready$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:19:"/admin/update/ready";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:19:"/admin/update/ready";s:8:"numParts";i:3;}}', 3),
('update.manual_status', '/admin/reports/updates/check', '/admin/reports/updates/check', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:28:"/admin/reports/updates/check";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:6:"_title";s:19:"Manual update check";s:11:"_controller";s:64:"\\Drupal\\update\\Controller\\UpdateController::updateStatusManually";}s:12:"requirements";a:2:{s:11:"_permission";s:29:"administer site configuration";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:35:"{^/admin/reports/updates/check$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:28:"/admin/reports/updates/check";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:28:"/admin/reports/updates/check";s:8:"numParts";i:4;}}', 4),
('update.module_update', '/admin/modules/update', '/admin/modules/update', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:21:"/admin/modules/update";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:39:"\\Drupal\\update\\Form\\UpdateManagerUpdate";s:6:"_title";s:6:"Update";}s:12:"requirements";a:1:{s:11:"_permission";s:27:"administer software updates";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:28:"{^/admin/modules/update$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:21:"/admin/modules/update";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:21:"/admin/modules/update";s:8:"numParts";i:3;}}', 3),
('update.report_update', '/admin/reports/updates/update', '/admin/reports/updates/update', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:29:"/admin/reports/updates/update";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:39:"\\Drupal\\update\\Form\\UpdateManagerUpdate";s:6:"_title";s:6:"Update";}s:12:"requirements";a:1:{s:11:"_permission";s:27:"administer software updates";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/reports/updates/update$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:29:"/admin/reports/updates/update";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:29:"/admin/reports/updates/update";s:8:"numParts";i:4;}}', 4),
('update.settings', '/admin/reports/updates/settings', '/admin/reports/updates/settings', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:31:"/admin/reports/updates/settings";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:33:"\\Drupal\\update\\UpdateSettingsForm";s:6:"_title";s:23:"Update Manager settings";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/admin/reports/updates/settings$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/reports/updates/settings";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:31:"/admin/reports/updates/settings";s:8:"numParts";i:4;}}', 4),
('update.status', '/admin/reports/updates', '/admin/reports/updates', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/admin/reports/updates";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:56:"\\Drupal\\update\\Controller\\UpdateController::updateStatus";s:6:"_title";s:17:"Available updates";}s:12:"requirements";a:1:{s:11:"_permission";s:29:"administer site configuration";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:29:"{^/admin/reports/updates$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/reports/updates";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:22:"/admin/reports/updates";s:8:"numParts";i:3;}}', 3),
('update.theme_update', '/admin/appearance/update', '/admin/appearance/update', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:24:"/admin/appearance/update";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:39:"\\Drupal\\update\\Form\\UpdateManagerUpdate";s:6:"_title";s:6:"Update";}s:12:"requirements";a:1:{s:11:"_permission";s:27:"administer software updates";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:31:"{^/admin/appearance/update$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:24:"/admin/appearance/update";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:24:"/admin/appearance/update";s:8:"numParts";i:3;}}', 3),
('user.admin_create', '/admin/people/create', '/admin/people/create', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/admin/people/create";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:13:"user.register";s:6:"_title";s:8:"Add user";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:4:"user";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/admin/people/create$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/people/create";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/admin/people/create";s:8:"numParts";i:3;}}', 3),
('user.admin_index', '/admin/config/people', '/admin/config/people', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/admin/config/people";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:68:"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage";s:6:"_title";s:6:"People";}s:12:"requirements";a:2:{s:11:"_permission";s:27:"access administration pages";s:29:"_access_admin_menu_block_page";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:34:"access_check.admin_menu_block_page";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/admin/config/people$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/config/people";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/admin/config/people";s:8:"numParts";i:3;}}', 3),
('user.admin_permissions', '/admin/people/permissions', '/admin/people/permissions', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:25:"/admin/people/permissions";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:37:"\\Drupal\\user\\Form\\UserPermissionsForm";s:6:"_title";s:11:"Permissions";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer permissions";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:32:"{^/admin/people/permissions$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:25:"/admin/people/permissions";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:25:"/admin/people/permissions";s:8:"numParts";i:3;}}', 3),
('user.admin_permissions.module', '/admin/people/permissions/module/{modules}', '/admin/people/permissions/module/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:42:"/admin/people/permissions/module/{modules}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:51:"\\Drupal\\user\\Form\\UserPermissionsModuleSpecificForm";s:6:"_title";s:18:"Module Permissions";}s:12:"requirements";a:3:{s:11:"_permission";s:22:"administer permissions";s:7:"modules";s:16:"[a-z][a-z0-9_,]*";s:14:"_custom_access";s:59:"\\Drupal\\user\\Form\\UserPermissionsModuleSpecificForm::access";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:2:{i:0;s:23:"access_check.permission";i:1;s:19:"access_check.custom";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:7:"modules";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:69:"{^/admin/people/permissions/module/(?P<modules>[a-z][a-z0-9_,]*)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:16:"[a-z][a-z0-9_,]*";i:3;s:7:"modules";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:32:"/admin/people/permissions/module";}}s:9:"path_vars";a:1:{i:0;s:7:"modules";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:34:"/admin/people/permissions/module/%";s:8:"numParts";i:5;}}', 5),
('user.cancel_confirm', '/user/{user}/cancel/confirm/{timestamp}/{hashed_pass}', '/user/%/cancel/confirm', 11, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:53:"/user/{user}/cancel/confirm/{timestamp}/{hashed_pass}";s:4:"host";s:0:"";s:8:"defaults";a:4:{s:6:"_title";s:28:"Confirm account cancellation";s:11:"_controller";s:53:"\\Drupal\\user\\Controller\\UserController::confirmCancel";s:9:"timestamp";i:0;s:11:"hashed_pass";s:0:"";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"user.delete";s:4:"user";s:3:"\\d+";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:10:"parameters";a:1:{s:4:"user";a:2:{s:4:"type";s:11:"entity:user";s:9:"converter";s:21:"paramconverter.entity";}}s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:4:"user";i:1;s:9:"timestamp";i:2;s:11:"hashed_pass";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:97:"{^/user/(?P<user>\\d+)/cancel/confirm(?:/(?P<timestamp>[^/]++)(?:/(?P<hashed_pass>[^/]++))?)?$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:11:"hashed_pass";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"timestamp";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:15:"/cancel/confirm";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:3:"\\d+";i:3;s:4:"user";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:5:"/user";}}s:9:"path_vars";a:3:{i:0;s:4:"user";i:1;s:9:"timestamp";i:2;s:11:"hashed_pass";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:11;s:14:"patternOutline";s:22:"/user/%/cancel/confirm";s:8:"numParts";i:6;}}', 6),
('user.edit', '/user/edit', '/user/edit', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:10:"/user/edit";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:52:"\\Drupal\\user\\Controller\\UserController::userEditPage";s:6:"_title";s:12:"Edit account";}s:12:"requirements";a:1:{s:18:"_user_is_logged_in";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:30:"access_check.user.login_status";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:17:"{^/user/edit$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:10:"/user/edit";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:10:"/user/edit";s:8:"numParts";i:2;}}', 2),
('user.login', '/user/login', '/user/login', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:11:"/user/login";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:31:"\\Drupal\\user\\Form\\UserLoginForm";s:6:"_title";s:6:"Log in";}s:12:"requirements";a:1:{s:18:"_user_is_logged_in";s:5:"FALSE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:19:"_maintenance_access";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:30:"access_check.user.login_status";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:18:"{^/user/login$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:11:"/user/login";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:11:"/user/login";s:8:"numParts";i:2;}}', 2),
('user.login.http', '/user/login', '/user/login', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:11:"/user/login";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:59:"\\Drupal\\user\\Controller\\UserAuthenticationController::login";}s:12:"requirements";a:2:{s:18:"_user_is_logged_in";s:5:"FALSE";s:7:"_format";s:4:"json";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:30:"access_check.user.login_status";}}s:7:"schemes";a:0:{}s:7:"methods";a:1:{i:0;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:18:"{^/user/login$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:11:"/user/login";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:11:"/user/login";s:8:"numParts";i:2;}}', 2),
('user.login_status.http', '/user/login_status', '/user/login_status', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:18:"/user/login_status";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:65:"\\Drupal\\user\\Controller\\UserAuthenticationController::loginStatus";}s:12:"requirements";a:2:{s:7:"_access";s:4:"TRUE";s:7:"_format";s:4:"json";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:1:{i:0;s:3:"GET";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:25:"{^/user/login_status$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:18:"/user/login_status";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:18:"/user/login_status";s:8:"numParts";i:2;}}', 2),
('user.logout', '/user/logout', '/user/logout', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:12:"/user/logout";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:46:"\\Drupal\\user\\Controller\\UserController::logout";}s:12:"requirements";a:2:{s:18:"_user_is_logged_in";s:4:"TRUE";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:24:"_csrf_confirm_form_route";s:19:"user.logout.confirm";s:4:"utf8";b:1;s:14:"_access_checks";a:2:{i:0;s:30:"access_check.user.login_status";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:19:"{^/user/logout$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/user/logout";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:12:"/user/logout";s:8:"numParts";i:2;}}', 2),
('user.logout.confirm', '/user/logout/confirm', '/user/logout/confirm', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/user/logout/confirm";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:5:"_form";s:35:"\\Drupal\\user\\Form\\UserLogoutConfirm";}s:12:"requirements";a:1:{s:18:"_user_is_logged_in";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:30:"access_check.user.login_status";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/user/logout/confirm$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/user/logout/confirm";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/user/logout/confirm";s:8:"numParts";i:3;}}', 3),
('user.logout.http', '/user/logout', '/user/logout', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:12:"/user/logout";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:60:"\\Drupal\\user\\Controller\\UserAuthenticationController::logout";}s:12:"requirements";a:3:{s:18:"_user_is_logged_in";s:4:"TRUE";s:7:"_format";s:4:"json";s:11:"_csrf_token";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:2:{i:0;s:30:"access_check.user.login_status";i:1;s:17:"access_check.csrf";}}s:7:"schemes";a:0:{}s:7:"methods";a:1:{i:0;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:19:"{^/user/logout$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:12:"/user/logout";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:12:"/user/logout";s:8:"numParts";i:2;}}', 2),
('user.multiple_cancel_confirm', '/admin/people/cancel', '/admin/people/cancel', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/admin/people/cancel";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:43:"\\Drupal\\user\\Form\\UserMultipleCancelConfirm";s:6:"_title";s:11:"Cancel user";}s:12:"requirements";a:1:{s:11:"_permission";s:16:"administer users";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/admin/people/cancel$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/people/cancel";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/admin/people/cancel";s:8:"numParts";i:3;}}', 3),
('user.page', '/user', '/user', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:5:"/user";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:48:"\\Drupal\\user\\Controller\\UserController::userPage";s:6:"_title";s:10:"My account";}s:12:"requirements";a:1:{s:18:"_user_is_logged_in";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:30:"access_check.user.login_status";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:12:"{^/user$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/user";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:5:"/user";s:8:"numParts";i:1;}}', 1),
('user.pass', '/user/password', '/user/password', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:14:"/user/password";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:34:"\\Drupal\\user\\Form\\UserPasswordForm";s:6:"_title";s:19:"Reset your password";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:19:"_maintenance_access";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:21:"{^/user/password$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:14:"/user/password";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:14:"/user/password";s:8:"numParts";i:2;}}', 2),
('user.pass.http', '/user/password', '/user/password', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:14:"/user/password";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:67:"\\Drupal\\user\\Controller\\UserAuthenticationController::resetPassword";}s:12:"requirements";a:2:{s:7:"_access";s:4:"TRUE";s:7:"_format";s:4:"json";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:1:{i:0;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:21:"{^/user/password$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:14:"/user/password";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:14:"/user/password";s:8:"numParts";i:2;}}', 2);
INSERT INTO `[[dbprefix]]router` VALUES
('user.register', '/user/register', '/user/register', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:14:"/user/register";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:13:"user.register";s:6:"_title";s:18:"Create new account";}s:12:"requirements";a:1:{s:21:"_access_user_register";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.user.register";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:21:"{^/user/register$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:14:"/user/register";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:14:"/user/register";s:8:"numParts";i:2;}}', 2),
('user.reset', '/user/reset/{uid}/{timestamp}/{hash}', '/user/reset/%/%/%', 24, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:36:"/user/reset/{uid}/{timestamp}/{hash}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:49:"\\Drupal\\user\\Controller\\UserController::resetPass";s:6:"_title";s:14:"Reset password";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:19:"_maintenance_access";b:1;s:8:"no_cache";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:3:"uid";i:1;s:9:"timestamp";i:2;s:4:"hash";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:73:"{^/user/reset/(?P<uid>[^/]++)/(?P<timestamp>[^/]++)/(?P<hash>[^/]++)$}sDu";s:11:"path_tokens";a:4:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"hash";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"timestamp";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:3:"uid";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:11:"/user/reset";}}s:9:"path_vars";a:3:{i:0;s:3:"uid";i:1;s:9:"timestamp";i:2;s:4:"hash";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:24;s:14:"patternOutline";s:17:"/user/reset/%/%/%";s:8:"numParts";i:5;}}', 5),
('user.reset.form', '/user/reset/{uid}', '/user/reset/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:17:"/user/reset/{uid}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:56:"\\Drupal\\user\\Controller\\UserController::getResetPassForm";s:6:"_title";s:14:"Reset password";}s:12:"requirements";a:1:{s:18:"_user_is_logged_in";s:5:"FALSE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:19:"_maintenance_access";b:1;s:8:"no_cache";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:30:"access_check.user.login_status";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:3:"uid";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:34:"{^/user/reset/(?P<uid>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:3:"uid";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:11:"/user/reset";}}s:9:"path_vars";a:1:{i:0;s:3:"uid";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:13:"/user/reset/%";s:8:"numParts";i:3;}}', 3),
('user.reset.login', '/user/reset/{uid}/{timestamp}/{hash}/login', '/user/reset/%/%/%/login', 49, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:42:"/user/reset/{uid}/{timestamp}/{hash}/login";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:54:"\\Drupal\\user\\Controller\\UserController::resetPassLogin";s:6:"_title";s:14:"Reset password";}s:12:"requirements";a:1:{s:18:"_user_is_logged_in";s:5:"FALSE";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:19:"_maintenance_access";b:1;s:8:"no_cache";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:30:"access_check.user.login_status";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:3:"uid";i:1;s:9:"timestamp";i:2;s:4:"hash";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:79:"{^/user/reset/(?P<uid>[^/]++)/(?P<timestamp>[^/]++)/(?P<hash>[^/]++)/login$}sDu";s:11:"path_tokens";a:5:{i:0;a:2:{i:0;s:4:"text";i:1;s:6:"/login";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"hash";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:9:"timestamp";i:4;b:1;}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:3:"uid";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:11:"/user/reset";}}s:9:"path_vars";a:3:{i:0;s:3:"uid";i:1;s:9:"timestamp";i:2;s:4:"hash";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:49;s:14:"patternOutline";s:23:"/user/reset/%/%/%/login";s:8:"numParts";i:6;}}', 6),
('user.role.settings', '/admin/people/role-settings', '/admin/people/role-settings', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:27:"/admin/people/role-settings";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:34:"\\Drupal\\user\\Form\\RoleSettingsForm";s:6:"_title";s:13:"Role settings";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer permissions";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:35:"{^/admin/people/role\\-settings$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:27:"/admin/people/role-settings";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:27:"/admin/people/role-settings";s:8:"numParts";i:3;}}', 3),
('user.role_add', '/admin/people/roles/add', '/admin/people/roles/add', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:23:"/admin/people/roles/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:17:"user_role.default";s:6:"_title";s:8:"Add role";}s:12:"requirements";a:1:{s:11:"_permission";s:22:"administer permissions";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:30:"{^/admin/people/roles/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:23:"/admin/people/roles/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:23:"/admin/people/roles/add";s:8:"numParts";i:4;}}', 4),
('user.well-known.change_password', '/.well-known/change-password', '/.well-known/change-password', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:28:"/.well-known/change-password";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:52:"\\Drupal\\user\\Controller\\UserController::userEditPage";}s:12:"requirements";a:1:{s:18:"_user_is_logged_in";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:30:"access_check.user.login_status";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/\\.well\\-known/change\\-password$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:28:"/.well-known/change-password";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:28:"/.well-known/change-password";s:8:"numParts";i:2;}}', 2),
('view.block_content.page_1', '/admin/content/block', '/admin/content/block', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/admin/content/block";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:13:"block_content";s:10:"display_id";s:6:"page_1";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:20:"access block library";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/admin/content/block$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/content/block";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/admin/content/block";s:8:"numParts";i:3;}}', 3),
('view.comment.page_published', '/admin/content/comment', '/admin/content/comment', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/admin/content/comment";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:7:"comment";s:10:"display_id";s:14:"page_published";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:19:"administer comments";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:29:"{^/admin/content/comment$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/content/comment";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:22:"/admin/content/comment";s:8:"numParts";i:3;}}', 3),
('view.comment.page_unapproved', '/admin/content/comment/approval', '/admin/content/comment/approval', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:31:"/admin/content/comment/approval";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:7:"comment";s:10:"display_id";s:15:"page_unapproved";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:19:"administer comments";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/admin/content/comment/approval$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/content/comment/approval";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:31:"/admin/content/comment/approval";s:8:"numParts";i:4;}}', 4),
('view.content.page_1', '/admin/content', '/admin/content', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:14:"/admin/content";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:7:"content";s:10:"display_id";s:6:"page_1";s:30:"_view_display_show_admin_links";b:0;}s:12:"requirements";a:2:{s:11:"_permission";s:23:"access content overview";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:0;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:21:"{^/admin/content$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:14:"/admin/content";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:14:"/admin/content";s:8:"numParts";i:2;}}', 2),
('view.files.page_1', '/admin/content/files', '/admin/content/files', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/admin/content/files";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:5:"files";s:10:"display_id";s:6:"page_1";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:21:"access files overview";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/admin/content/files$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/content/files";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/admin/content/files";s:8:"numParts";i:3;}}', 3),
('view.files.page_2', '/admin/content/files/usage/{arg_0}', '/admin/content/files/usage/%', 30, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:34:"/admin/content/files/usage/{arg_0}";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:5:"files";s:10:"display_id";s:6:"page_2";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:21:"access files overview";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:1:{s:5:"arg_0";s:5:"arg_0";}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"arg_0";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:51:"{^/admin/content/files/usage/(?P<arg_0>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"arg_0";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/content/files/usage";}}s:9:"path_vars";a:1:{i:0;s:5:"arg_0";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:30;s:14:"patternOutline";s:28:"/admin/content/files/usage/%";s:8:"numParts";i:5;}}', 5),
('view.frontpage.feed_1', '/rss.xml', '/rss.xml', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:8:"/rss.xml";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:9:"frontpage";s:10:"display_id";s:6:"feed_1";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:1:{s:11:"_permission";s:14:"access content";}s:7:"options";a:8:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"feed";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Feed";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:16:"{^/rss\\.xml$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:8:"/rss.xml";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:8:"/rss.xml";s:8:"numParts";i:1;}}', 1),
('view.frontpage.page_1', '/node', '/node', 1, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:5:"/node";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:9:"frontpage";s:10:"display_id";s:6:"page_1";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:14:"access content";s:7:"_format";s:4:"html";}s:7:"options";a:8:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:12:"{^/node$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/node";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:1;s:14:"patternOutline";s:5:"/node";s:8:"numParts";i:1;}}', 1),
('view.taxonomy_term.feed_1', '/taxonomy/term/{arg_0}/feed', '/taxonomy/term/%/feed', 13, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:27:"/taxonomy/term/{arg_0}/feed";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:13:"taxonomy_term";s:10:"display_id";s:6:"feed_1";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:1:{s:11:"_permission";s:14:"access content";}s:7:"options";a:8:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:1:{s:5:"arg_0";s:5:"arg_0";}s:23:"_view_display_plugin_id";s:4:"feed";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Feed";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:1;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"arg_0";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:44:"{^/taxonomy/term/(?P<arg_0>[^/]++)/feed$}sDu";s:11:"path_tokens";a:3:{i:0;a:2:{i:0;s:4:"text";i:1;s:5:"/feed";}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"arg_0";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:14:"/taxonomy/term";}}s:9:"path_vars";a:1:{i:0;s:5:"arg_0";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:13;s:14:"patternOutline";s:21:"/taxonomy/term/%/feed";s:8:"numParts";i:4;}}', 4),
('view.taxonomy_term.page_1', '/taxonomy/term/{arg_0}', '/taxonomy/term/%', 6, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:22:"/taxonomy/term/{arg_0}";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:13:"taxonomy_term";s:10:"display_id";s:6:"page_1";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:14:"access content";s:7:"_format";s:4:"html";}s:7:"options";a:8:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:1:{s:5:"arg_0";s:5:"arg_0";}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:1:{i:0;s:5:"arg_0";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:39:"{^/taxonomy/term/(?P<arg_0>[^/]++)$}sDu";s:11:"path_tokens";a:2:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:5:"arg_0";i:4;b:1;}i:1;a:2:{i:0;s:4:"text";i:1;s:14:"/taxonomy/term";}}s:9:"path_vars";a:1:{i:0;s:5:"arg_0";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:6;s:14:"patternOutline";s:16:"/taxonomy/term/%";s:8:"numParts";i:3;}}', 3),
('view.user_admin_people.page_1', '/admin/people', '/admin/people', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:13:"/admin/people";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:17:"user_admin_people";s:10:"display_id";s:6:"page_1";s:30:"_view_display_show_admin_links";b:0;}s:12:"requirements";a:2:{s:11:"_permission";s:16:"administer users";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:0;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:20:"{^/admin/people$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:13:"/admin/people";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:13:"/admin/people";s:8:"numParts";i:2;}}', 2),
('view.watchdog.page', '/admin/reports/dblog', '/admin/reports/dblog', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:20:"/admin/reports/dblog";s:4:"host";s:0:"";s:8:"defaults";a:5:{s:11:"_controller";s:47:"Drupal\\views\\Routing\\ViewPageController::handle";s:15:"_title_callback";s:49:"Drupal\\views\\Routing\\ViewPageController::getTitle";s:7:"view_id";s:8:"watchdog";s:10:"display_id";s:4:"page";s:30:"_view_display_show_admin_links";b:1;}s:12:"requirements";a:2:{s:11:"_permission";s:19:"access site reports";s:7:"_format";s:4:"html";}s:7:"options";a:9:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:18:"_view_argument_map";a:0:{}s:23:"_view_display_plugin_id";s:4:"page";s:26:"_view_display_plugin_class";s:38:"Drupal\\views\\Plugin\\views\\display\\Page";s:30:"_view_display_show_admin_links";b:1;s:16:"returns_response";b:0;s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:27:"{^/admin/reports/dblog$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:20:"/admin/reports/dblog";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:20:"/admin/reports/dblog";s:8:"numParts";i:3;}}', 3),
('views.ajax', '/views/ajax', '/views/ajax', 3, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:11:"/views/ajax";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:53:"\\Drupal\\views\\Controller\\ViewAjaxController::ajaxView";}s:12:"requirements";a:1:{s:7:"_access";s:4:"TRUE";}s:7:"options";a:3:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:14:"_access_checks";a:1:{i:0;s:20:"access_check.default";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:18:"{^/views/ajax$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:11:"/views/ajax";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:3;s:14:"patternOutline";s:11:"/views/ajax";s:8:"numParts";i:2;}}', 2),
('views_ui.add', '/admin/structure/views/add', '/admin/structure/views/add', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:26:"/admin/structure/views/add";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:12:"_entity_form";s:8:"view.add";s:6:"_title";s:8:"Add view";}s:12:"requirements";a:1:{s:21:"_entity_create_access";s:4:"view";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:26:"access_check.entity_create";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:33:"{^/admin/structure/views/add$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:26:"/admin/structure/views/add";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:26:"/admin/structure/views/add";s:8:"numParts";i:4;}}', 4),
('views_ui.autocomplete', '/admin/views/ajax/autocomplete/tag', '/admin/views/ajax/autocomplete/tag', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:34:"/admin/views/ajax/autocomplete/tag";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:62:"\\Drupal\\views_ui\\Controller\\ViewsUIController::autocompleteTag";}s:12:"requirements";a:1:{s:11:"_permission";s:16:"administer views";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:41:"{^/admin/views/ajax/autocomplete/tag$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:34:"/admin/views/ajax/autocomplete/tag";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:34:"/admin/views/ajax/autocomplete/tag";s:8:"numParts";i:5;}}', 5),
('views_ui.form_add_handler', '/admin/structure/views/{js}/add-handler/{view}/{display_id}/{type}', '/admin/structure/views/%/add-handler/%/%/%', 232, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:66:"/admin/structure/views/{js}/add-handler/{view}/{display_id}/{type}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:46:"\\Drupal\\views_ui\\Form\\Ajax\\AddHandler::getForm";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.update";s:2:"js";s:9:"nojs|ajax";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:4:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:117:"{^/admin/structure/views/(?P<js>nojs|ajax)/add\\-handler/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu";s:11:"path_tokens";a:6:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"type";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:12:"/add-handler";}i:4;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:9:"nojs|ajax";i:3;s:2:"js";i:4;b:1;}i:5;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:4:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:232;s:14:"patternOutline";s:42:"/admin/structure/views/%/add-handler/%/%/%";s:8:"numParts";i:8;}}', 8),
('views_ui.form_analyze', '/admin/structure/views/{js}/analyze/{view}/{display_id}', '/admin/structure/views/%/analyze/%/%', 116, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:55:"/admin/structure/views/{js}/analyze/{view}/{display_id}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:43:"\\Drupal\\views_ui\\Form\\Ajax\\Analyze::getForm";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.update";s:2:"js";s:9:"nojs|ajax";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:95:"{^/admin/structure/views/(?P<js>nojs|ajax)/analyze/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:8:"/analyze";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:9:"nojs|ajax";i:3;s:2:"js";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:3:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:116;s:14:"patternOutline";s:36:"/admin/structure/views/%/analyze/%/%";s:8:"numParts";i:7;}}', 7),
('views_ui.form_display', '/admin/structure/views/{js}/display/{view}/{display_id}/{type}', '/admin/structure/views/%/display/%/%/%', 232, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:62:"/admin/structure/views/{js}/display/{view}/{display_id}/{type}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:43:"\\Drupal\\views_ui\\Form\\Ajax\\Display::getForm";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.update";s:2:"js";s:9:"nojs|ajax";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:4:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:112:"{^/admin/structure/views/(?P<js>nojs|ajax)/display/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu";s:11:"path_tokens";a:6:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"type";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:8:"/display";}i:4;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:9:"nojs|ajax";i:3;s:2:"js";i:4;b:1;}i:5;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:4:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:232;s:14:"patternOutline";s:38:"/admin/structure/views/%/display/%/%/%";s:8:"numParts";i:8;}}', 8),
('views_ui.form_edit_details', '/admin/structure/views/{js}/edit-details/{view}/{display_id}', '/admin/structure/views/%/edit-details/%/%', 116, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:60:"/admin/structure/views/{js}/edit-details/{view}/{display_id}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:47:"\\Drupal\\views_ui\\Form\\Ajax\\EditDetails::getForm";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.update";s:2:"js";s:9:"nojs|ajax";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:101:"{^/admin/structure/views/(?P<js>nojs|ajax)/edit\\-details/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:13:"/edit-details";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:9:"nojs|ajax";i:3;s:2:"js";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:3:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:116;s:14:"patternOutline";s:41:"/admin/structure/views/%/edit-details/%/%";s:8:"numParts";i:7;}}', 7),
('views_ui.form_handler', '/admin/structure/views/{js}/handler/{view}/{display_id}/{type}/{id}', '/admin/structure/views/%/handler/%/%/%/%', 464, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:67:"/admin/structure/views/{js}/handler/{view}/{display_id}/{type}/{id}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:49:"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandler::getForm";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.update";s:2:"js";s:9:"nojs|ajax";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:5:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";i:4;s:2:"id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:127:"{^/admin/structure/views/(?P<js>nojs|ajax)/handler/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu";s:11:"path_tokens";a:7:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:2:"id";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"type";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:8:"/handler";}i:5;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:9:"nojs|ajax";i:3;s:2:"js";i:4;b:1;}i:6;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:5:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";i:4;s:2:"id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:464;s:14:"patternOutline";s:40:"/admin/structure/views/%/handler/%/%/%/%";s:8:"numParts";i:9;}}', 9),
('views_ui.form_handler_extra', '/admin/structure/views/{js}/handler-extra/{view}/{display_id}/{type}/{id}', '/admin/structure/views/%/handler-extra/%/%/%/%', 464, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:73:"/admin/structure/views/{js}/handler-extra/{view}/{display_id}/{type}/{id}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:54:"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandlerExtra::getForm";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.update";s:2:"js";s:9:"nojs|ajax";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:5:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";i:4;s:2:"id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:134:"{^/admin/structure/views/(?P<js>nojs|ajax)/handler\\-extra/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu";s:11:"path_tokens";a:7:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:2:"id";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"type";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:14:"/handler-extra";}i:5;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:9:"nojs|ajax";i:3;s:2:"js";i:4;b:1;}i:6;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:5:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";i:4;s:2:"id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:464;s:14:"patternOutline";s:46:"/admin/structure/views/%/handler-extra/%/%/%/%";s:8:"numParts";i:9;}}', 9),
('views_ui.form_handler_group', '/admin/structure/views/{js}/handler-group/{view}/{display_id}/{type}/{id}', '/admin/structure/views/%/handler-group/%/%/%/%', 464, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:73:"/admin/structure/views/{js}/handler-group/{view}/{display_id}/{type}/{id}";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:54:"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandlerGroup::getForm";s:10:"form_state";N;}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.update";s:2:"js";s:9:"nojs|ajax";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:5:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";i:4;s:2:"id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:134:"{^/admin/structure/views/(?P<js>nojs|ajax)/handler\\-group/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu";s:11:"path_tokens";a:7:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:2:"id";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"type";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:14:"/handler-group";}i:5;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:9:"nojs|ajax";i:3;s:2:"js";i:4;b:1;}i:6;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:5:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";i:4;s:2:"id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:464;s:14:"patternOutline";s:46:"/admin/structure/views/%/handler-group/%/%/%/%";s:8:"numParts";i:9;}}', 9),
('views_ui.form_rearrange', '/admin/structure/views/{js}/rearrange/{view}/{display_id}/{type}', '/admin/structure/views/%/rearrange/%/%/%', 232, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:64:"/admin/structure/views/{js}/rearrange/{view}/{display_id}/{type}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:45:"\\Drupal\\views_ui\\Form\\Ajax\\Rearrange::getForm";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.update";s:2:"js";s:9:"nojs|ajax";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:4:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:114:"{^/admin/structure/views/(?P<js>nojs|ajax)/rearrange/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu";s:11:"path_tokens";a:6:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"type";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:2;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:3;a:2:{i:0;s:4:"text";i:1;s:10:"/rearrange";}i:4;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:9:"nojs|ajax";i:3;s:2:"js";i:4;b:1;}i:5;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:4:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";i:3;s:4:"type";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:232;s:14:"patternOutline";s:40:"/admin/structure/views/%/rearrange/%/%/%";s:8:"numParts";i:8;}}', 8),
('views_ui.form_rearrange_filter', '/admin/structure/views/{js}/rearrange-filter/{view}/{display_id}', '/admin/structure/views/%/rearrange-filter/%/%', 116, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:64:"/admin/structure/views/{js}/rearrange-filter/{view}/{display_id}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:51:"\\Drupal\\views_ui\\Form\\Ajax\\RearrangeFilter::getForm";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.update";s:2:"js";s:9:"nojs|ajax";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:105:"{^/admin/structure/views/(?P<js>nojs|ajax)/rearrange\\-filter/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:17:"/rearrange-filter";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:9:"nojs|ajax";i:3;s:2:"js";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:3:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:116;s:14:"patternOutline";s:45:"/admin/structure/views/%/rearrange-filter/%/%";s:8:"numParts";i:7;}}', 7),
('views_ui.form_reorder_displays', '/admin/structure/views/{js}/reorder-displays/{view}/{display_id}', '/admin/structure/views/%/reorder-displays/%/%', 116, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:64:"/admin/structure/views/{js}/reorder-displays/{view}/{display_id}";s:4:"host";s:0:"";s:8:"defaults";a:1:{s:11:"_controller";s:51:"\\Drupal\\views_ui\\Form\\Ajax\\ReorderDisplays::getForm";}s:12:"requirements";a:2:{s:14:"_entity_access";s:11:"view.update";s:2:"js";s:9:"nojs|ajax";}s:7:"options";a:5:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:10:"parameters";a:1:{s:4:"view";a:3:{s:9:"tempstore";b:1;s:4:"type";s:11:"entity:view";s:9:"converter";s:53:"drupal.proxy_original_service.paramconverter.views_ui";}}s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:19:"access_check.entity";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:3:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:105:"{^/admin/structure/views/(?P<js>nojs|ajax)/reorder\\-displays/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu";s:11:"path_tokens";a:5:{i:0;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:10:"display_id";i:4;b:1;}i:1;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:6:"[^/]++";i:3;s:4:"view";i:4;b:1;}i:2;a:2:{i:0;s:4:"text";i:1;s:17:"/reorder-displays";}i:3;a:5:{i:0;s:8:"variable";i:1;s:1:"/";i:2;s:9:"nojs|ajax";i:3;s:2:"js";i:4;b:1;}i:4;a:2:{i:0;s:4:"text";i:1;s:22:"/admin/structure/views";}}s:9:"path_vars";a:3:{i:0;s:2:"js";i:1;s:4:"view";i:2;s:10:"display_id";}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:116;s:14:"patternOutline";s:45:"/admin/structure/views/%/reorder-displays/%/%";s:8:"numParts";i:7;}}', 7);
INSERT INTO `[[dbprefix]]router` VALUES
('views_ui.reports_fields', '/admin/reports/fields/views-fields', '/admin/reports/fields/views-fields', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:34:"/admin/reports/fields/views-fields";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:59:"\\Drupal\\views_ui\\Controller\\ViewsUIController::reportFields";s:6:"_title";s:13:"Used in views";}s:12:"requirements";a:1:{s:11:"_permission";s:16:"administer views";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:42:"{^/admin/reports/fields/views\\-fields$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:34:"/admin/reports/fields/views-fields";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:34:"/admin/reports/fields/views-fields";s:8:"numParts";i:4;}}', 4),
('views_ui.reports_plugins', '/admin/reports/views-plugins', '/admin/reports/views-plugins', 7, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:28:"/admin/reports/views-plugins";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:11:"_controller";s:60:"\\Drupal\\views_ui\\Controller\\ViewsUIController::reportPlugins";s:6:"_title";s:13:"Views plugins";}s:12:"requirements";a:1:{s:11:"_permission";s:16:"administer views";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:36:"{^/admin/reports/views\\-plugins$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:28:"/admin/reports/views-plugins";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:7;s:14:"patternOutline";s:28:"/admin/reports/views-plugins";s:8:"numParts";i:3;}}', 3),
('views_ui.settings_advanced', '/admin/structure/views/settings/advanced', '/admin/structure/views/settings/advanced', 31, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:40:"/admin/structure/views/settings/advanced";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:42:"\\Drupal\\views_ui\\Form\\AdvancedSettingsForm";s:6:"_title";s:23:"Advanced Views settings";}s:12:"requirements";a:1:{s:11:"_permission";s:16:"administer views";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:47:"{^/admin/structure/views/settings/advanced$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:40:"/admin/structure/views/settings/advanced";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:31;s:14:"patternOutline";s:40:"/admin/structure/views/settings/advanced";s:8:"numParts";i:5;}}', 5),
('views_ui.settings_basic', '/admin/structure/views/settings', '/admin/structure/views/settings', 15, 'O:31:"Symfony\\Component\\Routing\\Route":9:{s:4:"path";s:31:"/admin/structure/views/settings";s:4:"host";s:0:"";s:8:"defaults";a:2:{s:5:"_form";s:39:"\\Drupal\\views_ui\\Form\\BasicSettingsForm";s:6:"_title";s:14:"Views settings";}s:12:"requirements";a:1:{s:11:"_permission";s:16:"administer views";}s:7:"options";a:4:{s:14:"compiler_class";s:33:"Drupal\\Core\\Routing\\RouteCompiler";s:4:"utf8";b:1;s:12:"_admin_route";b:1;s:14:"_access_checks";a:1:{i:0;s:23:"access_check.permission";}}s:7:"schemes";a:0:{}s:7:"methods";a:2:{i:0;s:3:"GET";i:1;s:4:"POST";}s:9:"condition";s:0:"";s:8:"compiled";O:33:"Drupal\\Core\\Routing\\CompiledRoute":11:{s:4:"vars";a:0:{}s:11:"path_prefix";s:0:"";s:10:"path_regex";s:38:"{^/admin/structure/views/settings$}sDu";s:11:"path_tokens";a:1:{i:0;a:2:{i:0;s:4:"text";i:1;s:31:"/admin/structure/views/settings";}}s:9:"path_vars";a:0:{}s:10:"host_regex";N;s:11:"host_tokens";a:0:{}s:9:"host_vars";a:0:{}s:3:"fit";i:15;s:14:"patternOutline";s:31:"/admin/structure/views/settings";s:8:"numParts";i:4;}}', 4);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]search_dataset`
--

CREATE TABLE `[[dbprefix]]search_dataset` (
  `sid` int unsigned NOT NULL DEFAULT '0' COMMENT 'Search item ID, e.g. node ID for nodes.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "[[dbprefix]]languages".langcode of the item variant.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'Type of item, e.g. node.',
  `data` longtext NOT NULL COMMENT 'List of space-separated words from the item.',
  `reindex` int unsigned NOT NULL DEFAULT '0' COMMENT 'Set to force node reindexing.',
  PRIMARY KEY (`sid`,`langcode`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Stores items that will be searched.';

--
-- Dumping data for table `[[dbprefix]]search_dataset`
--

INSERT INTO `[[dbprefix]]search_dataset` VALUES
(1, 'en', 'help_search', ' exporting your complete site configuration goal create and download an archive containing all your site s configuration exported as yaml files see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   export  click export and save the archive file  ', 0),
(2, 'en', 'help_search', ' exporting a single configuration item goal export a single configuration item to a file see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   export   single item  select the configuration type that you want to export and then select the specific configuration name to export use your browser to copy the text in the box marked here is your configuration to the clipboard paste the copied text into a plaintext editor on your computer or other device and save it using the suggested file name below the text box  ', 0),
(3, 'en', 'help_search', ' importing your complete site configuration goal import the complete configuration of your site from an archive file such as one that was previously exported see exporting your complete site configuration see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   import  browse to find the configuration archive that you want to import click upload  your configuration archive will be unpacked and placed in the configuration synchronization directory and you will be redirected to the synchronize page review the differences between your uploaded configuration and the active configuration if any and click import all to import the changes  ', 0),
(4, 'en', 'help_search', ' importing a single configuration item goal import a single configuration item in yaml format such as one that was previously exported see exporting a single configuration item see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   import   single item  select the configuration type that you want to import on your computer or other device copy the yamlformat configuration that you want to import to the clipboard paste the clipboard text into the box labeled paste your configuration here  click import   ', 0),
(5, 'en', 'help_search', ' managing the fields of contact forms goal add remove or rearrange the fields on personal and sitewide contact forms what are the fields on contact forms  both personal and sitewide contact forms will always have subject and message fields you can add additional fields for users to fill out if desired note that if you want to display other content on a form page such as text or images you can use a content block steps in the manage administrative menu navigate to structure   contact forms  click manage fields for the form you want to change the fields of and add or remove one or more fields on the form click manage form display to change the order or configuration of the fields on the form  ', 0),
(6, 'en', 'help_search', ' configuring personal contact forms goal configure personal contact forms for registered users on the website steps in the manage administrative menu navigate to configuration   people   account settings  in the contact settings section check uncheck the box to enable disable the contact form for new user accounts click save configuration  in the manage administrative menu navigate to people   permissions  verify that permissions are correct for your site s roles including the generic anonymous user and authenticated user  in order to use personal contact forms users need both view user information  in the user section which enables them to view user profiles and use users personal contact forms  in the contact section which enables them to use contact forms if they can view user profiles click save permissions  the contact form will always have subject and message fields if you want to add more fields follow the steps in managing the fields of contact forms  ', 0),
(7, 'en', 'help_search', ' creating a new contact form goal create a new sitewide contact form steps in the manage administrative menu navigate to structure   contact forms  click add contact form  fill in the label  title for the form  recipients  and optionally the other settings click save  you should see your new contact form in the table along with a link to view it the contact form will always have subject and message fields if you want to add more fields follow the steps in managing the fields of contact forms  ', 0),
(8, 'en', 'help_search', ' managing contact forms what are contact forms  there are two different types of contact forms provided by the core contact module personal contact forms which allow users to contact other users on the site and sitewide contact forms which allow users to contact site managers or administrators a site can have more than one sitewide contact form each has its own fields to fill out recipients and url you can also change the fields that are shown on personal contact forms using the personal contact form site visitors can email registered users on your site by using the personal contact form without knowing or learning the email address of the recipient when a user with the correct permissions is viewing another user s profile the viewer will see a contact tab or link which leads to the personal contact form if the user whose profile is being viewed has their personal contact form enabled this is a user account setting  contact form management tasks see the related topics below for specific tasks  ', 0),
(9, 'en', 'help_search', ' setting a default contact form goal set a sitewide contact form to be the default contact form  the form displayed on the default contact page  for example   contact   steps in the manage administrative menu navigate to structure   contact forms  click edit for the sitewide form you want to be the default check make this the default form and click save   ', 0),
(10, 'en', 'help_search', ' changing the appearance of your site what is a theme  a theme is a set of files that define the visual look and feel of your site the core software and modules that run on your site determine which content including html text and other data stored in the database uploaded images and any other asset files is displayed on the pages of your site the theme determines the html markup and css styling that wraps the content several basic themes are supplied with the core software additional contributed themes can be downloaded separately from the download extend page on drupalorg  or you can create your own theme what is a base theme  a base theme is a theme that is not meant to be used directly on a site but instead acts as a scaffolding for building other themes the core stable 9 theme is one example other base themes can be downloaded from the download extend page on drupalorg  what is a layout  a layout is a template that defines where blocks and other pieces of content should be displayed the core layout discovery module allows modules and themes to register layouts and the core layout builder module provides a visual interface for placing fields and blocks in layouts for entity subtypes and individual entity items see managing content structure for more on entities and fields  changing site appearance overview the main way to change the overall appearance of your site is to switch the default theme the core layout builder and layout discovery modules allow you to define layouts for your site s content and the core breakpoint module helps themes change appearance for differentsized devices see the related topics listed below for specific tasks additional resources extending and customizing your site drupal user guide  theming drupal ', 0),
(11, 'en', 'help_search', ' managing and deploying configuration what is the configuration system  the configuration system provides the ability for administrators to customize the site and to move and synchronize configuration changes between development sites and the live site it does this in 2 ways providing storage for configuration providing a process in which configuration changes can be imported and exported between instances of the same site for example from dev to staging to live  what is configuration data  configuration data describes settings that define how your site behaves or is displayed for example when a site administrator updates settings using an administrative form these settings are stored as configuration data configuration data describes settings as simple as a site name and as complex as a view or image style what kinds of configuration are there  active configuration active configuration is the current working configuration of a site storage of active configuration is defined by the site and resides in the database by default simple configuration a simple configuration item is a group of settings such as the settings for a module or theme each simple configuration item has its own unique structure configuration entities configuration entities are userdefined configuration items grouped by type such as views image styles and content types each configuration entity within a type has a similar structure default configuration default configuration can be defined by a module theme or installation profile in its config install or config optional directories configuration is provided in yaml files file extension yml yaml is a humanreadable data serialization standard that is used by the core software for several purposes once the default configuration has been imported into the site s active configuration through installing the extension that configuration is owned by the site not the extension this means that future updates of the extension will not override the site s active configuration for that extension what is configuration synchronization  configuration synchronization is the process of exporting and importing configuration to keep configuration synchronized between different versions of a site for example between a development site and the live site each site has unique identifier also called a uuid  which identifies the site to the system in any instance of the site as long as the site instances have been reproduced as clones cloning is when the codebase and database are copied to create a new site instance when site instances are cloned a dev instance of the site has the same uuid as the live instance when site instances share the same uuid configuration can be exported from one instance to another the following list contains terms and concepts related to configuration synchronization exported configuration when configuration is exported the active configuration is exported as a set of files in yaml format when using the configuration synchronization administrative ui configuration can be exported as a fullexport or singleitem archive this archive can then be imported into the destination site instance imported configuration imported configuration is configuration that has been exported from another instance of the site the source and is now being imported into another site instance the destination thereby updating its active configuration to match the imported configuration data set configuration sync directory the configuration sync directory location is set in the site s settingsphp file when configuration is exported the active configuration is exported and described in yaml files which are stored in the configuration sync directory after the first export the system compares the site s active configuration with the configuration data in the sync directory and will only export active configuration items that are different than their counterparts in the sync directory managing configuration overview configuration management tasks such as exporting or importing configuration and synchronizing configuration can be done either through the administrative ui provided by the core configuration manager module or a commandline interface cli tool defining a configuration sync directory path other than the default value requires read write access to the site s settingsphp file most modules and themes also provide settings forms for updating the configuration they provide see the related topics listed below for specific tasks additional resources configuration management workflow using drush concept types of data drupal user guide  concept development sites drupal user guide  making a development site drupal user guide  ', 0),
(12, 'en', 'help_search', ' managing content structure what types of data does a site have  there are four main types of data content is the information text images etc meant to be displayed to website visitors configuration is data that defines how the content is displayed some configuration such as field labels may also be visible to site visitors state is temporary data about the state of your site such as the last time the system cron jobs ran session is a subset of state information related to users interactions with the site such as site cookies and whether or not they are logged in what is a content entity  a content entity  or more commonly  entity  is an item of content data which can consist of text html markup images attached files and other data content entities are grouped into entity types  which have different purposes and are displayed in very different ways on the site most entity types are also divided into entity subtypes  which are divisions within an entity type to allow for smaller variations in how the entities are used and displayed for example the content item entity type that stores pagelevel content is divided into content type subtypes the content block entity type has block types  but the user entity type for user profile information does not have subtypes what is a field  within entity items the data is stored in individual fields  each of which holds one type of data such as formatted or plain text images or other files or dates fields can be added by an administrator on entity subtypes so that all entity items of a given entity subtype have the same collection of fields available and they can be singlevalued or multiplevalued when you create or edit entity items you are specifying the values for the fields on the entity item what is a reference field  a reference field is a field that stores a relationship between an entity and one or more other entities which may belong to the same or different entity type for example a content reference field on a content type stores a relationship between one content item and one or more other content items what field types are available  the following field types are provided by the core system and core modules many more are provided by contributed modules boolean number provided by the core system stores true false values and numbers comment provided by the core comment module allows users to add comments to an entity date timestamp datetime module stores dates and times date range datetime range module stores time date periods with a start and an end email core system stores email addresses link link module stores urls and link text list options module stores values chosen from predefined lists where the values can be numbers or text see section below for more on list fields reference core system stores entity references see section above telephone telephone module stores telephone numbers text text module stores formatted and unformatted text see section below for more on text fields what settings are available for list field types  list fields associate predefined keys  or value codes with labels that the user sees for example you might define a list field that shows the user the names of several locations while behind the scenes a location code is stored in the database each list field type corresponds to one type of stored key for example a list integer  field stores integers while the list text  field stores text strings once you have chosen the field type the main setting for a list field is the allowed values list which associates the keys with the labels what types of text fields are available  there are several types of text fields with different characteristics text fields can be either plain or formatted  plain text fields do not contain html while formatted fields can contain html and are processed through text filters  these are provided by the core filter module if you have that module enabled see the related topic below on filters for more information text fields can also be regularlength with a limit of 255 characters or long  with a very large character limit and long formatted text fields can include a summary attribute all possible combinations of these characteristics exist as text field types for example  text plain  and text formatted long with summary  are two examples of text field types what is a formatter  a formatter is a way to display a field most field types offer several types of formatters and most formatters have settings that further define how the field is displayed it is also possible to completely hide a field from display and you have the option of showing or hiding the field s label when it is displayed what is a widget  a widget is a way to edit a field some field types such as plain text singleline fields have only one widget available in this case a singleline text input field other field types offer choices for the widget for example singlevalued list fields can use a select or radio button widget for editing many widget types have settings that further define how the field can be edited managing content structure overview besides the field modules listed in the previous section there are additional core modules that you can use to manage your content structure the core node comment content block custom menu links user file image media taxonomy and contact modules all provide content entity types the core field ui module provides a user interface for managing fields and their display on entities the core layout builder module provides a more flexible user interface for configuring the display of entities the core filter responsive image and path modules provide settings and display options for entities and fields depending on the core and contributed modules that you currently have installed on your site the related topics below and other topics listed on the main help page see help will help you with tasks related to content structure additional resources concept types of data drupal user guide  planning your site drupal user guide  concept reference fields drupal user guide  ', 0),
(13, 'en', 'help_search', ' running and configuring cron goal configure your system so that cron will run automatically what are cron tasks  to ensure that your site and its modules continue to function well a group of administrative operations should be run periodically these operations are called cron tasks and running the tasks is known as running cron  depending on how often content is updated on your site you might need to run cron on a schedule ranging from hourly to weekly to keep your site running well what options are available for running cron  if the core automated cron module is installed your site will run cron periodically on a schedule you can configure you can set up a task on your web server to visit the cron url  which is unique to your site on a schedule you can also run cron manually but this is not the recommended way to make sure it is run periodically steps in the manage administration menu navigate to configuration   system   cron  note the last run time on the page if you want to run cron right now click run cron and wait for cron to finish if you have a way to configure tasks on your web server copy the link where it says to run cron from outside the site go to  set up a task to visit that url on your desired cron schedule such as once an hour or once a week on linuxlike servers you can use the wget command to visit a url if you configure an outside task you should uninstall the automated cron module if you are not configuring an outside task and you have the core automated cron module installed select a schedule for automated cron runs in cron settings   run cron every  click save configuration  additional resources concept cron drupal user guide  configuring cron maintenance tasks drupal user guide  ', 0),
(14, 'en', 'help_search', ' extending and modifying your site functionality what is a module  a module is a set of php javascript and or css files that extends site features and adds functionality a set of core modules is distributed as part of the core software download additional contributed modules can be downloaded separately from the download extend page on drupalorg  what is an experimental module  an experimental module is a module that is still in development and is not yet stable using experimental modules on production sites is not recommended what are installing and uninstalling  installing a core or downloaded contributed module means turning it on so that you can use its features and functionality uninstalling means turning it off and removing all of its configuration a module cannot be uninstalled if another installed module depends on it or if you have created content on your site using the module you would need to delete the content and uninstall dependent modules first extending overview see the related topics listed below for help performing tasks related to extending the functionality of your site additional resources concept modules drupal user guide  extending and customizing your site drupal user guide  ', 0),
(15, 'en', 'help_search', ' maintaining and troubleshooting your site maintaining and troubleshooting overview here are some tasks and hints related to maintaining your site and troubleshooting problems that may come up on your site see the related topics below for more information when performing maintenance such as installing uninstalling or updating a module put your site in maintenance mode configure your site so that cron runs periodically if your site is not behaving as expected clear the cache before trying to diagnose the problem there are several site reports that can help you diagnose problems with your site there are also two core modules that can be used for error logging database logging and syslog additional resources preventing and fixing problems drupal user guide  security and maintenance drupal user guide  ', 0),
(16, 'en', 'help_search', ' managing media what are media items  core media items include audio images documents and videos you can add other media types such as social media posts through the use of contributed modules media items may be files located in your site s file system or remote items referenced by a url media items are content entities and they are divided into media types which are entity subtypes media types can have fields see managing content structure for more information on content entities and fields what is the media library  the media library is a visual user interface for managing and reusing media items add media items to content using media reference fields and the media library field widget what is an image style  an image style is a set of processing steps known as effects  that can be applied to images examples of effects include scaling and cropping images to different sizes responsive image styles can associate image styles with your theme s size breakpoints this allows serving images sized for the browser width overview of managing media the following modules provide mediarelated functionality media items and media types are managed by the core media module the core media module provides a media reference field to add media to content entities the core file and image modules also provide reference fields it is recommended to use the media reference field because it is more versatile the core media library module provides the media library and the media library field widget with this module installed the media library field widget becomes the default widget for editing media reference fields the core image module provides a user interface for defining image styles the core responsive image module provides responsive image styles using the core breakpoint module and a breakpointenabled theme these responsive styles can serve images sized for the browser see the related topics listed below for specific tasks additional resources media module ', 0),
(17, 'en', 'help_search', ' managing menus what is a menu  a menu is a collection of menu links used to navigate a web site menus and menu links can be provided by modules or site administrators managing menus overview the core menu ui module provides a user interface for managing menus including creating new menus reordering menu links and disabling links provided by modules it also provides the ability for links to content items to be added to menus while editing if configured on the content type the core custom menu links module provides the ability to add custom links to menus each menu can be displayed by placing a block in a theme region some themes also can display a menu outside of the block system see the related topics listed below for specific tasks additional resources concept menu drupal user guide  ', 0),
(18, 'en', 'help_search', ' optimizing site performance what is site performance  site performance in this context refers to speed factors such as the page load time and the response time after a user action on a page what is caching  caching is saving alreadyrendered html output and other calculated data for later use the first time it is needed this saves time because the next time the same data is needed it can be quickly retrieved instead of recalculated automatic caching systems also include mechanisms to delete cached calculations or mark them as no longer valid when the underlying data changes to facilitate that cached data has a lifetime  which is the maximum time before the data will be deleted from the cache forcing recalculation  what is file aggregation  aggregation is when css and javascript files are merged together and compressed into a format that is much smaller than the original this allows for faster transmission and faster rendering on the other end what can i do to improve my site s performance  the following core software modules and mechanisms can improve your site s performance internal page cache module caches pages requested by users who are not logged in anonymous users do not use if your site needs to send different output to different anonymous users internal dynamic page cache module caches data for both authenticated and anonymous users with noncacheable data in the page converted to placeholders and calculated when the page is requested big pipe module changes the way pages are sent to users so that cacheable parts are sent out first with placeholders and the uncacheable or personalized parts of the page are streamed afterwards this allows the browser to render the bulk of the page quickly and fill in the details later performance page settings in the manage administrative menu if you navigate to configuration   development   performance  you will find a setting for the maximum cache lifetime as well as the ability to turn on css and javascript file aggregation additional resources online documentation for the internal page cache module online documentation for the internal dynamic page cache module online documentation for the bigpipe module ', 0),
(19, 'en', 'help_search', ' making your site secure what are security updates  any software occasionally has bugs and sometimes these bugs have security implications when security bugs are fixed in the core software modules or themes that your site uses they are released in a security update  you will need to apply security updates in order to keep your site secure what are security advisories  a security advisory is a public announcement about a reported security problem in the core software contributed projects with a shield icon and stable releases for this project are covered by the security advisory policy on their project page are also covered by drupal s security advisory policy security advisories are managed by the drupal security team  security tasks keeping track of updates updating the core software and updating contributed modules and or themes are all part of keeping your site secure see the related topics listed below for specific tasks additional resources security and maintenance drupal user guide  security advisory process and permissions policy ', 0),
(20, 'en', 'help_search', ' using inline quick settings editing goal edit settings in place what is quick editing  the core settings tray module provides the ability to quickly edit settings inline it requires the core contextual links module in order to expose the links that let you edit in place who can edit settings in place  in order to follow these steps to edit settings in place the core settings tray module must be installed also either the core toolbar module or a contributed replacement must be installed you will need to have use contextual links permission as well as permission to edit the particular content or settings steps find and visit a page on your site that has the settings that you would like to edit click the contextual links edit button on the toolbar in most themes it looks like a pencil contextual edit links with the same icon will appear all over your page find the contextual link for the part of the page you want to edit for example if you want to edit the settings for a block the link should be in the topright corner of the block or topleft for righttoleft languages click the link to open the contextual links menu and click quick edit  an editing form for the settings should appear on the page make your edits and submit the form  ', 0),
(21, 'en', 'help_search', ' tracking the content of your website tracking overview the core history module tracks how recently users have viewed content items and provides a views field and filter that can be used to show users content that they haven t yet seen if you have one or more tracking modules installed on your site see the related topics listed below for specific tasks  ', 0),
(22, 'en', 'help_search', ' working with languages and translations what text can be translated in your site  there are three types of text that can be translated content blocks content items etc can be written in english or another language and can be translated into additional languages see managing content structure to learn more about content many configuration items also include text that can be translated default configuration provided by your site s software is provided in english you can also download communityprovided translations see managing and deploying configuration to learn more about configuration user interface text that is provided by the core software your install profile themes and modules is provided in english but can be translated into other languages you can also download translations that communitymembers have provided working with languages overview the core language module lets you add new languages to your site provides the language switcher block and provides the ability to configure block visibility by language the block and block visibility settings are only available if you have multiple languages configured the core content translation configuration translation and interface translation modules let you translate content configuration and the builtin user interface respectively the core update manager module manages automatic downloads of communityprovided translations of default configuration and userinterface text see the related topics listed below for specific tasks  ', 0),
(23, 'en', 'help_search', ' accessibility of the administrative interface overview of accessibility the core administrative interface has builtin compliance with many accessibility standards so that most pages are accessible to most users in their default state however certain pages become more accessible to some users through the use of a nondefault or improved interface these interfaces include disabling draganddrop functionality the default draganddrop user interface for ordering tables in the administrative interface presents a challenge for some users including keyboardonly users and users of screen readers and other assistive technology the draganddrop interface can be disabled in a table by clicking a link labeled show row weights above the table the replacement interface allows users to order the table by choosing numerical weights with increasing numbers instead of dragging table rows enabling inline form errors errors that occur when you submit a form such as not filling in a required field are sometimes difficult for users to understand and locate in order to make these errors easier to find the best practice is to put a summary of the errors at the top of the form page to make them easier to understand the best practice is to display error messages with the form fields they are related to both of these practices are implemented by the core inline form errors module  ', 0),
(24, 'en', 'help_search', ' using the administrative interface what administrative interface components are available  the following administrative interface components are provided by the core software and its modules some contributed modules offer additional functionality accessibility features to enable all users to perform administrative tasks see accessibility of the administrative interface for more information a menu system which you can navigate to find pages for administrative tasks the core toolbar module displays this menu on the top or left side of the page right side in righttoleft languages there are also contributed module replacements for the core toolbar module with additional features such as the admin toolbar module  the core shortcuts module enhances the toolbar with a configurable list of links to commonlyused tasks if you install the core contextual links module nonadministrative pages will contain links leading to related administrative tasks inplace or quick editing inplace editing of configuration is provided by the core settings tray module see using inline quick settings editing for more information the core help module displays help topics and provides a help block that can be placed on administrative pages to provide an overview of their functionality what are the sections of the administrative menu  the administrative menu which you can navigate by visiting  admin on your site or by using an administrative toolbar has the following sections some may not be available depending on which modules are currently installed on your site and your permissions  content  find manage and create new pages manage comments and files structure  place and edit blocks set up content types and fields configure menus administer taxonomy and configure some contributed modules appearance  switch between themes install themes and update existing themes extend  update install and uninstall modules configuration  configure the settings for various site functionality including some contributed modules people  manage user accounts and permissions reports  display information about site security necessary updates and site activity help  get help on using the administrative interface administrative interface overview install the core modules mentioned above to use the corresponding aspect of the administrative interface see the related topics listed below for more details on some aspects of the administrative interface  ', 0),
(25, 'en', 'help_search', ' enabling web services what is a web service  a web service allows your site to provide its content and data to other web sites and applications typically the data is transported via http in a serialized machinereadable format what is serialization  serialization is the process of converting complex data structures into text strings so that they can be exchanged and stored the reverse process is called deserialization  json and xml are the two mostcommonlyused data serialization formats for web services what is http basic authentication  http basic authentication is a method for authenticating requests by sending a user name and password along with the request what modules provide web services  the following core software modules provide web services json api module exposes entities to other applications using a fully compliant implementation of the json api specification  see managing content structure for more information on content entities and fields restful web services module exposes entities and other resources to other applications using a rest implementation data is exchanged using a serialization format such as json and transferred using an authentication method such as http basic authentication serialization module provides a framework for adding specific serialization formats for other modules to use http basic authentication module provides a way for web services to be authenticated using http basic authentication against site user accounts there are also contributed modules that provide web services additional resources online documentation for the restful web services module online documentation for the json api module comparison of the restful web services and json api modules ', 0),
(26, 'en', 'help_search', ' configuring help search goal set up your site so that users can search for help steps in the manage administrative menu navigate to extend  verify that the search help and block modules are installed or install them if they are not already installed in the manage administrative menu navigate to configuration   search and metadata   search pages  verify that a help search page is listed in the search pages section if not add a new page of type help  check the indexing status of the help search page if it is not fully indexed see running and configuring cron about how to run cron until indexing is complete in the future you can click rebuild search index on this page or clearing the site cache in order to force help topic text to be reindexed for searching this should be done whenever a module theme language or string translation is updated in the manage administrative menu navigate to structure   block layout  click the link for your administrative theme such as the core claro theme near the top of the page and verify that there is already a search block for help located in the help region if not follow the steps in the related topic to place the search form block in the help region when configuring the block choose help as the search page and in the pages tab under visibility  enter  admin help to make the search form only visible on the main help page in the manage administrative menu navigate to help  verify that the search block is visible and try a search  ', 0),
(27, 'en', 'help_search', ' working with help topics what is a help topic  a help topic describes a concept or steps to accomplish a task related to a feature provided by one or more modules or themes if the core search module is enabled these topics are also searchable where are help topics listed  the toplevel help topics are listed at help links to other topics including nontoplevel help topics can be found under the related heading when viewing a topic page how are help topics provided  modules and themes can provide help topics as twigfilebased plugins in a project subdirectory called helptopics  plugin metadata is provided in yaml front matter within each twig file pluginbased help topics provided by modules and themes will automatically be updated when a module or theme is updated use the plugins in core modules help helptopics as a guide when writing and formatting a help topic plugin for your theme or module how are help topics translated  the title and body text of help topics provided by contributed modules and themes are translatable using user interface translation provided by interface translation module topics provided by custom modules and themes are also translatable if they have been viewed at least once in a nonenglish language which triggers putting their translatable text into the translation database how can users search for help topics  to enable users to search help including help topics you will need to install the core search module configure a search page and add a search block to the help page or another administrative page a search page is provided automatically and if you use the core claro administrative theme a help search block is shown on the main help page then users with search permissions and permission to view help will be able to search help see the related topic configuring help search for stepbystep instructions additional resources help topics standards ', 0),
(28, 'en', 'help_search', ' configuring search pages goal configure one or more search pages steps in the manage administrative menu navigate to configuration   search and metadata   search pages  scroll down to the search pages section you will see a list of the alreadyconfigured search pages on your site to configure an existing search page click edit  or to add a new search page select the search page type and click add search page  enter the desired label name and url path for the search page for content search pages select the desired level of influence in ranking search results of the available content ranking factors click save  you will be returned to the search pages page verify that the correct search page is listed as default in the status column if not click set as default in the operations list for the correct search page optionally disable or delete any search pages that you do not want to have available on the site disabling is temporary while deleting is permanent follow the steps in managing the search index to make sure that the search index is updated  ', 0),
(29, 'en', 'help_search', ' managing the search index goal manage the search index and make sure that the site is fully indexed for searching what is the search index  the content and help search types provided by the core software preindex their content and store the results in several database tables that are collectively called the search index  the process of indexing renders the content and breaks it up into words which can then be matched more efficiently with keyword queries when users perform searches search indexing happens during cron runs see running and configuring cron for more information about cron steps in the manage administrative menu navigate to configuration   search and metadata   search pages  under indexing throttle  select the number of items to index per cron run  a smaller number will make cron faster and reduce the possibility of timeout a larger number will make sure more of your site is indexed in fewer cron runs under default indexing settings  enter the desired minimum word length to index  words smaller than this length will be dropped from both keywords when searching and content when indexing if your site uses chinese japanese or korean languages optionally check simple cjk handling under default indexing settings to provide some support for these languages click save configuration  and you should be returned to the search pages page click reindex site if you have changed the indexing configuration or later on if you believe that the search index has been corrupted follow the steps in running and configuring cron to make sure a cron task has been configured after waiting for cron to run several times verify that the content has been fully indexed for searching the overall status is listed under indexing progress  and the status for each search page is shown in the indexing progress column of the search pages section  ', 0),
(30, 'en', 'help_search', ' configuring site search what are search pages  the core search module organizes site search into pages  each page allows users to search a particular type of content with a particular configuration the configuration includes specifying a url that starts with search  a name for the page and additional options for some search page types when users visit the main search page see search  they will see the configured search pages that they have access to each search page has a search form on it and the page will display search results after the user enters keywords into the form and clicks the search button what modules provide site search  the core search module provides the ability to configure search pages search page types are provided by both core and contributed modules the core modules that provide search page types are the node module for searching content pages the user module for searching user profiles the help module for searching help topics as an alternative to the core search module s system of search pages you can use contributed modules to provide site search for example the apache solr and sphinx contributed modules use thirdparty technology to provide site search what are the limitations of the core search module  there are two main limitations of the core search module first it is not appropriate for very large sites if you have a large site look into other search technologies like apache solr second the node search page type only supports exact keyword matching which is not the behavior that most users will expect you can improve this by installing a languagespecific stemming module for your language such as porter stemmer for american english which makes it so that for example a search for the word walk would match pages containing the words walk walking and walked what are the search permissions  users with use search permission can use the search form block and search page this permission is required for any search configured in the core search module in addition to use search   view user information permission is needed for searching users in addition to use search   view published content permission is needed for searching content users with use advanced search permission can use more complex search filtering when performing content searches configuring site search overview in order to configure site search using the core search module you will need to configure one or more search pages you will also need to verify or alter permissions so that the desired user roles can search the site see managing user accounts and site visitors for more information about roles and permissions for content search you will also need to make sure that the search index is configured and that the site is fully indexed finally you may wish to place the search form block on pages of your site or add the search page to a navigation menu to give users easy access to search see the related topics listed below for specific tasks additional resources online documentation for the search module ', 0),
(31, 'en', 'help_search', ' clearing the site cache goal clear the data in the site cache what is the cache  some of the calculations that are done when your site loads a page take a long time to run to save time when these calculations would need to be done again their results can be cached in your site s database there are internal mechanisms to clear cached data when the conditions or assumptions that went into the calculation have changed but you can also clear cached data manually when your site is misbehaving a good first step is to clear the cache and see if the problem goes away steps in the manage administrative menu navigate to configuration   development   performance  click clear all caches  your site s cached data will be cleared additional resources concept cache drupal user guide  ', 0),
(32, 'en', 'help_search', ' changing basic site settings goal configure the basic settings of your site including the site name slogan main email address default time zone default country and the date formats to use steps in the manage administrative menu navigate to configuration   system   basic site settings  enter the site name slogan and main email address for your site click save configuration  you should see a message indicating that the settings were saved in the manage administrative menu navigate to configuration   region and language   regional settings  select the default country and default time zone for your site click save configuration  you should see a message indicating that the settings were saved in the manage administrative menu navigate to configuration   region and language   date and time formats  look at the patterns for the default long medium and short date formats if any of them does not match the date format you want to use on your site click edit in that row to edit the format adjust the format string until the displayed format matches what you want date format strings are composed of php date format codes click save format  you should see a message indicating that the format was saved repeat the previous three steps for any other date formats that need to be changed additional resources php date format codes reference ', 0);
INSERT INTO `[[dbprefix]]search_dataset` VALUES
(33, 'en', 'help_search', ' configuring error responses including 403404 pages goal set up your site to respond appropriately to site errors including 403 and 404 page responses what are 403 and 404 responses  when a user visits a web page the web server sends a response code in addition to the page content a normal nonerror response has code 200 if the page does not exist on the site the response code is 404 if the page exists but the user is not authorized to visit the page the response code is 403 the core software provides default responses for both 403 and 404 codes but if you prefer you can create your own pages for each what other errors can occur  under some situations your site can generate error messages these can be due to user errors such as entering invalid values in a form or incorrect configuration php runtime errors or software bugs some errors may result in a white screen of death  a totally blank web page response less drastic errors will generate error messages you can configure what happens when an error message is generated steps if desired create pages to use for 403 and 404 responses note the urls for these pages in the manage administrative menu navigate to configuration   system   basic site settings  in the error pages section enter the url for your 403404 pages starting after the site home page url for example if your site url is https examplecom and your 404 page is https examplecom notfound  you would enter  notfound  click save configuration  you should see a message indicating that the settings were saved in the manage administrative menu navigate to configuration   development   logging and errors  for a production site select none under error messages to display  for a site that is in development select one of the other options so that you are more aware of the errors the site is generating click save configuration  you should see a message indicating that the settings were saved  ', 0),
(34, 'en', 'help_search', ' enabling and disabling maintenance mode goal put your site in maintenance mode to perform maintenance operations and then return to normal mode when finished what is maintenance mode  when your site is in maintenance mode most site visitors will see a simple maintenance mode message page rather than being able to use the full functionality of the site users with use the site in maintenance mode permission who are already logged in will be able to use the full site and the log in page at  user will also be accessible to anyone steps in the manage administrative menu navigate to configuration   development   maintenance mode  check put site into maintenance mode  optionally change the message to display when in maintenance mode  and click save configuration  your site will be in maintenance mode perform your maintenance operations in the manage administrative menu navigate to configuration   development   maintenance mode  uncheck put site into maintenance mode and click save configuration  your site will be back in normal operation mode clear the site cache see clearing the site cache for instructions  ', 0),
(35, 'en', 'help_search', ' installing a module goal install a core module or a contributed module that has already been downloaded steps in the manage administrative menu navigate to extend  enter a word from the module name or description into the filter box to make the list of modules smaller locate the module you want to install check the box next to the name of the module you want to install you can also check more than one box to install multiple modules at the same time if the checkbox is disabled for the module you are trying to install expand the information to see why you may need to download an additional module that your module requires click install at the bottom of the page if you chose to install a module with dependencies that were not already installed or if you chose an experimental module confirm your choice on the next page wait for the module or modules to be installed you should be returned to the extend page with a message saying the module or modules were installed  ', 0),
(36, 'en', 'help_search', ' uninstalling a module goal uninstall a module your site should be in maintenance mode when you uninstall modules see enabling and disabling maintenance mode for details steps in the manage administrative menu navigate to extend   uninstall  enter a word from the module name or description into the filter box to make the list of modules smaller locate the module you want to uninstall in the description column see if there are reasons that this module cannot be uninstalled for example you may have created content using this module which you would need to delete first or there may be another module installed that requires this module to be installed you would need to uninstall the other module first if there are no reasons listed the module can be uninstalled check the box in the uninstall column next to the module s name click uninstall at the bottom of the page verify the list of modules to be uninstalled and configuration to be deleted on the confirmation page and click uninstall  wait for the module to be uninstalled you should be returned to the uninstall page with a message saying the module was uninstalled  ', 0),
(37, 'en', 'help_search', ' running reports on your site goal run reports to learn about the status and health of your site steps in the manage administrative menu navigate to reports   status report to see a report that summarizes the health and status of your site if there are any warnings or errors you will need to fix them take note of any upcoming highly critical security releases that may impact your site if you have the core database logging module installed in the manage administrative menu navigate to reports   recent log messages to see a report of the error and informational messages your site has generated you can filter the report by severity to see only the most critical messages if desired if you have the core update manager module installed in the manage administrative menu navigate to reports   available updates to see a report of the updates that are available for your site software if last checked is far in the past click check manually to update the report scan the report if the core software or any modules or themes have security updates available you should update them as soon as possible additional resources security and maintenance drupal user guide   which includes information on how to update your site s core software modules and themes  ', 0),
(38, 'en', 'help_search', ' installing a theme and setting default themes goal install a core theme or a contributed theme that has already been downloaded choose the default themes to use for the site and for administrative pages steps in the manage administrative menu navigate to appearance  locate the themes that you want to use as the site default theme and for administrative pages for each of these themes if the theme is in the uninstalled themes section click the install link to install the theme wait for the theme to be installed translations might be downloaded you should be returned to the appearance page locate the theme that you want to be your default theme which should now be in the installed themes section if it is not already labeled as the default theme  click the set as default link at the bottom of the page select the administration theme that you want to use on administrative pages click save configuration if you selected a new theme if you changed the default theme for your site visit the site home page or another page on the nonadministration part of your site and verify that the site is using the new theme if you changed the administration theme verify that the new theme is used on administrative pages  ', 0),
(39, 'en', 'help_search', ' uninstalling an unused theme goal uninstall a theme that was previously installed but is no longer being used on the site steps in the manage administrative menu navigate to appearance  locate the theme that you want to uninstall in the installed themes section click the uninstall link to uninstall the theme if there is not an uninstall link the theme cannot be uninstalled because it is either being used as the site default theme being used as the administration theme  or is the base theme for another installed theme  ', 0),
(40, 'en', 'help_search', ' creating a user account goal create a new user account steps in the manage administrative menu navigate to people  click add user  enter the email address   username  and password  twice for the new user verify that the roles checked for the new user are correct if you want the new user to receive an email message notifying them of the new account check notify user of new account  optionally change other settings on the form click create new account  you will be left on the add user page repeat these steps if you have more user accounts to create  ', 0),
(41, 'en', 'help_search', ' adding a new role goal create a new role steps in the manage administrative menu navigate to people   roles  click add role  enter the desired role name  if desired click edit to change the machine name for the role click save  you should be returned to the roles page and your new role should be in the role list  ', 0),
(42, 'en', 'help_search', ' managing user accounts and site visitors what is a user  a user is anyone accessing or viewing your site anonymous users are users who are not logged in and authenticated users are users who are logged in what is a role  roles are used to group and classify users each user can be assigned one or more roles there are also special roles for all anonymous and all authenticated users what is a permission  granting a permission to a role allows users who have been assigned that role to perform an action on the site such as viewing content editing or creating a particular type of content administering settings for a particular module or using a particular function of the site such as search  overview of managing user accounts and visitors the core user module allows users to register log in and log out and administrators to manage user roles and permissions the core ban module allows administrators to ban certain ip addresses from accessing the site depending on which modules you have installed on your site the related topics below will help you with tasks related to managing user accounts and visitors  ', 0),
(43, 'en', 'help_search', ' modifying the permissions for a role goal modify the permissions for an existing role steps in the manage administrative menu navigate to people   permissions  review the permissions for the role paying particular attention to the permissions marked with warning give to trusted roles only this permission has security implications uncheck permissions that this role should not have in the row of the permission and the column of the role check permissions that this role should have click save permissions   ', 0),
(44, 'en', 'help_search', ' configuring how user accounts are created and deleted goal configure settings related to how user accounts are created and deleted what are the settings related to user account creation and deletion  you can make it possible for new users to register themselves for accounts with or without email verification or administrative approval or you can make it so only administrators with administer users permission can register new users you can configure what happens to content that a user created if their account is canceled  deleted you can edit the email messages that are sent to users when their accounts are pending approved created blocked or canceled or when they request a password reset what are variables in email message text  variables are short text strings enclosed in square brackets that you can insert into configured email message text when an individual message is generated data from your site is substituted for the variables some commonlyused variables are site name the name of your website site url the url of your website site loginurl the url where users can log in to your site user displayname the user s displayed name user accountname the user s account name user mail the user s email alias user onetimeloginurl an expiring url that a user can use to log in once if they need to reset their password steps in the manage administrative menu navigate to configuration   people   account settings  select the method you want to use for creating user accounts and check or uncheck the box that requires email verification to match the settings you want for your site select the desired option for what happens to content that a user created if their account is canceled optionally edit the text of email messages related to user accounts verify that the other settings are correct click save configuration  you should see a message indicating that the settings were saved  ', 0),
(45, 'en', 'help_search', ' modifying or deleting a user account goal update or delete an existing user account steps in the manage administrative menu navigate to people  enter all or part of the user name or email address of the user account you want to update or delete and click filter  a short list of user accounts including the account of interest should be shown in the table if not modify the filter text until you can find the account of interest click edit in the operations area of the account of interest to delete the user account scroll to the bottom and click cancel account  select what you want to happen to the user s content on the next screen and click cancel account  to update the user account enter new values in the form and click save   ', 0),
(46, 'en', 'help_search', ' viewing drupal announcements what are drupal announcements  a feed of announcements about the drupal project and drupal association programs the purpose of this feed is to provide a channel for outreach directly to drupal site owners this content must be highly relevant to site owners interests serve the strategic goals of the project and or promote the sustainability of the project and the drupal association the module sources its content from a json feed generated from here  the governance policy for the content is documented here  how can i see the announcements in my site  if you have the toolbar module enabled you will see a direct link to them in the toolbar if the toolbar module is not enabled the content can always be accessed in the announcements page who can see the announcements  users with the view official announcements related to drupal permission can view drupal announcements additional resources announcement module overview ', 0),
(47, 'en', 'help_search', ' configuring a previouslyplaced block goal configure the settings of a block that was previously placed in a region of a theme steps in the manage administrative menu navigate to structure   block layout  click the name of the theme that contains the block optionally click demonstrate block regions to see the regions of the theme if you only want to change the region where a block is located or the ordering of blocks within a region drag blocks to their desired positions and click save blocks  if you want to change additional settings find the region where the block you want to update is currently located and click configure in the line of the block description edit the block s settings the available settings vary depending on the module that provides the block but for all blocks you can change  block title  the heading for the block on your site for some blocks you will need to check the override title checkbox in order to enter a title display title  check the box if you want the title displayed visibility  add conditions for when the block should be displayed region  change the theme region the block is displayed in click save block   ', 0),
(48, 'en', 'help_search', ' managing blocks what are blocks  blocks are boxes of content rendered into an area or region of a web page of your site blocks are placed and configured specifically for each theme what are content blocks  content blocks are blocks whose content you can edit you can define one or more block types  and attach fields to each block type content blocks can be placed just like blocks provided by other modules what is the block description  the block description is an identification name for a block which is shown in the administrative interface it is not displayed on the site what is the block title  the block title is the heading that is optionally shown to site visitors when the block is placed in a region overview for managing blocks the block module allows you to place blocks in regions of your installed themes and configure block settings the block content module allows you to manage block types and content blocks see the related topics listed below for specific tasks additional resources blocks drupal user guide  ', 0),
(49, 'en', 'help_search', ' placing a block goal place a block into a theme s region steps in the manage administrative menu navigate to structure  block layout click the name of the theme that you want to place the block in optionally click demonstrate block regions to see the regions of the theme find the region where you want the block and click place block in that region a modal dialog will pop up find the block you want to place and click place block  a configure block modal dialog will pop up configure the block and click save block  see configuring a previouslyplaced block for configuration details  ', 0),
(50, 'en', 'help_search', ' managing text filters and text formats goal configure text formats on the site what are text filters and text formats  a text filter is a processing step that can be applied to text either to transform it in some way such as converting urls in the text into html links or to defend against potentiallydangerous input from site users a text format is an ordered sequence of text filters text filters are provided by modules text formats are managed by the core filter module text fields that have formatted in the field type name such as text formatted   use text formats users choose the text format when editing the field text when the field text is shown on the site it is processed by the chosen text format administrators can configure text formats and assign permissions for who can use each format if the core text editor module is enabled administrators can also associate visual editors with text formats what text filters are available  some of the more commonly used text filters are limit allowed html tags and correct faulty html limits which html tags can be used useful both for site security and enforcing site design convert line breaks into html line breaks in html source are displayed as horizontal spaces this filter converts line breaks into html paragraph and line break tags convert urls into links takes plain urls in text and turns them into html links restrict images to this site for text formats that allow html image tags restricts images to urls within this site steps in the manage administrative menu navigate to configuration   content authoring   text formats and editors  if you do not have the core text editor module installed the menu link and page title will instead be text formats  click configure to configure an existing text format or  add text format to create a new text format enter the desired name for the text format check the roles that can use this text format some html tags allow users to embed malicious links or scripts in text to ensure security anonymous and untrusted users should only have access to text formats that restrict them to either plain text or a safe set of html tags improper text format configuration is a security risk if the core text editor module is installed see the related topic to connect a text editor to this text format under enabled filters  check the text filters that you want to use under filter processing order  drag the filters to the correct order choose the order carefully for example if you have a filter that results in a particular html tag being added to the text that should run after a filter that restricts html tags to avoid deleting the new tags the first filter added under filter settings  verify and adjust the settings for each active filter that has configuration options click save configuration  which will return you to the text formats and editors page repeat these steps if you have additional text formats to configure  ', 0),
(51, 'en', 'help_search', ' creating a content block goal create a content block which can later be placed on the site steps in the manage administrative menu navigate to content  open the content blocks tab click add content block  if you have more than one block type defined on your site click the name of the type you want to create enter a description of your block to be shown to administrators and the body text for your block click save   ', 0),
(52, 'en', 'help_search', ' defining a block type goal define a block type and its fields steps in the manage administrative menu navigate to structure   block types  click add block type  enter a label for this block type shown in the administrative interface optionally edit the automaticallygenerated machine name or the description click save  you will be returned to the block types page click manage fields in the row of your new block type and add the desired fields to your block type optionally click manage form display or manage display to change the editing form or field display for your block type  ', 0),
(53, 'en', 'help_search', ' managing height width and resolution breakpoints what are breakpoints  breakpoints are the point at which your site s content will respond to provide the user with the best possible layout to consume the information a breakpoint separates the height or width of viewports screens printers and other media output types into steps for instance a width breakpoint of 40em creates two steps one for widths up to 40em and one for widths above 40em breakpoints can be used to define when layouts should shift from one form to another when images should be resized and other changes that need to respond to changes in viewport height or width what are media queries  media queries are a formal way to encode breakpoints for instance a width breakpoint at 40em would be written as the media query minwidth 40em breakpoints are really just media queries with some additional metadata such as a name and multiplier information what are resolution multipliers  resolution multipliers are a measure of the viewport s device resolution defined to be the ratio between the physical pixel size of the active device and the deviceindependent pixel size the breakpoint module defines multipliers of 1 15 and 2 when defining breakpoints modules and themes can define which multipliers apply to each breakpoint what is a breakpoint group  breakpoints can be organized into groups modules and themes should use groups to separate out breakpoints that are meant to be used for different purposes such as breakpoints for layouts or breakpoints for image sizing managing breakpoints and breakpoint groups overview the breakpoint module allows you to define breakpoints and breakpoint groups in yaml files modules and themes can use the api provided by the breakpoint module to define breakpoints and breakpoint groups and to assign resolution multipliers to breakpoints additional resources working with breakpoints in drupal w3c standards for media queries ', 0),
(54, 'en', 'help_search', ' connecting text editors to text formats goal configure a text format so that when a user is editing text and selects this text format a text editor installed on your site is shown configure the text editor such as choosing which buttons and functions are available see managing text filters and text formats for more about text formats what is a text editor  a text editor is software typically a javascript library that provides buttons and other command mechanisms to make editing html text easier some editors are called visual or wysiwyg what you see is what you get  editors these editors hide the details of html from the user and instead show formatted output on the screen the core text editor module provides a framework for deploying text editors on your site the core ckeditor 5 module provides ckeditor 5 which is a widelyused javascript text editor that creates clean and valid html the module also enforces the html tag restrictions in the associated text format various contributed modules provide other editors to install a new editor besides installing the module you may need to download the editor library from a thirdparty site steps in the manage administrative menu navigate to configuration   content authoring   text formats and editors  the text editor column in the table shows the text editor that is currently connected to each text format if any follow the steps on managing text filters and text formats to add a new text format or configure an existing text format when you reach the step about text editors return to this topic select ckeditor 5 as the text editor  or another text editor that you have installed the rest of these steps assume you selected ckeditor 5  under toolbar configuration  drag buttons between available buttons and active toolbar  only buttons in active toolbar will be shown to the user focusing or hovering over a button will display a tooltip explaining what the button does drag buttons within active toolbar to the desired order and group buttons by dragging them between group identifiers drag a new group identifier to the toolbar to add additional groups if you add buttons that require configuration the ckeditor 5 plugin settings section will be visible and provide their respective configuration forms return to managing text filters and text formats to complete the text format configuration and be sure to save the text format  ', 0),
(55, 'en', 'help_search', ' configuring comments goal configure a content entity type subtype to allow commenting using a comment type that you have configured see managing content structure for more about content entities and fields and creating a comment type to configure a comment type who can configure comments  in order to follow these steps the field ui module must be installed you ll need the comment module s administer comments and comment settings permission in order to change comment settings for a comment field you ll also need to have the appropriate permission for adding fields to the entity type or subtype that the comments are attached to for example to add a comment field to content items provided by the node module you would need the node module s administer content types permission steps follow the steps in the related adding a field to an entity subtype topic to add a field of type comments to the desired entity type or subtype on the first field settings page choose the comment type to use for this entity type or subtype you ll also notice that the allowed number of values field cannot be changed for comment fields on the next field settings page enter the desired settings for the comment field  threading  whether or not the comments are collected by threads with people able to reply to particular comments instead of to the content entity itself comments per page  the maximum number of comments displayed on one page a pager will be added if you exceed this limit  anonymous commenting  whether or not anonymous commenters are allowed or required to leave contact information with their comments only applies if anonymous users have permission to post comments  show reply form on the same page as comments  whether the comment reply form is displayed on the same page as the comments if this is not selected clicking reply will open a new page with the reply form preview comments  whether previewing comments before submission is required   optional  or disabled  default value  each individual entity has its own comment settings but here you can set defaults for the comment settings for this entity type or subtype the comment settings values are  open  comments are allowed closed  past comments remain visible but no new comments are allowed hidden  past comments are hidden and no new comments are allowed additional resources online documentation for content comment settings ', 0),
(56, 'en', 'help_search', ' creating a comment type goal create a new comment type see managing comments for information about comments and comment types who can create a comment type  users with the administer comment types and settings permission typically administrators can create comment types steps in the manage administrative menu navigate to structure   comment types  click add comment type  in the label field enter a name for the comment type which is how it will be listed in the administrative interface in the target entity type field select the entity type to be commented on see managing content structure for more about content entities and fields click save  the comment type will be created optionally if you have the core field ui module installed you can follow the steps in the related topics to add fields to the new comment type set up the editing form and configure the display  ', 0),
(57, 'en', 'help_search', ' disabling comments goal turn off commenting for a particular entity see managing content structure for more about content entities and fields note that if you want to turn off commenting for all entities of an entity type or subtype you will need to edit the field settings for the comment field see configuring comments for more about configuring the comment field who can disable comments  you will need the administer comments and comment settings permission in order to disable commenting you will also need permission to edit the entity that the comments are on steps find the entity you want to disable comments for and edit it for example to turn off comments on a content item you could find it by navigating in the manage administrative menu to content  filtering to find the content item and clicking edit  under comment settings  select the desired comment setting  open  comments are allowed closed  past comments remain visible but no new comments are allowed hidden  past comments are hidden and no new comments are allowed save the entity  ', 0),
(58, 'en', 'help_search', ' moderating comments goal decide which comments are shown on the website who can moderate comments  users with the administer comments and comment settings permission typically administrators can moderate comments you will also need the access the content overview page permission from the node module if it is installed to navigate to the comment management page steps in the manage administrative menu navigate to content   comments  a list of all comments is shown to unpublish comments select one or more comments by checking the boxes on the left side right side in righttoleft languages then select unpublish comment from the action select list and click apply to selected items  if you select the delete comment action you can instead delete the unwanted comments to change the content of a comment click edit from the dropdown button for a particular comment to publish comments that are not yet visible on the website navigate to the unapproved comments tab select one or more comments by checking the boxes on the left side right side in righttoleft languages then select publish comment from the action select list and click apply to selected items  additional resources online documentation for moderating comments ', 0),
(59, 'en', 'help_search', ' managing comments what is a comment  a comment is a piece of content typically posted by a website visitor which provides discussion or commentary on other content like blog posts and news articles comments are a type of content entity and can have fields that store text html markup and other data comments are attached to other content entities via comment fields see managing content structure for more about content entities and fields what is a comment type  comments are divided into comment types  which are the entity subtypes for the comment entity type each comment type has its own fields and its own form and display settings each type can be used to comment on a single entity type you can set up different comment types for different commenting purposes on your web site for example you might set up a comment type for recipes that has fields how did it taste and did the instructions work and another comment type for blog entries that has only a generic comment body field what is moderation  moderation is a workflow where comments posted by some users on your site are verified before being published to prevent spam and other bad behavior the core software provides basic moderation functionality you can configure permissions so that new comments posted by some user roles start as unpublished until a user with a different role reviews and publishes them contributed modules provide additional moderation and spamreduction functionality such as requiring untrusted users pass a captcha test before submitting comments and letting community members flag comments as possible spam see managing user accounts and site visitors for more about users permissions and roles overview of managing comments the core comment module provides the following functionality posting comments creating comment types the core field ui module allows you to attach fields to comment types and attach comment reference fields to other entities so that people can comment on them configuring commenting moderating comments as discussed above see the related topics listed below for specific tasks  ', 0),
(60, 'en', 'help_search', ' using contextual links goal use contextual links to access administrative tasks without navigating the administrative menu what are contextual links  contextual links give users with the use contextual links permission quick access to administrative tasks related to areas of nonadministrative pages for example if a page on your site displays a block the block would have a contextual link that would allow users with permission to configure the block if the block contains a menu or a view it would also have a contextual link for editing the menu links or the view clicking a contextual link takes you to the related administrative page directly without needing to navigate through the administrative menu system steps make sure that the core contextual links module is installed and that you have a role with the use contextual links permission optionally make sure that a toolbar module is installed either the core toolbar module or a contributed module replacement visit a nonadministrative page on your site such as the home page locate a block or another area on the page that you want to edit or configure make the contextual links button visible by hovering your mouse over that area in the page in most themes this button looks like a pencil and is placed in the upper right corner of the page area upper left for righttoleft languages and hovering will also temporarily outline the affected area alternatively click the contextual links toggle button on the right end of the toolbar left end for righttoleft languages which will make all contextual link buttons on the page visible until it is clicked again while the contextual links button for the area of interest is visible click the button to display the list of links for that area click a link in the list to visit the corresponding administrative page complete your administrative task and save your settings or cancel the action you should be returned to the page you started from  ', 0),
(61, 'en', 'help_search', ' adding a field to an entity subtype goal add a field to an entity subtype see managing content structure for an overview of entity types and subtypes as well as an overview of field types steps navigate to the page for managing the entity subtype you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to add the field to and click manage fields  click add field  in add a new field  select the type of field you want to add see managing content structure for an overview of field types the label field should now be visible enter a label for the field which is used as the field label for both content editing and content display click save and continue  on the next screen enter a value for allowed number of values  you can limit the field to one value per entity item a set number of values or set it to have unlimited values click save field settings  on the next screen optionally edit the settings for the field which vary depending on what field type you are creating for all fields you can edit the label   help text  text to be displayed below the field on the content editing page and required field  to make it so a value must be entered in order to save the content when editing you can also configure a default value for the field click save settings  you should be returned to the manage fields page with your new field in the list  ', 0),
(62, 'en', 'help_search', ' configuring field display for an entity subtype goal configure the formatters used to display the fields of an entity subtype their order in the display and the formatter settings see managing content structure for background information steps navigate to the page for managing the entity type you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to configure the display of and click manage display in the operations list use the drag arrows to order the fields in your preferred order drag any fields that you do not wish to see in the display to the disabled section in the label column select the position for each field label in the display or  hidden  to hide a label you can also choose  visually hidden if you want the label s text to appear in the html page so that screen readers and search engines can read it but it will not be visible in the format column select the formatter for displaying each field after selecting the desired formatters click the settings gear in each row to change the settings for the formatter when you are done making changes click save  test the display for your entity subtype by viewing an entity if needed return to these steps to further refine the display  ', 0),
(63, 'en', 'help_search', ' configuring the edit form for an entity subtype goal configure the widgets used to edit the fields of an entity subtype their order on the form and the widget settings see managing content structure for background information steps navigate to the page for managing the entity type you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to configure the editing form for and click manage form display in the operations list use the drag arrows to order the fields in your preferred order drag any fields that you do not wish to see on the editing form to the disabled section in the widget column select the widget for editing each field after selecting the desired widgets click the settings gear in each row to change the settings for the widget when you are done making changes click save  test the editing form for your entity subtype by editing or creating an entity if needed return to these steps to further refine the form  ', 0),
(64, 'en', 'help_search', ' adding a reference field to an entity subtype goal add an entity reference field to an entity subtype see managing content structure for more information on entities and reference fields steps navigate to the page for managing the entity subtype you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to add the field to and click manage fields  click add field  in add a new field  select the type of reference field you want to add the reference section of the select list shows the most common types of reference field choose other  if the entity type you want to reference is not listed the label field should now be visible enter a label for the field which is used as the field label for both content editing and content display click save and continue  on the next screen verify that the type of entity you want to reference is shown in type of item to reference  or select it if not enter a value for allowed number of values  you can limit the field to one value per entity item a set number of values or set it to have unlimited values click save field settings  on the next screen optionally edit the settings for label   help text  text to be displayed below the field on the content editing page and required field  to make it so a value must be entered in order to save the content when editing in the reference type section you will usually want to limit the entity subtypes that can be referenced for example if you are creating a content reference you can check one or two content type choices the choices will be easier for content editors to scan if you also choose a sort value normally the entity title or label field click save settings  you should be returned to the manage fields page with your new field in the list  ', 0),
(65, 'en', 'help_search', ' creating a content item goal create and publish a content item see managing content for more about content types and content items who can create content  users with the access the content overview page permission can visit the content page as described in this topic each content type has its own create permissions for example to create content of type article a user would need the article create new content permission in addition users with the bypass content access control or administer content permission can create content items of all types some contributed modules change the permission structure for creating content steps in the manage administrative menu navigate to content  click add content  if there is more than one content type defined on your site that you have permission to create click the name of the type of content you want to create on the content edit form enter the title of your content which will show as the page title when the content item is displayed on a page and also as the label for the content item in administration screens fill in the other fields shown on the edit form for this specific content type leave the published field checked to publish the content immediately or uncheck it to make it unpublished unpublished content is generally not shown to nonadministrative site users optionally click preview to preview the content click save  you will see the content displayed on a page additional resources basic page management drupal user guide  creating a content item drupal user guide  ', 0),
(66, 'en', 'help_search', ' creating a content type goal create a new content type see managing content for more about content types who can create a content type  users with the administer content types permission typically administrators can create new content types steps in the manage administrative menu navigate to structure   content types  click add content type in the name field enter a name for the content type which is how it will be listed in the administrative interface optionally enter a description for the content type you may also want to adjust some of the settings in the vertical tabs section of the edit page click save and manage fields  your content type will be created and assuming you have the core field ui module installed you will be taken to the manage fields page for the content type if you do not have the core field ui module installed the button will say save instead if you have the core field ui module installed follow the steps in the related topics to add fields to the new content type set up the editing form and configure the display additional resources adding a content type drupal user guide  setting up content structure drupal user guide  ', 0),
(67, 'en', 'help_search', ' editing a content item goal find a content item and edit it or update a group of content items in bulk see managing content for more about content types and content items who can find and edit content  users with the access the content overview page permission can use the content page to find content each content type has its own edit permissions for example to edit content of type article a user would need the article edit own content permission to edit an article they created or the article edit any content permission to edit an article someone else created in addition users with the bypass content access control or administer content permission can edit content items of all types some contributed modules change the permission structure for editing content steps in the manage administrative menu navigate to content  optionally use filters to reduce the list of content items shown  title  key word s from the title content type published status language if you enter or select filter values click filter to apply the filters optionally sort the list by clicking a column header click again to reverse the order to edit the title or other field values for one content item click edit in the row of the content item update the values and click save  a few types of edits can be done in bulk to multiple content items for example to publish several unpublished content items check the boxes in the left column right column in righttoleft languages to select the desired content items for action  select the publish content action click apply to selected items to make the change the other actions under action work in a similar manner additional resources basic page management drupal user guide  editing a content item drupal user guide  ', 0),
(68, 'en', 'help_search', ' managing content what is a content item  a content item is a type of content entity for pagelevel content which can have fields that store text html markup images attached files and other data see managing content structure for more about content entities and fields what is a content type  content items are divided into content types  which are the entity subtypes for the content item entity type each content type has its own fields and display settings for example you might set up content types for pages articles recipes events and blog entries on your web site overview of managing content the core node module allows you to define content types and add and edit content items the core field ui module allows you to attach fields to each content type and manage the edit form and display for each content type see the related topics listed below for specific tasks many other core and contributed modules and installation profiles provide predefined content types modify the permission structure for content items and provide other functionality  ', 0),
(69, 'en', 'help_search', ' tracking which content a user has visited what content visits are tracked  the core history module tracks when each loggedin user has most recently visited each content item page on the site this allows content to be marked as new or updated for each user meaning that it was newly created or has been updated since the last time they visited its page these records are kept for one month meaning that content older than one month is never marked as new or updated what options are available for using this tracking information  you can display the new updated status of content by creating or editing a view there is a has new content field for content views which displays the new updated marker there is also a has new content filter which limits the view to new and updated content  ', 0),
(70, 'en', 'help_search', ' adding an image style goal add a new image style which can be used to process and display images see managing media for an overview of image styles steps in the manage administrative menu navigate to configuration   media  image styles click add image style  enter a descriptive image style name  and click create new style  under effect  choose an effect to apply and click add  configure the effect on the next page most effects require some additional configuration after they are added for example for the crop effect enter the width and height to crop the image to and choose the anchor point click add effect  repeat the previous two steps until all of the effects have been added drag to change the order of the effects then click save to save the new order the image style can now be used to format a field containing an image in your layouts or traditional field displays it can also be used as part of a responsive image style see related topics below for more information  ', 0);
INSERT INTO `[[dbprefix]]search_dataset` VALUES
(71, 'en', 'help_search', ' managing content listings views  what is a view  a view is a listing of items on your site for example a block showing the most recent comments a page listing news items or a list of registered users the listings can be formatted in a table grid list calendar rss feed and other formats some output formats may require you to install additional contributed modules  what are the components of a view  when you first create a view you will specify what type of base data is being displayed in the view which cannot be changed after choosing a base data type you can edit the following components which allow you to specify which data to output in what order and in what format  displays  whether the output goes to a page block feed etc a single view can have multiple displays each with different settings format  the output style for each display such as content item grid table or html list fields  if the format allows the particular fields to display filter criteria  criteria to limit the data to output such as whether the content is published the type of content etc filters can be exposed to let users choose how to filter the data sort criteria  how to order the data sorting can also be exposed to users page settings   block settings  etc settings specific to the display type such as the url for a page display most display types support an access setting where you can choose a permission or role that a user must have in order to see the view header and footer  content to display at the top or bottom of the view display no results behavior  what to do if the filter criteria result in having no data to display pager  how many items to display and how to paginate if there are additional items to display advanced   contextual filters  like regular filters except the criteria come from the context  such as the current date page the view is displayed on etc advanced   relationships  additional data to pull in and display related in some way to the base data of the view such as data about the user who created the content item  advanced   exposed form  if you have exposed filters or sorts how to display the form to the user what are bulk operations  views using a table display format can include a bulk operations form which allows users with sufficient permission to select one or more items from the view and apply an administrative action to them the bulk actions available are specific to the base data type of the view for example a view of content items could support bulk publishing and unpublishing actions if you have the core actions ui module installed see the related topic configuring actions for more about actions managing views overview the core views module handles the display of views and the core views ui module allows you to create edit and delete views in the administrative interface see the related topics listed below for specific tasks if the views ui module is installed  additional resources creating listings with views drupal user guide  ', 0),
(72, 'en', 'help_search', ' configure menu settings for a content type goal for an existing content type configure the available menus that will be shown as options on content editing screens links to content items of this type can be added to these menus during editing steps in the manage administrative menu navigate to structure  content types locate the content type you want to configure and click edit in the operations list under menu settings  check the menus that you want to be available when editing a content item of this type optionally select the default parent item  to put links to content items under a default location in the menu structure click save   ', 0),
(73, 'en', 'help_search', ' adding a link to a menu goal add a link to a menu note that you can also add a link to a menu from the content edit page if menu settings have been configured for the content type steps in the manage administration menu navigate to structure  menus locate the desired menu and click add link in the operations list enter the menu link title to be displayed enter the link  one of the following an internal path such as  node add a full external url start typing the title of a content item and select it when the full title comes up  nolink  to display the menu link title as plain text without a link  front  to link to the front page of your site make sure that enabled is checked if not the menu link will not be displayed optionally enter a description  which will be displayed when a user hovers over the link optionally check show as expanded to automatically show the children of this link if any when this link is shown optionally select the parent link  if this menu link should be a child of another menu link click save  you will be returned to the add link page to add another link in the manage administration menu navigate to structure  menus locate the menu you just added a link to and click edit in the operations list verify that the order of links is correct if it is not drag menu links until the order is correct and click save   ', 0),
(74, 'en', 'help_search', ' creating a menu goal create a new menu steps in the manage administration menu navigate structure  menus click add menu  enter the title for the menu which is used as the default block title if the menu is displayed as a block if desired also edit the machine name of the menu which is by default derived from the title enter an administrative summary which is displayed on the menus page if your site has more than one language choose the language for the menu click save  you will be on the menu editing page ready to add links to the menu if the core custom menu links module is installed see related topics for further tasks  ', 0),
(75, 'en', 'help_search', ' reordering and disabling menu links goal disable menu links or change the order and hierarchy of menu links steps in the manage administration menu navigate to structure  menus click edit menu for the menu that you want to edit drag menu links into a new order or check uncheck enabled to enable or disable menu links click save to save your changes  ', 0),
(76, 'en', 'help_search', ' creating a url alias for a content item goal give a content item page a human or seofriendly url alias you can follow similar steps to create an alias for a taxonomy term page see configuring aliases for urls for more about aliases who can create url aliases  users with the create and edit url aliases permission can create aliases to follow the steps in this topic you will also need permission to edit the content item steps locate and open the content edit form for the content item or create a new content item see related topics on creating and editing content under url alias on the edit form enter the desired alias for example aboutus make sure the alias starts with a character click save  verify that the page can be visited with the new alias for example https examplecom aboutus  additional resources creating a content item drupal user guide  ', 0),
(77, 'en', 'help_search', ' editing a url alias goal change an existing url alias to correct the path or the alias value see configuring aliases for urls for more about aliases who can manage url aliases  users with the administer url aliases permission can edit aliases steps in the manage administration menu navigate to configuration   search and metadata   url aliases  a list of all the site s aliases will appear click edit in the dropdown button for the alias that you would like to change make the required changes and click save  you will be returned to the url alias list page note that you can also add new aliases from this page for any path on your site  ', 0),
(78, 'en', 'help_search', ' configuring aliases for urls what is a url  url is the abbreviation for uniform resource locator which is the page s address on the web it is the name by which a browser identifies a page to display in the example visit us at examplecom   https examplecom would be the url for the home page of your website users use urls to locate content on the web what is a path  a path is the unique last part of the url for a specific function or piece of content for example for a page whose full url is https examplecom node 7  the path is node 7  here are some examples of paths you might find in your site node 7 path to a particular content item taxonomy term 6 path to a taxonomy term page user 3 path to a user profile page what is an alias  the core software allows you to provide more understandable urls for pages on your site which are called aliases  for example if you have an about us page with the path node 7  you can set up an alias of about so that your visitors will see it as https wwwexamplecom about  overview of configuring paths aliases and urls the core path module provides the url aliasing functionality the contributed pathauto module allows you to configure automaticallygenerated url aliases for content items and other pages see the related topics listed below for specific tasks additional resources concept paths aliases and urls drupal user guide  ', 0),
(79, 'en', 'help_search', ' creating and using shortcut administrative links goal create view and use a set of shortcuts to access administrative pages what are shortcuts  shortcuts are quick links to administrative pages they are managed by the core shortcut module a site can have one or more shortcut sets  which can be shared by one or more users by default there is only one set shared by all users each set contains a limited number of shortcuts users need use shortcuts permission to view shortcuts  edit current shortcut set permission to add delete or edit the shortcuts in the set assigned to them and select any shortcut set permission to select a different shortcut set when editing their user profile there is also an administer shortcuts permission which allows an administrator to do any of these actions as well as select shortcut sets for other users steps make sure that the core shortcut module is installed and that you have a role with edit current shortcut set or administer shortcuts permission also make sure that a toolbar module is installed either the core toolbar module or a contributed module replacement navigate to an administrative page that you want in your shortcut list click the shortcut link to add the page to your shortcut list in the core claro administrative theme the link looks like a star and is displayed next to the page title however if the page is already in your shortcut set clicking the shortcut link will remove it from your shortcut set repeat until all the desired links have been added to your shortcut set click shortcuts in the toolbar to display your shortcuts and verify that the list is complete optionally click edit shortcuts at the right end of the shortcut list left end in righttoleft languages to remove links or change their order click any link in the shortcut bar to go directly to the administrative page  ', 0),
(80, 'en', 'help_search', ' configuring taxonomy goal create a taxonomy vocabulary and add a reference field for that vocabulary to a content entity see managing taxonomy for information about taxonomy and managing content structure for more on content entities who can configure a taxonomy vocabulary  users with the administer vocabularies and terms permission can configure a vocabulary to add a field in the administrative interface the core field ui module must be installed and you will also need the administer fields permission for the entity you are adding the field to steps in the manage administrative menu navigate to structure   taxonomy  click add vocabulary  in the name field enter a name for the vocabulary for example ingredients which is how it will be shown in the administrative interface optionally add a description click save  your vocabulary will be created and you will see the page that lists all the terms in this vocabulary optionally click add term to add a term to the new vocabulary in the name field enter the term name for example butter click save  you will receive a confirmation about the term you created you may optionally continue to add more terms if you have the field ui module installed follow the instructions on the related adding a reference field to an entity subtype topic to add a taxonomy reference field to the entity type of your choice the settings page will allow you to choose the vocabulary that you created as the vocabulary to reference you may also want to configure the display and form display of the new field see related topics  additional resources setting up a taxonomy drupal user guide  ', 0),
(81, 'en', 'help_search', ' managing taxonomy what is taxonomy  taxonomy is used to classify website content one common example of taxonomy is the tags used to classify or categorize posts in a blog website a cooking website could use an ingredients taxonomy to classify recipes individual taxonomy items are known as terms  the blog tags or recipe ingredients in these examples and a set of terms is known as a vocabulary  the set of all blog post tags or the set of all recipe ingredients in these examples technically taxonomy terms are an entity type and the entity subtypes are the vocabularies see managing content structure for more on content entities like other entities taxonomy terms can have fields attached for instance you could set up an image field to contain an icon for each term an individual vocabulary can organize its terms in a hierarchy or it could be flat for example blog tags normally have a flat structure while a recipe ingredients vocabulary could be hierarchical for example tomatoes could be a subterm of vegetables and under tomatoes you could have green and red tomatoes taxonomy terms are normally attached as reference fields to other content entities which is how you can use them to classify content when you set up a taxonomy reference field you can let users enter terms in two ways free tagging new terms can be created right on the content editing form fixed list of terms the list of terms is curated and managed outside the content editing form and users can only select from the existing list when editing content taxonomy reference fields can be added to any entity such as user accounts content blocks or regular content items if you use them to classify regular content items your site will automatically be set up with taxonomy listing pages for each term each of these pages lists all of the content items that are classified with that term overview of managing taxonomy the core taxonomy module allows you to create and edit taxonomy vocabularies and taxonomy terms the core field ui module provides a user interface for adding fields to entities including the taxonomy reference field and configuring field editing and display see the related topics listed below for specific tasks additional resources concept taxonomy drupal user guide  ', 0),
(82, 'en', 'help_search', ' adding a new display to an existing view goal add a new display to an existing view this will allow you to display similar data to an existing view using similar settings in a new block page feed etc steps if you are not already editing your view in the manage administrative menu navigate to structure   views  find the view you want to edit and click its edit link under displays  click add  in the popup list click the link for the type of display you want to add the most common types are page and block  the new display will be added to your view and you will be editing that display optionally click the link next to display name and enter a new name to be shown for this display in the administrative interface follow the steps in editing an existing view display to edit the other settings for the display  ', 0),
(83, 'en', 'help_search', ' adding a bulk operations form to a view goal add one or more existing actions as bulk operations to an existing tablestyle view if you have the core actions ui module installed see the related topic configuring actions for more information about actions who can edit views  the core views ui module will need to be installed and you will need administer views permission in order to edit a view steps in the manage administrative menu navigate to structure   views  a list of all views is shown find the view that you would like to edit and click edit from the dropdown button note that bulk operations work best in a view with a page display and a table format if there is not already an operations bulk form in the fields list for the view click add in the fields section to add it the exact name of the bulk form field will vary and may contain keywords like bulk update form element or operations not to be confused with operations links  which are applied to each item in a row if the bulk operations field already exists click the field name to edit its settings check the action s you want to make available in the selected actions list and click apply all displays   verify that the access settings for the view are at least as restrictive as the permissions necessary to perform the bulk operations people with permission to see the view but who don t have permission to do the bulk operations will experience problems click save  the action s will be available as bulk operations in the view  ', 0),
(84, 'en', 'help_search', ' creating a new view goal create a new view to list content or other items on your site steps in the manage administrative menu navigate to structure   views  click add view  in the view name field enter a name for the view which is how it will be listed in the administrative interface in view settings   show  select the base data type to display in your view this cannot be changed later optionally select or enter filtering sorting and page block display settings these can be added or changed later click save and edit  your view will be created edit it following the steps in the related topics below  ', 0),
(85, 'en', 'help_search', ' editing an existing view display goal edit an existing view display to modify what data is displayed or how it is displayed steps if you are not already editing your view in the manage administrative menu navigate to structure   views  find the view you want to edit and click its edit link under displays  click the display you want to edit find the section whose settings you want to change such as format or filter criteria  see managing content listings views for more information for sections containing lists such as fields and filter criteria  to modify or delete an existing item click the name of the item to add a new item click add in the dropdown list to change the order of items click rearrange in the dropdown list for sections containing individual settings such as title and format  there are often two links for each setting the first link shows the current value click that link to change the value if there is a second link called settings  click that link to change the settings details for example if your format is currently shown as unformatted list  click unformatted list to switch to using a grid or table format click settings next to your format type to change the settings for your chosen format when you have finished changing all the settings verify that the display is correct by clicking update preview  return to editing settings if necessary when you have verified the display click save  alternatively if you have made mistakes and want to discard your changes click cancel  additional resources creating listings with views drupal user guide  ', 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]search_index`
--

CREATE TABLE `[[dbprefix]]search_index` (
  `word` varchar(50) NOT NULL DEFAULT '' COMMENT 'The "[[dbprefix]]search_total".word that is associated with the search item.',
  `sid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "[[dbprefix]]search_dataset".sid of the searchable item to which the word belongs.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "[[dbprefix]]languages".langcode of the item variant.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The "[[dbprefix]]search_dataset".type of the searchable item to which the word belongs.',
  `score` float DEFAULT NULL COMMENT 'The numeric score of the word, higher being more important.',
  PRIMARY KEY (`word`,`sid`,`langcode`,`type`),
  KEY `sid_type` (`sid`,`langcode`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Stores the search index, associating words, items and…';

--
-- Dumping data for table `[[dbprefix]]search_index`
--

INSERT INTO `[[dbprefix]]search_index` VALUES
('1', 53, 'en', 'help_search', 1),
('15', 53, 'en', 'help_search', 1),
('2', 11, 'en', 'help_search', 1),
('2', 53, 'en', 'help_search', 1),
('200', 33, 'en', 'help_search', 1),
('255', 12, 'en', 'help_search', 0.7017),
('3', 78, 'en', 'help_search', 1),
('403', 33, 'en', 'help_search', 23),
('403404', 33, 'en', 'help_search', 27),
('404', 33, 'en', 'help_search', 23.9769),
('40em', 53, 'en', 'help_search', 5),
('5', 54, 'en', 'help_search', 13.1162),
('6', 78, 'en', 'help_search', 1),
('7', 78, 'en', 'help_search', 13),
('9', 10, 'en', 'help_search', 1),
('abbreviation', 78, 'en', 'help_search', 1),
('ability', 11, 'en', 'help_search', 1),
('ability', 17, 'en', 'help_search', 2),
('ability', 18, 'en', 'help_search', 0.857458),
('ability', 20, 'en', 'help_search', 1),
('ability', 22, 'en', 'help_search', 1),
('ability', 30, 'en', 'help_search', 1),
('able', 27, 'en', 'help_search', 0.961087),
('able', 34, 'en', 'help_search', 2),
('able', 55, 'en', 'help_search', 1),
('about', 1, 'en', 'help_search', 1),
('about', 2, 'en', 'help_search', 1),
('about', 3, 'en', 'help_search', 1),
('about', 4, 'en', 'help_search', 1),
('about', 12, 'en', 'help_search', 1),
('about', 19, 'en', 'help_search', 1),
('about', 22, 'en', 'help_search', 2),
('about', 24, 'en', 'help_search', 0.902857),
('about', 26, 'en', 'help_search', 1),
('about', 29, 'en', 'help_search', 1),
('about', 30, 'en', 'help_search', 0.839384),
('about', 37, 'en', 'help_search', 1),
('about', 46, 'en', 'help_search', 1),
('about', 54, 'en', 'help_search', 1.98087),
('about', 55, 'en', 'help_search', 1),
('about', 56, 'en', 'help_search', 2),
('about', 57, 'en', 'help_search', 2),
('about', 59, 'en', 'help_search', 1.90974),
('about', 65, 'en', 'help_search', 1),
('about', 66, 'en', 'help_search', 1),
('about', 67, 'en', 'help_search', 1),
('about', 68, 'en', 'help_search', 1),
('about', 71, 'en', 'help_search', 1.68557),
('about', 76, 'en', 'help_search', 1),
('about', 77, 'en', 'help_search', 1),
('about', 78, 'en', 'help_search', 9),
('about', 80, 'en', 'help_search', 2),
('about', 83, 'en', 'help_search', 1),
('aboutus', 76, 'en', 'help_search', 5),
('above', 12, 'en', 'help_search', 0.800068),
('above', 23, 'en', 'help_search', 1),
('above', 24, 'en', 'help_search', 0.879565),
('above', 53, 'en', 'help_search', 1),
('above', 59, 'en', 'help_search', 0.869951),
('access', 11, 'en', 'help_search', 0.705825),
('access', 30, 'en', 'help_search', 1.7974),
('access', 50, 'en', 'help_search', 0.873132),
('access', 58, 'en', 'help_search', 4),
('access', 60, 'en', 'help_search', 2),
('access', 65, 'en', 'help_search', 8),
('access', 67, 'en', 'help_search', 8),
('access', 71, 'en', 'help_search', 4),
('access', 79, 'en', 'help_search', 1),
('access', 83, 'en', 'help_search', 4),
('accessed', 46, 'en', 'help_search', 1),
('accessibility', 23, 'en', 'help_search', 46),
('accessibility', 24, 'en', 'help_search', 2),
('accessible', 23, 'en', 'help_search', 2),
('accessible', 34, 'en', 'help_search', 1),
('accessing', 42, 'en', 'help_search', 2),
('accomplish', 27, 'en', 'help_search', 1),
('account', 6, 'en', 'help_search', 4),
('account', 8, 'en', 'help_search', 1),
('account', 40, 'en', 'help_search', 36),
('account', 44, 'en', 'help_search', 25.989),
('account', 45, 'en', 'help_search', 41),
('accountname', 44, 'en', 'help_search', 1),
('accounts', 6, 'en', 'help_search', 1),
('accounts', 24, 'en', 'help_search', 0.913226),
('accounts', 25, 'en', 'help_search', 1),
('accounts', 30, 'en', 'help_search', 0.845322),
('accounts', 40, 'en', 'help_search', 1),
('accounts', 42, 'en', 'help_search', 46),
('accounts', 44, 'en', 'help_search', 30.9849),
('accounts', 45, 'en', 'help_search', 1),
('accounts', 59, 'en', 'help_search', 0.916736),
('accounts', 81, 'en', 'help_search', 1),
('action', 18, 'en', 'help_search', 1),
('action', 42, 'en', 'help_search', 1),
('action', 58, 'en', 'help_search', 9),
('action', 60, 'en', 'help_search', 0.96498),
('action', 67, 'en', 'help_search', 8.88977),
('action', 71, 'en', 'help_search', 0.836446),
('action', 83, 'en', 'help_search', 1.98493),
('actions', 67, 'en', 'help_search', 0.98493),
('actions', 71, 'en', 'help_search', 4.06626),
('actions', 79, 'en', 'help_search', 1),
('actions', 83, 'en', 'help_search', 8),
('active', 3, 'en', 'help_search', 1),
('active', 11, 'en', 'help_search', 8.73661),
('active', 50, 'en', 'help_search', 0.792123),
('active', 53, 'en', 'help_search', 1),
('active', 54, 'en', 'help_search', 11.0194),
('activity', 24, 'en', 'help_search', 0.889397),
('acts', 10, 'en', 'help_search', 1),
('add', 5, 'en', 'help_search', 3),
('add', 6, 'en', 'help_search', 1),
('add', 7, 'en', 'help_search', 5),
('add', 12, 'en', 'help_search', 0.873132),
('add', 16, 'en', 'help_search', 3),
('add', 17, 'en', 'help_search', 1),
('add', 22, 'en', 'help_search', 1),
('add', 26, 'en', 'help_search', 1),
('add', 27, 'en', 'help_search', 1),
('add', 28, 'en', 'help_search', 5),
('add', 30, 'en', 'help_search', 0.810915),
('add', 40, 'en', 'help_search', 8),
('add', 41, 'en', 'help_search', 4),
('add', 47, 'en', 'help_search', 1),
('add', 50, 'en', 'help_search', 3.69535),
('add', 51, 'en', 'help_search', 4),
('add', 52, 'en', 'help_search', 5),
('add', 54, 'en', 'help_search', 2.73092),
('add', 55, 'en', 'help_search', 2),
('add', 56, 'en', 'help_search', 5),
('add', 61, 'en', 'help_search', 13),
('add', 62, 'en', 'help_search', 2),
('add', 63, 'en', 'help_search', 2),
('add', 64, 'en', 'help_search', 13),
('add', 65, 'en', 'help_search', 4),
('add', 66, 'en', 'help_search', 5),
('add', 68, 'en', 'help_search', 1),
('add', 70, 'en', 'help_search', 13),
('add', 73, 'en', 'help_search', 15),
('add', 74, 'en', 'help_search', 5),
('add', 77, 'en', 'help_search', 1),
('add', 79, 'en', 'help_search', 2),
('add', 80, 'en', 'help_search', 14),
('add', 82, 'en', 'help_search', 6),
('add', 83, 'en', 'help_search', 6),
('add', 84, 'en', 'help_search', 4),
('add', 85, 'en', 'help_search', 5),
('added', 12, 'en', 'help_search', 0.997306),
('added', 17, 'en', 'help_search', 1),
('added', 50, 'en', 'help_search', 1.61652),
('added', 55, 'en', 'help_search', 1),
('added', 70, 'en', 'help_search', 2),
('added', 72, 'en', 'help_search', 1),
('added', 73, 'en', 'help_search', 1),
('added', 79, 'en', 'help_search', 1),
('added', 81, 'en', 'help_search', 1),
('added', 82, 'en', 'help_search', 1),
('added', 84, 'en', 'help_search', 1),
('adding', 25, 'en', 'help_search', 1),
('adding', 41, 'en', 'help_search', 26),
('adding', 55, 'en', 'help_search', 5),
('adding', 61, 'en', 'help_search', 26),
('adding', 64, 'en', 'help_search', 26),
('adding', 66, 'en', 'help_search', 11),
('adding', 70, 'en', 'help_search', 26),
('adding', 73, 'en', 'help_search', 26),
('adding', 80, 'en', 'help_search', 5),
('adding', 81, 'en', 'help_search', 0.927431),
('adding', 82, 'en', 'help_search', 26),
('adding', 83, 'en', 'help_search', 26),
('addition', 30, 'en', 'help_search', 1.81959),
('addition', 33, 'en', 'help_search', 1),
('addition', 65, 'en', 'help_search', 1),
('addition', 67, 'en', 'help_search', 1),
('additional', 5, 'en', 'help_search', 1),
('additional', 10, 'en', 'help_search', 18.8293),
('additional', 11, 'en', 'help_search', 12.9539),
('additional', 12, 'en', 'help_search', 11.6723),
('additional', 13, 'en', 'help_search', 18.5602),
('additional', 14, 'en', 'help_search', 20),
('additional', 15, 'en', 'help_search', 19),
('additional', 16, 'en', 'help_search', 18.1873),
('additional', 17, 'en', 'help_search', 19),
('additional', 18, 'en', 'help_search', 16.1756),
('additional', 19, 'en', 'help_search', 19),
('additional', 22, 'en', 'help_search', 1),
('additional', 24, 'en', 'help_search', 2),
('additional', 25, 'en', 'help_search', 19),
('additional', 27, 'en', 'help_search', 17.8997),
('additional', 30, 'en', 'help_search', 15.9024),
('additional', 31, 'en', 'help_search', 19),
('additional', 32, 'en', 'help_search', 19),
('additional', 35, 'en', 'help_search', 1),
('additional', 37, 'en', 'help_search', 19),
('additional', 46, 'en', 'help_search', 19),
('additional', 47, 'en', 'help_search', 1),
('additional', 48, 'en', 'help_search', 19),
('additional', 50, 'en', 'help_search', 0.774192),
('additional', 53, 'en', 'help_search', 19.0423),
('additional', 54, 'en', 'help_search', 0.869951),
('additional', 55, 'en', 'help_search', 16.9618),
('additional', 58, 'en', 'help_search', 19),
('additional', 59, 'en', 'help_search', 0.968904),
('additional', 65, 'en', 'help_search', 19),
('additional', 66, 'en', 'help_search', 19),
('additional', 67, 'en', 'help_search', 18.3346),
('additional', 70, 'en', 'help_search', 1),
('additional', 71, 'en', 'help_search', 17.6775),
('additional', 76, 'en', 'help_search', 19),
('additional', 78, 'en', 'help_search', 19),
('additional', 80, 'en', 'help_search', 19),
('additional', 81, 'en', 'help_search', 16.9618),
('additional', 85, 'en', 'help_search', 18.5602),
('address', 8, 'en', 'help_search', 1),
('address', 32, 'en', 'help_search', 2),
('address', 40, 'en', 'help_search', 4),
('address', 45, 'en', 'help_search', 1),
('address', 78, 'en', 'help_search', 1),
('addresses', 12, 'en', 'help_search', 0.839384),
('addresses', 42, 'en', 'help_search', 1),
('adds', 14, 'en', 'help_search', 1),
('adjust', 32, 'en', 'help_search', 1),
('adjust', 50, 'en', 'help_search', 0.794753),
('adjust', 66, 'en', 'help_search', 1),
('admin', 24, 'en', 'help_search', 15),
('admin', 26, 'en', 'help_search', 4),
('administer', 24, 'en', 'help_search', 0.96498),
('administer', 44, 'en', 'help_search', 4),
('administer', 55, 'en', 'help_search', 8),
('administer', 56, 'en', 'help_search', 4),
('administer', 57, 'en', 'help_search', 4),
('administer', 58, 'en', 'help_search', 4),
('administer', 65, 'en', 'help_search', 4),
('administer', 66, 'en', 'help_search', 4),
('administer', 67, 'en', 'help_search', 4),
('administer', 77, 'en', 'help_search', 4),
('administer', 79, 'en', 'help_search', 8),
('administer', 80, 'en', 'help_search', 8),
('administer', 83, 'en', 'help_search', 4),
('administering', 42, 'en', 'help_search', 1),
('administration', 13, 'en', 'help_search', 1),
('administration', 38, 'en', 'help_search', 5),
('administration', 39, 'en', 'help_search', 4),
('administration', 65, 'en', 'help_search', 1),
('administration', 73, 'en', 'help_search', 2),
('administration', 74, 'en', 'help_search', 1),
('administration', 75, 'en', 'help_search', 1),
('administration', 77, 'en', 'help_search', 1),
('administrative', 1, 'en', 'help_search', 1),
('administrative', 2, 'en', 'help_search', 1),
('administrative', 3, 'en', 'help_search', 1),
('administrative', 4, 'en', 'help_search', 1),
('administrative', 5, 'en', 'help_search', 1),
('administrative', 6, 'en', 'help_search', 2),
('administrative', 7, 'en', 'help_search', 1),
('administrative', 9, 'en', 'help_search', 1),
('administrative', 11, 'en', 'help_search', 2.53983),
('administrative', 13, 'en', 'help_search', 1),
('administrative', 18, 'en', 'help_search', 0.886095),
('administrative', 23, 'en', 'help_search', 28),
('administrative', 24, 'en', 'help_search', 91.3775),
('administrative', 26, 'en', 'help_search', 5),
('administrative', 27, 'en', 'help_search', 1.97808),
('administrative', 28, 'en', 'help_search', 1),
('administrative', 29, 'en', 'help_search', 1),
('administrative', 31, 'en', 'help_search', 1),
('administrative', 32, 'en', 'help_search', 3),
('administrative', 33, 'en', 'help_search', 1.93838),
('administrative', 34, 'en', 'help_search', 2),
('administrative', 35, 'en', 'help_search', 1),
('administrative', 36, 'en', 'help_search', 1),
('administrative', 37, 'en', 'help_search', 3),
('administrative', 38, 'en', 'help_search', 5),
('administrative', 39, 'en', 'help_search', 1),
('administrative', 40, 'en', 'help_search', 1),
('administrative', 41, 'en', 'help_search', 1),
('administrative', 43, 'en', 'help_search', 1),
('administrative', 44, 'en', 'help_search', 2),
('administrative', 45, 'en', 'help_search', 1),
('administrative', 47, 'en', 'help_search', 1),
('administrative', 48, 'en', 'help_search', 1),
('administrative', 49, 'en', 'help_search', 1),
('administrative', 50, 'en', 'help_search', 0.98493),
('administrative', 51, 'en', 'help_search', 1),
('administrative', 52, 'en', 'help_search', 2),
('administrative', 54, 'en', 'help_search', 1),
('administrative', 56, 'en', 'help_search', 2),
('administrative', 57, 'en', 'help_search', 1),
('administrative', 58, 'en', 'help_search', 1),
('administrative', 60, 'en', 'help_search', 6.9658),
('administrative', 61, 'en', 'help_search', 1),
('administrative', 62, 'en', 'help_search', 1),
('administrative', 63, 'en', 'help_search', 1),
('administrative', 64, 'en', 'help_search', 1),
('administrative', 65, 'en', 'help_search', 1),
('administrative', 66, 'en', 'help_search', 2),
('administrative', 67, 'en', 'help_search', 1),
('administrative', 70, 'en', 'help_search', 1),
('administrative', 71, 'en', 'help_search', 1.63414),
('administrative', 72, 'en', 'help_search', 1),
('administrative', 74, 'en', 'help_search', 1),
('administrative', 79, 'en', 'help_search', 30.9496),
('administrative', 80, 'en', 'help_search', 3),
('administrative', 82, 'en', 'help_search', 2),
('administrative', 83, 'en', 'help_search', 1),
('administrative', 84, 'en', 'help_search', 2),
('administrative', 85, 'en', 'help_search', 1),
('administrator', 11, 'en', 'help_search', 1),
('administrator', 12, 'en', 'help_search', 0.993146),
('administrator', 79, 'en', 'help_search', 1),
('administrators', 8, 'en', 'help_search', 1),
('administrators', 11, 'en', 'help_search', 1),
('administrators', 17, 'en', 'help_search', 1),
('administrators', 42, 'en', 'help_search', 2),
('administrators', 44, 'en', 'help_search', 1),
('administrators', 50, 'en', 'help_search', 2),
('administrators', 51, 'en', 'help_search', 1),
('administrators', 56, 'en', 'help_search', 1),
('administrators', 58, 'en', 'help_search', 1),
('administrators', 66, 'en', 'help_search', 1),
('advanced', 30, 'en', 'help_search', 3.59781),
('advanced', 71, 'en', 'help_search', 10.801),
('advisories', 19, 'en', 'help_search', 20),
('advisory', 19, 'en', 'help_search', 14),
('affected', 60, 'en', 'help_search', 1),
('after', 11, 'en', 'help_search', 0.766757),
('after', 18, 'en', 'help_search', 1),
('after', 29, 'en', 'help_search', 0.906287),
('after', 30, 'en', 'help_search', 1),
('after', 33, 'en', 'help_search', 0.997306),
('after', 50, 'en', 'help_search', 0.810915),
('after', 62, 'en', 'help_search', 1),
('after', 63, 'en', 'help_search', 1),
('after', 70, 'en', 'help_search', 1),
('after', 71, 'en', 'help_search', 1),
('afterwards', 18, 'en', 'help_search', 0.913226),
('again', 31, 'en', 'help_search', 1),
('again', 60, 'en', 'help_search', 1),
('again', 67, 'en', 'help_search', 1),
('against', 25, 'en', 'help_search', 1),
('against', 50, 'en', 'help_search', 1),
('aggregation', 18, 'en', 'help_search', 20.8513),
('alias', 44, 'en', 'help_search', 1),
('alias', 76, 'en', 'help_search', 35),
('alias', 77, 'en', 'help_search', 30),
('alias', 78, 'en', 'help_search', 20),
('aliases', 76, 'en', 'help_search', 26),
('aliases', 77, 'en', 'help_search', 32),
('aliases', 78, 'en', 'help_search', 61),
('aliasing', 78, 'en', 'help_search', 1),
('all', 1, 'en', 'help_search', 1),
('all', 3, 'en', 'help_search', 4),
('all', 12, 'en', 'help_search', 2.28248),
('all', 14, 'en', 'help_search', 1),
('all', 19, 'en', 'help_search', 1),
('all', 20, 'en', 'help_search', 1),
('all', 24, 'en', 'help_search', 1),
('all', 31, 'en', 'help_search', 4),
('all', 42, 'en', 'help_search', 2),
('all', 45, 'en', 'help_search', 1),
('all', 47, 'en', 'help_search', 1),
('all', 57, 'en', 'help_search', 1),
('all', 58, 'en', 'help_search', 1),
('all', 60, 'en', 'help_search', 1),
('all', 61, 'en', 'help_search', 1),
('all', 65, 'en', 'help_search', 1),
('all', 67, 'en', 'help_search', 1),
('all', 70, 'en', 'help_search', 1),
('all', 77, 'en', 'help_search', 1),
('all', 79, 'en', 'help_search', 2),
('all', 80, 'en', 'help_search', 1),
('all', 81, 'en', 'help_search', 2.96498),
('all', 83, 'en', 'help_search', 5),
('all', 85, 'en', 'help_search', 1),
('allow', 8, 'en', 'help_search', 2),
('allow', 10, 'en', 'help_search', 0.980874),
('allow', 12, 'en', 'help_search', 1),
('allow', 50, 'en', 'help_search', 1.89945),
('allow', 55, 'en', 'help_search', 1),
('allow', 60, 'en', 'help_search', 1),
('allow', 71, 'en', 'help_search', 1),
('allow', 80, 'en', 'help_search', 1),
('allow', 82, 'en', 'help_search', 1),
('allowed', 12, 'en', 'help_search', 2.9266),
('allowed', 50, 'en', 'help_search', 1),
('allowed', 55, 'en', 'help_search', 7.69854),
('allowed', 57, 'en', 'help_search', 3),
('allowed', 61, 'en', 'help_search', 4),
('allowed', 64, 'en', 'help_search', 4),
('allows', 10, 'en', 'help_search', 1),
('allows', 12, 'en', 'help_search', 0.876337),
('allows', 16, 'en', 'help_search', 1),
('allows', 18, 'en', 'help_search', 1.90974),
('allows', 23, 'en', 'help_search', 1),
('allows', 25, 'en', 'help_search', 1),
('allows', 30, 'en', 'help_search', 1),
('allows', 42, 'en', 'help_search', 3),
('allows', 48, 'en', 'help_search', 2),
('allows', 53, 'en', 'help_search', 0.976851),
('allows', 59, 'en', 'help_search', 0.892724),
('allows', 68, 'en', 'help_search', 2),
('allows', 69, 'en', 'help_search', 1),
('allows', 71, 'en', 'help_search', 2.65179),
('allows', 78, 'en', 'help_search', 2),
('allows', 79, 'en', 'help_search', 1),
('allows', 81, 'en', 'help_search', 0.945829),
('along', 7, 'en', 'help_search', 1),
('along', 25, 'en', 'help_search', 1),
('already', 26, 'en', 'help_search', 2),
('already', 34, 'en', 'help_search', 1),
('already', 35, 'en', 'help_search', 2),
('already', 38, 'en', 'help_search', 2),
('already', 79, 'en', 'help_search', 1),
('already', 82, 'en', 'help_search', 1),
('already', 83, 'en', 'help_search', 2),
('already', 85, 'en', 'help_search', 1),
('alreadyconfigured', 28, 'en', 'help_search', 1),
('alreadyrendered', 18, 'en', 'help_search', 1),
('also', 8, 'en', 'help_search', 1),
('also', 11, 'en', 'help_search', 1.58702),
('also', 12, 'en', 'help_search', 3.37064),
('also', 13, 'en', 'help_search', 1),
('also', 15, 'en', 'help_search', 1),
('also', 16, 'en', 'help_search', 1),
('also', 17, 'en', 'help_search', 2),
('also', 18, 'en', 'help_search', 1),
('also', 19, 'en', 'help_search', 1),
('also', 20, 'en', 'help_search', 1),
('also', 22, 'en', 'help_search', 3),
('also', 24, 'en', 'help_search', 1),
('also', 25, 'en', 'help_search', 1),
('also', 27, 'en', 'help_search', 2),
('also', 30, 'en', 'help_search', 1.7001),
('also', 31, 'en', 'help_search', 1),
('also', 34, 'en', 'help_search', 1),
('also', 35, 'en', 'help_search', 1),
('also', 42, 'en', 'help_search', 1),
('also', 50, 'en', 'help_search', 1),
('also', 54, 'en', 'help_search', 1),
('also', 55, 'en', 'help_search', 2),
('also', 57, 'en', 'help_search', 1),
('also', 58, 'en', 'help_search', 1),
('also', 60, 'en', 'help_search', 2),
('also', 61, 'en', 'help_search', 1),
('also', 62, 'en', 'help_search', 1),
('also', 64, 'en', 'help_search', 1),
('also', 65, 'en', 'help_search', 1),
('also', 66, 'en', 'help_search', 1),
('also', 69, 'en', 'help_search', 1),
('also', 70, 'en', 'help_search', 1),
('also', 71, 'en', 'help_search', 1),
('also', 73, 'en', 'help_search', 1),
('also', 74, 'en', 'help_search', 1),
('also', 76, 'en', 'help_search', 1),
('also', 77, 'en', 'help_search', 1),
('also', 79, 'en', 'help_search', 2),
('also', 80, 'en', 'help_search', 2),
('alter', 30, 'en', 'help_search', 0.857458),
('alternative', 30, 'en', 'help_search', 1),
('alternatively', 60, 'en', 'help_search', 1),
('alternatively', 85, 'en', 'help_search', 1),
('always', 5, 'en', 'help_search', 1),
('always', 6, 'en', 'help_search', 1),
('always', 7, 'en', 'help_search', 1),
('always', 46, 'en', 'help_search', 1),
('american', 30, 'en', 'help_search', 0.976851),
('anchor', 70, 'en', 'help_search', 4),
('and', 1, 'en', 'help_search', 3),
('and', 2, 'en', 'help_search', 3),
('and', 3, 'en', 'help_search', 5),
('and', 4, 'en', 'help_search', 1),
('and', 5, 'en', 'help_search', 4),
('and', 6, 'en', 'help_search', 3),
('and', 7, 'en', 'help_search', 2),
('and', 8, 'en', 'help_search', 2),
('and', 9, 'en', 'help_search', 1),
('and', 10, 'en', 'help_search', 23.1993),
('and', 11, 'en', 'help_search', 40.2271),
('and', 12, 'en', 'help_search', 19.524),
('and', 13, 'en', 'help_search', 29.9973),
('and', 14, 'en', 'help_search', 62),
('and', 15, 'en', 'help_search', 70),
('and', 16, 'en', 'help_search', 9.99315),
('and', 17, 'en', 'help_search', 2),
('and', 18, 'en', 'help_search', 10.5892),
('and', 19, 'en', 'help_search', 26),
('and', 20, 'en', 'help_search', 3),
('and', 21, 'en', 'help_search', 2),
('and', 22, 'en', 'help_search', 34),
('and', 23, 'en', 'help_search', 3),
('and', 24, 'en', 'help_search', 11.5995),
('and', 25, 'en', 'help_search', 19),
('and', 26, 'en', 'help_search', 9),
('and', 27, 'en', 'help_search', 8.95792),
('and', 28, 'en', 'help_search', 6),
('and', 29, 'en', 'help_search', 13.7539),
('and', 30, 'en', 'help_search', 9.36877),
('and', 31, 'en', 'help_search', 1),
('and', 32, 'en', 'help_search', 16),
('and', 33, 'en', 'help_search', 26.7011),
('and', 34, 'en', 'help_search', 30),
('and', 36, 'en', 'help_search', 3),
('and', 37, 'en', 'help_search', 15),
('and', 38, 'en', 'help_search', 29),
('and', 40, 'en', 'help_search', 1),
('and', 41, 'en', 'help_search', 1),
('and', 42, 'en', 'help_search', 52),
('and', 43, 'en', 'help_search', 1),
('and', 44, 'en', 'help_search', 47),
('and', 45, 'en', 'help_search', 4),
('and', 46, 'en', 'help_search', 3),
('and', 47, 'en', 'help_search', 2),
('and', 48, 'en', 'help_search', 4),
('and', 49, 'en', 'help_search', 3),
('and', 50, 'en', 'help_search', 59.5847),
('and', 51, 'en', 'help_search', 1),
('and', 52, 'en', 'help_search', 2),
('and', 53, 'en', 'help_search', 56.4734),
('and', 54, 'en', 'help_search', 15.3423),
('and', 55, 'en', 'help_search', 6.89272),
('and', 56, 'en', 'help_search', 7),
('and', 57, 'en', 'help_search', 8),
('and', 58, 'en', 'help_search', 6),
('and', 59, 'en', 'help_search', 14.5978),
('and', 60, 'en', 'help_search', 3.97685),
('and', 61, 'en', 'help_search', 8),
('and', 62, 'en', 'help_search', 3),
('and', 63, 'en', 'help_search', 2),
('and', 64, 'en', 'help_search', 8),
('and', 65, 'en', 'help_search', 3),
('and', 66, 'en', 'help_search', 6),
('and', 67, 'en', 'help_search', 22),
('and', 68, 'en', 'help_search', 11),
('and', 69, 'en', 'help_search', 1),
('and', 70, 'en', 'help_search', 5),
('and', 71, 'en', 'help_search', 8.05703),
('and', 72, 'en', 'help_search', 1),
('and', 73, 'en', 'help_search', 4),
('and', 75, 'en', 'help_search', 27),
('and', 76, 'en', 'help_search', 6),
('and', 77, 'en', 'help_search', 5),
('and', 78, 'en', 'help_search', 31),
('and', 79, 'en', 'help_search', 30.9973),
('and', 80, 'en', 'help_search', 9),
('and', 81, 'en', 'help_search', 9.71009),
('and', 82, 'en', 'help_search', 4),
('and', 83, 'en', 'help_search', 5),
('and', 84, 'en', 'help_search', 5),
('and', 85, 'en', 'help_search', 3.98902),
('announcement', 19, 'en', 'help_search', 1),
('announcement', 46, 'en', 'help_search', 11),
('announcements', 46, 'en', 'help_search', 93),
('anonymous', 6, 'en', 'help_search', 4),
('anonymous', 18, 'en', 'help_search', 2.93498),
('anonymous', 42, 'en', 'help_search', 5),
('anonymous', 50, 'en', 'help_search', 0.886095),
('anonymous', 55, 'en', 'help_search', 6),
('another', 8, 'en', 'help_search', 1),
('another', 11, 'en', 'help_search', 2.4152),
('another', 14, 'en', 'help_search', 1),
('another', 22, 'en', 'help_search', 1),
('another', 27, 'en', 'help_search', 0.997306),
('another', 36, 'en', 'help_search', 1),
('another', 38, 'en', 'help_search', 1),
('another', 39, 'en', 'help_search', 1),
('another', 53, 'en', 'help_search', 1),
('another', 54, 'en', 'help_search', 0.968904),
('another', 59, 'en', 'help_search', 1),
('another', 60, 'en', 'help_search', 1),
('another', 73, 'en', 'help_search', 2),
('any', 3, 'en', 'help_search', 1),
('any', 10, 'en', 'help_search', 1),
('any', 11, 'en', 'help_search', 0.876337),
('any', 19, 'en', 'help_search', 1),
('any', 28, 'en', 'help_search', 1),
('any', 30, 'en', 'help_search', 0.920273),
('any', 32, 'en', 'help_search', 2),
('any', 37, 'en', 'help_search', 3),
('any', 54, 'en', 'help_search', 1),
('any', 62, 'en', 'help_search', 1),
('any', 63, 'en', 'help_search', 1),
('any', 67, 'en', 'help_search', 4),
('any', 73, 'en', 'help_search', 1),
('any', 77, 'en', 'help_search', 1),
('any', 79, 'en', 'help_search', 5.95723),
('any', 81, 'en', 'help_search', 1),
('anyone', 34, 'en', 'help_search', 1),
('anyone', 42, 'en', 'help_search', 1),
('apache', 30, 'en', 'help_search', 12),
('api', 25, 'en', 'help_search', 34),
('api', 53, 'en', 'help_search', 0.961087),
('appear', 20, 'en', 'help_search', 2),
('appear', 62, 'en', 'help_search', 1),
('appear', 77, 'en', 'help_search', 1),
('appearance', 10, 'en', 'help_search', 46.9579),
('appearance', 24, 'en', 'help_search', 3.8289),
('appearance', 38, 'en', 'help_search', 8),
('appearance', 39, 'en', 'help_search', 4),
('applications', 25, 'en', 'help_search', 3),
('applied', 16, 'en', 'help_search', 1),
('applied', 50, 'en', 'help_search', 1),
('applied', 83, 'en', 'help_search', 1),
('applies', 55, 'en', 'help_search', 1),
('apply', 19, 'en', 'help_search', 1),
('apply', 53, 'en', 'help_search', 1),
('apply', 58, 'en', 'help_search', 8),
('apply', 67, 'en', 'help_search', 4.97258),
('apply', 70, 'en', 'help_search', 1),
('apply', 71, 'en', 'help_search', 0.842342),
('apply', 83, 'en', 'help_search', 4),
('appropriate', 30, 'en', 'help_search', 1),
('appropriate', 55, 'en', 'help_search', 1),
('appropriately', 33, 'en', 'help_search', 1),
('approval', 44, 'en', 'help_search', 1),
('approved', 44, 'en', 'help_search', 1),
('archive', 1, 'en', 'help_search', 2),
('archive', 3, 'en', 'help_search', 6),
('archive', 11, 'en', 'help_search', 1.60282),
('are', 5, 'en', 'help_search', 19),
('are', 6, 'en', 'help_search', 1),
('are', 8, 'en', 'help_search', 21),
('are', 10, 'en', 'help_search', 1),
('are', 11, 'en', 'help_search', 24.2128),
('are', 12, 'en', 'help_search', 59.5296),
('are', 13, 'en', 'help_search', 39.9973),
('are', 14, 'en', 'help_search', 19),
('are', 15, 'en', 'help_search', 3),
('are', 16, 'en', 'help_search', 23),
('are', 18, 'en', 'help_search', 4.78255),
('are', 19, 'en', 'help_search', 44),
('are', 22, 'en', 'help_search', 2),
('are', 23, 'en', 'help_search', 3.98902),
('are', 24, 'en', 'help_search', 41),
('are', 25, 'en', 'help_search', 2),
('are', 26, 'en', 'help_search', 2),
('are', 27, 'en', 'help_search', 61),
('are', 29, 'en', 'help_search', 1),
('are', 30, 'en', 'help_search', 58.7594),
('are', 31, 'en', 'help_search', 2),
('are', 32, 'en', 'help_search', 1),
('are', 33, 'en', 'help_search', 19.9097),
('are', 34, 'en', 'help_search', 1),
('are', 35, 'en', 'help_search', 1),
('are', 36, 'en', 'help_search', 2),
('are', 37, 'en', 'help_search', 2),
('are', 40, 'en', 'help_search', 1),
('are', 42, 'en', 'help_search', 6),
('are', 44, 'en', 'help_search', 69.9769),
('are', 46, 'en', 'help_search', 19),
('are', 48, 'en', 'help_search', 41),
('are', 50, 'en', 'help_search', 42),
('are', 53, 'en', 'help_search', 62),
('are', 54, 'en', 'help_search', 2),
('are', 55, 'en', 'help_search', 7.50101),
('are', 57, 'en', 'help_search', 5),
('are', 58, 'en', 'help_search', 2),
('are', 59, 'en', 'help_search', 5),
('are', 60, 'en', 'help_search', 19),
('are', 61, 'en', 'help_search', 1),
('are', 62, 'en', 'help_search', 1),
('are', 63, 'en', 'help_search', 1),
('are', 64, 'en', 'help_search', 1),
('are', 68, 'en', 'help_search', 2),
('are', 69, 'en', 'help_search', 39),
('are', 70, 'en', 'help_search', 1),
('are', 71, 'en', 'help_search', 37.225),
('are', 78, 'en', 'help_search', 2),
('are', 79, 'en', 'help_search', 21),
('are', 80, 'en', 'help_search', 1),
('are', 81, 'en', 'help_search', 4.96109),
('are', 82, 'en', 'help_search', 2),
('are', 83, 'en', 'help_search', 2),
('are', 85, 'en', 'help_search', 2),
('area', 45, 'en', 'help_search', 1),
('area', 48, 'en', 'help_search', 1),
('area', 60, 'en', 'help_search', 5.98902),
('areas', 60, 'en', 'help_search', 1),
('arrows', 62, 'en', 'help_search', 1),
('arrows', 63, 'en', 'help_search', 1),
('article', 65, 'en', 'help_search', 2),
('article', 67, 'en', 'help_search', 11),
('articles', 59, 'en', 'help_search', 1),
('articles', 68, 'en', 'help_search', 1),
('aspect', 24, 'en', 'help_search', 0.869951),
('aspects', 24, 'en', 'help_search', 0.857458),
('asset', 10, 'en', 'help_search', 1),
('assign', 50, 'en', 'help_search', 1),
('assign', 53, 'en', 'help_search', 0.953396),
('assigned', 42, 'en', 'help_search', 2),
('assigned', 79, 'en', 'help_search', 1),
('assistive', 23, 'en', 'help_search', 1),
('associate', 12, 'en', 'help_search', 0.78951),
('associate', 16, 'en', 'help_search', 1),
('associate', 50, 'en', 'help_search', 1),
('associated', 54, 'en', 'help_search', 1),
('associates', 12, 'en', 'help_search', 0.729424),
('association', 46, 'en', 'help_search', 2),
('assume', 54, 'en', 'help_search', 0.957226),
('assuming', 66, 'en', 'help_search', 1),
('assumptions', 31, 'en', 'help_search', 1),
('attach', 48, 'en', 'help_search', 1),
('attach', 59, 'en', 'help_search', 1.77549),
('attach', 68, 'en', 'help_search', 1),
('attached', 12, 'en', 'help_search', 1),
('attached', 55, 'en', 'help_search', 1),
('attached', 59, 'en', 'help_search', 1),
('attached', 68, 'en', 'help_search', 1),
('attached', 81, 'en', 'help_search', 2),
('attention', 43, 'en', 'help_search', 1),
('attribute', 12, 'en', 'help_search', 0.687638),
('audio', 16, 'en', 'help_search', 1),
('authenticated', 6, 'en', 'help_search', 4),
('authenticated', 18, 'en', 'help_search', 0.968904),
('authenticated', 25, 'en', 'help_search', 1),
('authenticated', 42, 'en', 'help_search', 5),
('authenticating', 25, 'en', 'help_search', 1),
('authentication', 25, 'en', 'help_search', 34),
('authoring', 50, 'en', 'help_search', 3.85992),
('authoring', 54, 'en', 'help_search', 4),
('authorized', 33, 'en', 'help_search', 1),
('automated', 13, 'en', 'help_search', 3.98776),
('automatic', 18, 'en', 'help_search', 1),
('automatic', 22, 'en', 'help_search', 1),
('automatically', 13, 'en', 'help_search', 1),
('automatically', 27, 'en', 'help_search', 1.98902),
('automatically', 73, 'en', 'help_search', 1),
('automatically', 81, 'en', 'help_search', 0.98493),
('automaticallygenerated', 52, 'en', 'help_search', 1),
('automaticallygenerated', 78, 'en', 'help_search', 1),
('available', 12, 'en', 'help_search', 47.9205),
('available', 13, 'en', 'help_search', 19),
('available', 22, 'en', 'help_search', 1),
('available', 24, 'en', 'help_search', 20),
('available', 28, 'en', 'help_search', 2),
('available', 37, 'en', 'help_search', 6),
('available', 47, 'en', 'help_search', 1),
('available', 50, 'en', 'help_search', 19),
('available', 54, 'en', 'help_search', 4.73881),
('available', 69, 'en', 'help_search', 19),
('available', 71, 'en', 'help_search', 0.827757),
('available', 72, 'en', 'help_search', 2),
('available', 83, 'en', 'help_search', 1.98493),
('avoid', 50, 'en', 'help_search', 0.808176),
('aware', 33, 'en', 'help_search', 0.906287),
('away', 31, 'en', 'help_search', 1),
('back', 34, 'en', 'help_search', 1),
('background', 62, 'en', 'help_search', 1),
('background', 63, 'en', 'help_search', 1),
('bad', 59, 'en', 'help_search', 1),
('ban', 42, 'en', 'help_search', 2),
('bar', 79, 'en', 'help_search', 0.957226),
('base', 10, 'en', 'help_search', 21),
('base', 39, 'en', 'help_search', 1),
('base', 71, 'en', 'help_search', 6.70772),
('base', 84, 'en', 'help_search', 1),
('basic', 10, 'en', 'help_search', 1),
('basic', 25, 'en', 'help_search', 33),
('basic', 32, 'en', 'help_search', 31),
('basic', 33, 'en', 'help_search', 4),
('basic', 59, 'en', 'help_search', 1),
('basic', 65, 'en', 'help_search', 11),
('basic', 67, 'en', 'help_search', 10.5295),
('because', 16, 'en', 'help_search', 1),
('because', 18, 'en', 'help_search', 1),
('because', 39, 'en', 'help_search', 1),
('become', 23, 'en', 'help_search', 1),
('becomes', 16, 'en', 'help_search', 1),
('been', 11, 'en', 'help_search', 2.61181),
('been', 27, 'en', 'help_search', 1),
('been', 29, 'en', 'help_search', 2.7263),
('been', 35, 'en', 'help_search', 1),
('been', 38, 'en', 'help_search', 1),
('been', 42, 'en', 'help_search', 1),
('been', 69, 'en', 'help_search', 1),
('been', 70, 'en', 'help_search', 1),
('been', 73, 'en', 'help_search', 1),
('been', 79, 'en', 'help_search', 1),
('before', 15, 'en', 'help_search', 1),
('before', 18, 'en', 'help_search', 1),
('before', 55, 'en', 'help_search', 0.96498),
('before', 59, 'en', 'help_search', 1.93838),
('behaves', 11, 'en', 'help_search', 1),
('behaving', 15, 'en', 'help_search', 1),
('behavior', 30, 'en', 'help_search', 1),
('behavior', 59, 'en', 'help_search', 1),
('behavior', 71, 'en', 'help_search', 3.8289),
('behind', 12, 'en', 'help_search', 0.759465),
('being', 8, 'en', 'help_search', 1),
('being', 11, 'en', 'help_search', 0.78951),
('being', 34, 'en', 'help_search', 1),
('being', 39, 'en', 'help_search', 3),
('being', 50, 'en', 'help_search', 0.819249),
('being', 59, 'en', 'help_search', 1),
('being', 71, 'en', 'help_search', 1),
('believe', 29, 'en', 'help_search', 0.931053),
('belong', 12, 'en', 'help_search', 0.923838),
('below', 2, 'en', 'help_search', 1),
('below', 8, 'en', 'help_search', 1),
('below', 10, 'en', 'help_search', 0.949597),
('below', 11, 'en', 'help_search', 0.685676),
('below', 12, 'en', 'help_search', 2.89048),
('below', 14, 'en', 'help_search', 1),
('below', 15, 'en', 'help_search', 1),
('below', 16, 'en', 'help_search', 0.968904),
('below', 17, 'en', 'help_search', 1),
('below', 19, 'en', 'help_search', 1),
('below', 21, 'en', 'help_search', 1),
('below', 22, 'en', 'help_search', 1),
('below', 24, 'en', 'help_search', 0.863659),
('below', 30, 'en', 'help_search', 0.792123),
('below', 42, 'en', 'help_search', 1),
('below', 48, 'en', 'help_search', 1),
('below', 59, 'en', 'help_search', 0.857458),
('below', 61, 'en', 'help_search', 1),
('below', 64, 'en', 'help_search', 1),
('below', 68, 'en', 'help_search', 1),
('below', 70, 'en', 'help_search', 1),
('below', 71, 'en', 'help_search', 0.786915),
('below', 78, 'en', 'help_search', 1),
('below', 81, 'en', 'help_search', 0.902857),
('below', 84, 'en', 'help_search', 1),
('besides', 12, 'en', 'help_search', 0.630018),
('besides', 54, 'en', 'help_search', 1),
('best', 23, 'en', 'help_search', 2),
('best', 53, 'en', 'help_search', 1),
('best', 83, 'en', 'help_search', 1),
('between', 3, 'en', 'help_search', 1),
('between', 11, 'en', 'help_search', 3.79218),
('between', 12, 'en', 'help_search', 1.8477),
('between', 24, 'en', 'help_search', 0.949597),
('between', 53, 'en', 'help_search', 1),
('between', 54, 'en', 'help_search', 1.81472),
('big', 18, 'en', 'help_search', 0.949597),
('bigpipe', 18, 'en', 'help_search', 9.23322),
('blank', 33, 'en', 'help_search', 1),
('block', 5, 'en', 'help_search', 1),
('block', 12, 'en', 'help_search', 8.62029),
('block', 17, 'en', 'help_search', 2),
('block', 20, 'en', 'help_search', 2),
('block', 22, 'en', 'help_search', 4),
('block', 24, 'en', 'help_search', 1),
('block', 26, 'en', 'help_search', 9),
('block', 27, 'en', 'help_search', 1.98493),
('block', 30, 'en', 'help_search', 1.73835),
('block', 47, 'en', 'help_search', 52),
('block', 48, 'en', 'help_search', 57),
('block', 49, 'en', 'help_search', 53),
('block', 51, 'en', 'help_search', 34),
('block', 52, 'en', 'help_search', 43),
('block', 60, 'en', 'help_search', 5),
('block', 71, 'en', 'help_search', 6),
('block', 74, 'en', 'help_search', 2),
('block', 82, 'en', 'help_search', 5),
('block', 84, 'en', 'help_search', 1),
('blocked', 44, 'en', 'help_search', 1),
('blocks', 10, 'en', 'help_search', 2),
('blocks', 22, 'en', 'help_search', 1),
('blocks', 24, 'en', 'help_search', 0.989021),
('blocks', 47, 'en', 'help_search', 8),
('blocks', 48, 'en', 'help_search', 102),
('blocks', 51, 'en', 'help_search', 1),
('blocks', 81, 'en', 'help_search', 1),
('blog', 59, 'en', 'help_search', 2),
('blog', 68, 'en', 'help_search', 1),
('blog', 81, 'en', 'help_search', 4),
('body', 27, 'en', 'help_search', 1),
('body', 51, 'en', 'help_search', 1),
('body', 59, 'en', 'help_search', 1),
('boolean', 12, 'en', 'help_search', 0.899454),
('both', 5, 'en', 'help_search', 1),
('both', 6, 'en', 'help_search', 1),
('both', 18, 'en', 'help_search', 0.972861),
('both', 23, 'en', 'help_search', 0.997306),
('both', 29, 'en', 'help_search', 1),
('both', 30, 'en', 'help_search', 1),
('both', 33, 'en', 'help_search', 1),
('both', 50, 'en', 'help_search', 1),
('both', 61, 'en', 'help_search', 1),
('both', 64, 'en', 'help_search', 1),
('bottom', 35, 'en', 'help_search', 1),
('bottom', 36, 'en', 'help_search', 1),
('bottom', 38, 'en', 'help_search', 1),
('bottom', 45, 'en', 'help_search', 1),
('bottom', 71, 'en', 'help_search', 0.96498),
('box', 2, 'en', 'help_search', 2),
('box', 4, 'en', 'help_search', 1),
('box', 6, 'en', 'help_search', 1),
('box', 35, 'en', 'help_search', 3),
('box', 36, 'en', 'help_search', 2),
('box', 44, 'en', 'help_search', 1),
('box', 47, 'en', 'help_search', 1),
('boxes', 48, 'en', 'help_search', 1),
('boxes', 58, 'en', 'help_search', 2),
('boxes', 67, 'en', 'help_search', 1),
('brackets', 44, 'en', 'help_search', 1),
('break', 50, 'en', 'help_search', 1),
('breakpoint', 10, 'en', 'help_search', 0.976851),
('breakpoint', 16, 'en', 'help_search', 0.997306),
('breakpoint', 53, 'en', 'help_search', 52.2799),
('breakpointenabled', 16, 'en', 'help_search', 0.993146),
('breakpoints', 16, 'en', 'help_search', 1),
('breakpoints', 53, 'en', 'help_search', 85.8495),
('breaks', 29, 'en', 'help_search', 1),
('breaks', 50, 'en', 'help_search', 3),
('browse', 3, 'en', 'help_search', 1),
('browser', 2, 'en', 'help_search', 1),
('browser', 16, 'en', 'help_search', 1.98087),
('browser', 18, 'en', 'help_search', 0.909743),
('browser', 78, 'en', 'help_search', 1),
('bugs', 19, 'en', 'help_search', 3),
('bugs', 33, 'en', 'help_search', 1),
('builder', 10, 'en', 'help_search', 1.98087),
('builder', 12, 'en', 'help_search', 0.600219),
('building', 10, 'en', 'help_search', 1),
('builtin', 22, 'en', 'help_search', 1),
('builtin', 23, 'en', 'help_search', 1),
('bulk', 18, 'en', 'help_search', 0.902857),
('bulk', 67, 'en', 'help_search', 2),
('bulk', 71, 'en', 'help_search', 18.9762),
('bulk', 83, 'en', 'help_search', 37.9822),
('but', 10, 'en', 'help_search', 1),
('but', 12, 'en', 'help_search', 1),
('but', 13, 'en', 'help_search', 1),
('but', 22, 'en', 'help_search', 1),
('but', 31, 'en', 'help_search', 1),
('but', 33, 'en', 'help_search', 2),
('but', 39, 'en', 'help_search', 1),
('but', 47, 'en', 'help_search', 1),
('but', 55, 'en', 'help_search', 1.81991),
('but', 57, 'en', 'help_search', 1),
('but', 62, 'en', 'help_search', 1),
('but', 83, 'en', 'help_search', 1),
('butter', 80, 'en', 'help_search', 1),
('button', 12, 'en', 'help_search', 2.54671),
('button', 20, 'en', 'help_search', 1),
('button', 30, 'en', 'help_search', 1),
('button', 54, 'en', 'help_search', 1.81268),
('button', 58, 'en', 'help_search', 1),
('button', 60, 'en', 'help_search', 4.99731),
('button', 66, 'en', 'help_search', 1),
('button', 77, 'en', 'help_search', 1),
('button', 83, 'en', 'help_search', 1),
('buttons', 54, 'en', 'help_search', 10.2472),
('buttons', 60, 'en', 'help_search', 1),
('bypass', 65, 'en', 'help_search', 4),
('bypass', 67, 'en', 'help_search', 4),
('cache', 15, 'en', 'help_search', 1),
('cache', 18, 'en', 'help_search', 22.2999),
('cache', 26, 'en', 'help_search', 1),
('cache', 31, 'en', 'help_search', 58),
('cache', 34, 'en', 'help_search', 2),
('cacheable', 18, 'en', 'help_search', 0.934703),
('cached', 18, 'en', 'help_search', 2),
('cached', 31, 'en', 'help_search', 7),
('caches', 18, 'en', 'help_search', 1.97286),
('caches', 31, 'en', 'help_search', 4),
('caching', 18, 'en', 'help_search', 21),
('calculated', 18, 'en', 'help_search', 1.9496),
('calculation', 31, 'en', 'help_search', 1),
('calculations', 18, 'en', 'help_search', 1),
('calculations', 31, 'en', 'help_search', 2),
('calendar', 71, 'en', 'help_search', 1),
('called', 11, 'en', 'help_search', 0.886095),
('called', 13, 'en', 'help_search', 1),
('called', 25, 'en', 'help_search', 1),
('called', 27, 'en', 'help_search', 1),
('called', 29, 'en', 'help_search', 1),
('called', 54, 'en', 'help_search', 1),
('called', 78, 'en', 'help_search', 1),
('called', 85, 'en', 'help_search', 1),
('can', 5, 'en', 'help_search', 2),
('can', 6, 'en', 'help_search', 1),
('can', 8, 'en', 'help_search', 3),
('can', 10, 'en', 'help_search', 3),
('can', 11, 'en', 'help_search', 5.18083),
('can', 12, 'en', 'help_search', 8.51489),
('can', 13, 'en', 'help_search', 4),
('can', 14, 'en', 'help_search', 2),
('can', 15, 'en', 'help_search', 2),
('can', 16, 'en', 'help_search', 4.98493),
('can', 17, 'en', 'help_search', 3),
('can', 18, 'en', 'help_search', 21),
('can', 20, 'en', 'help_search', 19),
('can', 21, 'en', 'help_search', 1),
('can', 22, 'en', 'help_search', 26),
('can', 23, 'en', 'help_search', 1),
('can', 24, 'en', 'help_search', 3),
('can', 25, 'en', 'help_search', 1),
('can', 26, 'en', 'help_search', 2),
('can', 27, 'en', 'help_search', 21),
('can', 29, 'en', 'help_search', 1),
('can', 30, 'en', 'help_search', 4.67183),
('can', 31, 'en', 'help_search', 2),
('can', 33, 'en', 'help_search', 23),
('can', 35, 'en', 'help_search', 1),
('can', 36, 'en', 'help_search', 1),
('can', 37, 'en', 'help_search', 1),
('can', 42, 'en', 'help_search', 1),
('can', 44, 'en', 'help_search', 8),
('can', 45, 'en', 'help_search', 1),
('can', 46, 'en', 'help_search', 40),
('can', 47, 'en', 'help_search', 1),
('can', 48, 'en', 'help_search', 3),
('can', 50, 'en', 'help_search', 5.89945),
('can', 51, 'en', 'help_search', 1),
('can', 53, 'en', 'help_search', 3.96109),
('can', 55, 'en', 'help_search', 19.9167),
('can', 56, 'en', 'help_search', 21),
('can', 57, 'en', 'help_search', 19),
('can', 58, 'en', 'help_search', 21),
('can', 59, 'en', 'help_search', 4.87957),
('can', 61, 'en', 'help_search', 3),
('can', 62, 'en', 'help_search', 2),
('can', 64, 'en', 'help_search', 3),
('can', 65, 'en', 'help_search', 21),
('can', 66, 'en', 'help_search', 20),
('can', 67, 'en', 'help_search', 22),
('can', 68, 'en', 'help_search', 1),
('can', 69, 'en', 'help_search', 1),
('can', 70, 'en', 'help_search', 3),
('can', 71, 'en', 'help_search', 6.85746),
('can', 72, 'en', 'help_search', 1),
('can', 73, 'en', 'help_search', 1),
('can', 76, 'en', 'help_search', 22),
('can', 77, 'en', 'help_search', 21),
('can', 78, 'en', 'help_search', 1),
('can', 79, 'en', 'help_search', 2),
('can', 80, 'en', 'help_search', 20),
('can', 81, 'en', 'help_search', 7),
('can', 83, 'en', 'help_search', 19),
('can', 84, 'en', 'help_search', 1),
('cancel', 45, 'en', 'help_search', 8),
('cancel', 60, 'en', 'help_search', 0.968904),
('cancel', 85, 'en', 'help_search', 3.9235),
('canceled', 44, 'en', 'help_search', 5.98902),
('cannot', 14, 'en', 'help_search', 1),
('cannot', 36, 'en', 'help_search', 1),
('cannot', 39, 'en', 'help_search', 1),
('cannot', 55, 'en', 'help_search', 1),
('cannot', 71, 'en', 'help_search', 1),
('cannot', 84, 'en', 'help_search', 1),
('captcha', 59, 'en', 'help_search', 0.945829),
('carefully', 50, 'en', 'help_search', 0.833529),
('case', 12, 'en', 'help_search', 0.646943),
('categorize', 81, 'en', 'help_search', 1),
('certain', 23, 'en', 'help_search', 1),
('certain', 42, 'en', 'help_search', 1),
('challenge', 23, 'en', 'help_search', 1),
('change', 5, 'en', 'help_search', 2),
('change', 8, 'en', 'help_search', 1),
('change', 10, 'en', 'help_search', 1.96621),
('change', 34, 'en', 'help_search', 1),
('change', 40, 'en', 'help_search', 1),
('change', 41, 'en', 'help_search', 1),
('change', 47, 'en', 'help_search', 4),
('change', 52, 'en', 'help_search', 1),
('change', 55, 'en', 'help_search', 1),
('change', 58, 'en', 'help_search', 1),
('change', 62, 'en', 'help_search', 1),
('change', 63, 'en', 'help_search', 1),
('change', 65, 'en', 'help_search', 1),
('change', 67, 'en', 'help_search', 1.98493),
('change', 70, 'en', 'help_search', 1),
('change', 75, 'en', 'help_search', 1),
('change', 77, 'en', 'help_search', 2),
('change', 79, 'en', 'help_search', 0.96498),
('change', 85, 'en', 'help_search', 5),
('changed', 29, 'en', 'help_search', 0.938382),
('changed', 31, 'en', 'help_search', 1),
('changed', 32, 'en', 'help_search', 1),
('changed', 38, 'en', 'help_search', 2),
('changed', 55, 'en', 'help_search', 1),
('changed', 71, 'en', 'help_search', 1),
('changed', 84, 'en', 'help_search', 2),
('changes', 3, 'en', 'help_search', 1),
('changes', 11, 'en', 'help_search', 2),
('changes', 18, 'en', 'help_search', 1.94209),
('changes', 53, 'en', 'help_search', 2),
('changes', 62, 'en', 'help_search', 1),
('changes', 63, 'en', 'help_search', 1),
('changes', 75, 'en', 'help_search', 1),
('changes', 77, 'en', 'help_search', 1),
('changes', 85, 'en', 'help_search', 0.98493),
('changing', 10, 'en', 'help_search', 45),
('changing', 32, 'en', 'help_search', 26),
('changing', 85, 'en', 'help_search', 1),
('channel', 46, 'en', 'help_search', 1),
('character', 12, 'en', 'help_search', 0.693594),
('character', 76, 'en', 'help_search', 1),
('characteristics', 12, 'en', 'help_search', 1.409),
('characters', 12, 'en', 'help_search', 0.699655),
('check', 6, 'en', 'help_search', 1),
('check', 9, 'en', 'help_search', 1),
('check', 26, 'en', 'help_search', 1),
('check', 29, 'en', 'help_search', 1),
('check', 34, 'en', 'help_search', 1),
('check', 35, 'en', 'help_search', 2),
('check', 36, 'en', 'help_search', 1),
('check', 37, 'en', 'help_search', 4),
('check', 40, 'en', 'help_search', 1),
('check', 43, 'en', 'help_search', 1),
('check', 44, 'en', 'help_search', 1),
('check', 47, 'en', 'help_search', 2),
('check', 50, 'en', 'help_search', 1.74863),
('check', 64, 'en', 'help_search', 1),
('check', 67, 'en', 'help_search', 1),
('check', 72, 'en', 'help_search', 1),
('check', 73, 'en', 'help_search', 1),
('check', 75, 'en', 'help_search', 1),
('check', 83, 'en', 'help_search', 1),
('checkbox', 35, 'en', 'help_search', 1),
('checkbox', 47, 'en', 'help_search', 1),
('checked', 37, 'en', 'help_search', 4),
('checked', 40, 'en', 'help_search', 1),
('checked', 65, 'en', 'help_search', 1),
('checked', 73, 'en', 'help_search', 1),
('checking', 58, 'en', 'help_search', 2),
('child', 73, 'en', 'help_search', 1),
('children', 73, 'en', 'help_search', 1),
('chinese', 29, 'en', 'help_search', 1),
('choice', 35, 'en', 'help_search', 1),
('choice', 80, 'en', 'help_search', 1),
('choices', 12, 'en', 'help_search', 0.643484),
('choices', 64, 'en', 'help_search', 2),
('choose', 26, 'en', 'help_search', 1),
('choose', 38, 'en', 'help_search', 1),
('choose', 50, 'en', 'help_search', 1.83353),
('choose', 55, 'en', 'help_search', 1),
('choose', 62, 'en', 'help_search', 1),
('choose', 64, 'en', 'help_search', 2),
('choose', 70, 'en', 'help_search', 2),
('choose', 71, 'en', 'help_search', 2),
('choose', 74, 'en', 'help_search', 1),
('choose', 80, 'en', 'help_search', 1),
('choosing', 23, 'en', 'help_search', 1),
('choosing', 54, 'en', 'help_search', 1),
('choosing', 71, 'en', 'help_search', 1),
('chose', 35, 'en', 'help_search', 2),
('chosen', 12, 'en', 'help_search', 1.55879),
('chosen', 50, 'en', 'help_search', 1),
('chosen', 85, 'en', 'help_search', 1),
('cjk', 29, 'en', 'help_search', 3.97258),
('ckeditor', 54, 'en', 'help_search', 13.1162),
('claro', 26, 'en', 'help_search', 1),
('claro', 27, 'en', 'help_search', 0.989021),
('claro', 79, 'en', 'help_search', 1),
('classified', 81, 'en', 'help_search', 0.961087),
('classify', 42, 'en', 'help_search', 1),
('classify', 81, 'en', 'help_search', 4.99731),
('clean', 54, 'en', 'help_search', 1),
('clear', 15, 'en', 'help_search', 1),
('clear', 31, 'en', 'help_search', 11),
('clear', 34, 'en', 'help_search', 1),
('cleared', 31, 'en', 'help_search', 1),
('clearing', 26, 'en', 'help_search', 1),
('clearing', 31, 'en', 'help_search', 26),
('clearing', 34, 'en', 'help_search', 1),
('cli', 11, 'en', 'help_search', 0.725015),
('click', 1, 'en', 'help_search', 1),
('click', 3, 'en', 'help_search', 2),
('click', 4, 'en', 'help_search', 1),
('click', 5, 'en', 'help_search', 2),
('click', 6, 'en', 'help_search', 2),
('click', 7, 'en', 'help_search', 2),
('click', 9, 'en', 'help_search', 2),
('click', 13, 'en', 'help_search', 1.98087),
('click', 20, 'en', 'help_search', 3),
('click', 26, 'en', 'help_search', 2),
('click', 28, 'en', 'help_search', 4),
('click', 29, 'en', 'help_search', 1.91473),
('click', 31, 'en', 'help_search', 1),
('click', 32, 'en', 'help_search', 4),
('click', 33, 'en', 'help_search', 1.86836),
('click', 34, 'en', 'help_search', 2),
('click', 35, 'en', 'help_search', 1),
('click', 36, 'en', 'help_search', 2),
('click', 37, 'en', 'help_search', 1),
('click', 38, 'en', 'help_search', 3),
('click', 39, 'en', 'help_search', 1),
('click', 40, 'en', 'help_search', 2),
('click', 41, 'en', 'help_search', 3),
('click', 43, 'en', 'help_search', 1),
('click', 44, 'en', 'help_search', 0.972861),
('click', 45, 'en', 'help_search', 5),
('click', 47, 'en', 'help_search', 5),
('click', 49, 'en', 'help_search', 5),
('click', 50, 'en', 'help_search', 1.71539),
('click', 51, 'en', 'help_search', 3),
('click', 52, 'en', 'help_search', 4),
('click', 56, 'en', 'help_search', 2),
('click', 58, 'en', 'help_search', 3),
('click', 60, 'en', 'help_search', 2.98633),
('click', 61, 'en', 'help_search', 5),
('click', 62, 'en', 'help_search', 3),
('click', 63, 'en', 'help_search', 3),
('click', 64, 'en', 'help_search', 5),
('click', 65, 'en', 'help_search', 4),
('click', 66, 'en', 'help_search', 2),
('click', 67, 'en', 'help_search', 4.99315),
('click', 70, 'en', 'help_search', 5),
('click', 72, 'en', 'help_search', 2),
('click', 73, 'en', 'help_search', 4),
('click', 74, 'en', 'help_search', 2),
('click', 75, 'en', 'help_search', 2),
('click', 76, 'en', 'help_search', 1),
('click', 77, 'en', 'help_search', 2),
('click', 79, 'en', 'help_search', 3.94216),
('click', 80, 'en', 'help_search', 4),
('click', 82, 'en', 'help_search', 4),
('click', 83, 'en', 'help_search', 4.98902),
('click', 84, 'en', 'help_search', 2),
('click', 85, 'en', 'help_search', 10.9809),
('clicked', 60, 'en', 'help_search', 1),
('clicking', 23, 'en', 'help_search', 1),
('clicking', 55, 'en', 'help_search', 0.98493),
('clicking', 57, 'en', 'help_search', 1),
('clicking', 60, 'en', 'help_search', 1),
('clicking', 67, 'en', 'help_search', 1),
('clicking', 79, 'en', 'help_search', 1),
('clicking', 85, 'en', 'help_search', 1),
('clicks', 30, 'en', 'help_search', 1),
('clipboard', 2, 'en', 'help_search', 1),
('clipboard', 4, 'en', 'help_search', 2),
('cloned', 11, 'en', 'help_search', 0.842342),
('clones', 11, 'en', 'help_search', 0.860547),
('cloning', 11, 'en', 'help_search', 0.857458),
('closed', 55, 'en', 'help_search', 3.63897),
('closed', 57, 'en', 'help_search', 4),
('code', 12, 'en', 'help_search', 0.752312),
('code', 33, 'en', 'help_search', 4),
('codebase', 11, 'en', 'help_search', 0.854391),
('codes', 12, 'en', 'help_search', 0.781775),
('codes', 32, 'en', 'help_search', 12),
('codes', 33, 'en', 'help_search', 1),
('collected', 55, 'en', 'help_search', 1),
('collection', 12, 'en', 'help_search', 0.972861),
('collection', 17, 'en', 'help_search', 1),
('collectively', 29, 'en', 'help_search', 1),
('column', 28, 'en', 'help_search', 1),
('column', 29, 'en', 'help_search', 0.873132),
('column', 36, 'en', 'help_search', 2),
('column', 43, 'en', 'help_search', 1),
('column', 54, 'en', 'help_search', 1),
('column', 62, 'en', 'help_search', 2),
('column', 63, 'en', 'help_search', 1),
('column', 67, 'en', 'help_search', 3),
('combinations', 12, 'en', 'help_search', 0.683725),
('come', 15, 'en', 'help_search', 1),
('come', 71, 'en', 'help_search', 0.913226),
('comes', 73, 'en', 'help_search', 1),
('command', 13, 'en', 'help_search', 1),
('command', 54, 'en', 'help_search', 1),
('commandline', 11, 'en', 'help_search', 0.729424),
('comment', 12, 'en', 'help_search', 2.38267),
('comment', 55, 'en', 'help_search', 30.4076),
('comment', 56, 'en', 'help_search', 63),
('comment', 57, 'en', 'help_search', 11),
('comment', 58, 'en', 'help_search', 19),
('comment', 59, 'en', 'help_search', 55.4508),
('commentary', 59, 'en', 'help_search', 1),
('commented', 56, 'en', 'help_search', 1);
INSERT INTO `[[dbprefix]]search_index` VALUES
('commenters', 55, 'en', 'help_search', 1),
('commenting', 55, 'en', 'help_search', 5),
('commenting', 57, 'en', 'help_search', 3),
('commenting', 59, 'en', 'help_search', 1.87634),
('comments', 12, 'en', 'help_search', 0.869951),
('comments', 24, 'en', 'help_search', 1),
('comments', 55, 'en', 'help_search', 77.2798),
('comments', 56, 'en', 'help_search', 2),
('comments', 57, 'en', 'help_search', 58),
('comments', 58, 'en', 'help_search', 76),
('comments', 59, 'en', 'help_search', 51.8436),
('comments', 71, 'en', 'help_search', 1),
('common', 64, 'en', 'help_search', 1),
('common', 81, 'en', 'help_search', 1),
('common', 82, 'en', 'help_search', 1),
('commonly', 12, 'en', 'help_search', 1),
('commonly', 50, 'en', 'help_search', 1),
('commonlyused', 24, 'en', 'help_search', 1),
('commonlyused', 44, 'en', 'help_search', 1),
('community', 59, 'en', 'help_search', 0.931053),
('communitymembers', 22, 'en', 'help_search', 1),
('communityprovided', 22, 'en', 'help_search', 2),
('compares', 11, 'en', 'help_search', 0.759465),
('comparison', 25, 'en', 'help_search', 11),
('complete', 1, 'en', 'help_search', 26),
('complete', 3, 'en', 'help_search', 28),
('complete', 26, 'en', 'help_search', 1),
('complete', 54, 'en', 'help_search', 0.839384),
('complete', 60, 'en', 'help_search', 0.98493),
('complete', 79, 'en', 'help_search', 0.993146),
('completely', 12, 'en', 'help_search', 0.664818),
('complex', 11, 'en', 'help_search', 1),
('complex', 25, 'en', 'help_search', 1),
('complex', 30, 'en', 'help_search', 0.892724),
('compliance', 23, 'en', 'help_search', 1),
('compliant', 25, 'en', 'help_search', 1),
('components', 24, 'en', 'help_search', 20),
('components', 71, 'en', 'help_search', 20),
('composed', 32, 'en', 'help_search', 1),
('compressed', 18, 'en', 'help_search', 1),
('computer', 2, 'en', 'help_search', 1),
('computer', 4, 'en', 'help_search', 1),
('concept', 11, 'en', 'help_search', 14.7488),
('concept', 12, 'en', 'help_search', 12.7),
('concept', 13, 'en', 'help_search', 10.6579),
('concept', 14, 'en', 'help_search', 11),
('concept', 17, 'en', 'help_search', 11),
('concept', 27, 'en', 'help_search', 1),
('concept', 31, 'en', 'help_search', 11),
('concept', 78, 'en', 'help_search', 11),
('concept', 81, 'en', 'help_search', 9.74705),
('concepts', 11, 'en', 'help_search', 0.819249),
('conditions', 31, 'en', 'help_search', 1),
('conditions', 47, 'en', 'help_search', 1),
('config', 11, 'en', 'help_search', 8),
('configurable', 24, 'en', 'help_search', 1),
('configuration', 1, 'en', 'help_search', 37),
('configuration', 2, 'en', 'help_search', 49),
('configuration', 3, 'en', 'help_search', 46),
('configuration', 4, 'en', 'help_search', 47),
('configuration', 5, 'en', 'help_search', 1),
('configuration', 6, 'en', 'help_search', 8),
('configuration', 11, 'en', 'help_search', 172.074),
('configuration', 12, 'en', 'help_search', 5),
('configuration', 13, 'en', 'help_search', 7.9074),
('configuration', 14, 'en', 'help_search', 1),
('configuration', 18, 'en', 'help_search', 3.49253),
('configuration', 22, 'en', 'help_search', 7),
('configuration', 24, 'en', 'help_search', 4.70972),
('configuration', 26, 'en', 'help_search', 4),
('configuration', 28, 'en', 'help_search', 4),
('configuration', 29, 'en', 'help_search', 8.77905),
('configuration', 30, 'en', 'help_search', 2),
('configuration', 31, 'en', 'help_search', 4),
('configuration', 32, 'en', 'help_search', 20),
('configuration', 33, 'en', 'help_search', 16.1957),
('configuration', 34, 'en', 'help_search', 16),
('configuration', 36, 'en', 'help_search', 1),
('configuration', 38, 'en', 'help_search', 4),
('configuration', 44, 'en', 'help_search', 7.85992),
('configuration', 49, 'en', 'help_search', 1),
('configuration', 50, 'en', 'help_search', 11.2476),
('configuration', 54, 'en', 'help_search', 10.3077),
('configuration', 70, 'en', 'help_search', 5),
('configuration', 77, 'en', 'help_search', 4),
('configure', 6, 'en', 'help_search', 1),
('configure', 13, 'en', 'help_search', 4),
('configure', 15, 'en', 'help_search', 1),
('configure', 22, 'en', 'help_search', 1),
('configure', 24, 'en', 'help_search', 2.85752),
('configure', 27, 'en', 'help_search', 1),
('configure', 28, 'en', 'help_search', 2),
('configure', 30, 'en', 'help_search', 2.73993),
('configure', 32, 'en', 'help_search', 1),
('configure', 33, 'en', 'help_search', 1),
('configure', 44, 'en', 'help_search', 2),
('configure', 47, 'en', 'help_search', 5),
('configure', 48, 'en', 'help_search', 1),
('configure', 49, 'en', 'help_search', 5),
('configure', 50, 'en', 'help_search', 7.40885),
('configure', 54, 'en', 'help_search', 2.99315),
('configure', 55, 'en', 'help_search', 21),
('configure', 56, 'en', 'help_search', 1),
('configure', 59, 'en', 'help_search', 1),
('configure', 60, 'en', 'help_search', 2),
('configure', 61, 'en', 'help_search', 1),
('configure', 62, 'en', 'help_search', 2),
('configure', 63, 'en', 'help_search', 2),
('configure', 66, 'en', 'help_search', 1),
('configure', 70, 'en', 'help_search', 1),
('configure', 72, 'en', 'help_search', 28),
('configure', 78, 'en', 'help_search', 1),
('configure', 80, 'en', 'help_search', 21),
('configured', 17, 'en', 'help_search', 1),
('configured', 22, 'en', 'help_search', 1),
('configured', 29, 'en', 'help_search', 0.909743),
('configured', 30, 'en', 'help_search', 2.74449),
('configured', 44, 'en', 'help_search', 1),
('configured', 48, 'en', 'help_search', 1),
('configured', 55, 'en', 'help_search', 1),
('configured', 73, 'en', 'help_search', 1),
('configuring', 6, 'en', 'help_search', 26),
('configuring', 12, 'en', 'help_search', 0.597248),
('configuring', 13, 'en', 'help_search', 37.4847),
('configuring', 26, 'en', 'help_search', 28),
('configuring', 27, 'en', 'help_search', 0.953396),
('configuring', 28, 'en', 'help_search', 26),
('configuring', 29, 'en', 'help_search', 1.91323),
('configuring', 30, 'en', 'help_search', 42.7117),
('configuring', 33, 'en', 'help_search', 26),
('configuring', 44, 'en', 'help_search', 26),
('configuring', 47, 'en', 'help_search', 26),
('configuring', 49, 'en', 'help_search', 1),
('configuring', 55, 'en', 'help_search', 26),
('configuring', 57, 'en', 'help_search', 2),
('configuring', 59, 'en', 'help_search', 0.879565),
('configuring', 62, 'en', 'help_search', 26),
('configuring', 63, 'en', 'help_search', 26),
('configuring', 71, 'en', 'help_search', 0.805455),
('configuring', 76, 'en', 'help_search', 1),
('configuring', 77, 'en', 'help_search', 1),
('configuring', 78, 'en', 'help_search', 45),
('configuring', 80, 'en', 'help_search', 26),
('configuring', 81, 'en', 'help_search', 0.920273),
('configuring', 83, 'en', 'help_search', 1),
('confirm', 35, 'en', 'help_search', 1),
('confirmation', 36, 'en', 'help_search', 1),
('confirmation', 80, 'en', 'help_search', 1),
('confused', 83, 'en', 'help_search', 1),
('connect', 50, 'en', 'help_search', 0.848323),
('connected', 54, 'en', 'help_search', 1),
('connecting', 54, 'en', 'help_search', 26),
('consist', 12, 'en', 'help_search', 1),
('consume', 53, 'en', 'help_search', 1),
('contact', 5, 'en', 'help_search', 51),
('contact', 6, 'en', 'help_search', 44),
('contact', 7, 'en', 'help_search', 38),
('contact', 8, 'en', 'help_search', 98),
('contact', 9, 'en', 'help_search', 47),
('contact', 12, 'en', 'help_search', 0.609315),
('contact', 55, 'en', 'help_search', 1),
('contain', 12, 'en', 'help_search', 1.44349),
('contain', 24, 'en', 'help_search', 1),
('contain', 81, 'en', 'help_search', 1),
('contain', 83, 'en', 'help_search', 1),
('containing', 1, 'en', 'help_search', 1),
('containing', 30, 'en', 'help_search', 0.949597),
('containing', 70, 'en', 'help_search', 1),
('containing', 85, 'en', 'help_search', 2),
('contains', 11, 'en', 'help_search', 0.824901),
('contains', 47, 'en', 'help_search', 1),
('contains', 60, 'en', 'help_search', 1),
('contains', 79, 'en', 'help_search', 1),
('content', 5, 'en', 'help_search', 2),
('content', 10, 'en', 'help_search', 4.97685),
('content', 11, 'en', 'help_search', 1),
('content', 12, 'en', 'help_search', 89.8735),
('content', 13, 'en', 'help_search', 1),
('content', 14, 'en', 'help_search', 2),
('content', 16, 'en', 'help_search', 5),
('content', 17, 'en', 'help_search', 2),
('content', 20, 'en', 'help_search', 1),
('content', 21, 'en', 'help_search', 28),
('content', 22, 'en', 'help_search', 6),
('content', 24, 'en', 'help_search', 4.98087),
('content', 25, 'en', 'help_search', 3),
('content', 28, 'en', 'help_search', 8),
('content', 29, 'en', 'help_search', 7.89272),
('content', 30, 'en', 'help_search', 8.21653),
('content', 33, 'en', 'help_search', 1),
('content', 36, 'en', 'help_search', 1),
('content', 42, 'en', 'help_search', 2),
('content', 44, 'en', 'help_search', 1.98902),
('content', 45, 'en', 'help_search', 1),
('content', 46, 'en', 'help_search', 4),
('content', 48, 'en', 'help_search', 28),
('content', 50, 'en', 'help_search', 3.87562),
('content', 51, 'en', 'help_search', 36),
('content', 53, 'en', 'help_search', 1),
('content', 54, 'en', 'help_search', 4),
('content', 55, 'en', 'help_search', 18.6752),
('content', 56, 'en', 'help_search', 2),
('content', 57, 'en', 'help_search', 8),
('content', 58, 'en', 'help_search', 9),
('content', 59, 'en', 'help_search', 6),
('content', 61, 'en', 'help_search', 11),
('content', 62, 'en', 'help_search', 6),
('content', 63, 'en', 'help_search', 6),
('content', 64, 'en', 'help_search', 19),
('content', 65, 'en', 'help_search', 99.8792),
('content', 66, 'en', 'help_search', 88),
('content', 67, 'en', 'help_search', 107.333),
('content', 68, 'en', 'help_search', 105),
('content', 69, 'en', 'help_search', 62),
('content', 71, 'en', 'help_search', 31.6669),
('content', 72, 'en', 'help_search', 33),
('content', 73, 'en', 'help_search', 3),
('content', 76, 'en', 'help_search', 43),
('content', 78, 'en', 'help_search', 4),
('content', 80, 'en', 'help_search', 3),
('content', 81, 'en', 'help_search', 11.9596),
('content', 84, 'en', 'help_search', 1),
('content', 85, 'en', 'help_search', 1),
('context', 18, 'en', 'help_search', 1),
('context', 71, 'en', 'help_search', 3.62515),
('contextual', 20, 'en', 'help_search', 9),
('contextual', 24, 'en', 'help_search', 1),
('contextual', 60, 'en', 'help_search', 66),
('contextual', 71, 'en', 'help_search', 3.70972),
('continue', 13, 'en', 'help_search', 1),
('continue', 61, 'en', 'help_search', 4),
('continue', 64, 'en', 'help_search', 4),
('continue', 80, 'en', 'help_search', 1),
('contributed', 10, 'en', 'help_search', 4),
('contributed', 12, 'en', 'help_search', 1.49425),
('contributed', 14, 'en', 'help_search', 5),
('contributed', 16, 'en', 'help_search', 1),
('contributed', 19, 'en', 'help_search', 2),
('contributed', 20, 'en', 'help_search', 1),
('contributed', 24, 'en', 'help_search', 3.8775),
('contributed', 25, 'en', 'help_search', 1),
('contributed', 27, 'en', 'help_search', 1),
('contributed', 30, 'en', 'help_search', 3),
('contributed', 35, 'en', 'help_search', 1),
('contributed', 38, 'en', 'help_search', 1),
('contributed', 54, 'en', 'help_search', 1),
('contributed', 59, 'en', 'help_search', 0.980874),
('contributed', 60, 'en', 'help_search', 1),
('contributed', 65, 'en', 'help_search', 1),
('contributed', 67, 'en', 'help_search', 1),
('contributed', 68, 'en', 'help_search', 1),
('contributed', 71, 'en', 'help_search', 1),
('contributed', 78, 'en', 'help_search', 1),
('contributed', 79, 'en', 'help_search', 1),
('control', 65, 'en', 'help_search', 4),
('control', 67, 'en', 'help_search', 4),
('convert', 50, 'en', 'help_search', 2),
('converted', 18, 'en', 'help_search', 0.957226),
('converting', 25, 'en', 'help_search', 1),
('converting', 50, 'en', 'help_search', 1),
('converts', 50, 'en', 'help_search', 1),
('cookies', 12, 'en', 'help_search', 1),
('cooking', 81, 'en', 'help_search', 1),
('copied', 2, 'en', 'help_search', 1),
('copied', 11, 'en', 'help_search', 0.851346),
('copy', 2, 'en', 'help_search', 1),
('copy', 4, 'en', 'help_search', 1),
('copy', 13, 'en', 'help_search', 1),
('core', 8, 'en', 'help_search', 1),
('core', 10, 'en', 'help_search', 6.95772),
('core', 11, 'en', 'help_search', 1.70451),
('core', 12, 'en', 'help_search', 9.59002),
('core', 13, 'en', 'help_search', 1.99731),
('core', 14, 'en', 'help_search', 6),
('core', 15, 'en', 'help_search', 1),
('core', 16, 'en', 'help_search', 7.99461),
('core', 17, 'en', 'help_search', 2),
('core', 18, 'en', 'help_search', 1),
('core', 19, 'en', 'help_search', 3),
('core', 20, 'en', 'help_search', 4),
('core', 21, 'en', 'help_search', 1),
('core', 22, 'en', 'help_search', 4),
('core', 23, 'en', 'help_search', 1.98493),
('core', 24, 'en', 'help_search', 7.88282),
('core', 25, 'en', 'help_search', 1),
('core', 26, 'en', 'help_search', 1),
('core', 27, 'en', 'help_search', 6.98902),
('core', 29, 'en', 'help_search', 1),
('core', 30, 'en', 'help_search', 26.7867),
('core', 33, 'en', 'help_search', 1),
('core', 35, 'en', 'help_search', 1),
('core', 37, 'en', 'help_search', 4),
('core', 38, 'en', 'help_search', 1),
('core', 42, 'en', 'help_search', 2),
('core', 50, 'en', 'help_search', 3.81085),
('core', 54, 'en', 'help_search', 2),
('core', 56, 'en', 'help_search', 1),
('core', 59, 'en', 'help_search', 2.79901),
('core', 60, 'en', 'help_search', 2),
('core', 66, 'en', 'help_search', 3),
('core', 68, 'en', 'help_search', 3),
('core', 69, 'en', 'help_search', 1),
('core', 71, 'en', 'help_search', 2.41392),
('core', 74, 'en', 'help_search', 1),
('core', 78, 'en', 'help_search', 2),
('core', 79, 'en', 'help_search', 4),
('core', 80, 'en', 'help_search', 1),
('core', 81, 'en', 'help_search', 1.8881),
('core', 83, 'en', 'help_search', 2),
('corner', 20, 'en', 'help_search', 1),
('corner', 60, 'en', 'help_search', 1),
('correct', 6, 'en', 'help_search', 1),
('correct', 8, 'en', 'help_search', 1),
('correct', 28, 'en', 'help_search', 2),
('correct', 40, 'en', 'help_search', 1),
('correct', 44, 'en', 'help_search', 0.976851),
('correct', 50, 'en', 'help_search', 1.83353),
('correct', 73, 'en', 'help_search', 2),
('correct', 77, 'en', 'help_search', 1),
('correct', 85, 'en', 'help_search', 1),
('corresponding', 24, 'en', 'help_search', 0.873132),
('corresponding', 60, 'en', 'help_search', 0.989021),
('corresponds', 12, 'en', 'help_search', 0.747619),
('corrupted', 29, 'en', 'help_search', 0.920273),
('could', 57, 'en', 'help_search', 1),
('could', 71, 'en', 'help_search', 0.824901),
('could', 81, 'en', 'help_search', 6),
('counterparts', 11, 'en', 'help_search', 0.747619),
('country', 32, 'en', 'help_search', 2),
('covered', 19, 'en', 'help_search', 2),
('create', 1, 'en', 'help_search', 1),
('create', 7, 'en', 'help_search', 1),
('create', 10, 'en', 'help_search', 1),
('create', 11, 'en', 'help_search', 0.848323),
('create', 12, 'en', 'help_search', 0.949597),
('create', 24, 'en', 'help_search', 1),
('create', 33, 'en', 'help_search', 2),
('create', 40, 'en', 'help_search', 6),
('create', 41, 'en', 'help_search', 1),
('create', 50, 'en', 'help_search', 0.920273),
('create', 51, 'en', 'help_search', 2),
('create', 56, 'en', 'help_search', 21),
('create', 65, 'en', 'help_search', 26),
('create', 66, 'en', 'help_search', 21),
('create', 70, 'en', 'help_search', 4),
('create', 71, 'en', 'help_search', 1.7974),
('create', 74, 'en', 'help_search', 1),
('create', 76, 'en', 'help_search', 26),
('create', 79, 'en', 'help_search', 1),
('create', 80, 'en', 'help_search', 1),
('create', 81, 'en', 'help_search', 0.942091),
('create', 84, 'en', 'help_search', 1),
('created', 14, 'en', 'help_search', 1),
('created', 36, 'en', 'help_search', 1),
('created', 44, 'en', 'help_search', 29.989),
('created', 56, 'en', 'help_search', 1),
('created', 66, 'en', 'help_search', 1),
('created', 67, 'en', 'help_search', 2),
('created', 69, 'en', 'help_search', 1),
('created', 71, 'en', 'help_search', 0.876337),
('created', 80, 'en', 'help_search', 3),
('created', 81, 'en', 'help_search', 1),
('created', 84, 'en', 'help_search', 1),
('creates', 53, 'en', 'help_search', 1),
('creates', 54, 'en', 'help_search', 1),
('creating', 7, 'en', 'help_search', 26),
('creating', 17, 'en', 'help_search', 1),
('creating', 40, 'en', 'help_search', 26),
('creating', 42, 'en', 'help_search', 1),
('creating', 44, 'en', 'help_search', 1),
('creating', 51, 'en', 'help_search', 26),
('creating', 55, 'en', 'help_search', 1),
('creating', 56, 'en', 'help_search', 26),
('creating', 59, 'en', 'help_search', 0.896076),
('creating', 61, 'en', 'help_search', 1),
('creating', 63, 'en', 'help_search', 1),
('creating', 64, 'en', 'help_search', 1),
('creating', 65, 'en', 'help_search', 37.8792),
('creating', 66, 'en', 'help_search', 26),
('creating', 69, 'en', 'help_search', 1),
('creating', 71, 'en', 'help_search', 8.57154),
('creating', 74, 'en', 'help_search', 26),
('creating', 76, 'en', 'help_search', 38),
('creating', 79, 'en', 'help_search', 26),
('creating', 84, 'en', 'help_search', 26),
('creating', 85, 'en', 'help_search', 10.6579),
('creation', 44, 'en', 'help_search', 19),
('criteria', 71, 'en', 'help_search', 10.8666),
('criteria', 85, 'en', 'help_search', 8),
('critical', 37, 'en', 'help_search', 2),
('cron', 12, 'en', 'help_search', 4),
('cron', 13, 'en', 'help_search', 127.986),
('cron', 15, 'en', 'help_search', 1),
('cron', 26, 'en', 'help_search', 2),
('cron', 29, 'en', 'help_search', 11.7259),
('crop', 70, 'en', 'help_search', 5),
('cropping', 16, 'en', 'help_search', 1),
('css', 10, 'en', 'help_search', 1),
('css', 14, 'en', 'help_search', 1),
('css', 18, 'en', 'help_search', 1.85135),
('curated', 81, 'en', 'help_search', 1),
('current', 11, 'en', 'help_search', 1),
('current', 71, 'en', 'help_search', 0.902857),
('current', 79, 'en', 'help_search', 8),
('current', 85, 'en', 'help_search', 1),
('currently', 12, 'en', 'help_search', 0.591395),
('currently', 24, 'en', 'help_search', 1),
('currently', 47, 'en', 'help_search', 1),
('currently', 54, 'en', 'help_search', 1),
('currently', 85, 'en', 'help_search', 1),
('custom', 12, 'en', 'help_search', 0.620288),
('custom', 17, 'en', 'help_search', 2),
('custom', 27, 'en', 'help_search', 1),
('custom', 74, 'en', 'help_search', 1),
('customize', 11, 'en', 'help_search', 1),
('customizing', 10, 'en', 'help_search', 10.2416),
('customizing', 14, 'en', 'help_search', 11),
('data', 10, 'en', 'help_search', 1),
('data', 11, 'en', 'help_search', 31.9136),
('data', 12, 'en', 'help_search', 32.3651),
('data', 18, 'en', 'help_search', 6.93009),
('data', 25, 'en', 'help_search', 5),
('data', 31, 'en', 'help_search', 4),
('data', 44, 'en', 'help_search', 1),
('data', 59, 'en', 'help_search', 1),
('data', 68, 'en', 'help_search', 1),
('data', 71, 'en', 'help_search', 13.4291),
('data', 82, 'en', 'help_search', 1),
('data', 84, 'en', 'help_search', 1),
('data', 85, 'en', 'help_search', 1),
('database', 10, 'en', 'help_search', 1),
('database', 11, 'en', 'help_search', 1.85135),
('database', 12, 'en', 'help_search', 0.749958),
('database', 15, 'en', 'help_search', 1),
('database', 27, 'en', 'help_search', 1),
('database', 29, 'en', 'help_search', 1),
('database', 31, 'en', 'help_search', 1),
('database', 37, 'en', 'help_search', 1),
('date', 12, 'en', 'help_search', 2.57253),
('date', 32, 'en', 'help_search', 21),
('date', 71, 'en', 'help_search', 0.899454),
('dates', 12, 'en', 'help_search', 1.85746),
('datetime', 12, 'en', 'help_search', 1.71189),
('death', 33, 'en', 'help_search', 4),
('decide', 58, 'en', 'help_search', 1),
('default', 9, 'en', 'help_search', 43),
('default', 10, 'en', 'help_search', 0.98493),
('default', 11, 'en', 'help_search', 4.66762),
('default', 16, 'en', 'help_search', 1),
('default', 22, 'en', 'help_search', 2),
('default', 23, 'en', 'help_search', 2),
('default', 28, 'en', 'help_search', 8),
('default', 29, 'en', 'help_search', 7.93972),
('default', 32, 'en', 'help_search', 5),
('default', 33, 'en', 'help_search', 1),
('default', 38, 'en', 'help_search', 38),
('default', 39, 'en', 'help_search', 1),
('default', 55, 'en', 'help_search', 3.79839),
('default', 61, 'en', 'help_search', 1),
('default', 72, 'en', 'help_search', 5),
('default', 74, 'en', 'help_search', 2),
('default', 79, 'en', 'help_search', 1),
('defaults', 55, 'en', 'help_search', 0.913226),
('defend', 50, 'en', 'help_search', 1),
('define', 10, 'en', 'help_search', 1.97685),
('define', 11, 'en', 'help_search', 1),
('define', 12, 'en', 'help_search', 2.07234),
('define', 48, 'en', 'help_search', 1),
('define', 52, 'en', 'help_search', 1),
('define', 53, 'en', 'help_search', 3.9223),
('define', 68, 'en', 'help_search', 1),
('defined', 11, 'en', 'help_search', 2),
('defined', 51, 'en', 'help_search', 1),
('defined', 53, 'en', 'help_search', 1),
('defined', 65, 'en', 'help_search', 1),
('defines', 10, 'en', 'help_search', 1),
('defines', 12, 'en', 'help_search', 1),
('defines', 53, 'en', 'help_search', 1),
('defining', 11, 'en', 'help_search', 0.72066),
('defining', 16, 'en', 'help_search', 1),
('defining', 52, 'en', 'help_search', 26),
('defining', 53, 'en', 'help_search', 1),
('delete', 14, 'en', 'help_search', 1),
('delete', 18, 'en', 'help_search', 1),
('delete', 28, 'en', 'help_search', 1),
('delete', 36, 'en', 'help_search', 1),
('delete', 45, 'en', 'help_search', 3),
('delete', 58, 'en', 'help_search', 5),
('delete', 71, 'en', 'help_search', 0.797402),
('delete', 79, 'en', 'help_search', 1),
('delete', 85, 'en', 'help_search', 1),
('deleted', 18, 'en', 'help_search', 1),
('deleted', 36, 'en', 'help_search', 1),
('deleted', 44, 'en', 'help_search', 28),
('deleting', 28, 'en', 'help_search', 1),
('deleting', 45, 'en', 'help_search', 26),
('deleting', 50, 'en', 'help_search', 0.805455),
('deletion', 44, 'en', 'help_search', 19),
('demonstrate', 47, 'en', 'help_search', 4),
('demonstrate', 49, 'en', 'help_search', 4),
('dependencies', 35, 'en', 'help_search', 1),
('dependent', 14, 'en', 'help_search', 1),
('depending', 12, 'en', 'help_search', 0.592848),
('depending', 13, 'en', 'help_search', 1),
('depending', 24, 'en', 'help_search', 1),
('depending', 42, 'en', 'help_search', 1),
('depending', 47, 'en', 'help_search', 1),
('depending', 61, 'en', 'help_search', 1),
('depends', 14, 'en', 'help_search', 1),
('deploying', 1, 'en', 'help_search', 1),
('deploying', 2, 'en', 'help_search', 1),
('deploying', 3, 'en', 'help_search', 1),
('deploying', 4, 'en', 'help_search', 1),
('deploying', 11, 'en', 'help_search', 26),
('deploying', 22, 'en', 'help_search', 1),
('deploying', 54, 'en', 'help_search', 1),
('derived', 74, 'en', 'help_search', 1),
('described', 11, 'en', 'help_search', 0.769219),
('described', 65, 'en', 'help_search', 1),
('describes', 11, 'en', 'help_search', 2),
('describes', 27, 'en', 'help_search', 1),
('description', 35, 'en', 'help_search', 1),
('description', 36, 'en', 'help_search', 5),
('description', 47, 'en', 'help_search', 1),
('description', 48, 'en', 'help_search', 20),
('description', 51, 'en', 'help_search', 1),
('description', 52, 'en', 'help_search', 1),
('description', 66, 'en', 'help_search', 4),
('description', 73, 'en', 'help_search', 4),
('description', 80, 'en', 'help_search', 1),
('descriptive', 70, 'en', 'help_search', 1),
('deserialization', 25, 'en', 'help_search', 4),
('design', 50, 'en', 'help_search', 1),
('desired', 5, 'en', 'help_search', 1),
('desired', 13, 'en', 'help_search', 1),
('desired', 28, 'en', 'help_search', 2),
('desired', 29, 'en', 'help_search', 1),
('desired', 30, 'en', 'help_search', 0.854391),
('desired', 33, 'en', 'help_search', 1),
('desired', 37, 'en', 'help_search', 1),
('desired', 41, 'en', 'help_search', 2),
('desired', 44, 'en', 'help_search', 0.997306),
('desired', 47, 'en', 'help_search', 1),
('desired', 50, 'en', 'help_search', 0.909743),
('desired', 52, 'en', 'help_search', 1),
('desired', 54, 'en', 'help_search', 0.892724),
('desired', 55, 'en', 'help_search', 2),
('desired', 57, 'en', 'help_search', 1),
('desired', 62, 'en', 'help_search', 1),
('desired', 63, 'en', 'help_search', 1),
('desired', 67, 'en', 'help_search', 1),
('desired', 73, 'en', 'help_search', 1),
('desired', 74, 'en', 'help_search', 1),
('desired', 76, 'en', 'help_search', 1),
('desired', 79, 'en', 'help_search', 1),
('destination', 11, 'en', 'help_search', 1.58432),
('details', 18, 'en', 'help_search', 0.896076),
('details', 24, 'en', 'help_search', 0.860547),
('details', 36, 'en', 'help_search', 1),
('details', 49, 'en', 'help_search', 1),
('details', 54, 'en', 'help_search', 1),
('details', 85, 'en', 'help_search', 1),
('determine', 10, 'en', 'help_search', 1),
('determines', 10, 'en', 'help_search', 1),
('dev', 11, 'en', 'help_search', 1.83938),
('development', 1, 'en', 'help_search', 4),
('development', 2, 'en', 'help_search', 4),
('development', 3, 'en', 'help_search', 4),
('development', 4, 'en', 'help_search', 4),
('development', 11, 'en', 'help_search', 16.539),
('development', 14, 'en', 'help_search', 1),
('development', 18, 'en', 'help_search', 3.4798),
('development', 31, 'en', 'help_search', 4),
('development', 33, 'en', 'help_search', 4.67026),
('development', 34, 'en', 'help_search', 8),
('device', 2, 'en', 'help_search', 1),
('device', 4, 'en', 'help_search', 1),
('device', 53, 'en', 'help_search', 2),
('deviceindependent', 53, 'en', 'help_search', 11),
('devices', 10, 'en', 'help_search', 0.96498),
('diagnose', 15, 'en', 'help_search', 2),
('dialog', 49, 'en', 'help_search', 2),
('did', 59, 'en', 'help_search', 2),
('differences', 3, 'en', 'help_search', 1),
('different', 8, 'en', 'help_search', 1),
('different', 11, 'en', 'help_search', 1.65177),
('different', 12, 'en', 'help_search', 3.64749),
('different', 16, 'en', 'help_search', 1),
('different', 18, 'en', 'help_search', 1.95772),
('different', 53, 'en', 'help_search', 0.997306),
('different', 59, 'en', 'help_search', 2.99731),
('different', 71, 'en', 'help_search', 1),
('different', 79, 'en', 'help_search', 1),
('differentsized', 10, 'en', 'help_search', 0.968904),
('difficult', 23, 'en', 'help_search', 1),
('direct', 46, 'en', 'help_search', 1),
('directly', 10, 'en', 'help_search', 1),
('directly', 46, 'en', 'help_search', 1),
('directly', 60, 'en', 'help_search', 1),
('directly', 79, 'en', 'help_search', 0.953396),
('directories', 11, 'en', 'help_search', 1),
('directory', 3, 'en', 'help_search', 1),
('directory', 11, 'en', 'help_search', 4.53613),
('disable', 6, 'en', 'help_search', 1),
('disable', 28, 'en', 'help_search', 1),
('disable', 57, 'en', 'help_search', 21),
('disable', 75, 'en', 'help_search', 2),
('disabled', 23, 'en', 'help_search', 1),
('disabled', 35, 'en', 'help_search', 1),
('disabled', 55, 'en', 'help_search', 3.81358),
('disabled', 62, 'en', 'help_search', 4),
('disabled', 63, 'en', 'help_search', 4),
('disabling', 17, 'en', 'help_search', 1),
('disabling', 23, 'en', 'help_search', 1),
('disabling', 28, 'en', 'help_search', 1),
('disabling', 34, 'en', 'help_search', 26),
('disabling', 36, 'en', 'help_search', 1),
('disabling', 57, 'en', 'help_search', 26),
('disabling', 75, 'en', 'help_search', 26),
('discard', 85, 'en', 'help_search', 0.989021),
('discovery', 10, 'en', 'help_search', 1.98087),
('discussed', 59, 'en', 'help_search', 0.873132),
('discussion', 59, 'en', 'help_search', 1),
('display', 5, 'en', 'help_search', 5),
('display', 12, 'en', 'help_search', 3.12375),
('display', 17, 'en', 'help_search', 1),
('display', 23, 'en', 'help_search', 1),
('display', 24, 'en', 'help_search', 0.906287),
('display', 30, 'en', 'help_search', 1),
('display', 33, 'en', 'help_search', 3.68109),
('display', 34, 'en', 'help_search', 4),
('display', 47, 'en', 'help_search', 4),
('display', 52, 'en', 'help_search', 9),
('display', 54, 'en', 'help_search', 0.909743),
('display', 56, 'en', 'help_search', 1),
('display', 59, 'en', 'help_search', 1),
('display', 60, 'en', 'help_search', 0.997306),
('display', 61, 'en', 'help_search', 1),
('display', 62, 'en', 'help_search', 37),
('display', 63, 'en', 'help_search', 4),
('display', 64, 'en', 'help_search', 1),
('display', 66, 'en', 'help_search', 1),
('display', 68, 'en', 'help_search', 2),
('display', 69, 'en', 'help_search', 1),
('display', 70, 'en', 'help_search', 1),
('display', 71, 'en', 'help_search', 13.1563),
('display', 73, 'en', 'help_search', 1),
('display', 78, 'en', 'help_search', 1),
('display', 79, 'en', 'help_search', 1),
('display', 80, 'en', 'help_search', 2),
('display', 81, 'en', 'help_search', 0.916736),
('display', 82, 'en', 'help_search', 38),
('display', 83, 'en', 'help_search', 1),
('display', 84, 'en', 'help_search', 2),
('display', 85, 'en', 'help_search', 30),
('displayed', 9, 'en', 'help_search', 11),
('displayed', 10, 'en', 'help_search', 2),
('displayed', 11, 'en', 'help_search', 1),
('displayed', 12, 'en', 'help_search', 5.31879),
('displayed', 17, 'en', 'help_search', 1),
('displayed', 32, 'en', 'help_search', 4),
('displayed', 44, 'en', 'help_search', 1),
('displayed', 47, 'en', 'help_search', 3),
('displayed', 48, 'en', 'help_search', 1),
('displayed', 50, 'en', 'help_search', 1),
('displayed', 55, 'en', 'help_search', 1.98902),
('displayed', 61, 'en', 'help_search', 1),
('displayed', 64, 'en', 'help_search', 1),
('displayed', 65, 'en', 'help_search', 2),
('displayed', 71, 'en', 'help_search', 1.89608),
('displayed', 73, 'en', 'help_search', 3),
('displayed', 74, 'en', 'help_search', 2),
('displayed', 79, 'en', 'help_search', 1),
('displayed', 85, 'en', 'help_search', 2),
('displaying', 62, 'en', 'help_search', 1),
('displayname', 44, 'en', 'help_search', 1),
('displays', 24, 'en', 'help_search', 2),
('displays', 60, 'en', 'help_search', 1),
('displays', 69, 'en', 'help_search', 1),
('displays', 70, 'en', 'help_search', 1),
('displays', 71, 'en', 'help_search', 5),
('displays', 82, 'en', 'help_search', 4),
('displays', 83, 'en', 'help_search', 4),
('displays', 85, 'en', 'help_search', 4),
('distributed', 14, 'en', 'help_search', 1),
('divided', 12, 'en', 'help_search', 2),
('divided', 16, 'en', 'help_search', 1),
('divided', 59, 'en', 'help_search', 1),
('divided', 68, 'en', 'help_search', 1),
('divisions', 12, 'en', 'help_search', 1),
('documentation', 18, 'en', 'help_search', 27.7322),
('documentation', 25, 'en', 'help_search', 22),
('documentation', 30, 'en', 'help_search', 8.57154),
('documentation', 55, 'en', 'help_search', 9.711),
('documentation', 58, 'en', 'help_search', 11),
('documented', 46, 'en', 'help_search', 1),
('documents', 16, 'en', 'help_search', 1),
('does', 11, 'en', 'help_search', 1),
('does', 12, 'en', 'help_search', 20),
('does', 32, 'en', 'help_search', 1),
('does', 33, 'en', 'help_search', 1),
('does', 54, 'en', 'help_search', 0.899454),
('don', 83, 'en', 'help_search', 1),
('done', 11, 'en', 'help_search', 0.736141),
('done', 26, 'en', 'help_search', 1),
('done', 31, 'en', 'help_search', 2),
('done', 62, 'en', 'help_search', 1),
('done', 63, 'en', 'help_search', 1),
('done', 67, 'en', 'help_search', 1),
('down', 28, 'en', 'help_search', 1),
('download', 1, 'en', 'help_search', 1),
('download', 10, 'en', 'help_search', 22),
('download', 14, 'en', 'help_search', 12),
('download', 22, 'en', 'help_search', 2),
('download', 35, 'en', 'help_search', 1),
('download', 54, 'en', 'help_search', 1),
('downloaded', 10, 'en', 'help_search', 2),
('downloaded', 14, 'en', 'help_search', 2),
('downloaded', 35, 'en', 'help_search', 1),
('downloaded', 38, 'en', 'help_search', 2),
('downloads', 22, 'en', 'help_search', 1),
('drag', 47, 'en', 'help_search', 1),
('drag', 50, 'en', 'help_search', 0.836446),
('drag', 54, 'en', 'help_search', 2.7113),
('drag', 62, 'en', 'help_search', 2),
('drag', 63, 'en', 'help_search', 2),
('drag', 70, 'en', 'help_search', 1),
('drag', 73, 'en', 'help_search', 1),
('drag', 75, 'en', 'help_search', 1),
('draganddrop', 23, 'en', 'help_search', 3),
('dragging', 23, 'en', 'help_search', 1),
('dragging', 54, 'en', 'help_search', 0.882818),
('drastic', 33, 'en', 'help_search', 1),
('dropdown', 58, 'en', 'help_search', 1),
('dropdown', 77, 'en', 'help_search', 1),
('dropdown', 83, 'en', 'help_search', 1),
('dropdown', 85, 'en', 'help_search', 2),
('dropped', 29, 'en', 'help_search', 1),
('drupal', 10, 'en', 'help_search', 20.2472),
('drupal', 11, 'en', 'help_search', 22.041),
('drupal', 12, 'en', 'help_search', 19.0044),
('drupal', 13, 'en', 'help_search', 21.0603),
('drupal', 14, 'en', 'help_search', 22),
('drupal', 15, 'en', 'help_search', 22),
('drupal', 17, 'en', 'help_search', 11),
('drupal', 19, 'en', 'help_search', 23),
('drupal', 31, 'en', 'help_search', 11),
('drupal', 37, 'en', 'help_search', 11),
('drupal', 46, 'en', 'help_search', 54),
('drupal', 48, 'en', 'help_search', 11),
('drupal', 53, 'en', 'help_search', 10.363),
('drupal', 65, 'en', 'help_search', 21.8496),
('drupal', 66, 'en', 'help_search', 22),
('drupal', 67, 'en', 'help_search', 20.8086),
('drupal', 71, 'en', 'help_search', 8.54373),
('drupal', 76, 'en', 'help_search', 11),
('drupal', 78, 'en', 'help_search', 11),
('drupal', 80, 'en', 'help_search', 11),
('drupal', 81, 'en', 'help_search', 9.711),
('drupal', 85, 'en', 'help_search', 10.572),
('drupalorg', 10, 'en', 'help_search', 22),
('drupalorg', 14, 'en', 'help_search', 11),
('drush', 11, 'en', 'help_search', 7.43636),
('due', 33, 'en', 'help_search', 1),
('during', 29, 'en', 'help_search', 1),
('during', 72, 'en', 'help_search', 1),
('dynamic', 18, 'en', 'help_search', 10.2101),
('each', 8, 'en', 'help_search', 1),
('each', 11, 'en', 'help_search', 2.89272),
('each', 12, 'en', 'help_search', 1.74762),
('each', 17, 'en', 'help_search', 1),
('each', 27, 'en', 'help_search', 1),
('each', 29, 'en', 'help_search', 0.879565),
('each', 30, 'en', 'help_search', 2),
('each', 33, 'en', 'help_search', 1),
('each', 38, 'en', 'help_search', 1),
('each', 42, 'en', 'help_search', 1),
('each', 48, 'en', 'help_search', 2),
('each', 50, 'en', 'help_search', 1.79212),
('each', 53, 'en', 'help_search', 1),
('each', 54, 'en', 'help_search', 1),
('each', 55, 'en', 'help_search', 0.942091),
('each', 59, 'en', 'help_search', 2),
('each', 62, 'en', 'help_search', 3),
('each', 63, 'en', 'help_search', 2),
('each', 65, 'en', 'help_search', 1),
('each', 67, 'en', 'help_search', 1),
('each', 68, 'en', 'help_search', 3),
('each', 69, 'en', 'help_search', 3),
('each', 71, 'en', 'help_search', 2),
('each', 79, 'en', 'help_search', 1),
('each', 81, 'en', 'help_search', 2.93781),
('each', 83, 'en', 'help_search', 1),
('each', 85, 'en', 'help_search', 1),
('easier', 23, 'en', 'help_search', 2),
('easier', 54, 'en', 'help_search', 1),
('easier', 64, 'en', 'help_search', 1),
('easy', 30, 'en', 'help_search', 0.800068),
('edit', 9, 'en', 'help_search', 4),
('edit', 12, 'en', 'help_search', 1.59803),
('edit', 20, 'en', 'help_search', 39),
('edit', 24, 'en', 'help_search', 0.993146),
('edit', 28, 'en', 'help_search', 4),
('edit', 32, 'en', 'help_search', 5),
('edit', 41, 'en', 'help_search', 4),
('edit', 44, 'en', 'help_search', 1.98493),
('edit', 45, 'en', 'help_search', 4),
('edit', 47, 'en', 'help_search', 1),
('edit', 48, 'en', 'help_search', 1),
('edit', 52, 'en', 'help_search', 1),
('edit', 57, 'en', 'help_search', 7),
('edit', 58, 'en', 'help_search', 4),
('edit', 60, 'en', 'help_search', 1),
('edit', 61, 'en', 'help_search', 2),
('edit', 63, 'en', 'help_search', 27),
('edit', 64, 'en', 'help_search', 1),
('edit', 65, 'en', 'help_search', 2),
('edit', 66, 'en', 'help_search', 1),
('edit', 67, 'en', 'help_search', 38),
('edit', 68, 'en', 'help_search', 2),
('edit', 71, 'en', 'help_search', 1.7974),
('edit', 72, 'en', 'help_search', 4),
('edit', 73, 'en', 'help_search', 5),
('edit', 74, 'en', 'help_search', 1),
('edit', 75, 'en', 'help_search', 5),
('edit', 76, 'en', 'help_search', 7),
('edit', 77, 'en', 'help_search', 5),
('edit', 79, 'en', 'help_search', 12.9397),
('edit', 81, 'en', 'help_search', 0.938382),
('edit', 82, 'en', 'help_search', 6),
('edit', 83, 'en', 'help_search', 26),
('edit', 84, 'en', 'help_search', 5),
('edit', 85, 'en', 'help_search', 7),
('edited', 12, 'en', 'help_search', 0.63333),
('editing', 12, 'en', 'help_search', 0.635),
('editing', 16, 'en', 'help_search', 1),
('editing', 17, 'en', 'help_search', 1),
('editing', 20, 'en', 'help_search', 46),
('editing', 24, 'en', 'help_search', 3),
('editing', 42, 'en', 'help_search', 1),
('editing', 50, 'en', 'help_search', 1),
('editing', 52, 'en', 'help_search', 1),
('editing', 54, 'en', 'help_search', 2),
('editing', 56, 'en', 'help_search', 1),
('editing', 60, 'en', 'help_search', 1),
('editing', 61, 'en', 'help_search', 3),
('editing', 63, 'en', 'help_search', 5),
('editing', 64, 'en', 'help_search', 3),
('editing', 66, 'en', 'help_search', 1),
('editing', 67, 'en', 'help_search', 37.363),
('editing', 69, 'en', 'help_search', 1),
('editing', 72, 'en', 'help_search', 3),
('editing', 74, 'en', 'help_search', 1),
('editing', 76, 'en', 'help_search', 1),
('editing', 77, 'en', 'help_search', 26),
('editing', 79, 'en', 'help_search', 1),
('editing', 81, 'en', 'help_search', 3.91674),
('editing', 82, 'en', 'help_search', 3),
('editing', 85, 'en', 'help_search', 28),
('editor', 2, 'en', 'help_search', 1),
('editor', 50, 'en', 'help_search', 3.65618),
('editor', 54, 'en', 'help_search', 35.8406),
('editors', 50, 'en', 'help_search', 7.96127),
('editors', 54, 'en', 'help_search', 35.9809),
('editors', 64, 'en', 'help_search', 1),
('edits', 20, 'en', 'help_search', 1),
('edits', 67, 'en', 'help_search', 1),
('effect', 70, 'en', 'help_search', 11),
('effects', 16, 'en', 'help_search', 5),
('effects', 70, 'en', 'help_search', 3),
('efficiently', 29, 'en', 'help_search', 1),
('either', 11, 'en', 'help_search', 0.733888),
('either', 12, 'en', 'help_search', 0.725015),
('either', 20, 'en', 'help_search', 1),
('either', 39, 'en', 'help_search', 1),
('either', 50, 'en', 'help_search', 1.86995),
('either', 60, 'en', 'help_search', 1),
('either', 79, 'en', 'help_search', 1),
('element', 83, 'en', 'help_search', 1),
('else', 67, 'en', 'help_search', 1),
('email', 8, 'en', 'help_search', 2),
('email', 12, 'en', 'help_search', 1.68173),
('email', 32, 'en', 'help_search', 2),
('email', 40, 'en', 'help_search', 5),
('email', 44, 'en', 'help_search', 24.9849),
('email', 45, 'en', 'help_search', 1),
('embed', 50, 'en', 'help_search', 0.899454),
('enable', 6, 'en', 'help_search', 1),
('enable', 24, 'en', 'help_search', 1),
('enable', 27, 'en', 'help_search', 1),
('enable', 75, 'en', 'help_search', 1),
('enabled', 8, 'en', 'help_search', 1),
('enabled', 12, 'en', 'help_search', 0.71),
('enabled', 27, 'en', 'help_search', 1),
('enabled', 46, 'en', 'help_search', 2),
('enabled', 50, 'en', 'help_search', 4.36937),
('enabled', 73, 'en', 'help_search', 4),
('enabled', 75, 'en', 'help_search', 4),
('enables', 6, 'en', 'help_search', 2),
('enabling', 23, 'en', 'help_search', 1),
('enabling', 25, 'en', 'help_search', 26),
('enabling', 34, 'en', 'help_search', 26),
('enabling', 36, 'en', 'help_search', 1),
('enclosed', 44, 'en', 'help_search', 1),
('encode', 53, 'en', 'help_search', 1),
('end', 12, 'en', 'help_search', 0.845322),
('end', 18, 'en', 'help_search', 1),
('end', 60, 'en', 'help_search', 2),
('end', 79, 'en', 'help_search', 1.95373),
('enforces', 54, 'en', 'help_search', 1),
('enforcing', 50, 'en', 'help_search', 1),
('engines', 62, 'en', 'help_search', 1),
('english', 22, 'en', 'help_search', 3),
('english', 30, 'en', 'help_search', 0.972861),
('enhances', 24, 'en', 'help_search', 1),
('ensure', 13, 'en', 'help_search', 1),
('ensure', 50, 'en', 'help_search', 0.889397),
('enter', 26, 'en', 'help_search', 1),
('enter', 28, 'en', 'help_search', 1),
('enter', 29, 'en', 'help_search', 1),
('enter', 32, 'en', 'help_search', 1),
('enter', 33, 'en', 'help_search', 1.9689),
('enter', 35, 'en', 'help_search', 1),
('enter', 36, 'en', 'help_search', 1),
('enter', 40, 'en', 'help_search', 1),
('enter', 41, 'en', 'help_search', 1),
('enter', 45, 'en', 'help_search', 2),
('enter', 47, 'en', 'help_search', 1),
('enter', 50, 'en', 'help_search', 0.913226),
('enter', 51, 'en', 'help_search', 1),
('enter', 52, 'en', 'help_search', 1),
('enter', 55, 'en', 'help_search', 1),
('enter', 56, 'en', 'help_search', 1),
('enter', 61, 'en', 'help_search', 2),
('enter', 64, 'en', 'help_search', 2),
('enter', 65, 'en', 'help_search', 1),
('enter', 66, 'en', 'help_search', 2),
('enter', 67, 'en', 'help_search', 1),
('enter', 70, 'en', 'help_search', 2),
('enter', 73, 'en', 'help_search', 3),
('enter', 74, 'en', 'help_search', 2),
('enter', 76, 'en', 'help_search', 1),
('enter', 80, 'en', 'help_search', 2),
('enter', 81, 'en', 'help_search', 1),
('enter', 82, 'en', 'help_search', 1),
('enter', 84, 'en', 'help_search', 2),
('entered', 61, 'en', 'help_search', 1),
('entered', 64, 'en', 'help_search', 1),
('entering', 33, 'en', 'help_search', 1),
('enters', 30, 'en', 'help_search', 1),
('entities', 10, 'en', 'help_search', 1),
('entities', 11, 'en', 'help_search', 2),
('entities', 12, 'en', 'help_search', 4.71418),
('entities', 16, 'en', 'help_search', 3),
('entities', 25, 'en', 'help_search', 6),
('entities', 55, 'en', 'help_search', 1),
('entities', 56, 'en', 'help_search', 1),
('entities', 57, 'en', 'help_search', 2),
('entities', 59, 'en', 'help_search', 2.88282),
('entities', 64, 'en', 'help_search', 1),
('entities', 68, 'en', 'help_search', 1),
('entities', 80, 'en', 'help_search', 1),
('entities', 81, 'en', 'help_search', 3.92384),
('entity', 10, 'en', 'help_search', 2),
('entity', 11, 'en', 'help_search', 1),
('entity', 12, 'en', 'help_search', 49.9515),
('entity', 16, 'en', 'help_search', 1),
('entity', 55, 'en', 'help_search', 10.8444),
('entity', 56, 'en', 'help_search', 5),
('entity', 57, 'en', 'help_search', 5),
('entity', 59, 'en', 'help_search', 4),
('entity', 61, 'en', 'help_search', 30),
('entity', 62, 'en', 'help_search', 30),
('entity', 63, 'en', 'help_search', 30),
('entity', 64, 'en', 'help_search', 34),
('entity', 68, 'en', 'help_search', 3),
('entity', 80, 'en', 'help_search', 7),
('entity', 81, 'en', 'help_search', 3),
('entries', 59, 'en', 'help_search', 1),
('entries', 68, 'en', 'help_search', 1),
('error', 15, 'en', 'help_search', 1),
('error', 23, 'en', 'help_search', 1),
('error', 33, 'en', 'help_search', 36.6811),
('error', 37, 'en', 'help_search', 1),
('errors', 23, 'en', 'help_search', 4.98493),
('errors', 33, 'en', 'help_search', 28.6271),
('errors', 37, 'en', 'help_search', 1),
('etc', 12, 'en', 'help_search', 1),
('etc', 22, 'en', 'help_search', 1),
('etc', 71, 'en', 'help_search', 3.89608),
('etc', 82, 'en', 'help_search', 1),
('events', 68, 'en', 'help_search', 1),
('every', 13, 'en', 'help_search', 3.93972),
('exact', 30, 'en', 'help_search', 1),
('exact', 83, 'en', 'help_search', 1),
('example', 9, 'en', 'help_search', 1),
('example', 10, 'en', 'help_search', 1),
('example', 11, 'en', 'help_search', 2.89272),
('example', 12, 'en', 'help_search', 4.76159),
('example', 20, 'en', 'help_search', 1),
('example', 30, 'en', 'help_search', 1.96498),
('example', 33, 'en', 'help_search', 0.989021),
('example', 36, 'en', 'help_search', 1),
('example', 50, 'en', 'help_search', 0.830633),
('example', 55, 'en', 'help_search', 1),
('example', 57, 'en', 'help_search', 1),
('example', 59, 'en', 'help_search', 1),
('example', 60, 'en', 'help_search', 1),
('example', 61, 'en', 'help_search', 1),
('example', 62, 'en', 'help_search', 1),
('example', 63, 'en', 'help_search', 1),
('example', 64, 'en', 'help_search', 2),
('example', 65, 'en', 'help_search', 1),
('example', 67, 'en', 'help_search', 2),
('example', 68, 'en', 'help_search', 1),
('example', 70, 'en', 'help_search', 1),
('example', 71, 'en', 'help_search', 1.8249),
('example', 76, 'en', 'help_search', 2),
('example', 78, 'en', 'help_search', 3),
('example', 80, 'en', 'help_search', 2),
('example', 81, 'en', 'help_search', 3),
('example', 85, 'en', 'help_search', 1),
('examplecom', 33, 'en', 'help_search', 7.8309),
('examplecom', 76, 'en', 'help_search', 4),
('examplecom', 78, 'en', 'help_search', 12),
('examples', 12, 'en', 'help_search', 0.677939),
('examples', 16, 'en', 'help_search', 1),
('examples', 78, 'en', 'help_search', 1),
('examples', 81, 'en', 'help_search', 2),
('exceed', 55, 'en', 'help_search', 1),
('except', 71, 'en', 'help_search', 0.916736),
('exchanged', 25, 'en', 'help_search', 2),
('exist', 12, 'en', 'help_search', 0.681785),
('exist', 33, 'en', 'help_search', 1),
('existing', 24, 'en', 'help_search', 0.938382),
('existing', 28, 'en', 'help_search', 1),
('existing', 43, 'en', 'help_search', 1),
('existing', 45, 'en', 'help_search', 1),
('existing', 50, 'en', 'help_search', 0.927431),
('existing', 54, 'en', 'help_search', 0.993146),
('existing', 72, 'en', 'help_search', 1),
('existing', 77, 'en', 'help_search', 1),
('existing', 81, 'en', 'help_search', 1),
('existing', 82, 'en', 'help_search', 29),
('existing', 83, 'en', 'help_search', 2),
('existing', 85, 'en', 'help_search', 28),
('exists', 33, 'en', 'help_search', 1),
('exists', 83, 'en', 'help_search', 1),
('expand', 35, 'en', 'help_search', 1),
('expanded', 73, 'en', 'help_search', 4),
('expect', 30, 'en', 'help_search', 1),
('expected', 15, 'en', 'help_search', 1),
('experience', 83, 'en', 'help_search', 0.997306),
('experimental', 14, 'en', 'help_search', 24),
('experimental', 35, 'en', 'help_search', 1),
('expiring', 44, 'en', 'help_search', 1),
('explaining', 54, 'en', 'help_search', 0.902857),
('export', 1, 'en', 'help_search', 8),
('export', 2, 'en', 'help_search', 7),
('export', 11, 'en', 'help_search', 1.51419),
('exported', 1, 'en', 'help_search', 1),
('exported', 3, 'en', 'help_search', 1),
('exported', 4, 'en', 'help_search', 1),
('exported', 11, 'en', 'help_search', 7.41884),
('exporting', 1, 'en', 'help_search', 26),
('exporting', 2, 'en', 'help_search', 26),
('exporting', 3, 'en', 'help_search', 1),
('exporting', 4, 'en', 'help_search', 1),
('exporting', 11, 'en', 'help_search', 1.65163),
('expose', 20, 'en', 'help_search', 1),
('exposed', 71, 'en', 'help_search', 9.36248),
('exposes', 25, 'en', 'help_search', 2),
('extend', 10, 'en', 'help_search', 22),
('extend', 14, 'en', 'help_search', 11),
('extend', 24, 'en', 'help_search', 3.73881),
('extend', 26, 'en', 'help_search', 4),
('extend', 35, 'en', 'help_search', 8),
('extend', 36, 'en', 'help_search', 4),
('extending', 10, 'en', 'help_search', 10.2817),
('extending', 14, 'en', 'help_search', 57),
('extends', 14, 'en', 'help_search', 1),
('extension', 11, 'en', 'help_search', 4.70731),
('external', 73, 'en', 'help_search', 1),
('facilitate', 18, 'en', 'help_search', 1),
('factors', 18, 'en', 'help_search', 1),
('factors', 28, 'en', 'help_search', 1),
('false', 12, 'en', 'help_search', 0.889397),
('far', 37, 'en', 'help_search', 1),
('faster', 18, 'en', 'help_search', 2),
('faster', 29, 'en', 'help_search', 1),
('faulty', 50, 'en', 'help_search', 1),
('feature', 27, 'en', 'help_search', 1),
('features', 14, 'en', 'help_search', 2),
('features', 24, 'en', 'help_search', 2),
('feed', 46, 'en', 'help_search', 3),
('feed', 71, 'en', 'help_search', 2),
('feed', 82, 'en', 'help_search', 1),
('feel', 10, 'en', 'help_search', 1),
('few', 67, 'en', 'help_search', 1),
('fewer', 29, 'en', 'help_search', 1),
('field', 12, 'en', 'help_search', 90.2698),
('field', 16, 'en', 'help_search', 5),
('field', 21, 'en', 'help_search', 1),
('field', 23, 'en', 'help_search', 1),
('field', 50, 'en', 'help_search', 3),
('field', 52, 'en', 'help_search', 1),
('field', 55, 'en', 'help_search', 12),
('field', 56, 'en', 'help_search', 3),
('field', 57, 'en', 'help_search', 3),
('field', 59, 'en', 'help_search', 1.89272),
('field', 61, 'en', 'help_search', 58),
('field', 62, 'en', 'help_search', 30),
('field', 63, 'en', 'help_search', 3),
('field', 64, 'en', 'help_search', 54.9931),
('field', 65, 'en', 'help_search', 1),
('field', 66, 'en', 'help_search', 4),
('field', 67, 'en', 'help_search', 1),
('field', 68, 'en', 'help_search', 1),
('field', 69, 'en', 'help_search', 1),
('field', 70, 'en', 'help_search', 2),
('field', 80, 'en', 'help_search', 13),
('field', 81, 'en', 'help_search', 4.77171),
('field', 83, 'en', 'help_search', 3),
('field', 84, 'en', 'help_search', 1),
('fields', 5, 'en', 'help_search', 55),
('fields', 6, 'en', 'help_search', 3),
('fields', 7, 'en', 'help_search', 3),
('fields', 8, 'en', 'help_search', 2),
('fields', 10, 'en', 'help_search', 2),
('fields', 12, 'en', 'help_search', 36.2034),
('fields', 16, 'en', 'help_search', 5),
('fields', 23, 'en', 'help_search', 1),
('fields', 24, 'en', 'help_search', 0.976851),
('fields', 25, 'en', 'help_search', 1),
('fields', 48, 'en', 'help_search', 1),
('fields', 50, 'en', 'help_search', 1),
('fields', 52, 'en', 'help_search', 6),
('fields', 55, 'en', 'help_search', 3),
('fields', 56, 'en', 'help_search', 2),
('fields', 57, 'en', 'help_search', 1),
('fields', 59, 'en', 'help_search', 6.76891),
('fields', 61, 'en', 'help_search', 9),
('fields', 62, 'en', 'help_search', 3),
('fields', 63, 'en', 'help_search', 3),
('fields', 64, 'en', 'help_search', 9),
('fields', 65, 'en', 'help_search', 1),
('fields', 66, 'en', 'help_search', 9),
('fields', 68, 'en', 'help_search', 4),
('fields', 71, 'en', 'help_search', 5),
('fields', 80, 'en', 'help_search', 4),
('fields', 81, 'en', 'help_search', 3.92384),
('fields', 83, 'en', 'help_search', 8),
('fields', 85, 'en', 'help_search', 4),
('file', 1, 'en', 'help_search', 1),
('file', 2, 'en', 'help_search', 2),
('file', 3, 'en', 'help_search', 1),
('file', 11, 'en', 'help_search', 2.47298),
('file', 12, 'en', 'help_search', 0.615536),
('file', 16, 'en', 'help_search', 2),
('file', 18, 'en', 'help_search', 19.8513),
('file', 27, 'en', 'help_search', 1),
('files', 1, 'en', 'help_search', 1),
('files', 10, 'en', 'help_search', 2),
('files', 11, 'en', 'help_search', 2.57767),
('files', 12, 'en', 'help_search', 2),
('files', 14, 'en', 'help_search', 1),
('files', 16, 'en', 'help_search', 1),
('files', 18, 'en', 'help_search', 1),
('files', 24, 'en', 'help_search', 1),
('files', 53, 'en', 'help_search', 0.96498),
('files', 68, 'en', 'help_search', 1),
('fill', 5, 'en', 'help_search', 1),
('fill', 7, 'en', 'help_search', 1),
('fill', 8, 'en', 'help_search', 1),
('fill', 18, 'en', 'help_search', 0.899454),
('fill', 65, 'en', 'help_search', 1),
('filling', 23, 'en', 'help_search', 1),
('filter', 12, 'en', 'help_search', 1.30788),
('filter', 21, 'en', 'help_search', 1),
('filter', 35, 'en', 'help_search', 1),
('filter', 36, 'en', 'help_search', 1),
('filter', 37, 'en', 'help_search', 1),
('filter', 45, 'en', 'help_search', 5),
('filter', 50, 'en', 'help_search', 12.7833),
('filter', 67, 'en', 'help_search', 5),
('filter', 69, 'en', 'help_search', 1),
('filter', 71, 'en', 'help_search', 5.9534),
('filter', 85, 'en', 'help_search', 8),
('filtering', 30, 'en', 'help_search', 0.889397),
('filtering', 57, 'en', 'help_search', 1),
('filtering', 84, 'en', 'help_search', 1),
('filters', 12, 'en', 'help_search', 3.57125),
('filters', 50, 'en', 'help_search', 72.0452),
('filters', 54, 'en', 'help_search', 2.83669),
('filters', 67, 'en', 'help_search', 2),
('filters', 71, 'en', 'help_search', 6.48204),
('finally', 30, 'en', 'help_search', 0.822065),
('find', 3, 'en', 'help_search', 1),
('find', 18, 'en', 'help_search', 0.866793),
('find', 20, 'en', 'help_search', 2),
('find', 23, 'en', 'help_search', 1),
('find', 24, 'en', 'help_search', 2),
('find', 45, 'en', 'help_search', 1),
('find', 47, 'en', 'help_search', 1),
('find', 49, 'en', 'help_search', 2),
('find', 57, 'en', 'help_search', 3),
('find', 61, 'en', 'help_search', 1),
('find', 62, 'en', 'help_search', 1),
('find', 63, 'en', 'help_search', 1),
('find', 64, 'en', 'help_search', 1),
('find', 67, 'en', 'help_search', 21),
('find', 78, 'en', 'help_search', 1),
('find', 82, 'en', 'help_search', 1),
('find', 83, 'en', 'help_search', 1),
('find', 85, 'en', 'help_search', 2),
('finish', 13, 'en', 'help_search', 1),
('finished', 34, 'en', 'help_search', 1),
('finished', 85, 'en', 'help_search', 1),
('first', 11, 'en', 'help_search', 0.76431),
('first', 14, 'en', 'help_search', 1),
('first', 18, 'en', 'help_search', 1.92384),
('first', 30, 'en', 'help_search', 1),
('first', 31, 'en', 'help_search', 1),
('first', 36, 'en', 'help_search', 2),
('first', 50, 'en', 'help_search', 0.802752),
('first', 55, 'en', 'help_search', 1),
('first', 71, 'en', 'help_search', 1),
('first', 85, 'en', 'help_search', 1),
('fix', 37, 'en', 'help_search', 1),
('fixed', 19, 'en', 'help_search', 1),
('fixed', 81, 'en', 'help_search', 1),
('fixing', 15, 'en', 'help_search', 11);
INSERT INTO `[[dbprefix]]search_index` VALUES
('flag', 59, 'en', 'help_search', 0.923838),
('flat', 81, 'en', 'help_search', 2),
('flexible', 12, 'en', 'help_search', 0.59873),
('focusing', 54, 'en', 'help_search', 0.923838),
('follow', 6, 'en', 'help_search', 1),
('follow', 7, 'en', 'help_search', 1),
('follow', 20, 'en', 'help_search', 1),
('follow', 26, 'en', 'help_search', 1),
('follow', 28, 'en', 'help_search', 1),
('follow', 29, 'en', 'help_search', 0.916736),
('follow', 54, 'en', 'help_search', 1),
('follow', 55, 'en', 'help_search', 2),
('follow', 56, 'en', 'help_search', 1),
('follow', 66, 'en', 'help_search', 1),
('follow', 76, 'en', 'help_search', 2),
('follow', 80, 'en', 'help_search', 1),
('follow', 82, 'en', 'help_search', 1),
('following', 11, 'en', 'help_search', 0.830633),
('following', 12, 'en', 'help_search', 0.920273),
('following', 16, 'en', 'help_search', 1),
('following', 18, 'en', 'help_search', 1),
('following', 24, 'en', 'help_search', 2),
('following', 25, 'en', 'help_search', 1),
('following', 59, 'en', 'help_search', 0.902857),
('following', 71, 'en', 'help_search', 1),
('following', 73, 'en', 'help_search', 1),
('following', 84, 'en', 'help_search', 1),
('footer', 71, 'en', 'help_search', 3.89144),
('for', 1, 'en', 'help_search', 1),
('for', 2, 'en', 'help_search', 1),
('for', 3, 'en', 'help_search', 1),
('for', 4, 'en', 'help_search', 1),
('for', 5, 'en', 'help_search', 2),
('for', 6, 'en', 'help_search', 3),
('for', 7, 'en', 'help_search', 1),
('for', 8, 'en', 'help_search', 1),
('for', 9, 'en', 'help_search', 2),
('for', 10, 'en', 'help_search', 6.89158),
('for', 11, 'en', 'help_search', 9.15176),
('for', 12, 'en', 'help_search', 28.7994),
('for', 13, 'en', 'help_search', 20.9931),
('for', 14, 'en', 'help_search', 1),
('for', 15, 'en', 'help_search', 2),
('for', 16, 'en', 'help_search', 6.94585),
('for', 17, 'en', 'help_search', 3),
('for', 18, 'en', 'help_search', 31.5331),
('for', 19, 'en', 'help_search', 2),
('for', 20, 'en', 'help_search', 5),
('for', 21, 'en', 'help_search', 1),
('for', 22, 'en', 'help_search', 1),
('for', 23, 'en', 'help_search', 3),
('for', 24, 'en', 'help_search', 5.78798),
('for', 25, 'en', 'help_search', 28),
('for', 26, 'en', 'help_search', 4),
('for', 27, 'en', 'help_search', 20.9496),
('for', 28, 'en', 'help_search', 3),
('for', 29, 'en', 'help_search', 5.6446),
('for', 30, 'en', 'help_search', 24.6358),
('for', 32, 'en', 'help_search', 4),
('for', 33, 'en', 'help_search', 7.83681),
('for', 34, 'en', 'help_search', 1),
('for', 35, 'en', 'help_search', 2),
('for', 36, 'en', 'help_search', 3),
('for', 37, 'en', 'help_search', 1),
('for', 38, 'en', 'help_search', 6),
('for', 39, 'en', 'help_search', 1),
('for', 40, 'en', 'help_search', 2),
('for', 41, 'en', 'help_search', 1),
('for', 42, 'en', 'help_search', 2),
('for', 43, 'en', 'help_search', 28),
('for', 44, 'en', 'help_search', 5.98633),
('for', 46, 'en', 'help_search', 2),
('for', 47, 'en', 'help_search', 4),
('for', 48, 'en', 'help_search', 22),
('for', 49, 'en', 'help_search', 1),
('for', 50, 'en', 'help_search', 5.52904),
('for', 51, 'en', 'help_search', 1),
('for', 52, 'en', 'help_search', 2),
('for', 53, 'en', 'help_search', 17.2169),
('for', 54, 'en', 'help_search', 2),
('for', 55, 'en', 'help_search', 18.4947),
('for', 56, 'en', 'help_search', 3),
('for', 57, 'en', 'help_search', 7),
('for', 58, 'en', 'help_search', 12),
('for', 59, 'en', 'help_search', 7.76413),
('for', 60, 'en', 'help_search', 5.98902),
('for', 61, 'en', 'help_search', 10),
('for', 62, 'en', 'help_search', 33),
('for', 63, 'en', 'help_search', 33),
('for', 64, 'en', 'help_search', 9),
('for', 65, 'en', 'help_search', 5),
('for', 66, 'en', 'help_search', 4),
('for', 67, 'en', 'help_search', 5.99731),
('for', 68, 'en', 'help_search', 8),
('for', 69, 'en', 'help_search', 22),
('for', 70, 'en', 'help_search', 4),
('for', 71, 'en', 'help_search', 5.41199),
('for', 72, 'en', 'help_search', 27),
('for', 73, 'en', 'help_search', 1),
('for', 74, 'en', 'help_search', 3),
('for', 75, 'en', 'help_search', 1),
('for', 76, 'en', 'help_search', 32),
('for', 77, 'en', 'help_search', 4),
('for', 78, 'en', 'help_search', 35),
('for', 79, 'en', 'help_search', 1),
('for', 80, 'en', 'help_search', 7),
('for', 81, 'en', 'help_search', 7.79579),
('for', 82, 'en', 'help_search', 3),
('for', 83, 'en', 'help_search', 3),
('for', 84, 'en', 'help_search', 1),
('for', 85, 'en', 'help_search', 6),
('force', 26, 'en', 'help_search', 1),
('forcing', 18, 'en', 'help_search', 1),
('form', 5, 'en', 'help_search', 8),
('form', 6, 'en', 'help_search', 2),
('form', 7, 'en', 'help_search', 34),
('form', 8, 'en', 'help_search', 42),
('form', 9, 'en', 'help_search', 44),
('form', 11, 'en', 'help_search', 1),
('form', 20, 'en', 'help_search', 2),
('form', 23, 'en', 'help_search', 4.98493),
('form', 26, 'en', 'help_search', 5),
('form', 30, 'en', 'help_search', 8.95339),
('form', 33, 'en', 'help_search', 1),
('form', 40, 'en', 'help_search', 1),
('form', 45, 'en', 'help_search', 1),
('form', 52, 'en', 'help_search', 5),
('form', 53, 'en', 'help_search', 1),
('form', 55, 'en', 'help_search', 5.95111),
('form', 56, 'en', 'help_search', 1),
('form', 59, 'en', 'help_search', 1),
('form', 63, 'en', 'help_search', 35),
('form', 65, 'en', 'help_search', 2),
('form', 66, 'en', 'help_search', 1),
('form', 68, 'en', 'help_search', 1),
('form', 71, 'en', 'help_search', 5.21371),
('form', 76, 'en', 'help_search', 2),
('form', 80, 'en', 'help_search', 1),
('form', 81, 'en', 'help_search', 2),
('form', 83, 'en', 'help_search', 32),
('formal', 53, 'en', 'help_search', 1),
('format', 4, 'en', 'help_search', 1),
('format', 11, 'en', 'help_search', 0.810915),
('format', 18, 'en', 'help_search', 1),
('format', 25, 'en', 'help_search', 2),
('format', 32, 'en', 'help_search', 25),
('format', 50, 'en', 'help_search', 15.6114),
('format', 54, 'en', 'help_search', 7.64925),
('format', 62, 'en', 'help_search', 4),
('format', 70, 'en', 'help_search', 1),
('format', 71, 'en', 'help_search', 6.85746),
('format', 83, 'en', 'help_search', 1),
('format', 85, 'en', 'help_search', 15),
('formats', 25, 'en', 'help_search', 2),
('formats', 32, 'en', 'help_search', 7),
('formats', 50, 'en', 'help_search', 63.3271),
('formats', 54, 'en', 'help_search', 33.8367),
('formats', 71, 'en', 'help_search', 2),
('formatted', 12, 'en', 'help_search', 8.81776),
('formatted', 50, 'en', 'help_search', 5),
('formatted', 54, 'en', 'help_search', 1),
('formatted', 71, 'en', 'help_search', 1),
('formatter', 12, 'en', 'help_search', 15.5412),
('formatter', 62, 'en', 'help_search', 3),
('formatters', 12, 'en', 'help_search', 1.33517),
('formatters', 62, 'en', 'help_search', 5),
('formatting', 27, 'en', 'help_search', 1),
('forms', 5, 'en', 'help_search', 51),
('forms', 6, 'en', 'help_search', 34),
('forms', 7, 'en', 'help_search', 5),
('forms', 8, 'en', 'help_search', 49),
('forms', 9, 'en', 'help_search', 4),
('forms', 11, 'en', 'help_search', 0.695602),
('forms', 54, 'en', 'help_search', 0.842342),
('found', 27, 'en', 'help_search', 1),
('four', 12, 'en', 'help_search', 1),
('framework', 25, 'en', 'help_search', 1),
('framework', 54, 'en', 'help_search', 1),
('free', 81, 'en', 'help_search', 1),
('from', 3, 'en', 'help_search', 1),
('from', 10, 'en', 'help_search', 2),
('from', 11, 'en', 'help_search', 2.6312),
('from', 12, 'en', 'help_search', 1.48323),
('from', 13, 'en', 'help_search', 5),
('from', 14, 'en', 'help_search', 1),
('from', 18, 'en', 'help_search', 1),
('from', 29, 'en', 'help_search', 1),
('from', 35, 'en', 'help_search', 1),
('from', 36, 'en', 'help_search', 1),
('from', 42, 'en', 'help_search', 1),
('from', 44, 'en', 'help_search', 1),
('from', 46, 'en', 'help_search', 2),
('from', 50, 'en', 'help_search', 1),
('from', 53, 'en', 'help_search', 1),
('from', 54, 'en', 'help_search', 2),
('from', 58, 'en', 'help_search', 4),
('from', 60, 'en', 'help_search', 0.949597),
('from', 67, 'en', 'help_search', 1),
('from', 71, 'en', 'help_search', 1.75209),
('from', 73, 'en', 'help_search', 1),
('from', 74, 'en', 'help_search', 1),
('from', 77, 'en', 'help_search', 1),
('from', 79, 'en', 'help_search', 1),
('from', 81, 'en', 'help_search', 1),
('from', 83, 'en', 'help_search', 1),
('front', 27, 'en', 'help_search', 1),
('front', 73, 'en', 'help_search', 5),
('full', 34, 'en', 'help_search', 2),
('full', 73, 'en', 'help_search', 2),
('full', 78, 'en', 'help_search', 1),
('fullexport', 11, 'en', 'help_search', 0.808176),
('fully', 25, 'en', 'help_search', 1),
('fully', 26, 'en', 'help_search', 1),
('fully', 29, 'en', 'help_search', 1.89272),
('fully', 30, 'en', 'help_search', 0.827757),
('function', 13, 'en', 'help_search', 1),
('function', 42, 'en', 'help_search', 1),
('function', 78, 'en', 'help_search', 1),
('functionality', 14, 'en', 'help_search', 29),
('functionality', 16, 'en', 'help_search', 1),
('functionality', 23, 'en', 'help_search', 1),
('functionality', 24, 'en', 'help_search', 2.92384),
('functionality', 34, 'en', 'help_search', 1),
('functionality', 59, 'en', 'help_search', 2.86054),
('functionality', 68, 'en', 'help_search', 1),
('functionality', 78, 'en', 'help_search', 1),
('functions', 54, 'en', 'help_search', 1),
('further', 12, 'en', 'help_search', 1.29999),
('further', 62, 'en', 'help_search', 1),
('further', 63, 'en', 'help_search', 1),
('further', 74, 'en', 'help_search', 1),
('future', 11, 'en', 'help_search', 0.927431),
('future', 26, 'en', 'help_search', 1),
('gear', 62, 'en', 'help_search', 1),
('gear', 63, 'en', 'help_search', 1),
('generally', 65, 'en', 'help_search', 1),
('generate', 33, 'en', 'help_search', 2),
('generated', 33, 'en', 'help_search', 1),
('generated', 37, 'en', 'help_search', 1),
('generated', 44, 'en', 'help_search', 1),
('generated', 46, 'en', 'help_search', 1),
('generating', 33, 'en', 'help_search', 0.902857),
('generic', 6, 'en', 'help_search', 1),
('generic', 59, 'en', 'help_search', 1),
('get', 24, 'en', 'help_search', 0.886095),
('get', 54, 'en', 'help_search', 4),
('give', 30, 'en', 'help_search', 0.802752),
('give', 43, 'en', 'help_search', 4),
('give', 60, 'en', 'help_search', 1),
('give', 76, 'en', 'help_search', 1),
('given', 12, 'en', 'help_search', 0.98493),
('goal', 1, 'en', 'help_search', 19),
('goal', 2, 'en', 'help_search', 19),
('goal', 3, 'en', 'help_search', 19),
('goal', 4, 'en', 'help_search', 19),
('goal', 5, 'en', 'help_search', 19),
('goal', 6, 'en', 'help_search', 19),
('goal', 7, 'en', 'help_search', 19),
('goal', 9, 'en', 'help_search', 19),
('goal', 13, 'en', 'help_search', 19),
('goal', 20, 'en', 'help_search', 19),
('goal', 26, 'en', 'help_search', 19),
('goal', 28, 'en', 'help_search', 19),
('goal', 29, 'en', 'help_search', 19),
('goal', 31, 'en', 'help_search', 19),
('goal', 32, 'en', 'help_search', 19),
('goal', 33, 'en', 'help_search', 19),
('goal', 34, 'en', 'help_search', 19),
('goal', 35, 'en', 'help_search', 19),
('goal', 36, 'en', 'help_search', 19),
('goal', 37, 'en', 'help_search', 19),
('goal', 38, 'en', 'help_search', 19),
('goal', 39, 'en', 'help_search', 19),
('goal', 40, 'en', 'help_search', 19),
('goal', 41, 'en', 'help_search', 19),
('goal', 43, 'en', 'help_search', 19),
('goal', 44, 'en', 'help_search', 19),
('goal', 45, 'en', 'help_search', 19),
('goal', 47, 'en', 'help_search', 19),
('goal', 49, 'en', 'help_search', 19),
('goal', 50, 'en', 'help_search', 19),
('goal', 51, 'en', 'help_search', 19),
('goal', 52, 'en', 'help_search', 19),
('goal', 54, 'en', 'help_search', 19),
('goal', 55, 'en', 'help_search', 19),
('goal', 56, 'en', 'help_search', 19),
('goal', 57, 'en', 'help_search', 19),
('goal', 58, 'en', 'help_search', 19),
('goal', 60, 'en', 'help_search', 19),
('goal', 61, 'en', 'help_search', 19),
('goal', 62, 'en', 'help_search', 19),
('goal', 63, 'en', 'help_search', 19),
('goal', 64, 'en', 'help_search', 19),
('goal', 65, 'en', 'help_search', 19),
('goal', 66, 'en', 'help_search', 19),
('goal', 67, 'en', 'help_search', 19),
('goal', 70, 'en', 'help_search', 19),
('goal', 72, 'en', 'help_search', 19),
('goal', 73, 'en', 'help_search', 19),
('goal', 74, 'en', 'help_search', 19),
('goal', 75, 'en', 'help_search', 19),
('goal', 76, 'en', 'help_search', 19),
('goal', 77, 'en', 'help_search', 19),
('goal', 79, 'en', 'help_search', 19),
('goal', 80, 'en', 'help_search', 19),
('goal', 82, 'en', 'help_search', 19),
('goal', 83, 'en', 'help_search', 19),
('goal', 84, 'en', 'help_search', 19),
('goal', 85, 'en', 'help_search', 19),
('goals', 46, 'en', 'help_search', 1),
('goes', 31, 'en', 'help_search', 1),
('goes', 71, 'en', 'help_search', 1),
('good', 31, 'en', 'help_search', 1),
('governance', 46, 'en', 'help_search', 1),
('granting', 42, 'en', 'help_search', 1),
('green', 81, 'en', 'help_search', 1),
('grid', 71, 'en', 'help_search', 2),
('grid', 85, 'en', 'help_search', 4),
('group', 11, 'en', 'help_search', 1),
('group', 13, 'en', 'help_search', 1),
('group', 42, 'en', 'help_search', 1),
('group', 53, 'en', 'help_search', 19),
('group', 54, 'en', 'help_search', 5.25496),
('group', 67, 'en', 'help_search', 1),
('grouped', 11, 'en', 'help_search', 1),
('grouped', 12, 'en', 'help_search', 1),
('groups', 53, 'en', 'help_search', 22.5589),
('groups', 54, 'en', 'help_search', 0.866793),
('guide', 10, 'en', 'help_search', 10.123),
('guide', 11, 'en', 'help_search', 21.9999),
('guide', 12, 'en', 'help_search', 18.9892),
('guide', 13, 'en', 'help_search', 20.9751),
('guide', 14, 'en', 'help_search', 22),
('guide', 15, 'en', 'help_search', 22),
('guide', 17, 'en', 'help_search', 11),
('guide', 19, 'en', 'help_search', 11),
('guide', 27, 'en', 'help_search', 1),
('guide', 31, 'en', 'help_search', 11),
('guide', 37, 'en', 'help_search', 11),
('guide', 48, 'en', 'help_search', 11),
('guide', 65, 'en', 'help_search', 21.8038),
('guide', 66, 'en', 'help_search', 22),
('guide', 67, 'en', 'help_search', 20.7671),
('guide', 71, 'en', 'help_search', 8.51611),
('guide', 76, 'en', 'help_search', 11),
('guide', 78, 'en', 'help_search', 11),
('guide', 80, 'en', 'help_search', 11),
('guide', 81, 'en', 'help_search', 9.67522),
('guide', 85, 'en', 'help_search', 10.4874),
('handles', 71, 'en', 'help_search', 0.800068),
('handling', 29, 'en', 'help_search', 3.95608),
('happen', 45, 'en', 'help_search', 1),
('happens', 29, 'en', 'help_search', 1),
('happens', 33, 'en', 'help_search', 1),
('happens', 44, 'en', 'help_search', 1.98902),
('has', 8, 'en', 'help_search', 2),
('has', 11, 'en', 'help_search', 5.48026),
('has', 12, 'en', 'help_search', 1),
('has', 18, 'en', 'help_search', 1),
('has', 19, 'en', 'help_search', 1),
('has', 20, 'en', 'help_search', 1),
('has', 23, 'en', 'help_search', 1),
('has', 24, 'en', 'help_search', 1),
('has', 29, 'en', 'help_search', 2.7299),
('has', 30, 'en', 'help_search', 1),
('has', 33, 'en', 'help_search', 1),
('has', 35, 'en', 'help_search', 1),
('has', 37, 'en', 'help_search', 1),
('has', 38, 'en', 'help_search', 1),
('has', 43, 'en', 'help_search', 4),
('has', 50, 'en', 'help_search', 0.78951),
('has', 55, 'en', 'help_search', 0.934703),
('has', 59, 'en', 'help_search', 3),
('has', 65, 'en', 'help_search', 1),
('has', 67, 'en', 'help_search', 1),
('has', 68, 'en', 'help_search', 1),
('has', 69, 'en', 'help_search', 36),
('has', 74, 'en', 'help_search', 1),
('have', 5, 'en', 'help_search', 1),
('have', 6, 'en', 'help_search', 1),
('have', 7, 'en', 'help_search', 1),
('have', 8, 'en', 'help_search', 1),
('have', 11, 'en', 'help_search', 0.866793),
('have', 12, 'en', 'help_search', 26.6223),
('have', 13, 'en', 'help_search', 1.99731),
('have', 14, 'en', 'help_search', 1),
('have', 16, 'en', 'help_search', 1),
('have', 19, 'en', 'help_search', 1),
('have', 20, 'en', 'help_search', 1),
('have', 21, 'en', 'help_search', 2),
('have', 22, 'en', 'help_search', 2),
('have', 27, 'en', 'help_search', 1),
('have', 28, 'en', 'help_search', 1),
('have', 29, 'en', 'help_search', 0.942091),
('have', 30, 'en', 'help_search', 2),
('have', 31, 'en', 'help_search', 1),
('have', 36, 'en', 'help_search', 1),
('have', 37, 'en', 'help_search', 3),
('have', 40, 'en', 'help_search', 1),
('have', 42, 'en', 'help_search', 2),
('have', 43, 'en', 'help_search', 2),
('have', 46, 'en', 'help_search', 1),
('have', 50, 'en', 'help_search', 4.42848),
('have', 51, 'en', 'help_search', 1),
('have', 54, 'en', 'help_search', 0.96498),
('have', 55, 'en', 'help_search', 3),
('have', 56, 'en', 'help_search', 1),
('have', 59, 'en', 'help_search', 1),
('have', 60, 'en', 'help_search', 3),
('have', 61, 'en', 'help_search', 1),
('have', 64, 'en', 'help_search', 1),
('have', 65, 'en', 'help_search', 1),
('have', 66, 'en', 'help_search', 3),
('have', 68, 'en', 'help_search', 1),
('have', 70, 'en', 'help_search', 1),
('have', 71, 'en', 'help_search', 3.66728),
('have', 73, 'en', 'help_search', 1),
('have', 78, 'en', 'help_search', 1),
('have', 79, 'en', 'help_search', 3),
('have', 80, 'en', 'help_search', 1),
('have', 81, 'en', 'help_search', 3),
('have', 83, 'en', 'help_search', 1.99731),
('have', 85, 'en', 'help_search', 2.99731),
('haven', 21, 'en', 'help_search', 1),
('having', 71, 'en', 'help_search', 0.949597),
('header', 67, 'en', 'help_search', 1),
('header', 71, 'en', 'help_search', 3.9074),
('heading', 27, 'en', 'help_search', 1),
('heading', 47, 'en', 'help_search', 1),
('heading', 48, 'en', 'help_search', 1),
('health', 37, 'en', 'help_search', 2),
('height', 53, 'en', 'help_search', 28),
('height', 70, 'en', 'help_search', 4),
('help', 12, 'en', 'help_search', 1.75415),
('help', 14, 'en', 'help_search', 1),
('help', 15, 'en', 'help_search', 1),
('help', 24, 'en', 'help_search', 7.4272),
('help', 26, 'en', 'help_search', 54),
('help', 27, 'en', 'help_search', 151.109),
('help', 29, 'en', 'help_search', 4),
('help', 30, 'en', 'help_search', 2),
('help', 42, 'en', 'help_search', 1),
('help', 61, 'en', 'help_search', 4),
('help', 64, 'en', 'help_search', 4),
('helps', 10, 'en', 'help_search', 0.972861),
('helptopics', 27, 'en', 'help_search', 8),
('here', 2, 'en', 'help_search', 4),
('here', 4, 'en', 'help_search', 4),
('here', 15, 'en', 'help_search', 1),
('here', 46, 'en', 'help_search', 22),
('here', 55, 'en', 'help_search', 0.920273),
('here', 78, 'en', 'help_search', 1),
('hidden', 55, 'en', 'help_search', 4.47703),
('hidden', 57, 'en', 'help_search', 5),
('hidden', 62, 'en', 'help_search', 8),
('hide', 12, 'en', 'help_search', 0.662985),
('hide', 54, 'en', 'help_search', 1),
('hide', 62, 'en', 'help_search', 1),
('hiding', 12, 'en', 'help_search', 0.657549),
('hierarchical', 81, 'en', 'help_search', 1),
('hierarchy', 75, 'en', 'help_search', 1),
('hierarchy', 81, 'en', 'help_search', 1),
('highly', 37, 'en', 'help_search', 1),
('highly', 46, 'en', 'help_search', 1),
('hints', 15, 'en', 'help_search', 1),
('history', 21, 'en', 'help_search', 1),
('history', 69, 'en', 'help_search', 1),
('holds', 12, 'en', 'help_search', 1),
('home', 33, 'en', 'help_search', 0.993146),
('home', 38, 'en', 'help_search', 1),
('home', 60, 'en', 'help_search', 1),
('home', 78, 'en', 'help_search', 1),
('horizontal', 50, 'en', 'help_search', 1),
('hour', 13, 'en', 'help_search', 1),
('hourly', 13, 'en', 'help_search', 1),
('hovering', 54, 'en', 'help_search', 0.920273),
('hovering', 60, 'en', 'help_search', 2),
('hovers', 73, 'en', 'help_search', 1),
('how', 11, 'en', 'help_search', 1),
('how', 12, 'en', 'help_search', 3.29815),
('how', 13, 'en', 'help_search', 1),
('how', 21, 'en', 'help_search', 1),
('how', 26, 'en', 'help_search', 1),
('how', 27, 'en', 'help_search', 57),
('how', 37, 'en', 'help_search', 1),
('how', 44, 'en', 'help_search', 27),
('how', 46, 'en', 'help_search', 19),
('how', 56, 'en', 'help_search', 1),
('how', 59, 'en', 'help_search', 1),
('how', 66, 'en', 'help_search', 1),
('how', 71, 'en', 'help_search', 4.74727),
('how', 80, 'en', 'help_search', 1),
('how', 81, 'en', 'help_search', 1),
('how', 84, 'en', 'help_search', 1),
('how', 85, 'en', 'help_search', 1),
('however', 23, 'en', 'help_search', 1),
('however', 79, 'en', 'help_search', 1),
('html', 10, 'en', 'help_search', 2),
('html', 12, 'en', 'help_search', 2.44132),
('html', 18, 'en', 'help_search', 1),
('html', 50, 'en', 'help_search', 12.3934),
('html', 54, 'en', 'help_search', 4),
('html', 59, 'en', 'help_search', 1),
('html', 62, 'en', 'help_search', 1),
('html', 68, 'en', 'help_search', 1),
('html', 71, 'en', 'help_search', 1),
('http', 25, 'en', 'help_search', 44),
('https', 33, 'en', 'help_search', 7.84712),
('https', 76, 'en', 'help_search', 4),
('https', 78, 'en', 'help_search', 12),
('human', 76, 'en', 'help_search', 1),
('humanreadable', 11, 'en', 'help_search', 0.989021),
('icon', 19, 'en', 'help_search', 1),
('icon', 20, 'en', 'help_search', 1),
('icon', 81, 'en', 'help_search', 1),
('identification', 48, 'en', 'help_search', 1),
('identifier', 11, 'en', 'help_search', 0.892724),
('identifier', 54, 'en', 'help_search', 3.49253),
('identifiers', 54, 'en', 'help_search', 0.876337),
('identifies', 11, 'en', 'help_search', 0.879565),
('identifies', 78, 'en', 'help_search', 1),
('image', 11, 'en', 'help_search', 2),
('image', 12, 'en', 'help_search', 1.20828),
('image', 16, 'en', 'help_search', 26.9919),
('image', 50, 'en', 'help_search', 1),
('image', 53, 'en', 'help_search', 0.989021),
('image', 70, 'en', 'help_search', 41),
('image', 81, 'en', 'help_search', 1),
('images', 5, 'en', 'help_search', 1),
('images', 10, 'en', 'help_search', 1),
('images', 12, 'en', 'help_search', 3),
('images', 16, 'en', 'help_search', 4.98087),
('images', 50, 'en', 'help_search', 1.99731),
('images', 53, 'en', 'help_search', 1),
('images', 68, 'en', 'help_search', 1),
('images', 70, 'en', 'help_search', 1),
('immediately', 65, 'en', 'help_search', 1),
('impact', 37, 'en', 'help_search', 1),
('implementation', 25, 'en', 'help_search', 2),
('implemented', 23, 'en', 'help_search', 0.989021),
('implications', 19, 'en', 'help_search', 1),
('implications', 43, 'en', 'help_search', 4),
('import', 3, 'en', 'help_search', 11),
('import', 4, 'en', 'help_search', 11),
('imported', 11, 'en', 'help_search', 5.90265),
('importing', 3, 'en', 'help_search', 26),
('importing', 4, 'en', 'help_search', 26),
('importing', 11, 'en', 'help_search', 1.64815),
('improper', 50, 'en', 'help_search', 3.45463),
('improve', 18, 'en', 'help_search', 20),
('improve', 30, 'en', 'help_search', 1),
('improved', 23, 'en', 'help_search', 1),
('include', 12, 'en', 'help_search', 0.691597),
('include', 16, 'en', 'help_search', 2),
('include', 18, 'en', 'help_search', 1),
('include', 22, 'en', 'help_search', 1),
('include', 23, 'en', 'help_search', 1),
('include', 71, 'en', 'help_search', 0.857458),
('includes', 30, 'en', 'help_search', 1),
('includes', 37, 'en', 'help_search', 1),
('including', 6, 'en', 'help_search', 1),
('including', 10, 'en', 'help_search', 1),
('including', 17, 'en', 'help_search', 1),
('including', 23, 'en', 'help_search', 1),
('including', 24, 'en', 'help_search', 0.923838),
('including', 27, 'en', 'help_search', 2),
('including', 32, 'en', 'help_search', 1),
('including', 33, 'en', 'help_search', 27),
('including', 45, 'en', 'help_search', 1),
('including', 81, 'en', 'help_search', 0.923838),
('incorrect', 33, 'en', 'help_search', 1),
('increasing', 23, 'en', 'help_search', 1),
('index', 26, 'en', 'help_search', 4),
('index', 28, 'en', 'help_search', 2),
('index', 29, 'en', 'help_search', 58.9274),
('index', 30, 'en', 'help_search', 0.830633),
('indexed', 26, 'en', 'help_search', 1),
('indexed', 29, 'en', 'help_search', 2.89272),
('indexed', 30, 'en', 'help_search', 0.824901),
('indexing', 26, 'en', 'help_search', 2),
('indexing', 29, 'en', 'help_search', 22.8982),
('indicating', 32, 'en', 'help_search', 3),
('indicating', 33, 'en', 'help_search', 1.85285),
('indicating', 44, 'en', 'help_search', 0.957226),
('individual', 10, 'en', 'help_search', 1),
('individual', 12, 'en', 'help_search', 1),
('individual', 44, 'en', 'help_search', 1),
('individual', 55, 'en', 'help_search', 0.938382),
('individual', 81, 'en', 'help_search', 2),
('individual', 85, 'en', 'help_search', 1),
('influence', 28, 'en', 'help_search', 1),
('information', 1, 'en', 'help_search', 1),
('information', 2, 'en', 'help_search', 1),
('information', 3, 'en', 'help_search', 1),
('information', 4, 'en', 'help_search', 1),
('information', 6, 'en', 'help_search', 4),
('information', 12, 'en', 'help_search', 3.70583),
('information', 15, 'en', 'help_search', 1),
('information', 16, 'en', 'help_search', 1),
('information', 24, 'en', 'help_search', 2.90286),
('information', 25, 'en', 'help_search', 1),
('information', 29, 'en', 'help_search', 1),
('information', 30, 'en', 'help_search', 4.47836),
('information', 35, 'en', 'help_search', 1),
('information', 37, 'en', 'help_search', 1),
('information', 53, 'en', 'help_search', 2),
('information', 55, 'en', 'help_search', 1),
('information', 56, 'en', 'help_search', 1),
('information', 62, 'en', 'help_search', 1),
('information', 63, 'en', 'help_search', 1),
('information', 64, 'en', 'help_search', 1),
('information', 69, 'en', 'help_search', 19),
('information', 70, 'en', 'help_search', 1),
('information', 80, 'en', 'help_search', 1),
('information', 83, 'en', 'help_search', 1),
('information', 85, 'en', 'help_search', 1),
('informational', 37, 'en', 'help_search', 1),
('ingredients', 80, 'en', 'help_search', 1),
('ingredients', 81, 'en', 'help_search', 4),
('inline', 20, 'en', 'help_search', 27),
('inline', 23, 'en', 'help_search', 1.98493),
('inline', 24, 'en', 'help_search', 1),
('inplace', 24, 'en', 'help_search', 2),
('input', 12, 'en', 'help_search', 0.645209),
('input', 50, 'en', 'help_search', 1),
('insert', 44, 'en', 'help_search', 1),
('install', 11, 'en', 'help_search', 4),
('install', 22, 'en', 'help_search', 1),
('install', 24, 'en', 'help_search', 3.75596),
('install', 26, 'en', 'help_search', 1),
('install', 27, 'en', 'help_search', 1),
('install', 35, 'en', 'help_search', 10),
('install', 38, 'en', 'help_search', 6),
('install', 54, 'en', 'help_search', 1),
('install', 71, 'en', 'help_search', 1),
('installation', 11, 'en', 'help_search', 1),
('installation', 68, 'en', 'help_search', 1),
('installed', 12, 'en', 'help_search', 0.58995),
('installed', 13, 'en', 'help_search', 1.99731),
('installed', 14, 'en', 'help_search', 1),
('installed', 16, 'en', 'help_search', 1),
('installed', 20, 'en', 'help_search', 2),
('installed', 21, 'en', 'help_search', 1),
('installed', 24, 'en', 'help_search', 1),
('installed', 26, 'en', 'help_search', 2),
('installed', 35, 'en', 'help_search', 3),
('installed', 36, 'en', 'help_search', 2),
('installed', 37, 'en', 'help_search', 2),
('installed', 38, 'en', 'help_search', 5),
('installed', 39, 'en', 'help_search', 6),
('installed', 42, 'en', 'help_search', 1),
('installed', 48, 'en', 'help_search', 1),
('installed', 50, 'en', 'help_search', 1.81085),
('installed', 54, 'en', 'help_search', 1.96109),
('installed', 55, 'en', 'help_search', 1),
('installed', 56, 'en', 'help_search', 1),
('installed', 58, 'en', 'help_search', 1),
('installed', 60, 'en', 'help_search', 2),
('installed', 66, 'en', 'help_search', 3),
('installed', 71, 'en', 'help_search', 1.59269),
('installed', 74, 'en', 'help_search', 1),
('installed', 79, 'en', 'help_search', 2),
('installed', 80, 'en', 'help_search', 2),
('installed', 83, 'en', 'help_search', 2),
('installing', 11, 'en', 'help_search', 0.942091),
('installing', 14, 'en', 'help_search', 20),
('installing', 15, 'en', 'help_search', 1),
('installing', 30, 'en', 'help_search', 1),
('installing', 35, 'en', 'help_search', 26),
('installing', 38, 'en', 'help_search', 26),
('installing', 54, 'en', 'help_search', 1),
('instance', 11, 'en', 'help_search', 6.60419),
('instance', 53, 'en', 'help_search', 2),
('instance', 81, 'en', 'help_search', 1),
('instances', 11, 'en', 'help_search', 3.54852),
('instead', 10, 'en', 'help_search', 1),
('instead', 18, 'en', 'help_search', 1),
('instead', 23, 'en', 'help_search', 1),
('instead', 50, 'en', 'help_search', 0.934703),
('instead', 54, 'en', 'help_search', 1),
('instead', 55, 'en', 'help_search', 1),
('instead', 58, 'en', 'help_search', 1),
('instead', 66, 'en', 'help_search', 1),
('instructions', 27, 'en', 'help_search', 0.945829),
('instructions', 34, 'en', 'help_search', 1),
('instructions', 59, 'en', 'help_search', 1),
('instructions', 80, 'en', 'help_search', 1),
('integer', 12, 'en', 'help_search', 2.97194),
('integers', 12, 'en', 'help_search', 0.740689),
('interactions', 12, 'en', 'help_search', 1),
('interest', 45, 'en', 'help_search', 3),
('interest', 60, 'en', 'help_search', 1),
('interests', 46, 'en', 'help_search', 1),
('interface', 10, 'en', 'help_search', 1),
('interface', 11, 'en', 'help_search', 0.727213),
('interface', 12, 'en', 'help_search', 1.20198),
('interface', 16, 'en', 'help_search', 2),
('interface', 17, 'en', 'help_search', 1),
('interface', 22, 'en', 'help_search', 3),
('interface', 23, 'en', 'help_search', 32),
('interface', 24, 'en', 'help_search', 66.3775),
('interface', 27, 'en', 'help_search', 2),
('interface', 48, 'en', 'help_search', 1),
('interface', 52, 'en', 'help_search', 1),
('interface', 56, 'en', 'help_search', 1),
('interface', 66, 'en', 'help_search', 1),
('interface', 71, 'en', 'help_search', 0.794753),
('interface', 80, 'en', 'help_search', 2),
('interface', 81, 'en', 'help_search', 0.931053),
('interface', 82, 'en', 'help_search', 1),
('interface', 84, 'en', 'help_search', 1),
('interfaces', 23, 'en', 'help_search', 1),
('internal', 18, 'en', 'help_search', 20.4433),
('internal', 31, 'en', 'help_search', 1),
('internal', 73, 'en', 'help_search', 1),
('into', 2, 'en', 'help_search', 1),
('into', 4, 'en', 'help_search', 1),
('into', 11, 'en', 'help_search', 2.53391),
('into', 12, 'en', 'help_search', 3),
('into', 16, 'en', 'help_search', 1),
('into', 18, 'en', 'help_search', 1),
('into', 22, 'en', 'help_search', 2),
('into', 25, 'en', 'help_search', 1),
('into', 27, 'en', 'help_search', 1),
('into', 29, 'en', 'help_search', 1),
('into', 30, 'en', 'help_search', 3),
('into', 31, 'en', 'help_search', 1),
('into', 34, 'en', 'help_search', 8),
('into', 35, 'en', 'help_search', 1),
('into', 36, 'en', 'help_search', 1),
('into', 44, 'en', 'help_search', 1),
('into', 48, 'en', 'help_search', 1),
('into', 49, 'en', 'help_search', 1),
('into', 50, 'en', 'help_search', 5),
('into', 53, 'en', 'help_search', 2),
('into', 59, 'en', 'help_search', 1),
('into', 68, 'en', 'help_search', 1),
('into', 75, 'en', 'help_search', 1),
('invalid', 33, 'en', 'help_search', 1),
('item', 2, 'en', 'help_search', 31),
('item', 4, 'en', 'help_search', 32),
('item', 11, 'en', 'help_search', 2),
('item', 12, 'en', 'help_search', 6.85498),
('item', 57, 'en', 'help_search', 2),
('item', 61, 'en', 'help_search', 1),
('item', 64, 'en', 'help_search', 5),
('item', 65, 'en', 'help_search', 39.8792),
('item', 67, 'en', 'help_search', 39.363),
('item', 68, 'en', 'help_search', 24),
('item', 69, 'en', 'help_search', 1),
('item', 71, 'en', 'help_search', 1.87313),
('item', 72, 'en', 'help_search', 5),
('item', 73, 'en', 'help_search', 1),
('item', 76, 'en', 'help_search', 41),
('item', 78, 'en', 'help_search', 1),
('item', 83, 'en', 'help_search', 1),
('item', 85, 'en', 'help_search', 3),
('items', 10, 'en', 'help_search', 1),
('items', 11, 'en', 'help_search', 1.75231),
('items', 12, 'en', 'help_search', 3.84729),
('items', 16, 'en', 'help_search', 26),
('items', 17, 'en', 'help_search', 1),
('items', 21, 'en', 'help_search', 1),
('items', 22, 'en', 'help_search', 2),
('items', 29, 'en', 'help_search', 4),
('items', 55, 'en', 'help_search', 1),
('items', 58, 'en', 'help_search', 8),
('items', 65, 'en', 'help_search', 2),
('items', 67, 'en', 'help_search', 10.9534),
('items', 68, 'en', 'help_search', 3),
('items', 71, 'en', 'help_search', 5.53668),
('items', 72, 'en', 'help_search', 2),
('items', 78, 'en', 'help_search', 1),
('items', 81, 'en', 'help_search', 3.95959),
('items', 84, 'en', 'help_search', 1),
('items', 85, 'en', 'help_search', 1),
('its', 8, 'en', 'help_search', 1),
('its', 11, 'en', 'help_search', 2.78177),
('its', 13, 'en', 'help_search', 1),
('its', 14, 'en', 'help_search', 2),
('its', 24, 'en', 'help_search', 1),
('its', 25, 'en', 'help_search', 1),
('its', 46, 'en', 'help_search', 1),
('its', 52, 'en', 'help_search', 1),
('its', 55, 'en', 'help_search', 0.931053),
('its', 59, 'en', 'help_search', 2),
('its', 65, 'en', 'help_search', 1),
('its', 67, 'en', 'help_search', 1),
('its', 68, 'en', 'help_search', 1),
('its', 69, 'en', 'help_search', 1),
('its', 81, 'en', 'help_search', 1),
('its', 82, 'en', 'help_search', 1),
('its', 83, 'en', 'help_search', 1),
('its', 85, 'en', 'help_search', 1),
('itself', 55, 'en', 'help_search', 1),
('japanese', 29, 'en', 'help_search', 1),
('javascript', 14, 'en', 'help_search', 1),
('javascript', 18, 'en', 'help_search', 1.85135),
('javascript', 54, 'en', 'help_search', 2),
('jobs', 12, 'en', 'help_search', 1),
('json', 25, 'en', 'help_search', 36),
('json', 46, 'en', 'help_search', 1),
('just', 48, 'en', 'help_search', 1),
('just', 53, 'en', 'help_search', 1),
('just', 73, 'en', 'help_search', 1),
('keep', 11, 'en', 'help_search', 0.906287),
('keep', 13, 'en', 'help_search', 1),
('keep', 19, 'en', 'help_search', 1),
('keeping', 19, 'en', 'help_search', 2),
('kept', 69, 'en', 'help_search', 1),
('key', 12, 'en', 'help_search', 0.745294),
('key', 67, 'en', 'help_search', 1),
('keyboardonly', 23, 'en', 'help_search', 1),
('keys', 12, 'en', 'help_search', 3.87487),
('keyword', 29, 'en', 'help_search', 1),
('keyword', 30, 'en', 'help_search', 1),
('keywords', 29, 'en', 'help_search', 1),
('keywords', 30, 'en', 'help_search', 1),
('keywords', 83, 'en', 'help_search', 1),
('kinds', 11, 'en', 'help_search', 19),
('knowing', 8, 'en', 'help_search', 1),
('known', 13, 'en', 'help_search', 1),
('known', 16, 'en', 'help_search', 1),
('known', 81, 'en', 'help_search', 2),
('korean', 29, 'en', 'help_search', 1),
('label', 7, 'en', 'help_search', 4),
('label', 12, 'en', 'help_search', 0.655756),
('label', 28, 'en', 'help_search', 4),
('label', 52, 'en', 'help_search', 1),
('label', 56, 'en', 'help_search', 4),
('label', 61, 'en', 'help_search', 10),
('label', 62, 'en', 'help_search', 7),
('label', 64, 'en', 'help_search', 11),
('label', 65, 'en', 'help_search', 1),
('labeled', 4, 'en', 'help_search', 1),
('labeled', 23, 'en', 'help_search', 1),
('labeled', 38, 'en', 'help_search', 1),
('labels', 12, 'en', 'help_search', 4.84414),
('language', 22, 'en', 'help_search', 7),
('language', 26, 'en', 'help_search', 1),
('language', 27, 'en', 'help_search', 1),
('language', 30, 'en', 'help_search', 0.993146),
('language', 32, 'en', 'help_search', 8),
('language', 67, 'en', 'help_search', 4),
('language', 74, 'en', 'help_search', 2),
('languages', 20, 'en', 'help_search', 1),
('languages', 22, 'en', 'help_search', 49),
('languages', 24, 'en', 'help_search', 1),
('languages', 29, 'en', 'help_search', 1.9689),
('languages', 58, 'en', 'help_search', 2),
('languages', 60, 'en', 'help_search', 2),
('languages', 67, 'en', 'help_search', 1),
('languages', 79, 'en', 'help_search', 0.968904),
('languagespecific', 30, 'en', 'help_search', 1),
('large', 12, 'en', 'help_search', 0.695602),
('large', 30, 'en', 'help_search', 2),
('larger', 29, 'en', 'help_search', 1),
('last', 12, 'en', 'help_search', 1),
('last', 13, 'en', 'help_search', 4),
('last', 37, 'en', 'help_search', 4),
('last', 69, 'en', 'help_search', 1),
('last', 78, 'en', 'help_search', 1),
('later', 18, 'en', 'help_search', 1.89272),
('later', 29, 'en', 'help_search', 0.934703),
('later', 51, 'en', 'help_search', 1),
('later', 84, 'en', 'help_search', 2),
('layout', 10, 'en', 'help_search', 26.9617),
('layout', 12, 'en', 'help_search', 0.601716),
('layout', 26, 'en', 'help_search', 4),
('layout', 47, 'en', 'help_search', 4),
('layout', 49, 'en', 'help_search', 1),
('layout', 53, 'en', 'help_search', 1),
('layouts', 10, 'en', 'help_search', 2.97685),
('layouts', 53, 'en', 'help_search', 1.98902),
('layouts', 70, 'en', 'help_search', 1),
('leading', 24, 'en', 'help_search', 1),
('leads', 8, 'en', 'help_search', 1),
('learn', 22, 'en', 'help_search', 2),
('learn', 37, 'en', 'help_search', 1),
('learning', 8, 'en', 'help_search', 1),
('least', 27, 'en', 'help_search', 1),
('least', 83, 'en', 'help_search', 1),
('leave', 55, 'en', 'help_search', 1),
('leave', 65, 'en', 'help_search', 1),
('left', 24, 'en', 'help_search', 1),
('left', 40, 'en', 'help_search', 1),
('left', 58, 'en', 'help_search', 2),
('left', 60, 'en', 'help_search', 2),
('left', 67, 'en', 'help_search', 1),
('left', 79, 'en', 'help_search', 0.976851),
('length', 29, 'en', 'help_search', 5),
('less', 33, 'en', 'help_search', 1),
('let', 20, 'en', 'help_search', 1),
('let', 22, 'en', 'help_search', 1),
('let', 71, 'en', 'help_search', 1),
('let', 81, 'en', 'help_search', 1),
('lets', 22, 'en', 'help_search', 1),
('letting', 59, 'en', 'help_search', 0.934703),
('level', 28, 'en', 'help_search', 1),
('library', 16, 'en', 'help_search', 25),
('library', 54, 'en', 'help_search', 2),
('lifetime', 18, 'en', 'help_search', 4.86055),
('like', 20, 'en', 'help_search', 2),
('like', 30, 'en', 'help_search', 1),
('like', 48, 'en', 'help_search', 1),
('like', 59, 'en', 'help_search', 1),
('like', 60, 'en', 'help_search', 1),
('like', 71, 'en', 'help_search', 0.923838),
('like', 77, 'en', 'help_search', 1),
('like', 79, 'en', 'help_search', 1),
('like', 81, 'en', 'help_search', 1),
('like', 83, 'en', 'help_search', 2),
('limit', 12, 'en', 'help_search', 1.39535),
('limit', 50, 'en', 'help_search', 1),
('limit', 55, 'en', 'help_search', 1),
('limit', 61, 'en', 'help_search', 1),
('limit', 64, 'en', 'help_search', 2),
('limit', 71, 'en', 'help_search', 1),
('limitations', 30, 'en', 'help_search', 20),
('limited', 79, 'en', 'help_search', 1),
('limits', 50, 'en', 'help_search', 1),
('limits', 69, 'en', 'help_search', 1),
('line', 47, 'en', 'help_search', 1),
('line', 50, 'en', 'help_search', 4),
('link', 7, 'en', 'help_search', 1),
('link', 8, 'en', 'help_search', 1),
('link', 12, 'en', 'help_search', 2.50061),
('link', 13, 'en', 'help_search', 1),
('link', 20, 'en', 'help_search', 3),
('link', 23, 'en', 'help_search', 1),
('link', 26, 'en', 'help_search', 1),
('link', 38, 'en', 'help_search', 2),
('link', 39, 'en', 'help_search', 2),
('link', 46, 'en', 'help_search', 1),
('link', 50, 'en', 'help_search', 0.949597),
('link', 60, 'en', 'help_search', 4.98902),
('link', 73, 'en', 'help_search', 62),
('link', 79, 'en', 'help_search', 3.95723),
('link', 82, 'en', 'help_search', 3),
('link', 85, 'en', 'help_search', 5),
('links', 12, 'en', 'help_search', 0.617112),
('links', 17, 'en', 'help_search', 10),
('links', 20, 'en', 'help_search', 9),
('links', 24, 'en', 'help_search', 3),
('links', 27, 'en', 'help_search', 1),
('links', 50, 'en', 'help_search', 3.89272),
('links', 60, 'en', 'help_search', 63.989),
('links', 72, 'en', 'help_search', 2),
('links', 73, 'en', 'help_search', 2),
('links', 74, 'en', 'help_search', 2),
('links', 75, 'en', 'help_search', 30),
('links', 79, 'en', 'help_search', 28.965),
('links', 83, 'en', 'help_search', 4),
('links', 85, 'en', 'help_search', 1),
('linuxlike', 13, 'en', 'help_search', 1),
('list', 11, 'en', 'help_search', 0.827757),
('list', 12, 'en', 'help_search', 28.8966),
('list', 24, 'en', 'help_search', 1),
('list', 28, 'en', 'help_search', 2),
('list', 35, 'en', 'help_search', 1),
('list', 36, 'en', 'help_search', 2),
('list', 41, 'en', 'help_search', 1),
('list', 45, 'en', 'help_search', 1),
('list', 58, 'en', 'help_search', 3),
('list', 60, 'en', 'help_search', 1.98217),
('list', 61, 'en', 'help_search', 1),
('list', 62, 'en', 'help_search', 1),
('list', 63, 'en', 'help_search', 1),
('list', 64, 'en', 'help_search', 1.99315),
('list', 67, 'en', 'help_search', 2),
('list', 71, 'en', 'help_search', 3),
('list', 72, 'en', 'help_search', 1),
('list', 73, 'en', 'help_search', 2),
('list', 77, 'en', 'help_search', 2),
('list', 79, 'en', 'help_search', 3.97),
('list', 81, 'en', 'help_search', 3),
('list', 82, 'en', 'help_search', 1),
('list', 83, 'en', 'help_search', 3),
('list', 84, 'en', 'help_search', 1),
('list', 85, 'en', 'help_search', 10),
('listed', 10, 'en', 'help_search', 0.953396),
('listed', 11, 'en', 'help_search', 0.687638),
('listed', 12, 'en', 'help_search', 1.21546),
('listed', 14, 'en', 'help_search', 1),
('listed', 16, 'en', 'help_search', 0.972861),
('listed', 17, 'en', 'help_search', 1),
('listed', 19, 'en', 'help_search', 1),
('listed', 21, 'en', 'help_search', 1),
('listed', 22, 'en', 'help_search', 1),
('listed', 24, 'en', 'help_search', 0.866793),
('listed', 26, 'en', 'help_search', 1),
('listed', 27, 'en', 'help_search', 20),
('listed', 28, 'en', 'help_search', 1),
('listed', 29, 'en', 'help_search', 0.886095),
('listed', 30, 'en', 'help_search', 0.794753),
('listed', 36, 'en', 'help_search', 1),
('listed', 48, 'en', 'help_search', 1),
('listed', 56, 'en', 'help_search', 1),
('listed', 59, 'en', 'help_search', 0.860547),
('listed', 64, 'en', 'help_search', 1),
('listed', 66, 'en', 'help_search', 1),
('listed', 68, 'en', 'help_search', 1),
('listed', 71, 'en', 'help_search', 0.78951),
('listed', 78, 'en', 'help_search', 1),
('listed', 81, 'en', 'help_search', 0.906287),
('listed', 84, 'en', 'help_search', 1),
('listing', 71, 'en', 'help_search', 2),
('listing', 81, 'en', 'help_search', 0.976851),
('listings', 71, 'en', 'help_search', 35.5437),
('listings', 85, 'en', 'help_search', 11.6148),
('lists', 12, 'en', 'help_search', 0.816452),
('lists', 80, 'en', 'help_search', 1),
('lists', 81, 'en', 'help_search', 0.968904),
('lists', 85, 'en', 'help_search', 1),
('live', 11, 'en', 'help_search', 3.73211),
('load', 18, 'en', 'help_search', 1),
('loads', 31, 'en', 'help_search', 1),
('locate', 23, 'en', 'help_search', 1),
('locate', 35, 'en', 'help_search', 1),
('locate', 36, 'en', 'help_search', 1),
('locate', 38, 'en', 'help_search', 2),
('locate', 39, 'en', 'help_search', 1),
('locate', 60, 'en', 'help_search', 1),
('locate', 72, 'en', 'help_search', 1),
('locate', 73, 'en', 'help_search', 2),
('locate', 76, 'en', 'help_search', 1),
('locate', 78, 'en', 'help_search', 1),
('located', 16, 'en', 'help_search', 1),
('located', 26, 'en', 'help_search', 1),
('located', 47, 'en', 'help_search', 2),
('location', 11, 'en', 'help_search', 0.774192),
('location', 12, 'en', 'help_search', 0.754681),
('location', 72, 'en', 'help_search', 1),
('locations', 12, 'en', 'help_search', 0.76431),
('locator', 78, 'en', 'help_search', 1),
('log', 34, 'en', 'help_search', 1),
('log', 37, 'en', 'help_search', 4),
('log', 42, 'en', 'help_search', 2),
('log', 44, 'en', 'help_search', 2),
('logged', 12, 'en', 'help_search', 1),
('logged', 18, 'en', 'help_search', 0.997306),
('logged', 34, 'en', 'help_search', 1),
('logged', 42, 'en', 'help_search', 2),
('loggedin', 69, 'en', 'help_search', 1),
('logging', 15, 'en', 'help_search', 2),
('logging', 33, 'en', 'help_search', 3.73881),
('logging', 37, 'en', 'help_search', 1),
('loginurl', 44, 'en', 'help_search', 1),
('long', 11, 'en', 'help_search', 0.869951),
('long', 12, 'en', 'help_search', 6.20151),
('long', 31, 'en', 'help_search', 1),
('long', 32, 'en', 'help_search', 1),
('longer', 18, 'en', 'help_search', 1),
('longer', 39, 'en', 'help_search', 1),
('look', 10, 'en', 'help_search', 1),
('look', 30, 'en', 'help_search', 1),
('look', 32, 'en', 'help_search', 1),
('looks', 20, 'en', 'help_search', 1),
('looks', 60, 'en', 'help_search', 1),
('looks', 79, 'en', 'help_search', 1),
('machine', 41, 'en', 'help_search', 4),
('machine', 52, 'en', 'help_search', 1),
('machine', 74, 'en', 'help_search', 1),
('machinereadable', 25, 'en', 'help_search', 1),
('made', 85, 'en', 'help_search', 0.997306),
('mail', 44, 'en', 'help_search', 1),
('main', 10, 'en', 'help_search', 1),
('main', 12, 'en', 'help_search', 2.32097),
('main', 26, 'en', 'help_search', 1),
('main', 27, 'en', 'help_search', 0.980874),
('main', 30, 'en', 'help_search', 2),
('main', 32, 'en', 'help_search', 2),
('maintaining', 15, 'en', 'help_search', 46),
('maintenance', 13, 'en', 'help_search', 10.4874),
('maintenance', 15, 'en', 'help_search', 13),
('maintenance', 19, 'en', 'help_search', 11),
('maintenance', 34, 'en', 'help_search', 75),
('maintenance', 36, 'en', 'help_search', 5),
('maintenance', 37, 'en', 'help_search', 11),
('make', 9, 'en', 'help_search', 4),
('make', 13, 'en', 'help_search', 1),
('make', 20, 'en', 'help_search', 1),
('make', 23, 'en', 'help_search', 2),
('make', 26, 'en', 'help_search', 1),
('make', 28, 'en', 'help_search', 1),
('make', 29, 'en', 'help_search', 3.91323),
('make', 30, 'en', 'help_search', 0.836446),
('make', 35, 'en', 'help_search', 1),
('make', 36, 'en', 'help_search', 1),
('make', 44, 'en', 'help_search', 2),
('make', 54, 'en', 'help_search', 1),
('make', 60, 'en', 'help_search', 4),
('make', 61, 'en', 'help_search', 1),
('make', 64, 'en', 'help_search', 1),
('make', 65, 'en', 'help_search', 1),
('make', 67, 'en', 'help_search', 0.989021),
('make', 73, 'en', 'help_search', 1),
('make', 76, 'en', 'help_search', 1),
('make', 77, 'en', 'help_search', 1),
('make', 79, 'en', 'help_search', 2),
('make', 83, 'en', 'help_search', 1),
('makes', 30, 'en', 'help_search', 0.968904),
('making', 11, 'en', 'help_search', 7.33326),
('making', 19, 'en', 'help_search', 26),
('making', 62, 'en', 'help_search', 1),
('making', 63, 'en', 'help_search', 1),
('malicious', 50, 'en', 'help_search', 0.896076),
('manage', 1, 'en', 'help_search', 4),
('manage', 2, 'en', 'help_search', 4),
('manage', 3, 'en', 'help_search', 4),
('manage', 4, 'en', 'help_search', 4),
('manage', 5, 'en', 'help_search', 12),
('manage', 6, 'en', 'help_search', 8),
('manage', 7, 'en', 'help_search', 4),
('manage', 9, 'en', 'help_search', 4),
('manage', 12, 'en', 'help_search', 0.623497),
('manage', 13, 'en', 'help_search', 4),
('manage', 18, 'en', 'help_search', 3.55759),
('manage', 24, 'en', 'help_search', 2.91674),
('manage', 26, 'en', 'help_search', 16),
('manage', 28, 'en', 'help_search', 4),
('manage', 29, 'en', 'help_search', 5),
('manage', 31, 'en', 'help_search', 4),
('manage', 32, 'en', 'help_search', 12),
('manage', 33, 'en', 'help_search', 7.75353),
('manage', 34, 'en', 'help_search', 8),
('manage', 35, 'en', 'help_search', 4),
('manage', 36, 'en', 'help_search', 4),
('manage', 37, 'en', 'help_search', 12),
('manage', 38, 'en', 'help_search', 4),
('manage', 39, 'en', 'help_search', 4),
('manage', 40, 'en', 'help_search', 4),
('manage', 41, 'en', 'help_search', 4),
('manage', 42, 'en', 'help_search', 1),
('manage', 43, 'en', 'help_search', 4),
('manage', 44, 'en', 'help_search', 4),
('manage', 45, 'en', 'help_search', 4),
('manage', 47, 'en', 'help_search', 4),
('manage', 48, 'en', 'help_search', 1),
('manage', 49, 'en', 'help_search', 4),
('manage', 50, 'en', 'help_search', 3.95608),
('manage', 51, 'en', 'help_search', 4),
('manage', 52, 'en', 'help_search', 16),
('manage', 54, 'en', 'help_search', 4),
('manage', 56, 'en', 'help_search', 4),
('manage', 57, 'en', 'help_search', 4),
('manage', 58, 'en', 'help_search', 4),
('manage', 61, 'en', 'help_search', 12),
('manage', 62, 'en', 'help_search', 8),
('manage', 63, 'en', 'help_search', 8),
('manage', 64, 'en', 'help_search', 12),
('manage', 65, 'en', 'help_search', 4),
('manage', 66, 'en', 'help_search', 12),
('manage', 67, 'en', 'help_search', 4),
('manage', 68, 'en', 'help_search', 1),
('manage', 70, 'en', 'help_search', 4),
('manage', 72, 'en', 'help_search', 4),
('manage', 73, 'en', 'help_search', 8),
('manage', 74, 'en', 'help_search', 4),
('manage', 75, 'en', 'help_search', 4),
('manage', 77, 'en', 'help_search', 23),
('manage', 80, 'en', 'help_search', 4),
('manage', 82, 'en', 'help_search', 4),
('manage', 83, 'en', 'help_search', 4),
('manage', 84, 'en', 'help_search', 4),
('manage', 85, 'en', 'help_search', 4),
('managed', 16, 'en', 'help_search', 1),
('managed', 19, 'en', 'help_search', 1),
('managed', 50, 'en', 'help_search', 1),
('managed', 79, 'en', 'help_search', 1),
('managed', 81, 'en', 'help_search', 1),
('management', 8, 'en', 'help_search', 19),
('management', 11, 'en', 'help_search', 8.20031),
('management', 58, 'en', 'help_search', 1),
('management', 65, 'en', 'help_search', 11),
('management', 67, 'en', 'help_search', 10.4874),
('manager', 11, 'en', 'help_search', 0.731649),
('manager', 22, 'en', 'help_search', 1),
('manager', 37, 'en', 'help_search', 1),
('managers', 8, 'en', 'help_search', 1),
('manages', 22, 'en', 'help_search', 1),
('managing', 1, 'en', 'help_search', 1),
('managing', 2, 'en', 'help_search', 1),
('managing', 3, 'en', 'help_search', 1),
('managing', 4, 'en', 'help_search', 1),
('managing', 5, 'en', 'help_search', 26),
('managing', 6, 'en', 'help_search', 1),
('managing', 7, 'en', 'help_search', 1),
('managing', 8, 'en', 'help_search', 26),
('managing', 10, 'en', 'help_search', 1),
('managing', 11, 'en', 'help_search', 40.1606),
('managing', 12, 'en', 'help_search', 38.6049),
('managing', 16, 'en', 'help_search', 47),
('managing', 17, 'en', 'help_search', 46),
('managing', 22, 'en', 'help_search', 2),
('managing', 25, 'en', 'help_search', 1),
('managing', 28, 'en', 'help_search', 1),
('managing', 29, 'en', 'help_search', 26),
('managing', 30, 'en', 'help_search', 0.848323),
('managing', 42, 'en', 'help_search', 46),
('managing', 48, 'en', 'help_search', 45),
('managing', 50, 'en', 'help_search', 26),
('managing', 53, 'en', 'help_search', 44.6366),
('managing', 54, 'en', 'help_search', 2.83669),
('managing', 55, 'en', 'help_search', 1),
('managing', 56, 'en', 'help_search', 2),
('managing', 57, 'en', 'help_search', 1),
('managing', 59, 'en', 'help_search', 45.1362),
('managing', 61, 'en', 'help_search', 3),
('managing', 62, 'en', 'help_search', 2),
('managing', 63, 'en', 'help_search', 2),
('managing', 64, 'en', 'help_search', 2),
('managing', 65, 'en', 'help_search', 1),
('managing', 66, 'en', 'help_search', 1),
('managing', 67, 'en', 'help_search', 1),
('managing', 68, 'en', 'help_search', 46),
('managing', 70, 'en', 'help_search', 1),
('managing', 71, 'en', 'help_search', 41.2523),
('managing', 80, 'en', 'help_search', 2),
('managing', 81, 'en', 'help_search', 45.1145),
('managing', 85, 'en', 'help_search', 1),
('manner', 67, 'en', 'help_search', 0.968904),
('manually', 13, 'en', 'help_search', 1),
('manually', 31, 'en', 'help_search', 1),
('manually', 37, 'en', 'help_search', 4),
('many', 12, 'en', 'help_search', 1.53962),
('many', 22, 'en', 'help_search', 1),
('many', 23, 'en', 'help_search', 1),
('many', 68, 'en', 'help_search', 1),
('many', 71, 'en', 'help_search', 0.942091),
('mark', 18, 'en', 'help_search', 1),
('marked', 2, 'en', 'help_search', 1),
('marked', 43, 'en', 'help_search', 1),
('marked', 69, 'en', 'help_search', 2),
('marker', 69, 'en', 'help_search', 1),
('markup', 10, 'en', 'help_search', 1),
('markup', 12, 'en', 'help_search', 1),
('markup', 59, 'en', 'help_search', 1),
('markup', 68, 'en', 'help_search', 1),
('match', 11, 'en', 'help_search', 0.781775),
('match', 30, 'en', 'help_search', 0.953396),
('match', 32, 'en', 'help_search', 1),
('match', 44, 'en', 'help_search', 1),
('matched', 29, 'en', 'help_search', 1),
('matches', 32, 'en', 'help_search', 1),
('matching', 30, 'en', 'help_search', 1),
('matter', 27, 'en', 'help_search', 1),
('maximum', 18, 'en', 'help_search', 1.86055),
('maximum', 55, 'en', 'help_search', 1),
('may', 12, 'en', 'help_search', 1.92384),
('may', 15, 'en', 'help_search', 1),
('may', 16, 'en', 'help_search', 1),
('may', 24, 'en', 'help_search', 1),
('may', 30, 'en', 'help_search', 0.819249),
('may', 33, 'en', 'help_search', 1),
('may', 35, 'en', 'help_search', 1),
('may', 36, 'en', 'help_search', 2),
('may', 37, 'en', 'help_search', 1),
('may', 54, 'en', 'help_search', 1),
('may', 66, 'en', 'help_search', 1),
('may', 71, 'en', 'help_search', 1),
('may', 80, 'en', 'help_search', 2),
('may', 83, 'en', 'help_search', 1),
('meaning', 69, 'en', 'help_search', 2),
('means', 11, 'en', 'help_search', 0.931053),
('means', 14, 'en', 'help_search', 2),
('meant', 10, 'en', 'help_search', 1),
('meant', 12, 'en', 'help_search', 1),
('meant', 53, 'en', 'help_search', 1),
('measure', 53, 'en', 'help_search', 1),
('mechanisms', 18, 'en', 'help_search', 2),
('mechanisms', 31, 'en', 'help_search', 1),
('mechanisms', 54, 'en', 'help_search', 1),
('media', 12, 'en', 'help_search', 0.61241),
('media', 16, 'en', 'help_search', 117.446),
('media', 53, 'en', 'help_search', 33.2416),
('media', 70, 'en', 'help_search', 5);
INSERT INTO `[[dbprefix]]search_index` VALUES
('mediarelated', 16, 'en', 'help_search', 1),
('medium', 32, 'en', 'help_search', 1),
('members', 59, 'en', 'help_search', 0.927431),
('mentioned', 24, 'en', 'help_search', 0.882818),
('menu', 1, 'en', 'help_search', 1),
('menu', 2, 'en', 'help_search', 1),
('menu', 3, 'en', 'help_search', 1),
('menu', 4, 'en', 'help_search', 1),
('menu', 5, 'en', 'help_search', 1),
('menu', 6, 'en', 'help_search', 2),
('menu', 7, 'en', 'help_search', 1),
('menu', 9, 'en', 'help_search', 1),
('menu', 12, 'en', 'help_search', 0.618696),
('menu', 13, 'en', 'help_search', 1),
('menu', 17, 'en', 'help_search', 41),
('menu', 18, 'en', 'help_search', 0.882818),
('menu', 20, 'en', 'help_search', 1),
('menu', 24, 'en', 'help_search', 22),
('menu', 26, 'en', 'help_search', 4),
('menu', 28, 'en', 'help_search', 1),
('menu', 29, 'en', 'help_search', 1),
('menu', 30, 'en', 'help_search', 0.805455),
('menu', 31, 'en', 'help_search', 1),
('menu', 32, 'en', 'help_search', 3),
('menu', 33, 'en', 'help_search', 1.93838),
('menu', 34, 'en', 'help_search', 2),
('menu', 35, 'en', 'help_search', 1),
('menu', 36, 'en', 'help_search', 1),
('menu', 37, 'en', 'help_search', 3),
('menu', 38, 'en', 'help_search', 1),
('menu', 39, 'en', 'help_search', 1),
('menu', 40, 'en', 'help_search', 1),
('menu', 41, 'en', 'help_search', 1),
('menu', 43, 'en', 'help_search', 1),
('menu', 44, 'en', 'help_search', 1),
('menu', 45, 'en', 'help_search', 1),
('menu', 47, 'en', 'help_search', 1),
('menu', 49, 'en', 'help_search', 1),
('menu', 50, 'en', 'help_search', 1.93047),
('menu', 51, 'en', 'help_search', 1),
('menu', 52, 'en', 'help_search', 1),
('menu', 54, 'en', 'help_search', 1),
('menu', 56, 'en', 'help_search', 1),
('menu', 57, 'en', 'help_search', 1),
('menu', 58, 'en', 'help_search', 1),
('menu', 60, 'en', 'help_search', 4),
('menu', 61, 'en', 'help_search', 1),
('menu', 62, 'en', 'help_search', 1),
('menu', 63, 'en', 'help_search', 1),
('menu', 64, 'en', 'help_search', 1),
('menu', 65, 'en', 'help_search', 1),
('menu', 66, 'en', 'help_search', 1),
('menu', 67, 'en', 'help_search', 1),
('menu', 70, 'en', 'help_search', 1),
('menu', 72, 'en', 'help_search', 32),
('menu', 73, 'en', 'help_search', 45),
('menu', 74, 'en', 'help_search', 39),
('menu', 75, 'en', 'help_search', 36),
('menu', 77, 'en', 'help_search', 1),
('menu', 80, 'en', 'help_search', 1),
('menu', 82, 'en', 'help_search', 1),
('menu', 83, 'en', 'help_search', 1),
('menu', 84, 'en', 'help_search', 1),
('menu', 85, 'en', 'help_search', 1),
('menus', 17, 'en', 'help_search', 50),
('menus', 24, 'en', 'help_search', 0.968904),
('menus', 72, 'en', 'help_search', 3),
('menus', 73, 'en', 'help_search', 2),
('menus', 74, 'en', 'help_search', 5),
('menus', 75, 'en', 'help_search', 1),
('merged', 18, 'en', 'help_search', 1),
('message', 5, 'en', 'help_search', 4),
('message', 6, 'en', 'help_search', 4),
('message', 7, 'en', 'help_search', 4),
('message', 32, 'en', 'help_search', 3),
('message', 33, 'en', 'help_search', 2.85285),
('message', 34, 'en', 'help_search', 5),
('message', 35, 'en', 'help_search', 1),
('message', 36, 'en', 'help_search', 1),
('message', 40, 'en', 'help_search', 1),
('message', 44, 'en', 'help_search', 21.9572),
('messages', 23, 'en', 'help_search', 1),
('messages', 33, 'en', 'help_search', 5.68109),
('messages', 37, 'en', 'help_search', 6),
('messages', 44, 'en', 'help_search', 1.98493),
('metadata', 26, 'en', 'help_search', 4),
('metadata', 27, 'en', 'help_search', 1),
('metadata', 28, 'en', 'help_search', 4),
('metadata', 29, 'en', 'help_search', 4),
('metadata', 53, 'en', 'help_search', 1),
('metadata', 77, 'en', 'help_search', 4),
('method', 25, 'en', 'help_search', 2),
('method', 44, 'en', 'help_search', 1),
('might', 12, 'en', 'help_search', 0.776703),
('might', 13, 'en', 'help_search', 1),
('might', 38, 'en', 'help_search', 1),
('might', 59, 'en', 'help_search', 1),
('might', 68, 'en', 'help_search', 1),
('might', 78, 'en', 'help_search', 1),
('minimum', 29, 'en', 'help_search', 4),
('minwidth', 53, 'en', 'help_search', 1),
('misbehaving', 31, 'en', 'help_search', 1),
('mistakes', 85, 'en', 'help_search', 0.993146),
('modal', 49, 'en', 'help_search', 2),
('mode', 15, 'en', 'help_search', 1),
('mode', 34, 'en', 'help_search', 75),
('mode', 36, 'en', 'help_search', 5),
('moderate', 58, 'en', 'help_search', 20),
('moderating', 58, 'en', 'help_search', 37),
('moderating', 59, 'en', 'help_search', 0.876337),
('moderation', 59, 'en', 'help_search', 24.965),
('modify', 43, 'en', 'help_search', 1),
('modify', 45, 'en', 'help_search', 1),
('modify', 68, 'en', 'help_search', 1),
('modify', 85, 'en', 'help_search', 2),
('modifying', 14, 'en', 'help_search', 26),
('modifying', 43, 'en', 'help_search', 26),
('modifying', 45, 'en', 'help_search', 26),
('module', 8, 'en', 'help_search', 1),
('module', 10, 'en', 'help_search', 2.97286),
('module', 11, 'en', 'help_search', 2.72942),
('module', 12, 'en', 'help_search', 8.46129),
('module', 13, 'en', 'help_search', 2.99461),
('module', 14, 'en', 'help_search', 48),
('module', 15, 'en', 'help_search', 1),
('module', 16, 'en', 'help_search', 17.436),
('module', 17, 'en', 'help_search', 2),
('module', 18, 'en', 'help_search', 30.5823),
('module', 20, 'en', 'help_search', 4),
('module', 21, 'en', 'help_search', 1),
('module', 22, 'en', 'help_search', 2),
('module', 23, 'en', 'help_search', 0.98493),
('module', 24, 'en', 'help_search', 18),
('module', 25, 'en', 'help_search', 26),
('module', 26, 'en', 'help_search', 1),
('module', 27, 'en', 'help_search', 5),
('module', 30, 'en', 'help_search', 37.3277),
('module', 35, 'en', 'help_search', 38),
('module', 36, 'en', 'help_search', 38),
('module', 37, 'en', 'help_search', 2),
('module', 42, 'en', 'help_search', 3),
('module', 46, 'en', 'help_search', 14),
('module', 47, 'en', 'help_search', 1),
('module', 48, 'en', 'help_search', 2),
('module', 50, 'en', 'help_search', 3.81085),
('module', 53, 'en', 'help_search', 2.93025),
('module', 54, 'en', 'help_search', 4),
('module', 55, 'en', 'help_search', 4),
('module', 56, 'en', 'help_search', 1),
('module', 58, 'en', 'help_search', 1),
('module', 59, 'en', 'help_search', 1.79901),
('module', 60, 'en', 'help_search', 4),
('module', 66, 'en', 'help_search', 3),
('module', 68, 'en', 'help_search', 2),
('module', 69, 'en', 'help_search', 1),
('module', 71, 'en', 'help_search', 3.19292),
('module', 74, 'en', 'help_search', 1),
('module', 78, 'en', 'help_search', 2),
('module', 79, 'en', 'help_search', 5),
('module', 80, 'en', 'help_search', 2),
('module', 81, 'en', 'help_search', 1.8843),
('module', 83, 'en', 'help_search', 2),
('modules', 10, 'en', 'help_search', 2.98087),
('modules', 11, 'en', 'help_search', 0.7017),
('modules', 12, 'en', 'help_search', 4.85309),
('modules', 13, 'en', 'help_search', 1),
('modules', 14, 'en', 'help_search', 21),
('modules', 15, 'en', 'help_search', 1),
('modules', 16, 'en', 'help_search', 3),
('modules', 17, 'en', 'help_search', 2),
('modules', 18, 'en', 'help_search', 1),
('modules', 19, 'en', 'help_search', 2),
('modules', 21, 'en', 'help_search', 1),
('modules', 22, 'en', 'help_search', 2),
('modules', 24, 'en', 'help_search', 6.68775),
('modules', 25, 'en', 'help_search', 33),
('modules', 26, 'en', 'help_search', 1),
('modules', 27, 'en', 'help_search', 9),
('modules', 30, 'en', 'help_search', 23),
('modules', 35, 'en', 'help_search', 4),
('modules', 36, 'en', 'help_search', 3),
('modules', 37, 'en', 'help_search', 2),
('modules', 42, 'en', 'help_search', 1),
('modules', 48, 'en', 'help_search', 1),
('modules', 50, 'en', 'help_search', 1),
('modules', 53, 'en', 'help_search', 2.96109),
('modules', 54, 'en', 'help_search', 1),
('modules', 59, 'en', 'help_search', 0.976851),
('modules', 65, 'en', 'help_search', 1),
('modules', 67, 'en', 'help_search', 1),
('modules', 68, 'en', 'help_search', 1),
('modules', 71, 'en', 'help_search', 1),
('month', 69, 'en', 'help_search', 2),
('more', 1, 'en', 'help_search', 1),
('more', 2, 'en', 'help_search', 1),
('more', 3, 'en', 'help_search', 1),
('more', 4, 'en', 'help_search', 1),
('more', 5, 'en', 'help_search', 1),
('more', 6, 'en', 'help_search', 1),
('more', 7, 'en', 'help_search', 1),
('more', 8, 'en', 'help_search', 1),
('more', 10, 'en', 'help_search', 1),
('more', 12, 'en', 'help_search', 6.6464),
('more', 15, 'en', 'help_search', 1),
('more', 16, 'en', 'help_search', 2),
('more', 21, 'en', 'help_search', 1),
('more', 22, 'en', 'help_search', 2),
('more', 23, 'en', 'help_search', 1),
('more', 24, 'en', 'help_search', 2.86055),
('more', 25, 'en', 'help_search', 1),
('more', 27, 'en', 'help_search', 1),
('more', 28, 'en', 'help_search', 1),
('more', 29, 'en', 'help_search', 3),
('more', 30, 'en', 'help_search', 2.59912),
('more', 33, 'en', 'help_search', 0.909743),
('more', 35, 'en', 'help_search', 1),
('more', 40, 'en', 'help_search', 1),
('more', 42, 'en', 'help_search', 1),
('more', 48, 'en', 'help_search', 1),
('more', 50, 'en', 'help_search', 1),
('more', 51, 'en', 'help_search', 1),
('more', 54, 'en', 'help_search', 1),
('more', 55, 'en', 'help_search', 1),
('more', 56, 'en', 'help_search', 1),
('more', 57, 'en', 'help_search', 2),
('more', 58, 'en', 'help_search', 2),
('more', 59, 'en', 'help_search', 1.90974),
('more', 64, 'en', 'help_search', 1),
('more', 65, 'en', 'help_search', 2),
('more', 66, 'en', 'help_search', 1),
('more', 67, 'en', 'help_search', 1),
('more', 68, 'en', 'help_search', 1),
('more', 70, 'en', 'help_search', 1),
('more', 71, 'en', 'help_search', 1.64807),
('more', 74, 'en', 'help_search', 1),
('more', 76, 'en', 'help_search', 1),
('more', 77, 'en', 'help_search', 1),
('more', 78, 'en', 'help_search', 1),
('more', 79, 'en', 'help_search', 2),
('more', 80, 'en', 'help_search', 2),
('more', 81, 'en', 'help_search', 1),
('more', 83, 'en', 'help_search', 2),
('more', 85, 'en', 'help_search', 1),
('most', 11, 'en', 'help_search', 0.703756),
('most', 12, 'en', 'help_search', 2.33704),
('most', 20, 'en', 'help_search', 1),
('most', 23, 'en', 'help_search', 2),
('most', 30, 'en', 'help_search', 1),
('most', 34, 'en', 'help_search', 1),
('most', 37, 'en', 'help_search', 1),
('most', 60, 'en', 'help_search', 1),
('most', 64, 'en', 'help_search', 1),
('most', 69, 'en', 'help_search', 1),
('most', 70, 'en', 'help_search', 1),
('most', 71, 'en', 'help_search', 2),
('most', 82, 'en', 'help_search', 1),
('mostcommonlyused', 25, 'en', 'help_search', 1),
('mouse', 60, 'en', 'help_search', 1),
('move', 11, 'en', 'help_search', 1),
('much', 18, 'en', 'help_search', 1),
('multiple', 22, 'en', 'help_search', 1),
('multiple', 35, 'en', 'help_search', 1),
('multiple', 67, 'en', 'help_search', 1),
('multiple', 71, 'en', 'help_search', 1),
('multiplevalued', 12, 'en', 'help_search', 0.961087),
('multiplier', 53, 'en', 'help_search', 1),
('multipliers', 53, 'en', 'help_search', 22.9496),
('must', 20, 'en', 'help_search', 2),
('must', 46, 'en', 'help_search', 1),
('must', 55, 'en', 'help_search', 1),
('must', 61, 'en', 'help_search', 1),
('must', 64, 'en', 'help_search', 1),
('must', 71, 'en', 'help_search', 0.98493),
('must', 80, 'en', 'help_search', 1),
('name', 2, 'en', 'help_search', 5),
('name', 11, 'en', 'help_search', 1),
('name', 25, 'en', 'help_search', 1),
('name', 28, 'en', 'help_search', 1),
('name', 30, 'en', 'help_search', 1),
('name', 32, 'en', 'help_search', 2),
('name', 35, 'en', 'help_search', 2),
('name', 36, 'en', 'help_search', 2),
('name', 41, 'en', 'help_search', 8),
('name', 44, 'en', 'help_search', 4),
('name', 45, 'en', 'help_search', 1),
('name', 47, 'en', 'help_search', 1),
('name', 48, 'en', 'help_search', 1),
('name', 49, 'en', 'help_search', 1),
('name', 50, 'en', 'help_search', 4.62515),
('name', 51, 'en', 'help_search', 1),
('name', 52, 'en', 'help_search', 1),
('name', 53, 'en', 'help_search', 1),
('name', 56, 'en', 'help_search', 1),
('name', 65, 'en', 'help_search', 1),
('name', 66, 'en', 'help_search', 5),
('name', 70, 'en', 'help_search', 4),
('name', 74, 'en', 'help_search', 1),
('name', 78, 'en', 'help_search', 1),
('name', 80, 'en', 'help_search', 10),
('name', 82, 'en', 'help_search', 5),
('name', 83, 'en', 'help_search', 2),
('name', 84, 'en', 'help_search', 5),
('name', 85, 'en', 'help_search', 1),
('names', 12, 'en', 'help_search', 0.769219),
('navigate', 1, 'en', 'help_search', 1),
('navigate', 2, 'en', 'help_search', 1),
('navigate', 3, 'en', 'help_search', 1),
('navigate', 4, 'en', 'help_search', 1),
('navigate', 5, 'en', 'help_search', 1),
('navigate', 6, 'en', 'help_search', 2),
('navigate', 7, 'en', 'help_search', 1),
('navigate', 9, 'en', 'help_search', 1),
('navigate', 13, 'en', 'help_search', 1),
('navigate', 17, 'en', 'help_search', 1),
('navigate', 18, 'en', 'help_search', 0.876337),
('navigate', 24, 'en', 'help_search', 2),
('navigate', 26, 'en', 'help_search', 4),
('navigate', 28, 'en', 'help_search', 1),
('navigate', 29, 'en', 'help_search', 1),
('navigate', 31, 'en', 'help_search', 1),
('navigate', 32, 'en', 'help_search', 3),
('navigate', 33, 'en', 'help_search', 1.93838),
('navigate', 34, 'en', 'help_search', 2),
('navigate', 35, 'en', 'help_search', 1),
('navigate', 36, 'en', 'help_search', 1),
('navigate', 37, 'en', 'help_search', 3),
('navigate', 38, 'en', 'help_search', 1),
('navigate', 39, 'en', 'help_search', 1),
('navigate', 40, 'en', 'help_search', 1),
('navigate', 41, 'en', 'help_search', 1),
('navigate', 43, 'en', 'help_search', 1),
('navigate', 44, 'en', 'help_search', 1),
('navigate', 45, 'en', 'help_search', 1),
('navigate', 47, 'en', 'help_search', 1),
('navigate', 49, 'en', 'help_search', 1),
('navigate', 50, 'en', 'help_search', 0.976851),
('navigate', 51, 'en', 'help_search', 1),
('navigate', 52, 'en', 'help_search', 1),
('navigate', 54, 'en', 'help_search', 1),
('navigate', 56, 'en', 'help_search', 1),
('navigate', 58, 'en', 'help_search', 3),
('navigate', 60, 'en', 'help_search', 1),
('navigate', 61, 'en', 'help_search', 2),
('navigate', 62, 'en', 'help_search', 2),
('navigate', 63, 'en', 'help_search', 2),
('navigate', 64, 'en', 'help_search', 2),
('navigate', 65, 'en', 'help_search', 1),
('navigate', 66, 'en', 'help_search', 1),
('navigate', 67, 'en', 'help_search', 1),
('navigate', 70, 'en', 'help_search', 1),
('navigate', 72, 'en', 'help_search', 1),
('navigate', 73, 'en', 'help_search', 2),
('navigate', 74, 'en', 'help_search', 1),
('navigate', 75, 'en', 'help_search', 1),
('navigate', 77, 'en', 'help_search', 1),
('navigate', 79, 'en', 'help_search', 1),
('navigate', 80, 'en', 'help_search', 1),
('navigate', 82, 'en', 'help_search', 1),
('navigate', 83, 'en', 'help_search', 1),
('navigate', 84, 'en', 'help_search', 1),
('navigate', 85, 'en', 'help_search', 1),
('navigating', 57, 'en', 'help_search', 1),
('navigating', 60, 'en', 'help_search', 1),
('navigation', 30, 'en', 'help_search', 0.808176),
('near', 26, 'en', 'help_search', 1),
('necessary', 24, 'en', 'help_search', 0.896076),
('necessary', 83, 'en', 'help_search', 1),
('necessary', 85, 'en', 'help_search', 1),
('need', 6, 'en', 'help_search', 1),
('need', 13, 'en', 'help_search', 1),
('need', 14, 'en', 'help_search', 1),
('need', 19, 'en', 'help_search', 1),
('need', 20, 'en', 'help_search', 1),
('need', 27, 'en', 'help_search', 1),
('need', 30, 'en', 'help_search', 2.56694),
('need', 31, 'en', 'help_search', 1),
('need', 32, 'en', 'help_search', 1),
('need', 35, 'en', 'help_search', 1),
('need', 36, 'en', 'help_search', 2),
('need', 37, 'en', 'help_search', 1),
('need', 44, 'en', 'help_search', 1),
('need', 47, 'en', 'help_search', 1),
('need', 53, 'en', 'help_search', 1),
('need', 54, 'en', 'help_search', 1),
('need', 55, 'en', 'help_search', 3),
('need', 57, 'en', 'help_search', 3),
('need', 58, 'en', 'help_search', 1),
('need', 65, 'en', 'help_search', 1),
('need', 67, 'en', 'help_search', 1),
('need', 76, 'en', 'help_search', 1),
('need', 79, 'en', 'help_search', 1),
('need', 80, 'en', 'help_search', 1),
('need', 83, 'en', 'help_search', 2),
('needed', 18, 'en', 'help_search', 2),
('needed', 30, 'en', 'help_search', 1.80574),
('needed', 62, 'en', 'help_search', 1),
('needed', 63, 'en', 'help_search', 1),
('needing', 60, 'en', 'help_search', 1),
('needs', 18, 'en', 'help_search', 0.989021),
('never', 69, 'en', 'help_search', 1),
('new', 6, 'en', 'help_search', 1),
('new', 7, 'en', 'help_search', 28),
('new', 11, 'en', 'help_search', 0.845322),
('new', 17, 'en', 'help_search', 1),
('new', 22, 'en', 'help_search', 1),
('new', 24, 'en', 'help_search', 1),
('new', 26, 'en', 'help_search', 1),
('new', 28, 'en', 'help_search', 1),
('new', 38, 'en', 'help_search', 3),
('new', 40, 'en', 'help_search', 13),
('new', 41, 'en', 'help_search', 28),
('new', 44, 'en', 'help_search', 2),
('new', 45, 'en', 'help_search', 1),
('new', 50, 'en', 'help_search', 1.71949),
('new', 52, 'en', 'help_search', 1),
('new', 54, 'en', 'help_search', 5.48567),
('new', 55, 'en', 'help_search', 2.76565),
('new', 56, 'en', 'help_search', 2),
('new', 57, 'en', 'help_search', 2),
('new', 59, 'en', 'help_search', 1),
('new', 61, 'en', 'help_search', 5),
('new', 64, 'en', 'help_search', 4.99315),
('new', 65, 'en', 'help_search', 1),
('new', 66, 'en', 'help_search', 3),
('new', 69, 'en', 'help_search', 16),
('new', 70, 'en', 'help_search', 6),
('new', 74, 'en', 'help_search', 1),
('new', 75, 'en', 'help_search', 1),
('new', 76, 'en', 'help_search', 2),
('new', 77, 'en', 'help_search', 1),
('new', 80, 'en', 'help_search', 2),
('new', 81, 'en', 'help_search', 1),
('new', 82, 'en', 'help_search', 30),
('new', 84, 'en', 'help_search', 27),
('new', 85, 'en', 'help_search', 1),
('newly', 69, 'en', 'help_search', 1),
('news', 59, 'en', 'help_search', 1),
('news', 71, 'en', 'help_search', 1),
('next', 18, 'en', 'help_search', 1),
('next', 35, 'en', 'help_search', 2),
('next', 36, 'en', 'help_search', 1),
('next', 45, 'en', 'help_search', 1),
('next', 55, 'en', 'help_search', 1),
('next', 61, 'en', 'help_search', 2),
('next', 64, 'en', 'help_search', 2),
('next', 70, 'en', 'help_search', 1),
('next', 79, 'en', 'help_search', 1),
('next', 82, 'en', 'help_search', 1),
('next', 85, 'en', 'help_search', 1),
('node', 12, 'en', 'help_search', 0.621888),
('node', 30, 'en', 'help_search', 2),
('node', 55, 'en', 'help_search', 2),
('node', 58, 'en', 'help_search', 1),
('node', 68, 'en', 'help_search', 1),
('node', 73, 'en', 'help_search', 4),
('node', 78, 'en', 'help_search', 13),
('nolink', 73, 'en', 'help_search', 4),
('nonadministration', 38, 'en', 'help_search', 1),
('nonadministrative', 24, 'en', 'help_search', 1),
('nonadministrative', 60, 'en', 'help_search', 2),
('nonadministrative', 65, 'en', 'help_search', 1),
('noncacheable', 18, 'en', 'help_search', 0.961087),
('nondefault', 23, 'en', 'help_search', 1),
('none', 33, 'en', 'help_search', 3.69535),
('nonenglish', 27, 'en', 'help_search', 1),
('nonerror', 33, 'en', 'help_search', 1),
('nontoplevel', 27, 'en', 'help_search', 1),
('normal', 33, 'en', 'help_search', 1),
('normal', 34, 'en', 'help_search', 2),
('normally', 64, 'en', 'help_search', 1),
('normally', 81, 'en', 'help_search', 2),
('not', 10, 'en', 'help_search', 1),
('not', 11, 'en', 'help_search', 1.85498),
('not', 12, 'en', 'help_search', 2.72283),
('not', 13, 'en', 'help_search', 1.99731),
('not', 14, 'en', 'help_search', 2),
('not', 15, 'en', 'help_search', 1),
('not', 18, 'en', 'help_search', 1.98902),
('not', 23, 'en', 'help_search', 1),
('not', 24, 'en', 'help_search', 1),
('not', 26, 'en', 'help_search', 4),
('not', 28, 'en', 'help_search', 2),
('not', 30, 'en', 'help_search', 2),
('not', 32, 'en', 'help_search', 1),
('not', 33, 'en', 'help_search', 2),
('not', 35, 'en', 'help_search', 1),
('not', 38, 'en', 'help_search', 1),
('not', 39, 'en', 'help_search', 1),
('not', 42, 'en', 'help_search', 1),
('not', 43, 'en', 'help_search', 1),
('not', 45, 'en', 'help_search', 1),
('not', 46, 'en', 'help_search', 1),
('not', 48, 'en', 'help_search', 1),
('not', 50, 'en', 'help_search', 0.957226),
('not', 55, 'en', 'help_search', 2.98902),
('not', 58, 'en', 'help_search', 1),
('not', 62, 'en', 'help_search', 2),
('not', 63, 'en', 'help_search', 1),
('not', 64, 'en', 'help_search', 2),
('not', 65, 'en', 'help_search', 1),
('not', 66, 'en', 'help_search', 1),
('not', 73, 'en', 'help_search', 3),
('not', 82, 'en', 'help_search', 1),
('not', 83, 'en', 'help_search', 2),
('not', 85, 'en', 'help_search', 1),
('note', 5, 'en', 'help_search', 1),
('note', 13, 'en', 'help_search', 1),
('note', 33, 'en', 'help_search', 1),
('note', 37, 'en', 'help_search', 1),
('note', 57, 'en', 'help_search', 1),
('note', 73, 'en', 'help_search', 1),
('note', 77, 'en', 'help_search', 1),
('note', 83, 'en', 'help_search', 1),
('notfound', 33, 'en', 'help_search', 7.78302),
('notice', 55, 'en', 'help_search', 1),
('notify', 40, 'en', 'help_search', 4),
('notifying', 40, 'en', 'help_search', 1),
('now', 11, 'en', 'help_search', 0.792123),
('now', 13, 'en', 'help_search', 1),
('now', 38, 'en', 'help_search', 1),
('now', 61, 'en', 'help_search', 1),
('now', 64, 'en', 'help_search', 1),
('now', 70, 'en', 'help_search', 1),
('number', 12, 'en', 'help_search', 0.896076),
('number', 29, 'en', 'help_search', 6),
('number', 55, 'en', 'help_search', 5),
('number', 61, 'en', 'help_search', 5),
('number', 64, 'en', 'help_search', 5),
('number', 79, 'en', 'help_search', 1),
('numbers', 12, 'en', 'help_search', 2.49176),
('numbers', 23, 'en', 'help_search', 1),
('numerical', 23, 'en', 'help_search', 1),
('occasionally', 19, 'en', 'help_search', 1),
('occur', 23, 'en', 'help_search', 1),
('occur', 33, 'en', 'help_search', 19),
('off', 14, 'en', 'help_search', 1),
('off', 57, 'en', 'help_search', 3),
('offer', 12, 'en', 'help_search', 1.31386),
('offer', 24, 'en', 'help_search', 1),
('official', 46, 'en', 'help_search', 4),
('often', 13, 'en', 'help_search', 1),
('often', 85, 'en', 'help_search', 1),
('older', 69, 'en', 'help_search', 1),
('once', 11, 'en', 'help_search', 0.957226),
('once', 12, 'en', 'help_search', 0.736141),
('once', 13, 'en', 'help_search', 2),
('once', 27, 'en', 'help_search', 1),
('once', 44, 'en', 'help_search', 1),
('one', 3, 'en', 'help_search', 1),
('one', 4, 'en', 'help_search', 1),
('one', 5, 'en', 'help_search', 1),
('one', 8, 'en', 'help_search', 1),
('one', 10, 'en', 'help_search', 1),
('one', 11, 'en', 'help_search', 0.836446),
('one', 12, 'en', 'help_search', 5.15836),
('one', 21, 'en', 'help_search', 1),
('one', 27, 'en', 'help_search', 1),
('one', 28, 'en', 'help_search', 1),
('one', 30, 'en', 'help_search', 0.866793),
('one', 33, 'en', 'help_search', 0.916736),
('one', 35, 'en', 'help_search', 1),
('one', 42, 'en', 'help_search', 1),
('one', 48, 'en', 'help_search', 1),
('one', 51, 'en', 'help_search', 1),
('one', 53, 'en', 'help_search', 3),
('one', 55, 'en', 'help_search', 1),
('one', 58, 'en', 'help_search', 2),
('one', 61, 'en', 'help_search', 1),
('one', 64, 'en', 'help_search', 2),
('one', 65, 'en', 'help_search', 1),
('one', 67, 'en', 'help_search', 1),
('one', 69, 'en', 'help_search', 2),
('one', 71, 'en', 'help_search', 0.848323),
('one', 73, 'en', 'help_search', 1),
('one', 74, 'en', 'help_search', 1),
('one', 79, 'en', 'help_search', 3),
('one', 81, 'en', 'help_search', 1),
('one', 83, 'en', 'help_search', 1),
('onetimeloginurl', 44, 'en', 'help_search', 1),
('online', 18, 'en', 'help_search', 27.765),
('online', 25, 'en', 'help_search', 22),
('online', 30, 'en', 'help_search', 8.59953),
('online', 55, 'en', 'help_search', 9.74705),
('online', 58, 'en', 'help_search', 11),
('only', 11, 'en', 'help_search', 0.754681),
('only', 12, 'en', 'help_search', 0.650439),
('only', 22, 'en', 'help_search', 1),
('only', 26, 'en', 'help_search', 1),
('only', 30, 'en', 'help_search', 1),
('only', 37, 'en', 'help_search', 1),
('only', 43, 'en', 'help_search', 4),
('only', 44, 'en', 'help_search', 1),
('only', 47, 'en', 'help_search', 1),
('only', 50, 'en', 'help_search', 0.876337),
('only', 54, 'en', 'help_search', 0.931053),
('only', 55, 'en', 'help_search', 1),
('only', 59, 'en', 'help_search', 1),
('only', 79, 'en', 'help_search', 1),
('only', 81, 'en', 'help_search', 1),
('open', 20, 'en', 'help_search', 1),
('open', 51, 'en', 'help_search', 1),
('open', 55, 'en', 'help_search', 4.61985),
('open', 57, 'en', 'help_search', 4),
('open', 76, 'en', 'help_search', 1),
('operation', 34, 'en', 'help_search', 1),
('operations', 13, 'en', 'help_search', 2),
('operations', 28, 'en', 'help_search', 4),
('operations', 34, 'en', 'help_search', 2),
('operations', 45, 'en', 'help_search', 4),
('operations', 62, 'en', 'help_search', 4),
('operations', 63, 'en', 'help_search', 4),
('operations', 71, 'en', 'help_search', 17.2639),
('operations', 72, 'en', 'help_search', 4),
('operations', 73, 'en', 'help_search', 8),
('operations', 83, 'en', 'help_search', 40.9822),
('optimizing', 18, 'en', 'help_search', 26),
('option', 12, 'en', 'help_search', 0.661163),
('option', 44, 'en', 'help_search', 0.993146),
('optional', 11, 'en', 'help_search', 4),
('optional', 55, 'en', 'help_search', 3.8289),
('optionally', 7, 'en', 'help_search', 1),
('optionally', 28, 'en', 'help_search', 1),
('optionally', 29, 'en', 'help_search', 1),
('optionally', 34, 'en', 'help_search', 1),
('optionally', 40, 'en', 'help_search', 1),
('optionally', 44, 'en', 'help_search', 0.989021),
('optionally', 47, 'en', 'help_search', 1),
('optionally', 48, 'en', 'help_search', 1),
('optionally', 49, 'en', 'help_search', 1),
('optionally', 52, 'en', 'help_search', 2),
('optionally', 56, 'en', 'help_search', 1),
('optionally', 60, 'en', 'help_search', 1),
('optionally', 61, 'en', 'help_search', 1),
('optionally', 64, 'en', 'help_search', 1),
('optionally', 65, 'en', 'help_search', 1),
('optionally', 66, 'en', 'help_search', 1),
('optionally', 67, 'en', 'help_search', 2),
('optionally', 72, 'en', 'help_search', 1),
('optionally', 73, 'en', 'help_search', 3),
('optionally', 79, 'en', 'help_search', 0.989021),
('optionally', 80, 'en', 'help_search', 3),
('optionally', 82, 'en', 'help_search', 1),
('optionally', 84, 'en', 'help_search', 1),
('options', 12, 'en', 'help_search', 1.4206),
('options', 13, 'en', 'help_search', 19),
('options', 30, 'en', 'help_search', 1),
('options', 33, 'en', 'help_search', 0.913226),
('options', 50, 'en', 'help_search', 0.786915),
('options', 69, 'en', 'help_search', 19),
('options', 72, 'en', 'help_search', 1),
('order', 5, 'en', 'help_search', 1),
('order', 6, 'en', 'help_search', 1),
('order', 19, 'en', 'help_search', 1),
('order', 20, 'en', 'help_search', 2),
('order', 23, 'en', 'help_search', 2),
('order', 26, 'en', 'help_search', 1),
('order', 30, 'en', 'help_search', 0.876337),
('order', 47, 'en', 'help_search', 1),
('order', 50, 'en', 'help_search', 5.02459),
('order', 54, 'en', 'help_search', 0.889397),
('order', 55, 'en', 'help_search', 2),
('order', 57, 'en', 'help_search', 1),
('order', 61, 'en', 'help_search', 1),
('order', 62, 'en', 'help_search', 3),
('order', 63, 'en', 'help_search', 3),
('order', 64, 'en', 'help_search', 1),
('order', 67, 'en', 'help_search', 1),
('order', 70, 'en', 'help_search', 2),
('order', 71, 'en', 'help_search', 2.98087),
('order', 73, 'en', 'help_search', 2),
('order', 75, 'en', 'help_search', 2),
('order', 79, 'en', 'help_search', 0.961087),
('order', 83, 'en', 'help_search', 1),
('order', 85, 'en', 'help_search', 1),
('ordered', 50, 'en', 'help_search', 1),
('ordering', 23, 'en', 'help_search', 1),
('ordering', 47, 'en', 'help_search', 1),
('organize', 81, 'en', 'help_search', 1),
('organized', 53, 'en', 'help_search', 1),
('organizes', 30, 'en', 'help_search', 1),
('original', 18, 'en', 'help_search', 1),
('other', 2, 'en', 'help_search', 1),
('other', 4, 'en', 'help_search', 1),
('other', 5, 'en', 'help_search', 1),
('other', 7, 'en', 'help_search', 1),
('other', 8, 'en', 'help_search', 1),
('other', 10, 'en', 'help_search', 5),
('other', 11, 'en', 'help_search', 0.716357),
('other', 12, 'en', 'help_search', 5.07468),
('other', 16, 'en', 'help_search', 1),
('other', 18, 'en', 'help_search', 2),
('other', 22, 'en', 'help_search', 1),
('other', 23, 'en', 'help_search', 1),
('other', 25, 'en', 'help_search', 5),
('other', 27, 'en', 'help_search', 1),
('other', 30, 'en', 'help_search', 1),
('other', 32, 'en', 'help_search', 1),
('other', 33, 'en', 'help_search', 19.9132),
('other', 36, 'en', 'help_search', 1),
('other', 40, 'en', 'help_search', 1),
('other', 44, 'en', 'help_search', 0.980874),
('other', 48, 'en', 'help_search', 1),
('other', 53, 'en', 'help_search', 2),
('other', 54, 'en', 'help_search', 2),
('other', 59, 'en', 'help_search', 4.88282),
('other', 64, 'en', 'help_search', 4),
('other', 65, 'en', 'help_search', 1),
('other', 67, 'en', 'help_search', 1.98493),
('other', 68, 'en', 'help_search', 3),
('other', 71, 'en', 'help_search', 1),
('other', 78, 'en', 'help_search', 1),
('other', 79, 'en', 'help_search', 1),
('other', 81, 'en', 'help_search', 2),
('other', 82, 'en', 'help_search', 1),
('other', 84, 'en', 'help_search', 1),
('out', 5, 'en', 'help_search', 1),
('out', 8, 'en', 'help_search', 1),
('out', 18, 'en', 'help_search', 0.927431),
('out', 42, 'en', 'help_search', 1),
('out', 53, 'en', 'help_search', 1),
('outline', 60, 'en', 'help_search', 1),
('output', 18, 'en', 'help_search', 1.97685),
('output', 53, 'en', 'help_search', 1),
('output', 54, 'en', 'help_search', 1),
('output', 71, 'en', 'help_search', 5),
('outreach', 46, 'en', 'help_search', 1),
('outside', 13, 'en', 'help_search', 5.99731),
('outside', 17, 'en', 'help_search', 1),
('outside', 81, 'en', 'help_search', 1),
('over', 20, 'en', 'help_search', 1),
('over', 54, 'en', 'help_search', 0.916736),
('over', 60, 'en', 'help_search', 1),
('over', 73, 'en', 'help_search', 1),
('overall', 10, 'en', 'help_search', 0.993146),
('overall', 29, 'en', 'help_search', 0.892724),
('override', 11, 'en', 'help_search', 0.920273),
('override', 47, 'en', 'help_search', 4),
('overview', 10, 'en', 'help_search', 19),
('overview', 11, 'en', 'help_search', 14.1606),
('overview', 12, 'en', 'help_search', 12.0017),
('overview', 14, 'en', 'help_search', 19),
('overview', 15, 'en', 'help_search', 19),
('overview', 16, 'en', 'help_search', 19),
('overview', 17, 'en', 'help_search', 19),
('overview', 21, 'en', 'help_search', 19),
('overview', 22, 'en', 'help_search', 19),
('overview', 23, 'en', 'help_search', 19),
('overview', 24, 'en', 'help_search', 17.7735),
('overview', 30, 'en', 'help_search', 16.7117),
('overview', 42, 'en', 'help_search', 19),
('overview', 46, 'en', 'help_search', 11),
('overview', 48, 'en', 'help_search', 19),
('overview', 53, 'en', 'help_search', 18.6366),
('overview', 58, 'en', 'help_search', 4),
('overview', 59, 'en', 'help_search', 17.2851),
('overview', 61, 'en', 'help_search', 3),
('overview', 65, 'en', 'help_search', 4),
('overview', 67, 'en', 'help_search', 4),
('overview', 68, 'en', 'help_search', 19),
('overview', 70, 'en', 'help_search', 1),
('overview', 71, 'en', 'help_search', 15.2523),
('overview', 78, 'en', 'help_search', 19),
('overview', 81, 'en', 'help_search', 18.1873),
('own', 8, 'en', 'help_search', 1),
('own', 10, 'en', 'help_search', 1),
('own', 11, 'en', 'help_search', 1),
('own', 33, 'en', 'help_search', 1),
('own', 55, 'en', 'help_search', 0.927431),
('own', 59, 'en', 'help_search', 2),
('own', 65, 'en', 'help_search', 1),
('own', 67, 'en', 'help_search', 5),
('own', 68, 'en', 'help_search', 1),
('owned', 11, 'en', 'help_search', 0.938382),
('owners', 46, 'en', 'help_search', 2),
('page', 3, 'en', 'help_search', 1),
('page', 5, 'en', 'help_search', 1),
('page', 9, 'en', 'help_search', 11),
('page', 10, 'en', 'help_search', 22),
('page', 12, 'en', 'help_search', 0.585658),
('page', 13, 'en', 'help_search', 1),
('page', 14, 'en', 'help_search', 11),
('page', 18, 'en', 'help_search', 27.055),
('page', 19, 'en', 'help_search', 1),
('page', 20, 'en', 'help_search', 4),
('page', 23, 'en', 'help_search', 1),
('page', 24, 'en', 'help_search', 1),
('page', 26, 'en', 'help_search', 7),
('page', 27, 'en', 'help_search', 5.9522),
('page', 28, 'en', 'help_search', 14),
('page', 29, 'en', 'help_search', 1.82593),
('page', 30, 'en', 'help_search', 10.732),
('page', 31, 'en', 'help_search', 1),
('page', 33, 'en', 'help_search', 8.96587),
('page', 34, 'en', 'help_search', 2),
('page', 35, 'en', 'help_search', 3),
('page', 36, 'en', 'help_search', 3),
('page', 38, 'en', 'help_search', 4),
('page', 40, 'en', 'help_search', 1),
('page', 41, 'en', 'help_search', 1),
('page', 46, 'en', 'help_search', 1),
('page', 48, 'en', 'help_search', 1),
('page', 50, 'en', 'help_search', 1.72506),
('page', 52, 'en', 'help_search', 1),
('page', 55, 'en', 'help_search', 12.918),
('page', 58, 'en', 'help_search', 5),
('page', 60, 'en', 'help_search', 9.93833),
('page', 61, 'en', 'help_search', 3),
('page', 62, 'en', 'help_search', 2),
('page', 63, 'en', 'help_search', 1),
('page', 64, 'en', 'help_search', 3),
('page', 65, 'en', 'help_search', 19),
('page', 66, 'en', 'help_search', 2),
('page', 67, 'en', 'help_search', 15.4874),
('page', 69, 'en', 'help_search', 2),
('page', 70, 'en', 'help_search', 1),
('page', 71, 'en', 'help_search', 7.89608),
('page', 73, 'en', 'help_search', 3),
('page', 74, 'en', 'help_search', 2),
('page', 76, 'en', 'help_search', 3),
('page', 77, 'en', 'help_search', 2),
('page', 78, 'en', 'help_search', 7),
('page', 79, 'en', 'help_search', 4.9496),
('page', 80, 'en', 'help_search', 2),
('page', 82, 'en', 'help_search', 5),
('page', 83, 'en', 'help_search', 1),
('page', 84, 'en', 'help_search', 1),
('pagelevel', 12, 'en', 'help_search', 1),
('pagelevel', 68, 'en', 'help_search', 1),
('pager', 55, 'en', 'help_search', 1),
('pager', 71, 'en', 'help_search', 3.78332),
('pages', 10, 'en', 'help_search', 1),
('pages', 18, 'en', 'help_search', 1.93838),
('pages', 23, 'en', 'help_search', 2),
('pages', 24, 'en', 'help_search', 4),
('pages', 26, 'en', 'help_search', 12),
('pages', 28, 'en', 'help_search', 42),
('pages', 29, 'en', 'help_search', 11.2782),
('pages', 30, 'en', 'help_search', 29.6242),
('pages', 33, 'en', 'help_search', 34),
('pages', 38, 'en', 'help_search', 4),
('pages', 60, 'en', 'help_search', 1),
('pages', 68, 'en', 'help_search', 1),
('pages', 78, 'en', 'help_search', 2),
('pages', 79, 'en', 'help_search', 2),
('pages', 81, 'en', 'help_search', 1.94177),
('paginate', 71, 'en', 'help_search', 0.938382),
('paragraph', 50, 'en', 'help_search', 1),
('parent', 72, 'en', 'help_search', 4),
('parent', 73, 'en', 'help_search', 4),
('part', 14, 'en', 'help_search', 1),
('part', 19, 'en', 'help_search', 1),
('part', 20, 'en', 'help_search', 1),
('part', 38, 'en', 'help_search', 1),
('part', 45, 'en', 'help_search', 1),
('part', 70, 'en', 'help_search', 1),
('part', 78, 'en', 'help_search', 1),
('particular', 20, 'en', 'help_search', 1),
('particular', 30, 'en', 'help_search', 2),
('particular', 42, 'en', 'help_search', 3),
('particular', 43, 'en', 'help_search', 1),
('particular', 50, 'en', 'help_search', 0.824901),
('particular', 55, 'en', 'help_search', 1),
('particular', 57, 'en', 'help_search', 1),
('particular', 58, 'en', 'help_search', 1),
('particular', 61, 'en', 'help_search', 1),
('particular', 62, 'en', 'help_search', 1),
('particular', 63, 'en', 'help_search', 1),
('particular', 64, 'en', 'help_search', 1),
('particular', 71, 'en', 'help_search', 1),
('particular', 78, 'en', 'help_search', 1),
('parts', 18, 'en', 'help_search', 1.84779),
('pass', 59, 'en', 'help_search', 0.949597),
('password', 25, 'en', 'help_search', 1),
('password', 40, 'en', 'help_search', 4),
('password', 44, 'en', 'help_search', 2),
('past', 37, 'en', 'help_search', 1),
('past', 55, 'en', 'help_search', 1.79901),
('past', 57, 'en', 'help_search', 2),
('paste', 2, 'en', 'help_search', 1),
('paste', 4, 'en', 'help_search', 5),
('path', 11, 'en', 'help_search', 0.718502),
('path', 12, 'en', 'help_search', 0.594307),
('path', 28, 'en', 'help_search', 4),
('path', 73, 'en', 'help_search', 1),
('path', 77, 'en', 'help_search', 2),
('path', 78, 'en', 'help_search', 26),
('pathauto', 78, 'en', 'help_search', 11),
('paths', 78, 'en', 'help_search', 31),
('patterns', 32, 'en', 'help_search', 4),
('paying', 43, 'en', 'help_search', 1),
('pencil', 20, 'en', 'help_search', 1),
('pencil', 60, 'en', 'help_search', 1),
('pending', 44, 'en', 'help_search', 1),
('people', 6, 'en', 'help_search', 8),
('people', 24, 'en', 'help_search', 3.68109),
('people', 40, 'en', 'help_search', 4),
('people', 41, 'en', 'help_search', 4),
('people', 43, 'en', 'help_search', 4),
('people', 44, 'en', 'help_search', 4),
('people', 45, 'en', 'help_search', 4),
('people', 55, 'en', 'help_search', 1),
('people', 59, 'en', 'help_search', 0.882818),
('people', 83, 'en', 'help_search', 1),
('per', 29, 'en', 'help_search', 4),
('per', 55, 'en', 'help_search', 4),
('per', 61, 'en', 'help_search', 1),
('per', 64, 'en', 'help_search', 1),
('perform', 24, 'en', 'help_search', 1),
('perform', 29, 'en', 'help_search', 1),
('perform', 34, 'en', 'help_search', 2),
('perform', 42, 'en', 'help_search', 1),
('perform', 83, 'en', 'help_search', 1),
('performance', 18, 'en', 'help_search', 70.3599),
('performance', 31, 'en', 'help_search', 4),
('performing', 14, 'en', 'help_search', 1),
('performing', 15, 'en', 'help_search', 1),
('performing', 30, 'en', 'help_search', 0.886095),
('periodically', 13, 'en', 'help_search', 3),
('periodically', 15, 'en', 'help_search', 1),
('periods', 12, 'en', 'help_search', 0.851346),
('permanent', 28, 'en', 'help_search', 1),
('permission', 20, 'en', 'help_search', 2),
('permission', 27, 'en', 'help_search', 0.968904),
('permission', 30, 'en', 'help_search', 4.55671),
('permission', 34, 'en', 'help_search', 1),
('permission', 42, 'en', 'help_search', 23),
('permission', 43, 'en', 'help_search', 5),
('permission', 44, 'en', 'help_search', 1),
('permission', 46, 'en', 'help_search', 1),
('permission', 55, 'en', 'help_search', 4),
('permission', 56, 'en', 'help_search', 1),
('permission', 57, 'en', 'help_search', 2),
('permission', 58, 'en', 'help_search', 2),
('permission', 60, 'en', 'help_search', 3),
('permission', 65, 'en', 'help_search', 5),
('permission', 66, 'en', 'help_search', 1),
('permission', 67, 'en', 'help_search', 5),
('permission', 68, 'en', 'help_search', 1),
('permission', 71, 'en', 'help_search', 1.85135),
('permission', 76, 'en', 'help_search', 2),
('permission', 77, 'en', 'help_search', 1),
('permission', 79, 'en', 'help_search', 5),
('permission', 80, 'en', 'help_search', 2),
('permission', 83, 'en', 'help_search', 2.99731),
('permissions', 6, 'en', 'help_search', 9),
('permissions', 8, 'en', 'help_search', 1),
('permissions', 19, 'en', 'help_search', 11),
('permissions', 24, 'en', 'help_search', 1.90974),
('permissions', 27, 'en', 'help_search', 0.972861),
('permissions', 30, 'en', 'help_search', 19.4502),
('permissions', 42, 'en', 'help_search', 1),
('permissions', 43, 'en', 'help_search', 39),
('permissions', 50, 'en', 'help_search', 1),
('permissions', 59, 'en', 'help_search', 1.90974),
('permissions', 65, 'en', 'help_search', 1),
('permissions', 67, 'en', 'help_search', 1),
('permissions', 83, 'en', 'help_search', 1),
('personal', 5, 'en', 'help_search', 2),
('personal', 6, 'en', 'help_search', 32),
('personal', 8, 'en', 'help_search', 24),
('personalized', 18, 'en', 'help_search', 0.920273),
('php', 14, 'en', 'help_search', 1),
('php', 32, 'en', 'help_search', 12),
('php', 33, 'en', 'help_search', 1),
('physical', 53, 'en', 'help_search', 1),
('piece', 59, 'en', 'help_search', 1),
('piece', 78, 'en', 'help_search', 1),
('pieces', 10, 'en', 'help_search', 1),
('pipe', 18, 'en', 'help_search', 0.945829),
('pixel', 53, 'en', 'help_search', 12),
('place', 20, 'en', 'help_search', 22),
('place', 24, 'en', 'help_search', 0.997306),
('place', 26, 'en', 'help_search', 1),
('place', 30, 'en', 'help_search', 0.813674),
('place', 48, 'en', 'help_search', 1),
('place', 49, 'en', 'help_search', 11),
('placed', 3, 'en', 'help_search', 1),
('placed', 24, 'en', 'help_search', 1),
('placed', 47, 'en', 'help_search', 1),
('placed', 48, 'en', 'help_search', 3),
('placed', 51, 'en', 'help_search', 1),
('placed', 60, 'en', 'help_search', 1),
('placeholders', 18, 'en', 'help_search', 1.87723),
('placing', 10, 'en', 'help_search', 1),
('placing', 17, 'en', 'help_search', 1),
('placing', 49, 'en', 'help_search', 26),
('plain', 12, 'en', 'help_search', 7.98578),
('plain', 50, 'en', 'help_search', 1.86995),
('plain', 73, 'en', 'help_search', 1),
('plaintext', 2, 'en', 'help_search', 1),
('planning', 12, 'en', 'help_search', 6.33474),
('plugin', 27, 'en', 'help_search', 2),
('plugin', 54, 'en', 'help_search', 3.44219),
('pluginbased', 27, 'en', 'help_search', 1),
('plugins', 27, 'en', 'help_search', 2),
('point', 53, 'en', 'help_search', 1),
('point', 70, 'en', 'help_search', 1),
('policy', 19, 'en', 'help_search', 13),
('policy', 46, 'en', 'help_search', 1),
('pop', 49, 'en', 'help_search', 2),
('popup', 82, 'en', 'help_search', 1),
('porter', 30, 'en', 'help_search', 10.8342),
('position', 62, 'en', 'help_search', 1),
('positions', 47, 'en', 'help_search', 1),
('possibility', 29, 'en', 'help_search', 1),
('possible', 12, 'en', 'help_search', 1.35049),
('possible', 37, 'en', 'help_search', 1),
('possible', 44, 'en', 'help_search', 1),
('possible', 53, 'en', 'help_search', 1),
('possible', 59, 'en', 'help_search', 0.920273),
('post', 55, 'en', 'help_search', 1),
('post', 81, 'en', 'help_search', 1),
('posted', 59, 'en', 'help_search', 3),
('posting', 59, 'en', 'help_search', 0.899454),
('posts', 16, 'en', 'help_search', 1),
('posts', 59, 'en', 'help_search', 1),
('posts', 81, 'en', 'help_search', 1),
('potentiallydangerous', 50, 'en', 'help_search', 1),
('practice', 23, 'en', 'help_search', 2),
('practices', 23, 'en', 'help_search', 0.993146),
('predefined', 12, 'en', 'help_search', 1.60616),
('predefined', 68, 'en', 'help_search', 1),
('prefer', 33, 'en', 'help_search', 1),
('preferred', 62, 'en', 'help_search', 1),
('preferred', 63, 'en', 'help_search', 1),
('preindex', 29, 'en', 'help_search', 1),
('presents', 23, 'en', 'help_search', 1),
('prevent', 59, 'en', 'help_search', 1),
('preventing', 15, 'en', 'help_search', 11),
('preview', 55, 'en', 'help_search', 3.89144),
('preview', 65, 'en', 'help_search', 5),
('preview', 85, 'en', 'help_search', 4),
('previewing', 55, 'en', 'help_search', 0.968904),
('previous', 12, 'en', 'help_search', 0.62674),
('previous', 32, 'en', 'help_search', 1),
('previous', 70, 'en', 'help_search', 1),
('previously', 3, 'en', 'help_search', 1),
('previously', 4, 'en', 'help_search', 1),
('previously', 39, 'en', 'help_search', 1),
('previously', 47, 'en', 'help_search', 1),
('previouslyplaced', 47, 'en', 'help_search', 26),
('previouslyplaced', 49, 'en', 'help_search', 1),
('printers', 53, 'en', 'help_search', 1),
('problem', 15, 'en', 'help_search', 1),
('problem', 19, 'en', 'help_search', 1),
('problem', 31, 'en', 'help_search', 1),
('problems', 15, 'en', 'help_search', 13),
('problems', 83, 'en', 'help_search', 0.993146),
('process', 11, 'en', 'help_search', 1.91323),
('process', 19, 'en', 'help_search', 11),
('process', 25, 'en', 'help_search', 2),
('process', 29, 'en', 'help_search', 1),
('process', 70, 'en', 'help_search', 1),
('processed', 12, 'en', 'help_search', 0.72066),
('processed', 50, 'en', 'help_search', 1),
('processing', 16, 'en', 'help_search', 1),
('processing', 50, 'en', 'help_search', 4.35754),
('production', 14, 'en', 'help_search', 1),
('production', 33, 'en', 'help_search', 0.931053),
('profile', 8, 'en', 'help_search', 2),
('profile', 11, 'en', 'help_search', 1),
('profile', 12, 'en', 'help_search', 1),
('profile', 22, 'en', 'help_search', 1),
('profile', 78, 'en', 'help_search', 1),
('profile', 79, 'en', 'help_search', 1),
('profiles', 6, 'en', 'help_search', 2),
('profiles', 30, 'en', 'help_search', 1),
('profiles', 68, 'en', 'help_search', 1),
('programs', 46, 'en', 'help_search', 1),
('progress', 29, 'en', 'help_search', 7.0238),
('project', 19, 'en', 'help_search', 2),
('project', 27, 'en', 'help_search', 1),
('project', 46, 'en', 'help_search', 3),
('projects', 19, 'en', 'help_search', 1),
('promote', 46, 'en', 'help_search', 1),
('provide', 11, 'en', 'help_search', 1.38922),
('provide', 12, 'en', 'help_search', 1.20063),
('provide', 16, 'en', 'help_search', 2),
('provide', 24, 'en', 'help_search', 1),
('provide', 25, 'en', 'help_search', 22),
('provide', 27, 'en', 'help_search', 1),
('provide', 29, 'en', 'help_search', 0.98493),
('provide', 30, 'en', 'help_search', 22),
('provide', 46, 'en', 'help_search', 1),
('provide', 53, 'en', 'help_search', 1),
('provide', 54, 'en', 'help_search', 1.84832),
('provide', 59, 'en', 'help_search', 0.972861),
('provide', 68, 'en', 'help_search', 2),
('provide', 78, 'en', 'help_search', 1),
('provided', 8, 'en', 'help_search', 1),
('provided', 11, 'en', 'help_search', 1.73165),
('provided', 12, 'en', 'help_search', 4.30399),
('provided', 17, 'en', 'help_search', 2),
('provided', 22, 'en', 'help_search', 5),
('provided', 24, 'en', 'help_search', 2),
('provided', 27, 'en', 'help_search', 25.989),
('provided', 29, 'en', 'help_search', 1),
('provided', 30, 'en', 'help_search', 1),
('provided', 48, 'en', 'help_search', 1),
('provided', 50, 'en', 'help_search', 1),
('provided', 53, 'en', 'help_search', 0.957226),
('provided', 55, 'en', 'help_search', 1),
('provides', 10, 'en', 'help_search', 1),
('provides', 11, 'en', 'help_search', 1),
('provides', 12, 'en', 'help_search', 1.20498),
('provides', 16, 'en', 'help_search', 3.99731),
('provides', 17, 'en', 'help_search', 3),
('provides', 20, 'en', 'help_search', 1),
('provides', 21, 'en', 'help_search', 1),
('provides', 22, 'en', 'help_search', 2),
('provides', 24, 'en', 'help_search', 1),
('provides', 25, 'en', 'help_search', 2),
('provides', 30, 'en', 'help_search', 1),
('provides', 33, 'en', 'help_search', 1),
('provides', 47, 'en', 'help_search', 1),
('provides', 54, 'en', 'help_search', 3),
('provides', 59, 'en', 'help_search', 2.90286),
('provides', 78, 'en', 'help_search', 1),
('provides', 81, 'en', 'help_search', 0.934703),
('providing', 11, 'en', 'help_search', 2),
('public', 19, 'en', 'help_search', 1),
('publish', 58, 'en', 'help_search', 5),
('publish', 65, 'en', 'help_search', 2),
('publish', 67, 'en', 'help_search', 4.97258),
('published', 30, 'en', 'help_search', 3.61143),
('published', 59, 'en', 'help_search', 1),
('published', 65, 'en', 'help_search', 4),
('published', 67, 'en', 'help_search', 4),
('published', 71, 'en', 'help_search', 1),
('publishes', 59, 'en', 'help_search', 0.989021),
('publishing', 71, 'en', 'help_search', 0.822065),
('pull', 71, 'en', 'help_search', 0.892724),
('purpose', 46, 'en', 'help_search', 1),
('purposes', 11, 'en', 'help_search', 0.961087),
('purposes', 12, 'en', 'help_search', 1),
('purposes', 53, 'en', 'help_search', 0.993146),
('purposes', 59, 'en', 'help_search', 1),
('put', 15, 'en', 'help_search', 1),
('put', 23, 'en', 'help_search', 1),
('put', 34, 'en', 'help_search', 9),
('put', 72, 'en', 'help_search', 1),
('putting', 27, 'en', 'help_search', 1),
('queries', 29, 'en', 'help_search', 1),
('queries', 53, 'en', 'help_search', 31.2416),
('query', 53, 'en', 'help_search', 1),
('quick', 20, 'en', 'help_search', 49),
('quick', 24, 'en', 'help_search', 5),
('quick', 60, 'en', 'help_search', 1),
('quick', 79, 'en', 'help_search', 1),
('quickly', 18, 'en', 'help_search', 1.89945),
('quickly', 20, 'en', 'help_search', 1),
('radio', 12, 'en', 'help_search', 2.55346),
('ran', 12, 'en', 'help_search', 1),
('range', 12, 'en', 'help_search', 1.70574),
('ranging', 13, 'en', 'help_search', 1),
('ranking', 28, 'en', 'help_search', 5),
('rather', 34, 'en', 'help_search', 1),
('ratio', 53, 'en', 'help_search', 1),
('reach', 54, 'en', 'help_search', 0.989021),
('read', 11, 'en', 'help_search', 0.71),
('read', 62, 'en', 'help_search', 1),
('readers', 23, 'en', 'help_search', 1),
('readers', 62, 'en', 'help_search', 1),
('ready', 74, 'en', 'help_search', 1),
('really', 53, 'en', 'help_search', 1),
('rearrange', 5, 'en', 'help_search', 1),
('rearrange', 85, 'en', 'help_search', 4),
('reasons', 36, 'en', 'help_search', 2),
('rebuild', 26, 'en', 'help_search', 4),
('recalculated', 18, 'en', 'help_search', 1),
('recalculation', 18, 'en', 'help_search', 1),
('receive', 40, 'en', 'help_search', 1),
('receive', 80, 'en', 'help_search', 1),
('recent', 37, 'en', 'help_search', 4),
('recent', 71, 'en', 'help_search', 1),
('recently', 21, 'en', 'help_search', 1),
('recently', 69, 'en', 'help_search', 1),
('recipe', 81, 'en', 'help_search', 3),
('recipes', 59, 'en', 'help_search', 1),
('recipes', 68, 'en', 'help_search', 1),
('recipes', 81, 'en', 'help_search', 1),
('recipient', 8, 'en', 'help_search', 1),
('recipients', 7, 'en', 'help_search', 4),
('recipients', 8, 'en', 'help_search', 1),
('recommended', 13, 'en', 'help_search', 1),
('recommended', 14, 'en', 'help_search', 1),
('recommended', 16, 'en', 'help_search', 1),
('records', 69, 'en', 'help_search', 1),
('red', 81, 'en', 'help_search', 1),
('redirected', 3, 'en', 'help_search', 1),
('reduce', 29, 'en', 'help_search', 1),
('reduce', 67, 'en', 'help_search', 1),
('reference', 12, 'en', 'help_search', 32.2871),
('reference', 16, 'en', 'help_search', 5),
('reference', 32, 'en', 'help_search', 11),
('reference', 59, 'en', 'help_search', 0.886095),
('reference', 64, 'en', 'help_search', 45),
('reference', 80, 'en', 'help_search', 7),
('reference', 81, 'en', 'help_search', 3.92027),
('referenced', 16, 'en', 'help_search', 1),
('referenced', 64, 'en', 'help_search', 1),
('references', 12, 'en', 'help_search', 0.802752),
('refers', 18, 'en', 'help_search', 1),
('refine', 62, 'en', 'help_search', 1),
('refine', 63, 'en', 'help_search', 1),
('region', 17, 'en', 'help_search', 1),
('region', 26, 'en', 'help_search', 2),
('region', 32, 'en', 'help_search', 8),
('region', 47, 'en', 'help_search', 9),
('region', 48, 'en', 'help_search', 2),
('region', 49, 'en', 'help_search', 3),
('regional', 32, 'en', 'help_search', 4),
('regions', 47, 'en', 'help_search', 5),
('regions', 48, 'en', 'help_search', 1),
('regions', 49, 'en', 'help_search', 5),
('register', 10, 'en', 'help_search', 1),
('register', 42, 'en', 'help_search', 1),
('register', 44, 'en', 'help_search', 2),
('registered', 6, 'en', 'help_search', 1),
('registered', 8, 'en', 'help_search', 1),
('registered', 71, 'en', 'help_search', 1),
('regular', 71, 'en', 'help_search', 0.920273),
('regular', 81, 'en', 'help_search', 1.99731),
('regularlength', 12, 'en', 'help_search', 0.705825),
('reindex', 29, 'en', 'help_search', 3.78332),
('reindexed', 26, 'en', 'help_search', 1),
('related', 8, 'en', 'help_search', 1),
('related', 10, 'en', 'help_search', 0.961087),
('related', 11, 'en', 'help_search', 1.50606),
('related', 12, 'en', 'help_search', 2.87785),
('related', 14, 'en', 'help_search', 2),
('related', 15, 'en', 'help_search', 2),
('related', 16, 'en', 'help_search', 0.980874),
('related', 17, 'en', 'help_search', 1),
('related', 19, 'en', 'help_search', 1),
('related', 21, 'en', 'help_search', 1),
('related', 22, 'en', 'help_search', 1),
('related', 23, 'en', 'help_search', 1),
('related', 24, 'en', 'help_search', 1.86679),
('related', 26, 'en', 'help_search', 1),
('related', 27, 'en', 'help_search', 2.9534),
('related', 30, 'en', 'help_search', 0.797402),
('related', 42, 'en', 'help_search', 2),
('related', 44, 'en', 'help_search', 20.9849),
('related', 46, 'en', 'help_search', 4),
('related', 48, 'en', 'help_search', 1),
('related', 50, 'en', 'help_search', 0.854391),
('related', 55, 'en', 'help_search', 1),
('related', 56, 'en', 'help_search', 1),
('related', 59, 'en', 'help_search', 0.866793),
('related', 60, 'en', 'help_search', 2),
('related', 66, 'en', 'help_search', 1),
('related', 68, 'en', 'help_search', 1),
('related', 70, 'en', 'help_search', 1),
('related', 71, 'en', 'help_search', 2.4897),
('related', 74, 'en', 'help_search', 1),
('related', 76, 'en', 'help_search', 1),
('related', 78, 'en', 'help_search', 1),
('related', 80, 'en', 'help_search', 2),
('related', 81, 'en', 'help_search', 0.913226),
('related', 83, 'en', 'help_search', 1),
('related', 84, 'en', 'help_search', 1),
('relationship', 12, 'en', 'help_search', 1.85133),
('relationships', 71, 'en', 'help_search', 3.5843),
('released', 19, 'en', 'help_search', 1),
('releases', 19, 'en', 'help_search', 1),
('releases', 37, 'en', 'help_search', 1),
('relevant', 46, 'en', 'help_search', 1),
('remain', 55, 'en', 'help_search', 0.902857);
INSERT INTO `[[dbprefix]]search_index` VALUES
('remain', 57, 'en', 'help_search', 1),
('remote', 16, 'en', 'help_search', 1),
('remove', 5, 'en', 'help_search', 2),
('remove', 79, 'en', 'help_search', 1.96498),
('removing', 14, 'en', 'help_search', 1),
('render', 18, 'en', 'help_search', 0.906287),
('rendered', 48, 'en', 'help_search', 1),
('rendering', 18, 'en', 'help_search', 1),
('renders', 29, 'en', 'help_search', 1),
('reordering', 17, 'en', 'help_search', 1),
('reordering', 75, 'en', 'help_search', 26),
('repeat', 32, 'en', 'help_search', 1),
('repeat', 40, 'en', 'help_search', 1),
('repeat', 50, 'en', 'help_search', 0.779231),
('repeat', 70, 'en', 'help_search', 1),
('repeat', 79, 'en', 'help_search', 1),
('replacement', 20, 'en', 'help_search', 1),
('replacement', 23, 'en', 'help_search', 1),
('replacement', 60, 'en', 'help_search', 1),
('replacement', 79, 'en', 'help_search', 1),
('replacements', 24, 'en', 'help_search', 1),
('reply', 55, 'en', 'help_search', 10.8746),
('report', 37, 'en', 'help_search', 10),
('reported', 19, 'en', 'help_search', 1),
('reports', 15, 'en', 'help_search', 1),
('reports', 24, 'en', 'help_search', 3.63897),
('reports', 37, 'en', 'help_search', 39),
('reproduced', 11, 'en', 'help_search', 0.863659),
('request', 25, 'en', 'help_search', 1),
('request', 44, 'en', 'help_search', 1),
('requested', 18, 'en', 'help_search', 1.9496),
('requests', 25, 'en', 'help_search', 1),
('require', 54, 'en', 'help_search', 0.863659),
('require', 70, 'en', 'help_search', 1),
('require', 71, 'en', 'help_search', 1),
('required', 23, 'en', 'help_search', 1),
('required', 30, 'en', 'help_search', 0.923838),
('required', 55, 'en', 'help_search', 4.8289),
('required', 61, 'en', 'help_search', 4),
('required', 64, 'en', 'help_search', 4),
('required', 77, 'en', 'help_search', 1),
('requires', 11, 'en', 'help_search', 0.712106),
('requires', 20, 'en', 'help_search', 1),
('requires', 35, 'en', 'help_search', 1),
('requires', 36, 'en', 'help_search', 1),
('requires', 44, 'en', 'help_search', 1),
('requiring', 59, 'en', 'help_search', 0.957226),
('reset', 44, 'en', 'help_search', 2),
('resides', 11, 'en', 'help_search', 1),
('resized', 53, 'en', 'help_search', 1),
('resolution', 53, 'en', 'help_search', 47.9496),
('resource', 78, 'en', 'help_search', 1),
('resources', 10, 'en', 'help_search', 17.8293),
('resources', 11, 'en', 'help_search', 12.9173),
('resources', 12, 'en', 'help_search', 11.0471),
('resources', 13, 'en', 'help_search', 18.4844),
('resources', 14, 'en', 'help_search', 19),
('resources', 15, 'en', 'help_search', 19),
('resources', 16, 'en', 'help_search', 18.1145),
('resources', 17, 'en', 'help_search', 19),
('resources', 18, 'en', 'help_search', 16.1181),
('resources', 19, 'en', 'help_search', 19),
('resources', 25, 'en', 'help_search', 20),
('resources', 27, 'en', 'help_search', 17.8293),
('resources', 30, 'en', 'help_search', 14.9024),
('resources', 31, 'en', 'help_search', 19),
('resources', 32, 'en', 'help_search', 19),
('resources', 37, 'en', 'help_search', 19),
('resources', 46, 'en', 'help_search', 19),
('resources', 48, 'en', 'help_search', 19),
('resources', 53, 'en', 'help_search', 18.0423),
('resources', 55, 'en', 'help_search', 16.8985),
('resources', 58, 'en', 'help_search', 19),
('resources', 65, 'en', 'help_search', 19),
('resources', 66, 'en', 'help_search', 19),
('resources', 67, 'en', 'help_search', 18.2607),
('resources', 71, 'en', 'help_search', 14.8537),
('resources', 76, 'en', 'help_search', 19),
('resources', 78, 'en', 'help_search', 19),
('resources', 80, 'en', 'help_search', 19),
('resources', 81, 'en', 'help_search', 16.8985),
('resources', 85, 'en', 'help_search', 18.4844),
('respective', 54, 'en', 'help_search', 0.845322),
('respectively', 22, 'en', 'help_search', 1),
('respond', 33, 'en', 'help_search', 1),
('respond', 53, 'en', 'help_search', 2),
('response', 18, 'en', 'help_search', 1),
('response', 33, 'en', 'help_search', 5),
('responses', 33, 'en', 'help_search', 48),
('responsive', 12, 'en', 'help_search', 0.595774),
('responsive', 16, 'en', 'help_search', 3.97954),
('responsive', 70, 'en', 'help_search', 1),
('rest', 25, 'en', 'help_search', 11),
('rest', 54, 'en', 'help_search', 0.961087),
('restful', 25, 'en', 'help_search', 23),
('restrict', 50, 'en', 'help_search', 1.86995),
('restrictions', 54, 'en', 'help_search', 1),
('restrictive', 83, 'en', 'help_search', 1),
('restricts', 50, 'en', 'help_search', 1.80818),
('result', 33, 'en', 'help_search', 1),
('result', 71, 'en', 'help_search', 0.953396),
('results', 28, 'en', 'help_search', 1),
('results', 29, 'en', 'help_search', 1),
('results', 30, 'en', 'help_search', 1),
('results', 31, 'en', 'help_search', 1),
('results', 50, 'en', 'help_search', 0.827757),
('results', 71, 'en', 'help_search', 3.84435),
('retrieved', 18, 'en', 'help_search', 1),
('return', 34, 'en', 'help_search', 1),
('return', 50, 'en', 'help_search', 0.781775),
('return', 54, 'en', 'help_search', 1.82026),
('return', 62, 'en', 'help_search', 1),
('return', 63, 'en', 'help_search', 1),
('return', 85, 'en', 'help_search', 1),
('returned', 28, 'en', 'help_search', 1),
('returned', 29, 'en', 'help_search', 0.953396),
('returned', 35, 'en', 'help_search', 1),
('returned', 36, 'en', 'help_search', 1),
('returned', 38, 'en', 'help_search', 1),
('returned', 41, 'en', 'help_search', 1),
('returned', 52, 'en', 'help_search', 1),
('returned', 60, 'en', 'help_search', 0.957226),
('returned', 61, 'en', 'help_search', 1),
('returned', 64, 'en', 'help_search', 1),
('returned', 73, 'en', 'help_search', 1),
('returned', 77, 'en', 'help_search', 1),
('reusing', 16, 'en', 'help_search', 1),
('reverse', 25, 'en', 'help_search', 1),
('reverse', 67, 'en', 'help_search', 1),
('review', 3, 'en', 'help_search', 1),
('review', 43, 'en', 'help_search', 1),
('reviews', 59, 'en', 'help_search', 0.993146),
('right', 13, 'en', 'help_search', 1),
('right', 24, 'en', 'help_search', 1),
('right', 58, 'en', 'help_search', 2),
('right', 60, 'en', 'help_search', 2),
('right', 67, 'en', 'help_search', 1),
('right', 79, 'en', 'help_search', 0.98493),
('right', 81, 'en', 'help_search', 1),
('righttoleft', 20, 'en', 'help_search', 1),
('righttoleft', 24, 'en', 'help_search', 1),
('righttoleft', 58, 'en', 'help_search', 2),
('righttoleft', 60, 'en', 'help_search', 2),
('righttoleft', 67, 'en', 'help_search', 1),
('righttoleft', 79, 'en', 'help_search', 0.972861),
('risk', 50, 'en', 'help_search', 3.44219),
('role', 41, 'en', 'help_search', 38),
('role', 42, 'en', 'help_search', 21),
('role', 43, 'en', 'help_search', 31),
('role', 59, 'en', 'help_search', 0.997306),
('role', 60, 'en', 'help_search', 1),
('role', 71, 'en', 'help_search', 0.997306),
('role', 79, 'en', 'help_search', 1),
('roles', 6, 'en', 'help_search', 1),
('roles', 30, 'en', 'help_search', 1.68779),
('roles', 40, 'en', 'help_search', 4),
('roles', 41, 'en', 'help_search', 8),
('roles', 42, 'en', 'help_search', 7),
('roles', 43, 'en', 'help_search', 4),
('roles', 50, 'en', 'help_search', 3.61143),
('roles', 59, 'en', 'help_search', 1.90974),
('row', 23, 'en', 'help_search', 4),
('row', 32, 'en', 'help_search', 1),
('row', 43, 'en', 'help_search', 1),
('row', 52, 'en', 'help_search', 1),
('row', 62, 'en', 'help_search', 1),
('row', 63, 'en', 'help_search', 1),
('row', 67, 'en', 'help_search', 1),
('row', 83, 'en', 'help_search', 1),
('rows', 23, 'en', 'help_search', 1),
('rss', 71, 'en', 'help_search', 1),
('run', 10, 'en', 'help_search', 1),
('run', 13, 'en', 'help_search', 22.9397),
('run', 26, 'en', 'help_search', 1),
('run', 29, 'en', 'help_search', 4.89945),
('run', 31, 'en', 'help_search', 1),
('run', 37, 'en', 'help_search', 1),
('run', 50, 'en', 'help_search', 0.813674),
('running', 13, 'en', 'help_search', 51),
('running', 26, 'en', 'help_search', 1),
('running', 29, 'en', 'help_search', 1.91323),
('running', 37, 'en', 'help_search', 26),
('runs', 13, 'en', 'help_search', 0.993146),
('runs', 15, 'en', 'help_search', 1),
('runs', 29, 'en', 'help_search', 2),
('runtime', 33, 'en', 'help_search', 1),
('safe', 50, 'en', 'help_search', 0.869951),
('same', 11, 'en', 'help_search', 2.67583),
('same', 12, 'en', 'help_search', 1.89712),
('same', 18, 'en', 'help_search', 1),
('same', 20, 'en', 'help_search', 1),
('same', 35, 'en', 'help_search', 1),
('same', 55, 'en', 'help_search', 4.96161),
('save', 1, 'en', 'help_search', 1),
('save', 2, 'en', 'help_search', 1),
('save', 6, 'en', 'help_search', 8),
('save', 7, 'en', 'help_search', 4),
('save', 9, 'en', 'help_search', 4),
('save', 13, 'en', 'help_search', 3.9235),
('save', 28, 'en', 'help_search', 4),
('save', 29, 'en', 'help_search', 3.85992),
('save', 31, 'en', 'help_search', 1),
('save', 32, 'en', 'help_search', 12),
('save', 33, 'en', 'help_search', 7.45773),
('save', 34, 'en', 'help_search', 8),
('save', 38, 'en', 'help_search', 4),
('save', 41, 'en', 'help_search', 4),
('save', 43, 'en', 'help_search', 4),
('save', 44, 'en', 'help_search', 3.87562),
('save', 45, 'en', 'help_search', 4),
('save', 47, 'en', 'help_search', 8),
('save', 49, 'en', 'help_search', 4),
('save', 50, 'en', 'help_search', 3.13735),
('save', 51, 'en', 'help_search', 4),
('save', 52, 'en', 'help_search', 4),
('save', 54, 'en', 'help_search', 0.833529),
('save', 56, 'en', 'help_search', 4),
('save', 57, 'en', 'help_search', 1),
('save', 60, 'en', 'help_search', 0.976851),
('save', 61, 'en', 'help_search', 13),
('save', 62, 'en', 'help_search', 4),
('save', 63, 'en', 'help_search', 4),
('save', 64, 'en', 'help_search', 13),
('save', 65, 'en', 'help_search', 4),
('save', 66, 'en', 'help_search', 8),
('save', 67, 'en', 'help_search', 4),
('save', 70, 'en', 'help_search', 5),
('save', 72, 'en', 'help_search', 4),
('save', 73, 'en', 'help_search', 8),
('save', 74, 'en', 'help_search', 4),
('save', 75, 'en', 'help_search', 5),
('save', 76, 'en', 'help_search', 4),
('save', 77, 'en', 'help_search', 4),
('save', 80, 'en', 'help_search', 8),
('save', 83, 'en', 'help_search', 3.95608),
('save', 84, 'en', 'help_search', 4),
('save', 85, 'en', 'help_search', 4),
('saved', 32, 'en', 'help_search', 3),
('saved', 33, 'en', 'help_search', 1.84154),
('saved', 44, 'en', 'help_search', 0.949597),
('saves', 18, 'en', 'help_search', 1),
('saving', 18, 'en', 'help_search', 1),
('say', 66, 'en', 'help_search', 1),
('saying', 35, 'en', 'help_search', 1),
('saying', 36, 'en', 'help_search', 1),
('says', 13, 'en', 'help_search', 1),
('scaffolding', 10, 'en', 'help_search', 1),
('scaling', 16, 'en', 'help_search', 1),
('scan', 37, 'en', 'help_search', 1),
('scan', 64, 'en', 'help_search', 1),
('scenes', 12, 'en', 'help_search', 0.757065),
('schedule', 13, 'en', 'help_search', 4.99315),
('screen', 23, 'en', 'help_search', 1),
('screen', 33, 'en', 'help_search', 4),
('screen', 45, 'en', 'help_search', 1),
('screen', 54, 'en', 'help_search', 1),
('screen', 61, 'en', 'help_search', 2),
('screen', 62, 'en', 'help_search', 1),
('screen', 64, 'en', 'help_search', 2),
('screens', 53, 'en', 'help_search', 1),
('screens', 65, 'en', 'help_search', 1),
('screens', 72, 'en', 'help_search', 1),
('scripts', 50, 'en', 'help_search', 0.892724),
('scroll', 28, 'en', 'help_search', 1),
('scroll', 45, 'en', 'help_search', 1),
('search', 26, 'en', 'help_search', 55),
('search', 27, 'en', 'help_search', 28.8536),
('search', 28, 'en', 'help_search', 62),
('search', 29, 'en', 'help_search', 69.082),
('search', 30, 'en', 'help_search', 197.652),
('search', 42, 'en', 'help_search', 1),
('search', 62, 'en', 'help_search', 1),
('search', 77, 'en', 'help_search', 4),
('searchable', 27, 'en', 'help_search', 1),
('searches', 29, 'en', 'help_search', 1),
('searches', 30, 'en', 'help_search', 0.882818),
('searching', 26, 'en', 'help_search', 1),
('searching', 29, 'en', 'help_search', 2.89272),
('searching', 30, 'en', 'help_search', 4.80231),
('second', 30, 'en', 'help_search', 1),
('second', 85, 'en', 'help_search', 1),
('section', 6, 'en', 'help_search', 3),
('section', 12, 'en', 'help_search', 3.02548),
('section', 26, 'en', 'help_search', 1),
('section', 28, 'en', 'help_search', 1),
('section', 29, 'en', 'help_search', 0.869951),
('section', 33, 'en', 'help_search', 1),
('section', 38, 'en', 'help_search', 2),
('section', 39, 'en', 'help_search', 1),
('section', 54, 'en', 'help_search', 0.854391),
('section', 62, 'en', 'help_search', 1),
('section', 63, 'en', 'help_search', 1),
('section', 64, 'en', 'help_search', 2),
('section', 66, 'en', 'help_search', 1),
('section', 83, 'en', 'help_search', 1),
('section', 85, 'en', 'help_search', 1),
('sections', 24, 'en', 'help_search', 20),
('sections', 85, 'en', 'help_search', 2),
('secure', 19, 'en', 'help_search', 28),
('security', 15, 'en', 'help_search', 11),
('security', 19, 'en', 'help_search', 102),
('security', 24, 'en', 'help_search', 0.899454),
('security', 37, 'en', 'help_search', 13),
('security', 43, 'en', 'help_search', 4),
('security', 50, 'en', 'help_search', 5.32828),
('see', 1, 'en', 'help_search', 1),
('see', 2, 'en', 'help_search', 1),
('see', 3, 'en', 'help_search', 2),
('see', 4, 'en', 'help_search', 2),
('see', 7, 'en', 'help_search', 1),
('see', 8, 'en', 'help_search', 2),
('see', 10, 'en', 'help_search', 1.96109),
('see', 11, 'en', 'help_search', 0.691597),
('see', 12, 'en', 'help_search', 3.69525),
('see', 14, 'en', 'help_search', 1),
('see', 15, 'en', 'help_search', 1),
('see', 16, 'en', 'help_search', 1.98087),
('see', 17, 'en', 'help_search', 1),
('see', 19, 'en', 'help_search', 1),
('see', 21, 'en', 'help_search', 1),
('see', 22, 'en', 'help_search', 3),
('see', 24, 'en', 'help_search', 2.86679),
('see', 25, 'en', 'help_search', 1),
('see', 26, 'en', 'help_search', 1),
('see', 27, 'en', 'help_search', 0.957226),
('see', 28, 'en', 'help_search', 1),
('see', 29, 'en', 'help_search', 1),
('see', 30, 'en', 'help_search', 3.64573),
('see', 31, 'en', 'help_search', 1),
('see', 32, 'en', 'help_search', 3),
('see', 33, 'en', 'help_search', 1.85668),
('see', 34, 'en', 'help_search', 2),
('see', 35, 'en', 'help_search', 1),
('see', 36, 'en', 'help_search', 2),
('see', 37, 'en', 'help_search', 4),
('see', 44, 'en', 'help_search', 0.961087),
('see', 46, 'en', 'help_search', 39),
('see', 47, 'en', 'help_search', 1),
('see', 48, 'en', 'help_search', 1),
('see', 49, 'en', 'help_search', 2),
('see', 50, 'en', 'help_search', 0.857458),
('see', 54, 'en', 'help_search', 5),
('see', 55, 'en', 'help_search', 1),
('see', 56, 'en', 'help_search', 2),
('see', 57, 'en', 'help_search', 2),
('see', 59, 'en', 'help_search', 2.78353),
('see', 61, 'en', 'help_search', 2),
('see', 62, 'en', 'help_search', 2),
('see', 63, 'en', 'help_search', 2),
('see', 64, 'en', 'help_search', 1),
('see', 65, 'en', 'help_search', 2),
('see', 66, 'en', 'help_search', 1),
('see', 67, 'en', 'help_search', 1),
('see', 68, 'en', 'help_search', 2),
('see', 70, 'en', 'help_search', 2),
('see', 71, 'en', 'help_search', 2.58117),
('see', 74, 'en', 'help_search', 1),
('see', 76, 'en', 'help_search', 2),
('see', 77, 'en', 'help_search', 1),
('see', 78, 'en', 'help_search', 2),
('see', 80, 'en', 'help_search', 3),
('see', 81, 'en', 'help_search', 1.91323),
('see', 83, 'en', 'help_search', 2),
('see', 85, 'en', 'help_search', 1),
('seen', 21, 'en', 'help_search', 1),
('sees', 12, 'en', 'help_search', 0.779231),
('select', 2, 'en', 'help_search', 2),
('select', 4, 'en', 'help_search', 1),
('select', 12, 'en', 'help_search', 2.56025),
('select', 13, 'en', 'help_search', 0.997306),
('select', 28, 'en', 'help_search', 2),
('select', 29, 'en', 'help_search', 1),
('select', 32, 'en', 'help_search', 1),
('select', 33, 'en', 'help_search', 1.84417),
('select', 38, 'en', 'help_search', 1),
('select', 44, 'en', 'help_search', 1.99731),
('select', 45, 'en', 'help_search', 1),
('select', 54, 'en', 'help_search', 0.972861),
('select', 56, 'en', 'help_search', 1),
('select', 57, 'en', 'help_search', 1),
('select', 58, 'en', 'help_search', 7),
('select', 61, 'en', 'help_search', 1),
('select', 62, 'en', 'help_search', 2),
('select', 63, 'en', 'help_search', 1),
('select', 64, 'en', 'help_search', 3),
('select', 67, 'en', 'help_search', 2.99315),
('select', 71, 'en', 'help_search', 0.851346),
('select', 72, 'en', 'help_search', 1),
('select', 73, 'en', 'help_search', 2),
('select', 79, 'en', 'help_search', 6),
('select', 81, 'en', 'help_search', 1),
('select', 84, 'en', 'help_search', 2),
('selected', 38, 'en', 'help_search', 1),
('selected', 54, 'en', 'help_search', 0.953396),
('selected', 55, 'en', 'help_search', 0.989021),
('selected', 58, 'en', 'help_search', 8),
('selected', 67, 'en', 'help_search', 3.97258),
('selected', 83, 'en', 'help_search', 4),
('selecting', 62, 'en', 'help_search', 1),
('selecting', 63, 'en', 'help_search', 1),
('selects', 54, 'en', 'help_search', 1),
('send', 18, 'en', 'help_search', 0.98493),
('sending', 25, 'en', 'help_search', 1),
('sends', 33, 'en', 'help_search', 1),
('sent', 18, 'en', 'help_search', 1.86581),
('sent', 44, 'en', 'help_search', 1),
('seofriendly', 76, 'en', 'help_search', 1),
('separate', 53, 'en', 'help_search', 1),
('separately', 10, 'en', 'help_search', 1),
('separately', 14, 'en', 'help_search', 1),
('separates', 53, 'en', 'help_search', 1),
('sequence', 50, 'en', 'help_search', 1),
('serialization', 11, 'en', 'help_search', 0.98493),
('serialization', 25, 'en', 'help_search', 24),
('serialized', 25, 'en', 'help_search', 1),
('serve', 16, 'en', 'help_search', 0.98493),
('serve', 46, 'en', 'help_search', 1),
('server', 13, 'en', 'help_search', 2),
('server', 33, 'en', 'help_search', 1),
('servers', 13, 'en', 'help_search', 1),
('service', 25, 'en', 'help_search', 20),
('services', 25, 'en', 'help_search', 72),
('serving', 16, 'en', 'help_search', 1),
('session', 12, 'en', 'help_search', 4),
('set', 9, 'en', 'help_search', 1),
('set', 10, 'en', 'help_search', 1),
('set', 11, 'en', 'help_search', 2.3646),
('set', 13, 'en', 'help_search', 2),
('set', 14, 'en', 'help_search', 2),
('set', 16, 'en', 'help_search', 1),
('set', 24, 'en', 'help_search', 0.98493),
('set', 26, 'en', 'help_search', 1),
('set', 28, 'en', 'help_search', 4),
('set', 33, 'en', 'help_search', 1),
('set', 38, 'en', 'help_search', 4),
('set', 50, 'en', 'help_search', 0.866793),
('set', 55, 'en', 'help_search', 0.916736),
('set', 56, 'en', 'help_search', 1),
('set', 59, 'en', 'help_search', 2),
('set', 61, 'en', 'help_search', 2),
('set', 64, 'en', 'help_search', 2),
('set', 66, 'en', 'help_search', 1),
('set', 68, 'en', 'help_search', 1),
('set', 78, 'en', 'help_search', 1),
('set', 79, 'en', 'help_search', 20),
('set', 81, 'en', 'help_search', 5.98087),
('sets', 79, 'en', 'help_search', 5),
('setting', 8, 'en', 'help_search', 1),
('setting', 9, 'en', 'help_search', 26),
('setting', 12, 'en', 'help_search', 0.733888),
('setting', 18, 'en', 'help_search', 0.863659),
('setting', 38, 'en', 'help_search', 26),
('setting', 57, 'en', 'help_search', 1),
('setting', 66, 'en', 'help_search', 11),
('setting', 71, 'en', 'help_search', 1),
('setting', 80, 'en', 'help_search', 11),
('setting', 85, 'en', 'help_search', 1),
('settings', 6, 'en', 'help_search', 8),
('settings', 7, 'en', 'help_search', 1),
('settings', 11, 'en', 'help_search', 6.6956),
('settings', 12, 'en', 'help_search', 16.9432),
('settings', 13, 'en', 'help_search', 3.95608),
('settings', 18, 'en', 'help_search', 0.892724),
('settings', 20, 'en', 'help_search', 54),
('settings', 22, 'en', 'help_search', 1),
('settings', 24, 'en', 'help_search', 2.92743),
('settings', 29, 'en', 'help_search', 7.93972),
('settings', 32, 'en', 'help_search', 37),
('settings', 33, 'en', 'help_search', 5.84528),
('settings', 40, 'en', 'help_search', 1),
('settings', 42, 'en', 'help_search', 1),
('settings', 44, 'en', 'help_search', 26.9276),
('settings', 47, 'en', 'help_search', 4),
('settings', 48, 'en', 'help_search', 1),
('settings', 50, 'en', 'help_search', 3.99239),
('settings', 54, 'en', 'help_search', 3.42983),
('settings', 55, 'en', 'help_search', 20.4185),
('settings', 56, 'en', 'help_search', 4),
('settings', 57, 'en', 'help_search', 9),
('settings', 58, 'en', 'help_search', 4),
('settings', 59, 'en', 'help_search', 1),
('settings', 60, 'en', 'help_search', 0.972861),
('settings', 61, 'en', 'help_search', 9),
('settings', 62, 'en', 'help_search', 3),
('settings', 63, 'en', 'help_search', 3),
('settings', 64, 'en', 'help_search', 9),
('settings', 66, 'en', 'help_search', 1),
('settings', 68, 'en', 'help_search', 1),
('settings', 71, 'en', 'help_search', 10),
('settings', 72, 'en', 'help_search', 30),
('settings', 73, 'en', 'help_search', 1),
('settings', 80, 'en', 'help_search', 1),
('settings', 82, 'en', 'help_search', 2),
('settings', 83, 'en', 'help_search', 2),
('settings', 84, 'en', 'help_search', 5),
('settings', 85, 'en', 'help_search', 14),
('settingsphp', 11, 'en', 'help_search', 5.90181),
('several', 10, 'en', 'help_search', 1),
('several', 11, 'en', 'help_search', 0.96498),
('several', 12, 'en', 'help_search', 2.16248),
('several', 15, 'en', 'help_search', 1),
('several', 29, 'en', 'help_search', 1.89945),
('several', 67, 'en', 'help_search', 1),
('severity', 37, 'en', 'help_search', 4),
('share', 11, 'en', 'help_search', 0.839384),
('shared', 79, 'en', 'help_search', 2),
('shield', 19, 'en', 'help_search', 1),
('shift', 53, 'en', 'help_search', 1),
('short', 32, 'en', 'help_search', 1),
('short', 44, 'en', 'help_search', 1),
('short', 45, 'en', 'help_search', 1),
('shortcut', 79, 'en', 'help_search', 54.9341),
('shortcuts', 24, 'en', 'help_search', 1),
('shortcuts', 79, 'en', 'help_search', 47.937),
('should', 7, 'en', 'help_search', 1),
('should', 10, 'en', 'help_search', 1),
('should', 13, 'en', 'help_search', 2),
('should', 20, 'en', 'help_search', 2),
('should', 26, 'en', 'help_search', 1),
('should', 29, 'en', 'help_search', 0.957226),
('should', 32, 'en', 'help_search', 3),
('should', 33, 'en', 'help_search', 1.86054),
('should', 35, 'en', 'help_search', 1),
('should', 36, 'en', 'help_search', 2),
('should', 37, 'en', 'help_search', 1),
('should', 38, 'en', 'help_search', 2),
('should', 41, 'en', 'help_search', 2),
('should', 43, 'en', 'help_search', 2),
('should', 44, 'en', 'help_search', 0.96498),
('should', 45, 'en', 'help_search', 1),
('should', 47, 'en', 'help_search', 1),
('should', 50, 'en', 'help_search', 1.69324),
('should', 53, 'en', 'help_search', 3),
('should', 60, 'en', 'help_search', 0.961087),
('should', 61, 'en', 'help_search', 2),
('should', 64, 'en', 'help_search', 2),
('should', 73, 'en', 'help_search', 1),
('show', 21, 'en', 'help_search', 1),
('show', 23, 'en', 'help_search', 4),
('show', 54, 'en', 'help_search', 1),
('show', 55, 'en', 'help_search', 4),
('show', 65, 'en', 'help_search', 1),
('show', 73, 'en', 'help_search', 5),
('show', 84, 'en', 'help_search', 4),
('showing', 12, 'en', 'help_search', 0.659351),
('showing', 71, 'en', 'help_search', 1),
('shown', 8, 'en', 'help_search', 1),
('shown', 27, 'en', 'help_search', 0.98493),
('shown', 29, 'en', 'help_search', 0.876337),
('shown', 45, 'en', 'help_search', 1),
('shown', 48, 'en', 'help_search', 2),
('shown', 50, 'en', 'help_search', 1),
('shown', 51, 'en', 'help_search', 1),
('shown', 52, 'en', 'help_search', 1),
('shown', 54, 'en', 'help_search', 1.92384),
('shown', 58, 'en', 'help_search', 2),
('shown', 64, 'en', 'help_search', 1),
('shown', 65, 'en', 'help_search', 2),
('shown', 67, 'en', 'help_search', 1),
('shown', 72, 'en', 'help_search', 1),
('shown', 73, 'en', 'help_search', 1),
('shown', 80, 'en', 'help_search', 1),
('shown', 82, 'en', 'help_search', 1),
('shown', 83, 'en', 'help_search', 1),
('shown', 85, 'en', 'help_search', 1),
('shows', 12, 'en', 'help_search', 0.771698),
('shows', 54, 'en', 'help_search', 1),
('shows', 64, 'en', 'help_search', 1),
('shows', 85, 'en', 'help_search', 1),
('side', 24, 'en', 'help_search', 2),
('side', 58, 'en', 'help_search', 4),
('similar', 11, 'en', 'help_search', 1),
('similar', 67, 'en', 'help_search', 0.972861),
('similar', 76, 'en', 'help_search', 1),
('similar', 82, 'en', 'help_search', 2),
('simple', 11, 'en', 'help_search', 4),
('simple', 29, 'en', 'help_search', 3.98922),
('simple', 34, 'en', 'help_search', 1),
('since', 69, 'en', 'help_search', 1),
('single', 2, 'en', 'help_search', 31),
('single', 4, 'en', 'help_search', 32),
('single', 59, 'en', 'help_search', 1),
('single', 71, 'en', 'help_search', 1),
('singleitem', 11, 'en', 'help_search', 0.805455),
('singleline', 12, 'en', 'help_search', 1.29741),
('singlevalued', 12, 'en', 'help_search', 1.60675),
('site', 1, 'en', 'help_search', 27),
('site', 3, 'en', 'help_search', 28),
('site', 6, 'en', 'help_search', 1),
('site', 8, 'en', 'help_search', 5),
('site', 10, 'en', 'help_search', 61.1676),
('site', 11, 'en', 'help_search', 32.2666),
('site', 12, 'en', 'help_search', 30.9082),
('site', 13, 'en', 'help_search', 9),
('site', 14, 'en', 'help_search', 40),
('site', 15, 'en', 'help_search', 33),
('site', 16, 'en', 'help_search', 1),
('site', 17, 'en', 'help_search', 2),
('site', 18, 'en', 'help_search', 66.989),
('site', 19, 'en', 'help_search', 29),
('site', 20, 'en', 'help_search', 1),
('site', 21, 'en', 'help_search', 1),
('site', 22, 'en', 'help_search', 21),
('site', 24, 'en', 'help_search', 4.71269),
('site', 25, 'en', 'help_search', 2),
('site', 26, 'en', 'help_search', 2),
('site', 28, 'en', 'help_search', 2),
('site', 29, 'en', 'help_search', 6.76836),
('site', 30, 'en', 'help_search', 69.9142),
('site', 31, 'en', 'help_search', 31),
('site', 32, 'en', 'help_search', 36),
('site', 33, 'en', 'help_search', 12.7251),
('site', 34, 'en', 'help_search', 21),
('site', 36, 'en', 'help_search', 1),
('site', 37, 'en', 'help_search', 32),
('site', 38, 'en', 'help_search', 6),
('site', 39, 'en', 'help_search', 2),
('site', 42, 'en', 'help_search', 31),
('site', 44, 'en', 'help_search', 5.99731),
('site', 46, 'en', 'help_search', 21),
('site', 47, 'en', 'help_search', 1),
('site', 48, 'en', 'help_search', 3),
('site', 50, 'en', 'help_search', 6.99315),
('site', 51, 'en', 'help_search', 2),
('site', 53, 'en', 'help_search', 1),
('site', 54, 'en', 'help_search', 3),
('site', 59, 'en', 'help_search', 2.91323),
('site', 60, 'en', 'help_search', 2),
('site', 65, 'en', 'help_search', 2),
('site', 68, 'en', 'help_search', 1),
('site', 69, 'en', 'help_search', 1),
('site', 71, 'en', 'help_search', 1),
('site', 73, 'en', 'help_search', 1),
('site', 74, 'en', 'help_search', 1),
('site', 77, 'en', 'help_search', 2),
('site', 78, 'en', 'help_search', 2),
('site', 79, 'en', 'help_search', 1),
('site', 81, 'en', 'help_search', 0.993146),
('site', 84, 'en', 'help_search', 1),
('sites', 11, 'en', 'help_search', 8.33326),
('sites', 14, 'en', 'help_search', 1),
('sites', 25, 'en', 'help_search', 1),
('sites', 30, 'en', 'help_search', 1),
('sitewide', 5, 'en', 'help_search', 2),
('sitewide', 7, 'en', 'help_search', 1),
('sitewide', 8, 'en', 'help_search', 2),
('sitewide', 9, 'en', 'help_search', 2),
('situations', 33, 'en', 'help_search', 1),
('size', 16, 'en', 'help_search', 1),
('size', 53, 'en', 'help_search', 2),
('sized', 16, 'en', 'help_search', 1.98087),
('sizes', 16, 'en', 'help_search', 1),
('sizing', 53, 'en', 'help_search', 0.98493),
('slogan', 32, 'en', 'help_search', 2),
('smaller', 12, 'en', 'help_search', 1),
('smaller', 18, 'en', 'help_search', 1),
('smaller', 29, 'en', 'help_search', 2),
('smaller', 35, 'en', 'help_search', 1),
('smaller', 36, 'en', 'help_search', 1),
('social', 16, 'en', 'help_search', 1),
('software', 10, 'en', 'help_search', 2),
('software', 11, 'en', 'help_search', 0.968904),
('software', 14, 'en', 'help_search', 1),
('software', 18, 'en', 'help_search', 1),
('software', 19, 'en', 'help_search', 4),
('software', 22, 'en', 'help_search', 2),
('software', 24, 'en', 'help_search', 1),
('software', 25, 'en', 'help_search', 1),
('software', 29, 'en', 'help_search', 1),
('software', 33, 'en', 'help_search', 2),
('software', 37, 'en', 'help_search', 3),
('software', 54, 'en', 'help_search', 1),
('software', 59, 'en', 'help_search', 1),
('software', 78, 'en', 'help_search', 1),
('solr', 30, 'en', 'help_search', 12),
('some', 12, 'en', 'help_search', 1.6522),
('some', 15, 'en', 'help_search', 1),
('some', 17, 'en', 'help_search', 1),
('some', 23, 'en', 'help_search', 2),
('some', 24, 'en', 'help_search', 4.73496),
('some', 29, 'en', 'help_search', 0.980874),
('some', 30, 'en', 'help_search', 1),
('some', 31, 'en', 'help_search', 1),
('some', 33, 'en', 'help_search', 2),
('some', 44, 'en', 'help_search', 1),
('some', 47, 'en', 'help_search', 1),
('some', 50, 'en', 'help_search', 2.89945),
('some', 53, 'en', 'help_search', 1),
('some', 54, 'en', 'help_search', 1),
('some', 59, 'en', 'help_search', 2),
('some', 65, 'en', 'help_search', 1),
('some', 66, 'en', 'help_search', 1),
('some', 67, 'en', 'help_search', 1),
('some', 70, 'en', 'help_search', 1),
('some', 71, 'en', 'help_search', 1.8861),
('some', 78, 'en', 'help_search', 1),
('someone', 67, 'en', 'help_search', 1),
('sometimes', 19, 'en', 'help_search', 1),
('sometimes', 23, 'en', 'help_search', 1),
('soon', 37, 'en', 'help_search', 1),
('sort', 64, 'en', 'help_search', 1),
('sort', 67, 'en', 'help_search', 1),
('sort', 71, 'en', 'help_search', 4),
('sorting', 71, 'en', 'help_search', 1),
('sorting', 84, 'en', 'help_search', 1),
('sorts', 71, 'en', 'help_search', 0.869951),
('source', 11, 'en', 'help_search', 0.794753),
('source', 50, 'en', 'help_search', 1),
('sources', 46, 'en', 'help_search', 1),
('spaces', 50, 'en', 'help_search', 1),
('spam', 59, 'en', 'help_search', 1.91674),
('spamreduction', 59, 'en', 'help_search', 0.96498),
('special', 42, 'en', 'help_search', 1),
('specific', 2, 'en', 'help_search', 1),
('specific', 8, 'en', 'help_search', 1),
('specific', 10, 'en', 'help_search', 0.945829),
('specific', 11, 'en', 'help_search', 0.683725),
('specific', 16, 'en', 'help_search', 0.96498),
('specific', 17, 'en', 'help_search', 1),
('specific', 19, 'en', 'help_search', 1),
('specific', 21, 'en', 'help_search', 1),
('specific', 22, 'en', 'help_search', 1),
('specific', 25, 'en', 'help_search', 1),
('specific', 30, 'en', 'help_search', 0.78951),
('specific', 48, 'en', 'help_search', 1),
('specific', 59, 'en', 'help_search', 0.854391),
('specific', 65, 'en', 'help_search', 1),
('specific', 68, 'en', 'help_search', 1),
('specific', 71, 'en', 'help_search', 2.60924),
('specific', 78, 'en', 'help_search', 2),
('specific', 81, 'en', 'help_search', 0.899454),
('specifically', 48, 'en', 'help_search', 1),
('specification', 25, 'en', 'help_search', 11),
('specify', 71, 'en', 'help_search', 2),
('specifying', 12, 'en', 'help_search', 0.942091),
('specifying', 30, 'en', 'help_search', 1),
('speed', 18, 'en', 'help_search', 1),
('sphinx', 30, 'en', 'help_search', 11),
('square', 44, 'en', 'help_search', 1),
('stable', 10, 'en', 'help_search', 1),
('stable', 14, 'en', 'help_search', 1),
('stable', 19, 'en', 'help_search', 1),
('staging', 11, 'en', 'help_search', 1),
('standard', 11, 'en', 'help_search', 0.980874),
('standards', 23, 'en', 'help_search', 1),
('standards', 27, 'en', 'help_search', 10.2817),
('standards', 53, 'en', 'help_search', 10.2817),
('star', 79, 'en', 'help_search', 1),
('start', 12, 'en', 'help_search', 0.848323),
('start', 59, 'en', 'help_search', 1),
('start', 73, 'en', 'help_search', 1),
('started', 60, 'en', 'help_search', 0.953396),
('starting', 33, 'en', 'help_search', 1),
('starts', 30, 'en', 'help_search', 1),
('starts', 76, 'en', 'help_search', 1),
('state', 12, 'en', 'help_search', 6),
('state', 23, 'en', 'help_search', 1),
('status', 26, 'en', 'help_search', 1),
('status', 28, 'en', 'help_search', 4),
('status', 29, 'en', 'help_search', 1.76896),
('status', 37, 'en', 'help_search', 6),
('status', 67, 'en', 'help_search', 4),
('status', 69, 'en', 'help_search', 1),
('stemmer', 30, 'en', 'help_search', 10.7896),
('stemming', 30, 'en', 'help_search', 1),
('step', 31, 'en', 'help_search', 1),
('step', 50, 'en', 'help_search', 1),
('step', 54, 'en', 'help_search', 0.98493),
('stepbystep', 27, 'en', 'help_search', 0.949597),
('steps', 1, 'en', 'help_search', 19),
('steps', 2, 'en', 'help_search', 19),
('steps', 3, 'en', 'help_search', 19),
('steps', 4, 'en', 'help_search', 19),
('steps', 5, 'en', 'help_search', 19),
('steps', 6, 'en', 'help_search', 20),
('steps', 7, 'en', 'help_search', 20),
('steps', 9, 'en', 'help_search', 19),
('steps', 13, 'en', 'help_search', 19),
('steps', 16, 'en', 'help_search', 1),
('steps', 20, 'en', 'help_search', 20),
('steps', 26, 'en', 'help_search', 20),
('steps', 27, 'en', 'help_search', 1),
('steps', 28, 'en', 'help_search', 20),
('steps', 29, 'en', 'help_search', 19.9132),
('steps', 31, 'en', 'help_search', 19),
('steps', 32, 'en', 'help_search', 20),
('steps', 33, 'en', 'help_search', 19),
('steps', 34, 'en', 'help_search', 19),
('steps', 35, 'en', 'help_search', 19),
('steps', 36, 'en', 'help_search', 19),
('steps', 37, 'en', 'help_search', 19),
('steps', 38, 'en', 'help_search', 19),
('steps', 39, 'en', 'help_search', 19),
('steps', 40, 'en', 'help_search', 20),
('steps', 41, 'en', 'help_search', 19),
('steps', 43, 'en', 'help_search', 19),
('steps', 44, 'en', 'help_search', 19),
('steps', 45, 'en', 'help_search', 19),
('steps', 47, 'en', 'help_search', 19),
('steps', 49, 'en', 'help_search', 19),
('steps', 50, 'en', 'help_search', 19.644),
('steps', 51, 'en', 'help_search', 19),
('steps', 52, 'en', 'help_search', 19),
('steps', 53, 'en', 'help_search', 2),
('steps', 54, 'en', 'help_search', 20.9545),
('steps', 55, 'en', 'help_search', 21),
('steps', 56, 'en', 'help_search', 20),
('steps', 57, 'en', 'help_search', 19),
('steps', 58, 'en', 'help_search', 19),
('steps', 60, 'en', 'help_search', 19),
('steps', 61, 'en', 'help_search', 19),
('steps', 62, 'en', 'help_search', 20),
('steps', 63, 'en', 'help_search', 20),
('steps', 64, 'en', 'help_search', 19),
('steps', 65, 'en', 'help_search', 19),
('steps', 66, 'en', 'help_search', 20),
('steps', 67, 'en', 'help_search', 19),
('steps', 70, 'en', 'help_search', 20),
('steps', 72, 'en', 'help_search', 19),
('steps', 73, 'en', 'help_search', 19),
('steps', 74, 'en', 'help_search', 19),
('steps', 75, 'en', 'help_search', 19),
('steps', 76, 'en', 'help_search', 21),
('steps', 77, 'en', 'help_search', 19),
('steps', 79, 'en', 'help_search', 19),
('steps', 80, 'en', 'help_search', 19),
('steps', 82, 'en', 'help_search', 20),
('steps', 83, 'en', 'help_search', 19),
('steps', 84, 'en', 'help_search', 20),
('steps', 85, 'en', 'help_search', 19),
('still', 14, 'en', 'help_search', 1),
('storage', 11, 'en', 'help_search', 2),
('store', 29, 'en', 'help_search', 1),
('store', 59, 'en', 'help_search', 1),
('store', 68, 'en', 'help_search', 1),
('stored', 10, 'en', 'help_search', 1),
('stored', 11, 'en', 'help_search', 1.76676),
('stored', 12, 'en', 'help_search', 2.49525),
('stored', 25, 'en', 'help_search', 1),
('stores', 12, 'en', 'help_search', 11.822),
('strategic', 46, 'en', 'help_search', 1),
('streamed', 18, 'en', 'help_search', 0.916736),
('string', 26, 'en', 'help_search', 1),
('string', 32, 'en', 'help_search', 4),
('strings', 12, 'en', 'help_search', 0.738408),
('strings', 25, 'en', 'help_search', 1),
('strings', 32, 'en', 'help_search', 1),
('strings', 44, 'en', 'help_search', 1),
('structure', 5, 'en', 'help_search', 4),
('structure', 7, 'en', 'help_search', 4),
('structure', 9, 'en', 'help_search', 4),
('structure', 10, 'en', 'help_search', 1),
('structure', 11, 'en', 'help_search', 2),
('structure', 12, 'en', 'help_search', 39.205),
('structure', 16, 'en', 'help_search', 1),
('structure', 22, 'en', 'help_search', 1),
('structure', 24, 'en', 'help_search', 4),
('structure', 25, 'en', 'help_search', 1),
('structure', 26, 'en', 'help_search', 4),
('structure', 47, 'en', 'help_search', 4),
('structure', 49, 'en', 'help_search', 4),
('structure', 52, 'en', 'help_search', 4),
('structure', 55, 'en', 'help_search', 1),
('structure', 56, 'en', 'help_search', 5),
('structure', 57, 'en', 'help_search', 1),
('structure', 59, 'en', 'help_search', 1),
('structure', 61, 'en', 'help_search', 6),
('structure', 62, 'en', 'help_search', 5),
('structure', 63, 'en', 'help_search', 5),
('structure', 64, 'en', 'help_search', 5),
('structure', 65, 'en', 'help_search', 1),
('structure', 66, 'en', 'help_search', 15),
('structure', 67, 'en', 'help_search', 1),
('structure', 68, 'en', 'help_search', 2),
('structure', 72, 'en', 'help_search', 5),
('structure', 73, 'en', 'help_search', 8),
('structure', 74, 'en', 'help_search', 4),
('structure', 75, 'en', 'help_search', 4),
('structure', 80, 'en', 'help_search', 5),
('structure', 81, 'en', 'help_search', 2),
('structure', 82, 'en', 'help_search', 4),
('structure', 83, 'en', 'help_search', 4),
('structure', 84, 'en', 'help_search', 4),
('structure', 85, 'en', 'help_search', 4),
('structures', 25, 'en', 'help_search', 1),
('style', 11, 'en', 'help_search', 1),
('style', 16, 'en', 'help_search', 20),
('style', 70, 'en', 'help_search', 41),
('style', 71, 'en', 'help_search', 1),
('styles', 11, 'en', 'help_search', 1),
('styles', 16, 'en', 'help_search', 4.97954),
('styles', 70, 'en', 'help_search', 2),
('styling', 10, 'en', 'help_search', 1),
('subdirectory', 27, 'en', 'help_search', 1),
('subject', 5, 'en', 'help_search', 4),
('subject', 6, 'en', 'help_search', 4),
('subject', 7, 'en', 'help_search', 4),
('submission', 55, 'en', 'help_search', 0.961087),
('submit', 20, 'en', 'help_search', 1),
('submit', 23, 'en', 'help_search', 1),
('submitting', 59, 'en', 'help_search', 0.938382),
('subset', 12, 'en', 'help_search', 1),
('substituted', 44, 'en', 'help_search', 1),
('subterm', 81, 'en', 'help_search', 1),
('subtype', 12, 'en', 'help_search', 0.980874),
('subtype', 55, 'en', 'help_search', 8.90974),
('subtype', 57, 'en', 'help_search', 1),
('subtype', 61, 'en', 'help_search', 29),
('subtype', 62, 'en', 'help_search', 29),
('subtype', 63, 'en', 'help_search', 29),
('subtype', 64, 'en', 'help_search', 29),
('subtype', 80, 'en', 'help_search', 4),
('subtypes', 10, 'en', 'help_search', 1),
('subtypes', 12, 'en', 'help_search', 6.98902),
('subtypes', 16, 'en', 'help_search', 1),
('subtypes', 59, 'en', 'help_search', 1),
('subtypes', 61, 'en', 'help_search', 1),
('subtypes', 64, 'en', 'help_search', 1),
('subtypes', 68, 'en', 'help_search', 1),
('subtypes', 81, 'en', 'help_search', 1),
('such', 3, 'en', 'help_search', 1),
('such', 4, 'en', 'help_search', 1),
('such', 5, 'en', 'help_search', 1),
('such', 11, 'en', 'help_search', 2.73841),
('such', 12, 'en', 'help_search', 4.6522),
('such', 13, 'en', 'help_search', 1),
('such', 15, 'en', 'help_search', 1),
('such', 16, 'en', 'help_search', 1),
('such', 18, 'en', 'help_search', 1),
('such', 23, 'en', 'help_search', 1),
('such', 24, 'en', 'help_search', 1),
('such', 25, 'en', 'help_search', 2),
('such', 26, 'en', 'help_search', 1),
('such', 30, 'en', 'help_search', 0.989021),
('such', 33, 'en', 'help_search', 1),
('such', 42, 'en', 'help_search', 2),
('such', 50, 'en', 'help_search', 2),
('such', 53, 'en', 'help_search', 1.98902),
('such', 54, 'en', 'help_search', 1),
('such', 59, 'en', 'help_search', 0.961087),
('such', 60, 'en', 'help_search', 1),
('such', 71, 'en', 'help_search', 4.78568),
('such', 73, 'en', 'help_search', 1),
('such', 81, 'en', 'help_search', 1),
('such', 85, 'en', 'help_search', 3),
('sufficient', 71, 'en', 'help_search', 0.854391),
('suggested', 2, 'en', 'help_search', 1),
('summarizes', 37, 'en', 'help_search', 1),
('summary', 12, 'en', 'help_search', 5.47787),
('summary', 23, 'en', 'help_search', 1),
('summary', 74, 'en', 'help_search', 1),
('supplied', 10, 'en', 'help_search', 1),
('support', 29, 'en', 'help_search', 0.976851),
('support', 71, 'en', 'help_search', 1.82206),
('supports', 30, 'en', 'help_search', 1),
('sure', 13, 'en', 'help_search', 1),
('sure', 28, 'en', 'help_search', 1),
('sure', 29, 'en', 'help_search', 2.91323),
('sure', 30, 'en', 'help_search', 0.833529),
('sure', 54, 'en', 'help_search', 0.836446),
('sure', 60, 'en', 'help_search', 2),
('sure', 73, 'en', 'help_search', 1),
('sure', 76, 'en', 'help_search', 1),
('sure', 79, 'en', 'help_search', 2),
('sustainability', 46, 'en', 'help_search', 1),
('switch', 10, 'en', 'help_search', 0.989021),
('switch', 24, 'en', 'help_search', 0.953396),
('switch', 85, 'en', 'help_search', 1),
('switcher', 22, 'en', 'help_search', 4),
('sync', 11, 'en', 'help_search', 4.53866),
('synchronization', 1, 'en', 'help_search', 4),
('synchronization', 2, 'en', 'help_search', 4),
('synchronization', 3, 'en', 'help_search', 5),
('synchronization', 4, 'en', 'help_search', 4),
('synchronization', 11, 'en', 'help_search', 22.3776),
('synchronize', 3, 'en', 'help_search', 4),
('synchronize', 11, 'en', 'help_search', 1),
('synchronized', 11, 'en', 'help_search', 0.902857),
('synchronizing', 11, 'en', 'help_search', 0.738408),
('syslog', 15, 'en', 'help_search', 1),
('system', 11, 'en', 'help_search', 21.6358),
('system', 12, 'en', 'help_search', 4.4446),
('system', 13, 'en', 'help_search', 5),
('system', 16, 'en', 'help_search', 1),
('system', 17, 'en', 'help_search', 1),
('system', 24, 'en', 'help_search', 1),
('system', 30, 'en', 'help_search', 1),
('system', 32, 'en', 'help_search', 4),
('system', 33, 'en', 'help_search', 4),
('system', 60, 'en', 'help_search', 1),
('systems', 18, 'en', 'help_search', 1),
('tab', 8, 'en', 'help_search', 1),
('tab', 26, 'en', 'help_search', 1),
('tab', 51, 'en', 'help_search', 1),
('tab', 58, 'en', 'help_search', 1),
('table', 7, 'en', 'help_search', 1),
('table', 23, 'en', 'help_search', 4),
('table', 45, 'en', 'help_search', 1),
('table', 54, 'en', 'help_search', 1),
('table', 71, 'en', 'help_search', 2.85746),
('table', 83, 'en', 'help_search', 1),
('table', 85, 'en', 'help_search', 4),
('tables', 23, 'en', 'help_search', 1),
('tables', 29, 'en', 'help_search', 1),
('tablestyle', 83, 'en', 'help_search', 1),
('tabs', 66, 'en', 'help_search', 1),
('tag', 50, 'en', 'help_search', 0.822065),
('tag', 54, 'en', 'help_search', 1),
('tagging', 81, 'en', 'help_search', 1),
('tags', 50, 'en', 'help_search', 7.37404),
('tags', 81, 'en', 'help_search', 4),
('take', 31, 'en', 'help_search', 1),
('take', 37, 'en', 'help_search', 1),
('taken', 66, 'en', 'help_search', 1),
('takes', 50, 'en', 'help_search', 1),
('takes', 60, 'en', 'help_search', 1),
('target', 56, 'en', 'help_search', 4),
('task', 13, 'en', 'help_search', 3.99731),
('task', 27, 'en', 'help_search', 1),
('task', 29, 'en', 'help_search', 0.913226),
('task', 60, 'en', 'help_search', 0.980874),
('tasks', 8, 'en', 'help_search', 20),
('tasks', 10, 'en', 'help_search', 0.942091),
('tasks', 11, 'en', 'help_search', 1.42247),
('tasks', 12, 'en', 'help_search', 0.582831),
('tasks', 13, 'en', 'help_search', 32.4456),
('tasks', 14, 'en', 'help_search', 1),
('tasks', 15, 'en', 'help_search', 1),
('tasks', 16, 'en', 'help_search', 0.961087),
('tasks', 17, 'en', 'help_search', 1),
('tasks', 19, 'en', 'help_search', 20),
('tasks', 21, 'en', 'help_search', 1),
('tasks', 22, 'en', 'help_search', 1),
('tasks', 24, 'en', 'help_search', 4),
('tasks', 30, 'en', 'help_search', 0.786915),
('tasks', 42, 'en', 'help_search', 1),
('tasks', 48, 'en', 'help_search', 1),
('tasks', 59, 'en', 'help_search', 0.851346),
('tasks', 60, 'en', 'help_search', 2),
('tasks', 68, 'en', 'help_search', 1),
('tasks', 71, 'en', 'help_search', 0.784336),
('tasks', 74, 'en', 'help_search', 1),
('tasks', 78, 'en', 'help_search', 1),
('tasks', 81, 'en', 'help_search', 0.896076),
('taste', 59, 'en', 'help_search', 1),
('taxonomy', 12, 'en', 'help_search', 0.610858),
('taxonomy', 24, 'en', 'help_search', 0.961087),
('taxonomy', 76, 'en', 'help_search', 1),
('taxonomy', 78, 'en', 'help_search', 2),
('taxonomy', 80, 'en', 'help_search', 64),
('taxonomy', 81, 'en', 'help_search', 89.5416),
('team', 19, 'en', 'help_search', 11),
('technically', 81, 'en', 'help_search', 1),
('technologies', 30, 'en', 'help_search', 1),
('technology', 23, 'en', 'help_search', 1),
('technology', 30, 'en', 'help_search', 1),
('telephone', 12, 'en', 'help_search', 2.38691),
('template', 10, 'en', 'help_search', 1),
('temporarily', 60, 'en', 'help_search', 1),
('temporary', 12, 'en', 'help_search', 1),
('temporary', 28, 'en', 'help_search', 1),
('term', 76, 'en', 'help_search', 1),
('term', 78, 'en', 'help_search', 2),
('term', 80, 'en', 'help_search', 7),
('term', 81, 'en', 'help_search', 2.92613),
('terms', 11, 'en', 'help_search', 0.822065),
('terms', 80, 'en', 'help_search', 6),
('terms', 81, 'en', 'help_search', 13.9347),
('test', 59, 'en', 'help_search', 0.942091),
('test', 62, 'en', 'help_search', 1),
('test', 63, 'en', 'help_search', 1),
('text', 2, 'en', 'help_search', 3),
('text', 4, 'en', 'help_search', 1),
('text', 5, 'en', 'help_search', 1),
('text', 10, 'en', 'help_search', 1),
('text', 12, 'en', 'help_search', 39.8545),
('text', 22, 'en', 'help_search', 23),
('text', 25, 'en', 'help_search', 1),
('text', 26, 'en', 'help_search', 1),
('text', 27, 'en', 'help_search', 2),
('text', 44, 'en', 'help_search', 21.9849),
('text', 45, 'en', 'help_search', 1),
('text', 50, 'en', 'help_search', 163.01),
('text', 51, 'en', 'help_search', 1),
('text', 54, 'en', 'help_search', 108.144),
('text', 59, 'en', 'help_search', 1),
('text', 61, 'en', 'help_search', 5),
('text', 62, 'en', 'help_search', 1),
('text', 64, 'en', 'help_search', 5),
('text', 68, 'en', 'help_search', 1),
('text', 73, 'en', 'help_search', 1),
('than', 8, 'en', 'help_search', 1),
('than', 11, 'en', 'help_search', 1.46654),
('than', 18, 'en', 'help_search', 1),
('than', 29, 'en', 'help_search', 1),
('than', 34, 'en', 'help_search', 1),
('than', 35, 'en', 'help_search', 1),
('than', 51, 'en', 'help_search', 1),
('than', 65, 'en', 'help_search', 1),
('than', 69, 'en', 'help_search', 1),
('than', 74, 'en', 'help_search', 1),
('that', 2, 'en', 'help_search', 1),
('that', 3, 'en', 'help_search', 2),
('that', 4, 'en', 'help_search', 3),
('that', 5, 'en', 'help_search', 1),
('that', 6, 'en', 'help_search', 1),
('that', 8, 'en', 'help_search', 1),
('that', 10, 'en', 'help_search', 5),
('that', 11, 'en', 'help_search', 6.30646),
('that', 12, 'en', 'help_search', 8.69588),
('that', 13, 'en', 'help_search', 3),
('that', 14, 'en', 'help_search', 3),
('that', 15, 'en', 'help_search', 4),
('that', 16, 'en', 'help_search', 1),
('that', 18, 'en', 'help_search', 2.9347),
('that', 19, 'en', 'help_search', 1),
('that', 20, 'en', 'help_search', 3),
('that', 21, 'en', 'help_search', 2),
('that', 22, 'en', 'help_search', 4),
('that', 23, 'en', 'help_search', 2),
('that', 24, 'en', 'help_search', 1),
('that', 25, 'en', 'help_search', 2),
('that', 26, 'en', 'help_search', 5),
('that', 28, 'en', 'help_search', 3),
('that', 29, 'en', 'help_search', 3.82016),
('that', 30, 'en', 'help_search', 7.47776),
('that', 31, 'en', 'help_search', 2),
('that', 32, 'en', 'help_search', 5),
('that', 33, 'en', 'help_search', 3.67553),
('that', 35, 'en', 'help_search', 3),
('that', 36, 'en', 'help_search', 2),
('that', 37, 'en', 'help_search', 3),
('that', 38, 'en', 'help_search', 6),
('that', 39, 'en', 'help_search', 2),
('that', 40, 'en', 'help_search', 1),
('that', 42, 'en', 'help_search', 1),
('that', 43, 'en', 'help_search', 2),
('that', 44, 'en', 'help_search', 7.92329),
('that', 47, 'en', 'help_search', 3),
('that', 48, 'en', 'help_search', 1),
('that', 49, 'en', 'help_search', 2),
('that', 50, 'en', 'help_search', 8.85086),
('that', 53, 'en', 'help_search', 2),
('that', 54, 'en', 'help_search', 5.82864),
('that', 55, 'en', 'help_search', 3),
('that', 57, 'en', 'help_search', 2),
('that', 58, 'en', 'help_search', 1),
('that', 59, 'en', 'help_search', 4.88282),
('that', 60, 'en', 'help_search', 6.98902),
('that', 61, 'en', 'help_search', 1),
('that', 62, 'en', 'help_search', 3),
('that', 63, 'en', 'help_search', 2),
('that', 64, 'en', 'help_search', 3),
('that', 65, 'en', 'help_search', 1),
('that', 68, 'en', 'help_search', 1),
('that', 69, 'en', 'help_search', 2),
('that', 71, 'en', 'help_search', 0.993146),
('that', 72, 'en', 'help_search', 2),
('that', 73, 'en', 'help_search', 3),
('that', 75, 'en', 'help_search', 1),
('that', 76, 'en', 'help_search', 1),
('that', 77, 'en', 'help_search', 2),
('that', 78, 'en', 'help_search', 1),
('that', 79, 'en', 'help_search', 4.99315),
('that', 80, 'en', 'help_search', 3),
('that', 81, 'en', 'help_search', 1.92221),
('that', 82, 'en', 'help_search', 1),
('that', 83, 'en', 'help_search', 3),
('that', 85, 'en', 'help_search', 3),
('the', 1, 'en', 'help_search', 2),
('the', 2, 'en', 'help_search', 9),
('the', 3, 'en', 'help_search', 8),
('the', 4, 'en', 'help_search', 6),
('the', 5, 'en', 'help_search', 53),
('the', 6, 'en', 'help_search', 12),
('the', 7, 'en', 'help_search', 8),
('the', 8, 'en', 'help_search', 30),
('the', 9, 'en', 'help_search', 30),
('the', 10, 'en', 'help_search', 44.8969),
('the', 11, 'en', 'help_search', 63.3085),
('the', 12, 'en', 'help_search', 40.0589),
('the', 13, 'en', 'help_search', 14.9946),
('the', 14, 'en', 'help_search', 6),
('the', 15, 'en', 'help_search', 3),
('the', 16, 'en', 'help_search', 37.9564),
('the', 17, 'en', 'help_search', 7),
('the', 18, 'en', 'help_search', 50.6047),
('the', 19, 'en', 'help_search', 6),
('the', 20, 'en', 'help_search', 23),
('the', 21, 'en', 'help_search', 28),
('the', 22, 'en', 'help_search', 9),
('the', 23, 'en', 'help_search', 40.9849),
('the', 24, 'en', 'help_search', 85.1542),
('the', 25, 'en', 'help_search', 40),
('the', 26, 'en', 'help_search', 25),
('the', 27, 'en', 'help_search', 10.9206),
('the', 28, 'en', 'help_search', 17),
('the', 29, 'en', 'help_search', 65.133),
('the', 30, 'en', 'help_search', 94.7056),
('the', 31, 'en', 'help_search', 53),
('the', 32, 'en', 'help_search', 18),
('the', 33, 'en', 'help_search', 20.4958),
('the', 34, 'en', 'help_search', 13),
('the', 35, 'en', 'help_search', 18),
('the', 36, 'en', 'help_search', 18),
('the', 37, 'en', 'help_search', 15),
('the', 38, 'en', 'help_search', 25),
('the', 39, 'en', 'help_search', 10),
('the', 40, 'en', 'help_search', 9),
('the', 41, 'en', 'help_search', 6),
('the', 42, 'en', 'help_search', 6),
('the', 43, 'en', 'help_search', 35),
('the', 44, 'en', 'help_search', 34.9138),
('the', 45, 'en', 'help_search', 15),
('the', 46, 'en', 'help_search', 54),
('the', 47, 'en', 'help_search', 25),
('the', 48, 'en', 'help_search', 47),
('the', 49, 'en', 'help_search', 10),
('the', 50, 'en', 'help_search', 25.6562),
('the', 51, 'en', 'help_search', 6),
('the', 52, 'en', 'help_search', 8),
('the', 53, 'en', 'help_search', 14.8913),
('the', 54, 'en', 'help_search', 25.0258),
('the', 55, 'en', 'help_search', 28.732),
('the', 56, 'en', 'help_search', 14),
('the', 57, 'en', 'help_search', 11),
('the', 58, 'en', 'help_search', 22),
('the', 59, 'en', 'help_search', 7.56866),
('the', 60, 'en', 'help_search', 30.8869),
('the', 61, 'en', 'help_search', 22),
('the', 62, 'en', 'help_search', 28),
('the', 63, 'en', 'help_search', 49),
('the', 64, 'en', 'help_search', 27.9931),
('the', 65, 'en', 'help_search', 24),
('the', 66, 'en', 'help_search', 20),
('the', 67, 'en', 'help_search', 25.963),
('the', 68, 'en', 'help_search', 7),
('the', 69, 'en', 'help_search', 6),
('the', 70, 'en', 'help_search', 13),
('the', 71, 'en', 'help_search', 56.4415),
('the', 72, 'en', 'help_search', 7),
('the', 73, 'en', 'help_search', 22),
('the', 74, 'en', 'help_search', 14),
('the', 75, 'en', 'help_search', 3),
('the', 76, 'en', 'help_search', 10),
('the', 77, 'en', 'help_search', 9),
('the', 78, 'en', 'help_search', 17),
('the', 79, 'en', 'help_search', 18.8617),
('the', 80, 'en', 'help_search', 25),
('the', 81, 'en', 'help_search', 14.6866),
('the', 82, 'en', 'help_search', 12),
('the', 83, 'en', 'help_search', 22.9672),
('the', 84, 'en', 'help_search', 7),
('the', 85, 'en', 'help_search', 17),
('their', 8, 'en', 'help_search', 1),
('their', 11, 'en', 'help_search', 0.749958),
('their', 12, 'en', 'help_search', 0.60322),
('their', 19, 'en', 'help_search', 1),
('their', 23, 'en', 'help_search', 1),
('their', 24, 'en', 'help_search', 1),
('their', 27, 'en', 'help_search', 1),
('their', 29, 'en', 'help_search', 1),
('their', 31, 'en', 'help_search', 1),
('their', 44, 'en', 'help_search', 3.98902),
('their', 47, 'en', 'help_search', 1),
('their', 54, 'en', 'help_search', 0.848323),
('their', 55, 'en', 'help_search', 1),
('their', 62, 'en', 'help_search', 1),
('their', 63, 'en', 'help_search', 1),
('their', 79, 'en', 'help_search', 1.96109),
('them', 6, 'en', 'help_search', 2),
('them', 18, 'en', 'help_search', 1);
INSERT INTO `[[dbprefix]]search_index` VALUES
('them', 23, 'en', 'help_search', 1),
('them', 26, 'en', 'help_search', 1),
('them', 32, 'en', 'help_search', 1),
('them', 37, 'en', 'help_search', 2),
('them', 40, 'en', 'help_search', 1),
('them', 46, 'en', 'help_search', 1),
('them', 50, 'en', 'help_search', 1.86995),
('them', 54, 'en', 'help_search', 0.879565),
('them', 59, 'en', 'help_search', 1.8645),
('them', 71, 'en', 'help_search', 0.833529),
('them', 79, 'en', 'help_search', 1),
('them', 81, 'en', 'help_search', 1.99731),
('theme', 10, 'en', 'help_search', 47.9809),
('theme', 11, 'en', 'help_search', 2),
('theme', 16, 'en', 'help_search', 1.98902),
('theme', 17, 'en', 'help_search', 1),
('theme', 26, 'en', 'help_search', 3),
('theme', 27, 'en', 'help_search', 2.98493),
('theme', 38, 'en', 'help_search', 47),
('theme', 39, 'en', 'help_search', 37),
('theme', 47, 'en', 'help_search', 4),
('theme', 48, 'en', 'help_search', 1),
('theme', 49, 'en', 'help_search', 3),
('theme', 79, 'en', 'help_search', 1),
('themes', 10, 'en', 'help_search', 8.9689),
('themes', 11, 'en', 'help_search', 0.699655),
('themes', 17, 'en', 'help_search', 1),
('themes', 19, 'en', 'help_search', 2),
('themes', 20, 'en', 'help_search', 1),
('themes', 22, 'en', 'help_search', 1),
('themes', 24, 'en', 'help_search', 2.82262),
('themes', 27, 'en', 'help_search', 5),
('themes', 37, 'en', 'help_search', 2),
('themes', 38, 'en', 'help_search', 37),
('themes', 39, 'en', 'help_search', 4),
('themes', 48, 'en', 'help_search', 1),
('themes', 53, 'en', 'help_search', 2.96109),
('themes', 60, 'en', 'help_search', 1),
('theming', 10, 'en', 'help_search', 10.0841),
('themselves', 44, 'en', 'help_search', 1),
('then', 2, 'en', 'help_search', 1),
('then', 11, 'en', 'help_search', 0.800068),
('then', 27, 'en', 'help_search', 0.976851),
('then', 29, 'en', 'help_search', 1),
('then', 34, 'en', 'help_search', 1),
('then', 58, 'en', 'help_search', 2),
('then', 70, 'en', 'help_search', 1),
('there', 8, 'en', 'help_search', 1),
('there', 11, 'en', 'help_search', 19),
('there', 12, 'en', 'help_search', 2.35233),
('there', 15, 'en', 'help_search', 2),
('there', 22, 'en', 'help_search', 1),
('there', 24, 'en', 'help_search', 1),
('there', 25, 'en', 'help_search', 1),
('there', 26, 'en', 'help_search', 1),
('there', 30, 'en', 'help_search', 1),
('there', 31, 'en', 'help_search', 1),
('there', 36, 'en', 'help_search', 3),
('there', 37, 'en', 'help_search', 1),
('there', 39, 'en', 'help_search', 1),
('there', 42, 'en', 'help_search', 1),
('there', 65, 'en', 'help_search', 1),
('there', 69, 'en', 'help_search', 2),
('there', 71, 'en', 'help_search', 0.934703),
('there', 79, 'en', 'help_search', 2),
('there', 83, 'en', 'help_search', 1),
('there', 85, 'en', 'help_search', 2),
('thereby', 11, 'en', 'help_search', 0.786915),
('these', 11, 'en', 'help_search', 1),
('these', 12, 'en', 'help_search', 1.39601),
('these', 13, 'en', 'help_search', 1),
('these', 16, 'en', 'help_search', 0.989021),
('these', 19, 'en', 'help_search', 1),
('these', 20, 'en', 'help_search', 1),
('these', 23, 'en', 'help_search', 2.99315),
('these', 27, 'en', 'help_search', 1),
('these', 29, 'en', 'help_search', 0.972861),
('these', 31, 'en', 'help_search', 1),
('these', 33, 'en', 'help_search', 2),
('these', 38, 'en', 'help_search', 1),
('these', 40, 'en', 'help_search', 1),
('these', 50, 'en', 'help_search', 0.776703),
('these', 54, 'en', 'help_search', 1.95723),
('these', 55, 'en', 'help_search', 1),
('these', 62, 'en', 'help_search', 1),
('these', 63, 'en', 'help_search', 1),
('these', 69, 'en', 'help_search', 1),
('these', 72, 'en', 'help_search', 1),
('these', 79, 'en', 'help_search', 1),
('these', 81, 'en', 'help_search', 2.9689),
('these', 84, 'en', 'help_search', 1),
('they', 6, 'en', 'help_search', 1),
('they', 11, 'en', 'help_search', 0.693594),
('they', 12, 'en', 'help_search', 1.96498),
('they', 16, 'en', 'help_search', 1),
('they', 19, 'en', 'help_search', 1),
('they', 21, 'en', 'help_search', 1),
('they', 23, 'en', 'help_search', 1),
('they', 25, 'en', 'help_search', 1),
('they', 26, 'en', 'help_search', 1),
('they', 27, 'en', 'help_search', 1),
('they', 30, 'en', 'help_search', 2),
('they', 44, 'en', 'help_search', 2),
('they', 67, 'en', 'help_search', 1),
('they', 69, 'en', 'help_search', 1),
('they', 70, 'en', 'help_search', 1),
('they', 79, 'en', 'help_search', 1),
('thirdparty', 30, 'en', 'help_search', 1),
('thirdparty', 54, 'en', 'help_search', 1),
('this', 8, 'en', 'help_search', 1),
('this', 9, 'en', 'help_search', 4),
('this', 11, 'en', 'help_search', 2.73112),
('this', 12, 'en', 'help_search', 0.648686),
('this', 13, 'en', 'help_search', 1),
('this', 16, 'en', 'help_search', 2),
('this', 18, 'en', 'help_search', 3.90974),
('this', 19, 'en', 'help_search', 1),
('this', 24, 'en', 'help_search', 1),
('this', 26, 'en', 'help_search', 2),
('this', 29, 'en', 'help_search', 1),
('this', 30, 'en', 'help_search', 1.92384),
('this', 36, 'en', 'help_search', 3),
('this', 43, 'en', 'help_search', 6),
('this', 46, 'en', 'help_search', 2),
('this', 50, 'en', 'help_search', 4.73792),
('this', 52, 'en', 'help_search', 1),
('this', 54, 'en', 'help_search', 1.97685),
('this', 55, 'en', 'help_search', 3.89876),
('this', 60, 'en', 'help_search', 1),
('this', 65, 'en', 'help_search', 2),
('this', 69, 'en', 'help_search', 20),
('this', 72, 'en', 'help_search', 2),
('this', 73, 'en', 'help_search', 3),
('this', 76, 'en', 'help_search', 1),
('this', 77, 'en', 'help_search', 1),
('this', 80, 'en', 'help_search', 1),
('this', 82, 'en', 'help_search', 2),
('this', 84, 'en', 'help_search', 1),
('threading', 55, 'en', 'help_search', 4),
('threads', 55, 'en', 'help_search', 1),
('three', 22, 'en', 'help_search', 1),
('three', 32, 'en', 'help_search', 1),
('throttle', 29, 'en', 'help_search', 4),
('through', 11, 'en', 'help_search', 1.67748),
('through', 12, 'en', 'help_search', 0.718502),
('through', 16, 'en', 'help_search', 1),
('through', 23, 'en', 'help_search', 1),
('through', 60, 'en', 'help_search', 1),
('time', 12, 'en', 'help_search', 1.85135),
('time', 13, 'en', 'help_search', 1),
('time', 18, 'en', 'help_search', 6),
('time', 31, 'en', 'help_search', 2),
('time', 32, 'en', 'help_search', 6),
('time', 35, 'en', 'help_search', 1),
('time', 69, 'en', 'help_search', 1),
('timeout', 29, 'en', 'help_search', 1),
('times', 12, 'en', 'help_search', 0.857458),
('times', 29, 'en', 'help_search', 0.899454),
('timestamp', 12, 'en', 'help_search', 0.863659),
('title', 7, 'en', 'help_search', 1),
('title', 27, 'en', 'help_search', 1),
('title', 47, 'en', 'help_search', 14),
('title', 48, 'en', 'help_search', 20),
('title', 50, 'en', 'help_search', 0.942091),
('title', 64, 'en', 'help_search', 1),
('title', 65, 'en', 'help_search', 5),
('title', 67, 'en', 'help_search', 6),
('title', 73, 'en', 'help_search', 10),
('title', 74, 'en', 'help_search', 3),
('title', 79, 'en', 'help_search', 1),
('title', 85, 'en', 'help_search', 4),
('together', 18, 'en', 'help_search', 1),
('toggle', 60, 'en', 'help_search', 1),
('tomatoes', 81, 'en', 'help_search', 3),
('tool', 11, 'en', 'help_search', 0.722831),
('toolbar', 20, 'en', 'help_search', 2),
('toolbar', 24, 'en', 'help_search', 15),
('toolbar', 46, 'en', 'help_search', 3),
('toolbar', 54, 'en', 'help_search', 15.6581),
('toolbar', 60, 'en', 'help_search', 3),
('toolbar', 79, 'en', 'help_search', 3),
('tooltip', 54, 'en', 'help_search', 0.906287),
('top', 23, 'en', 'help_search', 1),
('top', 24, 'en', 'help_search', 1),
('top', 26, 'en', 'help_search', 1),
('top', 71, 'en', 'help_search', 0.968904),
('topic', 12, 'en', 'help_search', 0.707906),
('topic', 26, 'en', 'help_search', 2),
('topic', 27, 'en', 'help_search', 22.9534),
('topic', 50, 'en', 'help_search', 0.851346),
('topic', 54, 'en', 'help_search', 0.976851),
('topic', 55, 'en', 'help_search', 1),
('topic', 65, 'en', 'help_search', 1),
('topic', 71, 'en', 'help_search', 0.808176),
('topic', 76, 'en', 'help_search', 1),
('topic', 80, 'en', 'help_search', 1),
('topic', 83, 'en', 'help_search', 1),
('topics', 8, 'en', 'help_search', 1),
('topics', 10, 'en', 'help_search', 0.957226),
('topics', 11, 'en', 'help_search', 0.689612),
('topics', 12, 'en', 'help_search', 1.17559),
('topics', 14, 'en', 'help_search', 1),
('topics', 15, 'en', 'help_search', 1),
('topics', 16, 'en', 'help_search', 0.976851),
('topics', 17, 'en', 'help_search', 1),
('topics', 19, 'en', 'help_search', 1),
('topics', 21, 'en', 'help_search', 1),
('topics', 22, 'en', 'help_search', 1),
('topics', 24, 'en', 'help_search', 1.86679),
('topics', 27, 'en', 'help_search', 121.282),
('topics', 30, 'en', 'help_search', 1.79475),
('topics', 42, 'en', 'help_search', 1),
('topics', 48, 'en', 'help_search', 1),
('topics', 56, 'en', 'help_search', 1),
('topics', 59, 'en', 'help_search', 0.863659),
('topics', 66, 'en', 'help_search', 1),
('topics', 68, 'en', 'help_search', 1),
('topics', 70, 'en', 'help_search', 1),
('topics', 71, 'en', 'help_search', 0.792123),
('topics', 74, 'en', 'help_search', 1),
('topics', 76, 'en', 'help_search', 1),
('topics', 78, 'en', 'help_search', 1),
('topics', 80, 'en', 'help_search', 1),
('topics', 81, 'en', 'help_search', 0.909743),
('topics', 84, 'en', 'help_search', 1),
('topleft', 20, 'en', 'help_search', 1),
('toplevel', 27, 'en', 'help_search', 1),
('topright', 20, 'en', 'help_search', 1),
('totally', 33, 'en', 'help_search', 1),
('track', 19, 'en', 'help_search', 1),
('tracked', 69, 'en', 'help_search', 19),
('tracking', 21, 'en', 'help_search', 46),
('tracking', 69, 'en', 'help_search', 45),
('tracks', 21, 'en', 'help_search', 1),
('tracks', 69, 'en', 'help_search', 1),
('traditional', 70, 'en', 'help_search', 1),
('transferred', 25, 'en', 'help_search', 1),
('transform', 50, 'en', 'help_search', 1),
('translatable', 27, 'en', 'help_search', 3),
('translate', 22, 'en', 'help_search', 1),
('translated', 22, 'en', 'help_search', 23),
('translated', 27, 'en', 'help_search', 19),
('translation', 22, 'en', 'help_search', 3),
('translation', 26, 'en', 'help_search', 1),
('translation', 27, 'en', 'help_search', 3),
('translations', 22, 'en', 'help_search', 29),
('translations', 38, 'en', 'help_search', 1),
('transmission', 18, 'en', 'help_search', 1),
('transported', 25, 'en', 'help_search', 1),
('tray', 20, 'en', 'help_search', 2),
('tray', 24, 'en', 'help_search', 1),
('triggers', 27, 'en', 'help_search', 1),
('troubleshooting', 15, 'en', 'help_search', 46),
('true', 12, 'en', 'help_search', 0.892724),
('trusted', 43, 'en', 'help_search', 4),
('try', 26, 'en', 'help_search', 1),
('trying', 15, 'en', 'help_search', 1),
('trying', 35, 'en', 'help_search', 1),
('turn', 18, 'en', 'help_search', 0.854391),
('turn', 57, 'en', 'help_search', 3),
('turning', 14, 'en', 'help_search', 2),
('turns', 50, 'en', 'help_search', 1),
('twice', 40, 'en', 'help_search', 1),
('twig', 27, 'en', 'help_search', 1),
('twigfilebased', 27, 'en', 'help_search', 1),
('two', 8, 'en', 'help_search', 1),
('two', 12, 'en', 'help_search', 0.679856),
('two', 15, 'en', 'help_search', 1),
('two', 25, 'en', 'help_search', 1),
('two', 30, 'en', 'help_search', 1),
('two', 53, 'en', 'help_search', 1),
('two', 64, 'en', 'help_search', 1),
('two', 70, 'en', 'help_search', 1),
('two', 81, 'en', 'help_search', 1),
('two', 85, 'en', 'help_search', 1),
('type', 2, 'en', 'help_search', 4),
('type', 4, 'en', 'help_search', 4),
('type', 11, 'en', 'help_search', 2),
('type', 12, 'en', 'help_search', 13.0673),
('type', 17, 'en', 'help_search', 1),
('type', 26, 'en', 'help_search', 1),
('type', 28, 'en', 'help_search', 4),
('type', 30, 'en', 'help_search', 2),
('type', 42, 'en', 'help_search', 1),
('type', 48, 'en', 'help_search', 1),
('type', 50, 'en', 'help_search', 1),
('type', 51, 'en', 'help_search', 2),
('type', 52, 'en', 'help_search', 35),
('type', 55, 'en', 'help_search', 12.9097),
('type', 56, 'en', 'help_search', 58),
('type', 57, 'en', 'help_search', 1),
('type', 59, 'en', 'help_search', 26),
('type', 61, 'en', 'help_search', 3),
('type', 62, 'en', 'help_search', 2),
('type', 63, 'en', 'help_search', 2),
('type', 64, 'en', 'help_search', 16),
('type', 65, 'en', 'help_search', 5),
('type', 66, 'en', 'help_search', 66),
('type', 67, 'en', 'help_search', 6),
('type', 68, 'en', 'help_search', 24),
('type', 71, 'en', 'help_search', 4.8249),
('type', 72, 'en', 'help_search', 30),
('type', 73, 'en', 'help_search', 1),
('type', 80, 'en', 'help_search', 1),
('type', 81, 'en', 'help_search', 1),
('type', 82, 'en', 'help_search', 1),
('type', 84, 'en', 'help_search', 1),
('type', 85, 'en', 'help_search', 1),
('types', 8, 'en', 'help_search', 1),
('types', 11, 'en', 'help_search', 8.39477),
('types', 12, 'en', 'help_search', 88.542),
('types', 16, 'en', 'help_search', 4),
('types', 22, 'en', 'help_search', 1),
('types', 24, 'en', 'help_search', 0.980874),
('types', 29, 'en', 'help_search', 1),
('types', 30, 'en', 'help_search', 3),
('types', 48, 'en', 'help_search', 5),
('types', 52, 'en', 'help_search', 8),
('types', 53, 'en', 'help_search', 1),
('types', 55, 'en', 'help_search', 4),
('types', 56, 'en', 'help_search', 10),
('types', 59, 'en', 'help_search', 6.77882),
('types', 61, 'en', 'help_search', 7),
('types', 62, 'en', 'help_search', 4),
('types', 63, 'en', 'help_search', 4),
('types', 64, 'en', 'help_search', 5),
('types', 65, 'en', 'help_search', 2),
('types', 66, 'en', 'help_search', 10),
('types', 67, 'en', 'help_search', 3),
('types', 68, 'en', 'help_search', 7),
('types', 71, 'en', 'help_search', 1),
('types', 72, 'en', 'help_search', 1),
('types', 82, 'en', 'help_search', 1),
('typically', 25, 'en', 'help_search', 1),
('typically', 54, 'en', 'help_search', 1),
('typically', 56, 'en', 'help_search', 1),
('typically', 58, 'en', 'help_search', 1),
('typically', 59, 'en', 'help_search', 1),
('typically', 66, 'en', 'help_search', 1),
('typing', 73, 'en', 'help_search', 1),
('unapproved', 58, 'en', 'help_search', 4),
('uncacheable', 18, 'en', 'help_search', 0.923838),
('uncheck', 6, 'en', 'help_search', 1),
('uncheck', 34, 'en', 'help_search', 1),
('uncheck', 43, 'en', 'help_search', 1),
('uncheck', 44, 'en', 'help_search', 1),
('uncheck', 65, 'en', 'help_search', 1),
('uncheck', 75, 'en', 'help_search', 1),
('under', 26, 'en', 'help_search', 1),
('under', 27, 'en', 'help_search', 1),
('under', 29, 'en', 'help_search', 3.86775),
('under', 33, 'en', 'help_search', 1.92027),
('under', 50, 'en', 'help_search', 2.48477),
('under', 54, 'en', 'help_search', 0.949597),
('under', 57, 'en', 'help_search', 1),
('under', 67, 'en', 'help_search', 0.980874),
('under', 70, 'en', 'help_search', 1),
('under', 72, 'en', 'help_search', 2),
('under', 76, 'en', 'help_search', 1),
('under', 81, 'en', 'help_search', 1),
('under', 82, 'en', 'help_search', 1),
('under', 85, 'en', 'help_search', 1),
('underlying', 18, 'en', 'help_search', 1),
('understand', 23, 'en', 'help_search', 2),
('understandable', 78, 'en', 'help_search', 1),
('unformatted', 12, 'en', 'help_search', 0.794753),
('unformatted', 85, 'en', 'help_search', 8),
('uniform', 78, 'en', 'help_search', 1),
('uninstall', 13, 'en', 'help_search', 1),
('uninstall', 14, 'en', 'help_search', 1),
('uninstall', 24, 'en', 'help_search', 0.931053),
('uninstall', 36, 'en', 'help_search', 24),
('uninstall', 39, 'en', 'help_search', 11),
('uninstalled', 14, 'en', 'help_search', 1),
('uninstalled', 36, 'en', 'help_search', 5),
('uninstalled', 38, 'en', 'help_search', 4),
('uninstalled', 39, 'en', 'help_search', 1),
('uninstalling', 14, 'en', 'help_search', 20),
('uninstalling', 15, 'en', 'help_search', 1),
('uninstalling', 36, 'en', 'help_search', 26),
('uninstalling', 39, 'en', 'help_search', 26),
('unique', 11, 'en', 'help_search', 1.89272),
('unique', 13, 'en', 'help_search', 1),
('unique', 78, 'en', 'help_search', 1),
('unlimited', 61, 'en', 'help_search', 1),
('unlimited', 64, 'en', 'help_search', 1),
('unpacked', 3, 'en', 'help_search', 1),
('unpublish', 58, 'en', 'help_search', 5),
('unpublished', 59, 'en', 'help_search', 1),
('unpublished', 65, 'en', 'help_search', 2),
('unpublished', 67, 'en', 'help_search', 1),
('unpublishing', 71, 'en', 'help_search', 0.819249),
('until', 26, 'en', 'help_search', 1),
('until', 32, 'en', 'help_search', 1),
('until', 45, 'en', 'help_search', 1),
('until', 59, 'en', 'help_search', 1),
('until', 60, 'en', 'help_search', 1),
('until', 70, 'en', 'help_search', 1),
('until', 73, 'en', 'help_search', 1),
('until', 79, 'en', 'help_search', 1),
('untrusted', 50, 'en', 'help_search', 0.882818),
('untrusted', 59, 'en', 'help_search', 0.953396),
('unused', 39, 'en', 'help_search', 26),
('unwanted', 58, 'en', 'help_search', 1),
('upcoming', 37, 'en', 'help_search', 1),
('update', 19, 'en', 'help_search', 4),
('update', 22, 'en', 'help_search', 1),
('update', 24, 'en', 'help_search', 1.87314),
('update', 37, 'en', 'help_search', 4),
('update', 45, 'en', 'help_search', 3),
('update', 47, 'en', 'help_search', 1),
('update', 67, 'en', 'help_search', 2),
('update', 83, 'en', 'help_search', 1),
('update', 85, 'en', 'help_search', 4),
('updated', 13, 'en', 'help_search', 1),
('updated', 26, 'en', 'help_search', 1),
('updated', 27, 'en', 'help_search', 2),
('updated', 28, 'en', 'help_search', 1),
('updated', 69, 'en', 'help_search', 9),
('updates', 11, 'en', 'help_search', 1.92384),
('updates', 19, 'en', 'help_search', 21),
('updates', 24, 'en', 'help_search', 0.892724),
('updates', 37, 'en', 'help_search', 6),
('updating', 11, 'en', 'help_search', 1.47793),
('updating', 15, 'en', 'help_search', 1),
('updating', 19, 'en', 'help_search', 2),
('upload', 3, 'en', 'help_search', 4),
('uploaded', 3, 'en', 'help_search', 1),
('uploaded', 10, 'en', 'help_search', 1),
('upper', 60, 'en', 'help_search', 2),
('url', 8, 'en', 'help_search', 1),
('url', 13, 'en', 'help_search', 6),
('url', 16, 'en', 'help_search', 1),
('url', 28, 'en', 'help_search', 1),
('url', 30, 'en', 'help_search', 1),
('url', 33, 'en', 'help_search', 2.97395),
('url', 44, 'en', 'help_search', 4),
('url', 71, 'en', 'help_search', 1),
('url', 73, 'en', 'help_search', 1),
('url', 76, 'en', 'help_search', 54),
('url', 77, 'en', 'help_search', 55),
('url', 78, 'en', 'help_search', 25),
('urls', 12, 'en', 'help_search', 0.833529),
('urls', 33, 'en', 'help_search', 1),
('urls', 50, 'en', 'help_search', 3.99731),
('urls', 76, 'en', 'help_search', 1),
('urls', 77, 'en', 'help_search', 1),
('urls', 78, 'en', 'help_search', 58),
('use', 2, 'en', 'help_search', 1),
('use', 5, 'en', 'help_search', 1),
('use', 6, 'en', 'help_search', 6),
('use', 12, 'en', 'help_search', 1.26527),
('use', 13, 'en', 'help_search', 1),
('use', 14, 'en', 'help_search', 1),
('use', 16, 'en', 'help_search', 2),
('use', 18, 'en', 'help_search', 1.98902),
('use', 20, 'en', 'help_search', 4),
('use', 23, 'en', 'help_search', 1),
('use', 24, 'en', 'help_search', 0.876337),
('use', 25, 'en', 'help_search', 1),
('use', 27, 'en', 'help_search', 1.98902),
('use', 30, 'en', 'help_search', 18.4099),
('use', 32, 'en', 'help_search', 2),
('use', 33, 'en', 'help_search', 1),
('use', 34, 'en', 'help_search', 6),
('use', 38, 'en', 'help_search', 3),
('use', 44, 'en', 'help_search', 2),
('use', 50, 'en', 'help_search', 3.73884),
('use', 53, 'en', 'help_search', 1.96109),
('use', 55, 'en', 'help_search', 1),
('use', 60, 'en', 'help_search', 9),
('use', 62, 'en', 'help_search', 1),
('use', 63, 'en', 'help_search', 1),
('use', 67, 'en', 'help_search', 2),
('use', 78, 'en', 'help_search', 1),
('use', 79, 'en', 'help_search', 5),
('use', 81, 'en', 'help_search', 2.99731),
('used', 10, 'en', 'help_search', 1),
('used', 11, 'en', 'help_search', 0.976851),
('used', 12, 'en', 'help_search', 1),
('used', 15, 'en', 'help_search', 1),
('used', 17, 'en', 'help_search', 1),
('used', 21, 'en', 'help_search', 1),
('used', 38, 'en', 'help_search', 1),
('used', 39, 'en', 'help_search', 3),
('used', 42, 'en', 'help_search', 1),
('used', 50, 'en', 'help_search', 2),
('used', 53, 'en', 'help_search', 1.99731),
('used', 59, 'en', 'help_search', 1),
('used', 61, 'en', 'help_search', 1),
('used', 62, 'en', 'help_search', 1),
('used', 63, 'en', 'help_search', 1),
('used', 64, 'en', 'help_search', 1),
('used', 70, 'en', 'help_search', 3),
('used', 74, 'en', 'help_search', 1),
('used', 81, 'en', 'help_search', 2),
('useful', 50, 'en', 'help_search', 1),
('user', 6, 'en', 'help_search', 19),
('user', 8, 'en', 'help_search', 4),
('user', 10, 'en', 'help_search', 10.1622),
('user', 11, 'en', 'help_search', 22.0204),
('user', 12, 'en', 'help_search', 27.3552),
('user', 13, 'en', 'help_search', 21.0175),
('user', 14, 'en', 'help_search', 22),
('user', 15, 'en', 'help_search', 22),
('user', 16, 'en', 'help_search', 2),
('user', 17, 'en', 'help_search', 12),
('user', 18, 'en', 'help_search', 1),
('user', 19, 'en', 'help_search', 11),
('user', 22, 'en', 'help_search', 2),
('user', 23, 'en', 'help_search', 1),
('user', 24, 'en', 'help_search', 0.916736),
('user', 25, 'en', 'help_search', 2),
('user', 27, 'en', 'help_search', 1),
('user', 30, 'en', 'help_search', 8.33564),
('user', 31, 'en', 'help_search', 11),
('user', 33, 'en', 'help_search', 3),
('user', 34, 'en', 'help_search', 4),
('user', 37, 'en', 'help_search', 11),
('user', 40, 'en', 'help_search', 43),
('user', 42, 'en', 'help_search', 69),
('user', 44, 'en', 'help_search', 57.974),
('user', 45, 'en', 'help_search', 33),
('user', 48, 'en', 'help_search', 11),
('user', 53, 'en', 'help_search', 1),
('user', 54, 'en', 'help_search', 2.92384),
('user', 59, 'en', 'help_search', 2.91674),
('user', 65, 'en', 'help_search', 22.8038),
('user', 66, 'en', 'help_search', 22),
('user', 67, 'en', 'help_search', 21.7671),
('user', 69, 'en', 'help_search', 28),
('user', 71, 'en', 'help_search', 11.2515),
('user', 73, 'en', 'help_search', 1),
('user', 76, 'en', 'help_search', 11),
('user', 78, 'en', 'help_search', 13),
('user', 79, 'en', 'help_search', 1),
('user', 80, 'en', 'help_search', 11),
('user', 81, 'en', 'help_search', 11.6063),
('user', 85, 'en', 'help_search', 10.5295),
('userdefined', 11, 'en', 'help_search', 1),
('userinterface', 22, 'en', 'help_search', 1),
('username', 40, 'en', 'help_search', 4),
('users', 5, 'en', 'help_search', 1),
('users', 6, 'en', 'help_search', 6),
('users', 8, 'en', 'help_search', 4),
('users', 12, 'en', 'help_search', 1.87313),
('users', 18, 'en', 'help_search', 4.86555),
('users', 21, 'en', 'help_search', 2),
('users', 23, 'en', 'help_search', 7),
('users', 24, 'en', 'help_search', 1),
('users', 26, 'en', 'help_search', 1),
('users', 27, 'en', 'help_search', 20.9729),
('users', 29, 'en', 'help_search', 1),
('users', 30, 'en', 'help_search', 6.53343),
('users', 34, 'en', 'help_search', 1),
('users', 42, 'en', 'help_search', 8),
('users', 44, 'en', 'help_search', 8),
('users', 46, 'en', 'help_search', 1),
('users', 50, 'en', 'help_search', 3.77902),
('users', 55, 'en', 'help_search', 1),
('users', 56, 'en', 'help_search', 1),
('users', 58, 'en', 'help_search', 1),
('users', 59, 'en', 'help_search', 2.85934),
('users', 60, 'en', 'help_search', 2),
('users', 65, 'en', 'help_search', 3),
('users', 66, 'en', 'help_search', 1),
('users', 67, 'en', 'help_search', 2),
('users', 71, 'en', 'help_search', 3.85439),
('users', 76, 'en', 'help_search', 1),
('users', 77, 'en', 'help_search', 1),
('users', 78, 'en', 'help_search', 1),
('users', 79, 'en', 'help_search', 4),
('users', 80, 'en', 'help_search', 1),
('users', 81, 'en', 'help_search', 2),
('uses', 19, 'en', 'help_search', 1),
('uses', 29, 'en', 'help_search', 1),
('using', 2, 'en', 'help_search', 1),
('using', 8, 'en', 'help_search', 20),
('using', 11, 'en', 'help_search', 9.24453),
('using', 14, 'en', 'help_search', 2),
('using', 16, 'en', 'help_search', 1.99731),
('using', 20, 'en', 'help_search', 26),
('using', 24, 'en', 'help_search', 28.8828),
('using', 25, 'en', 'help_search', 5),
('using', 27, 'en', 'help_search', 1),
('using', 30, 'en', 'help_search', 0.873132),
('using', 36, 'en', 'help_search', 1),
('using', 38, 'en', 'help_search', 1),
('using', 42, 'en', 'help_search', 1),
('using', 55, 'en', 'help_search', 1),
('using', 60, 'en', 'help_search', 26),
('using', 69, 'en', 'help_search', 19),
('using', 71, 'en', 'help_search', 0.860547),
('using', 79, 'en', 'help_search', 26),
('using', 82, 'en', 'help_search', 1),
('using', 85, 'en', 'help_search', 1),
('usually', 64, 'en', 'help_search', 1),
('uuid', 11, 'en', 'help_search', 5.2071),
('valid', 18, 'en', 'help_search', 1),
('valid', 54, 'en', 'help_search', 1),
('value', 11, 'en', 'help_search', 0.714225),
('value', 12, 'en', 'help_search', 0.784336),
('value', 55, 'en', 'help_search', 3.78332),
('value', 61, 'en', 'help_search', 4),
('value', 64, 'en', 'help_search', 4),
('value', 77, 'en', 'help_search', 1),
('value', 85, 'en', 'help_search', 2),
('values', 12, 'en', 'help_search', 6.37799),
('values', 33, 'en', 'help_search', 1),
('values', 45, 'en', 'help_search', 1),
('values', 55, 'en', 'help_search', 4.90974),
('values', 61, 'en', 'help_search', 6),
('values', 64, 'en', 'help_search', 6),
('values', 67, 'en', 'help_search', 3),
('variables', 44, 'en', 'help_search', 25),
('variations', 12, 'en', 'help_search', 1),
('various', 24, 'en', 'help_search', 0.927431),
('various', 54, 'en', 'help_search', 1),
('vary', 47, 'en', 'help_search', 1),
('vary', 61, 'en', 'help_search', 1),
('vary', 83, 'en', 'help_search', 1),
('vegetables', 81, 'en', 'help_search', 1),
('verification', 44, 'en', 'help_search', 2),
('verified', 59, 'en', 'help_search', 1),
('verified', 85, 'en', 'help_search', 1),
('verify', 6, 'en', 'help_search', 1),
('verify', 26, 'en', 'help_search', 4),
('verify', 28, 'en', 'help_search', 1),
('verify', 29, 'en', 'help_search', 0.896076),
('verify', 30, 'en', 'help_search', 0.860547),
('verify', 36, 'en', 'help_search', 1),
('verify', 38, 'en', 'help_search', 2),
('verify', 40, 'en', 'help_search', 1),
('verify', 44, 'en', 'help_search', 0.98493),
('verify', 50, 'en', 'help_search', 0.797402),
('verify', 64, 'en', 'help_search', 1),
('verify', 73, 'en', 'help_search', 1),
('verify', 76, 'en', 'help_search', 1),
('verify', 79, 'en', 'help_search', 0.997306),
('verify', 83, 'en', 'help_search', 1),
('verify', 85, 'en', 'help_search', 1),
('versatile', 16, 'en', 'help_search', 1),
('versions', 11, 'en', 'help_search', 0.896076),
('vertical', 66, 'en', 'help_search', 1),
('very', 12, 'en', 'help_search', 1.6956),
('very', 30, 'en', 'help_search', 1),
('via', 25, 'en', 'help_search', 1),
('via', 59, 'en', 'help_search', 1),
('videos', 16, 'en', 'help_search', 1),
('view', 6, 'en', 'help_search', 6),
('view', 7, 'en', 'help_search', 1),
('view', 11, 'en', 'help_search', 1),
('view', 27, 'en', 'help_search', 0.96498),
('view', 30, 'en', 'help_search', 7.26433),
('view', 46, 'en', 'help_search', 5),
('view', 60, 'en', 'help_search', 2),
('view', 69, 'en', 'help_search', 2),
('view', 71, 'en', 'help_search', 51.209),
('view', 79, 'en', 'help_search', 2),
('view', 82, 'en', 'help_search', 32),
('view', 83, 'en', 'help_search', 33.9849),
('view', 84, 'en', 'help_search', 42),
('view', 85, 'en', 'help_search', 29),
('viewed', 8, 'en', 'help_search', 1),
('viewed', 21, 'en', 'help_search', 1),
('viewed', 27, 'en', 'help_search', 1),
('viewer', 8, 'en', 'help_search', 1),
('viewing', 8, 'en', 'help_search', 1),
('viewing', 27, 'en', 'help_search', 1),
('viewing', 42, 'en', 'help_search', 2),
('viewing', 46, 'en', 'help_search', 26),
('viewing', 62, 'en', 'help_search', 1),
('viewport', 53, 'en', 'help_search', 2),
('viewports', 53, 'en', 'help_search', 1),
('views', 11, 'en', 'help_search', 1),
('views', 21, 'en', 'help_search', 1),
('views', 69, 'en', 'help_search', 1),
('views', 71, 'en', 'help_search', 54.628),
('views', 82, 'en', 'help_search', 4),
('views', 83, 'en', 'help_search', 29),
('views', 84, 'en', 'help_search', 4),
('views', 85, 'en', 'help_search', 15.572),
('visibility', 22, 'en', 'help_search', 2),
('visibility', 26, 'en', 'help_search', 4),
('visibility', 47, 'en', 'help_search', 4),
('visible', 12, 'en', 'help_search', 1),
('visible', 26, 'en', 'help_search', 2),
('visible', 54, 'en', 'help_search', 0.851346),
('visible', 55, 'en', 'help_search', 0.899454),
('visible', 57, 'en', 'help_search', 1),
('visible', 58, 'en', 'help_search', 1),
('visible', 60, 'en', 'help_search', 2.99731),
('visible', 61, 'en', 'help_search', 1),
('visible', 62, 'en', 'help_search', 1),
('visible', 64, 'en', 'help_search', 1),
('visit', 13, 'en', 'help_search', 3),
('visit', 20, 'en', 'help_search', 1),
('visit', 30, 'en', 'help_search', 1),
('visit', 33, 'en', 'help_search', 1),
('visit', 38, 'en', 'help_search', 1),
('visit', 60, 'en', 'help_search', 1.98902),
('visit', 65, 'en', 'help_search', 1),
('visit', 78, 'en', 'help_search', 1),
('visited', 69, 'en', 'help_search', 28),
('visited', 76, 'en', 'help_search', 1),
('visiting', 24, 'en', 'help_search', 1),
('visitor', 59, 'en', 'help_search', 1),
('visitors', 8, 'en', 'help_search', 1),
('visitors', 12, 'en', 'help_search', 2),
('visitors', 30, 'en', 'help_search', 0.842342),
('visitors', 34, 'en', 'help_search', 1),
('visitors', 42, 'en', 'help_search', 46),
('visitors', 48, 'en', 'help_search', 1),
('visitors', 59, 'en', 'help_search', 0.913226),
('visitors', 78, 'en', 'help_search', 1),
('visits', 33, 'en', 'help_search', 1),
('visits', 69, 'en', 'help_search', 19),
('visual', 10, 'en', 'help_search', 2),
('visual', 16, 'en', 'help_search', 1),
('visual', 50, 'en', 'help_search', 1),
('visual', 54, 'en', 'help_search', 4),
('visually', 62, 'en', 'help_search', 4),
('vocabularies', 80, 'en', 'help_search', 4),
('vocabularies', 81, 'en', 'help_search', 1.9347),
('vocabulary', 80, 'en', 'help_search', 35),
('vocabulary', 81, 'en', 'help_search', 6),
('w3c', 53, 'en', 'help_search', 10.3222),
('wait', 13, 'en', 'help_search', 1),
('wait', 35, 'en', 'help_search', 1),
('wait', 36, 'en', 'help_search', 1),
('wait', 38, 'en', 'help_search', 1),
('waiting', 29, 'en', 'help_search', 0.902857),
('walk', 30, 'en', 'help_search', 1.90318),
('walked', 30, 'en', 'help_search', 0.938382),
('walking', 30, 'en', 'help_search', 0.942091),
('want', 2, 'en', 'help_search', 1),
('want', 3, 'en', 'help_search', 1),
('want', 4, 'en', 'help_search', 2),
('want', 5, 'en', 'help_search', 2),
('want', 6, 'en', 'help_search', 1),
('want', 7, 'en', 'help_search', 1),
('want', 9, 'en', 'help_search', 1),
('want', 13, 'en', 'help_search', 1),
('want', 20, 'en', 'help_search', 2),
('want', 28, 'en', 'help_search', 1),
('want', 32, 'en', 'help_search', 2),
('want', 35, 'en', 'help_search', 2),
('want', 36, 'en', 'help_search', 1),
('want', 38, 'en', 'help_search', 3),
('want', 39, 'en', 'help_search', 1),
('want', 40, 'en', 'help_search', 1),
('want', 44, 'en', 'help_search', 1.99731),
('want', 45, 'en', 'help_search', 2),
('want', 47, 'en', 'help_search', 4),
('want', 49, 'en', 'help_search', 3),
('want', 50, 'en', 'help_search', 0.842342),
('want', 51, 'en', 'help_search', 1),
('want', 57, 'en', 'help_search', 2),
('want', 60, 'en', 'help_search', 1),
('want', 61, 'en', 'help_search', 3),
('want', 62, 'en', 'help_search', 3),
('want', 63, 'en', 'help_search', 2),
('want', 64, 'en', 'help_search', 6),
('want', 65, 'en', 'help_search', 1),
('want', 66, 'en', 'help_search', 1),
('want', 72, 'en', 'help_search', 2),
('want', 75, 'en', 'help_search', 1),
('want', 79, 'en', 'help_search', 1),
('want', 80, 'en', 'help_search', 1),
('want', 82, 'en', 'help_search', 2),
('want', 83, 'en', 'help_search', 1),
('want', 85, 'en', 'help_search', 3.98902),
('warning', 43, 'en', 'help_search', 4),
('warnings', 37, 'en', 'help_search', 1),
('was', 3, 'en', 'help_search', 1),
('was', 4, 'en', 'help_search', 1),
('was', 32, 'en', 'help_search', 1),
('was', 36, 'en', 'help_search', 1),
('was', 39, 'en', 'help_search', 1),
('was', 47, 'en', 'help_search', 1),
('was', 69, 'en', 'help_search', 1),
('way', 10, 'en', 'help_search', 1),
('way', 12, 'en', 'help_search', 1.32634),
('way', 13, 'en', 'help_search', 2),
('way', 18, 'en', 'help_search', 0.942091),
('way', 25, 'en', 'help_search', 1),
('way', 50, 'en', 'help_search', 1),
('way', 53, 'en', 'help_search', 1),
('way', 71, 'en', 'help_search', 0.886095),
('ways', 11, 'en', 'help_search', 1),
('ways', 12, 'en', 'help_search', 1),
('ways', 81, 'en', 'help_search', 1),
('web', 13, 'en', 'help_search', 2),
('web', 17, 'en', 'help_search', 1),
('web', 25, 'en', 'help_search', 93),
('web', 33, 'en', 'help_search', 3),
('web', 48, 'en', 'help_search', 1),
('web', 59, 'en', 'help_search', 1),
('web', 68, 'en', 'help_search', 1),
('web', 78, 'en', 'help_search', 2),
('website', 6, 'en', 'help_search', 1),
('website', 12, 'en', 'help_search', 1),
('website', 21, 'en', 'help_search', 26),
('website', 44, 'en', 'help_search', 2),
('website', 58, 'en', 'help_search', 2),
('website', 59, 'en', 'help_search', 1),
('website', 78, 'en', 'help_search', 1),
('website', 81, 'en', 'help_search', 3),
('week', 13, 'en', 'help_search', 1),
('weekly', 13, 'en', 'help_search', 1),
('weights', 23, 'en', 'help_search', 5),
('well', 13, 'en', 'help_search', 2),
('well', 18, 'en', 'help_search', 0.860547),
('well', 20, 'en', 'help_search', 1),
('well', 61, 'en', 'help_search', 1),
('well', 79, 'en', 'help_search', 1),
('went', 31, 'en', 'help_search', 1),
('were', 32, 'en', 'help_search', 2),
('were', 33, 'en', 'help_search', 1.84528),
('were', 35, 'en', 'help_search', 2),
('were', 44, 'en', 'help_search', 0.953396),
('wget', 13, 'en', 'help_search', 4),
('what', 5, 'en', 'help_search', 19),
('what', 8, 'en', 'help_search', 19),
('what', 10, 'en', 'help_search', 57),
('what', 11, 'en', 'help_search', 74.418),
('what', 12, 'en', 'help_search', 146.382),
('what', 13, 'en', 'help_search', 38),
('what', 14, 'en', 'help_search', 57),
('what', 16, 'en', 'help_search', 57),
('what', 17, 'en', 'help_search', 19),
('what', 18, 'en', 'help_search', 76),
('what', 19, 'en', 'help_search', 38),
('what', 20, 'en', 'help_search', 19),
('what', 22, 'en', 'help_search', 19),
('what', 24, 'en', 'help_search', 38),
('what', 25, 'en', 'help_search', 76),
('what', 27, 'en', 'help_search', 19),
('what', 29, 'en', 'help_search', 19),
('what', 30, 'en', 'help_search', 74.7594),
('what', 31, 'en', 'help_search', 19),
('what', 32, 'en', 'help_search', 1),
('what', 33, 'en', 'help_search', 39),
('what', 34, 'en', 'help_search', 19),
('what', 42, 'en', 'help_search', 57),
('what', 44, 'en', 'help_search', 39.989),
('what', 45, 'en', 'help_search', 1),
('what', 46, 'en', 'help_search', 19),
('what', 48, 'en', 'help_search', 76),
('what', 50, 'en', 'help_search', 38),
('what', 53, 'en', 'help_search', 76),
('what', 54, 'en', 'help_search', 27.8995),
('what', 59, 'en', 'help_search', 57),
('what', 60, 'en', 'help_search', 19),
('what', 61, 'en', 'help_search', 1),
('what', 68, 'en', 'help_search', 38),
('what', 69, 'en', 'help_search', 38),
('what', 71, 'en', 'help_search', 58.4225),
('what', 78, 'en', 'help_search', 57),
('what', 79, 'en', 'help_search', 19),
('what', 81, 'en', 'help_search', 19),
('what', 85, 'en', 'help_search', 1),
('when', 8, 'en', 'help_search', 1),
('when', 11, 'en', 'help_search', 5.92719),
('when', 12, 'en', 'help_search', 1.6112),
('when', 15, 'en', 'help_search', 1),
('when', 18, 'en', 'help_search', 2.9496),
('when', 19, 'en', 'help_search', 1),
('when', 23, 'en', 'help_search', 1),
('when', 26, 'en', 'help_search', 1),
('when', 27, 'en', 'help_search', 3),
('when', 29, 'en', 'help_search', 3),
('when', 30, 'en', 'help_search', 1.8861),
('when', 31, 'en', 'help_search', 4),
('when', 33, 'en', 'help_search', 2),
('when', 34, 'en', 'help_search', 6),
('when', 36, 'en', 'help_search', 1),
('when', 44, 'en', 'help_search', 3),
('when', 47, 'en', 'help_search', 1),
('when', 48, 'en', 'help_search', 1),
('when', 50, 'en', 'help_search', 2),
('when', 53, 'en', 'help_search', 3),
('when', 54, 'en', 'help_search', 1.98902),
('when', 61, 'en', 'help_search', 1),
('when', 62, 'en', 'help_search', 1),
('when', 63, 'en', 'help_search', 1),
('when', 64, 'en', 'help_search', 1),
('when', 65, 'en', 'help_search', 1),
('when', 69, 'en', 'help_search', 1),
('when', 71, 'en', 'help_search', 1),
('when', 72, 'en', 'help_search', 1),
('when', 73, 'en', 'help_search', 3),
('when', 79, 'en', 'help_search', 1),
('when', 81, 'en', 'help_search', 2),
('when', 85, 'en', 'help_search', 2),
('whenever', 26, 'en', 'help_search', 1),
('where', 10, 'en', 'help_search', 1),
('where', 12, 'en', 'help_search', 0.813674),
('where', 13, 'en', 'help_search', 1),
('where', 27, 'en', 'help_search', 19),
('where', 44, 'en', 'help_search', 1),
('where', 47, 'en', 'help_search', 2),
('where', 49, 'en', 'help_search', 1),
('where', 59, 'en', 'help_search', 1),
('where', 71, 'en', 'help_search', 1),
('whether', 12, 'en', 'help_search', 1),
('whether', 55, 'en', 'help_search', 3.95793),
('whether', 71, 'en', 'help_search', 2),
('which', 6, 'en', 'help_search', 2),
('which', 8, 'en', 'help_search', 3),
('which', 10, 'en', 'help_search', 1),
('which', 11, 'en', 'help_search', 2.64632),
('which', 12, 'en', 'help_search', 5.65326),
('which', 13, 'en', 'help_search', 1),
('which', 16, 'en', 'help_search', 1),
('which', 18, 'en', 'help_search', 1),
('which', 24, 'en', 'help_search', 3),
('which', 27, 'en', 'help_search', 1),
('which', 29, 'en', 'help_search', 1),
('which', 30, 'en', 'help_search', 1.9689),
('which', 36, 'en', 'help_search', 1),
('which', 37, 'en', 'help_search', 1),
('which', 38, 'en', 'help_search', 1),
('which', 42, 'en', 'help_search', 1),
('which', 48, 'en', 'help_search', 1),
('which', 50, 'en', 'help_search', 1.78178),
('which', 51, 'en', 'help_search', 1),
('which', 53, 'en', 'help_search', 2),
('which', 54, 'en', 'help_search', 2),
('which', 56, 'en', 'help_search', 1),
('which', 58, 'en', 'help_search', 1),
('which', 59, 'en', 'help_search', 2),
('which', 60, 'en', 'help_search', 1),
('which', 61, 'en', 'help_search', 2),
('which', 64, 'en', 'help_search', 1),
('which', 65, 'en', 'help_search', 1),
('which', 66, 'en', 'help_search', 1),
('which', 68, 'en', 'help_search', 2),
('which', 69, 'en', 'help_search', 28),
('which', 70, 'en', 'help_search', 1),
('which', 71, 'en', 'help_search', 3.85439),
('which', 73, 'en', 'help_search', 1),
('which', 74, 'en', 'help_search', 3),
('which', 78, 'en', 'help_search', 3),
('which', 79, 'en', 'help_search', 2),
('which', 80, 'en', 'help_search', 1),
('which', 81, 'en', 'help_search', 1),
('which', 83, 'en', 'help_search', 1),
('which', 84, 'en', 'help_search', 1),
('while', 12, 'en', 'help_search', 2.22095),
('while', 17, 'en', 'help_search', 1),
('while', 28, 'en', 'help_search', 1),
('while', 60, 'en', 'help_search', 1),
('while', 81, 'en', 'help_search', 1),
('white', 33, 'en', 'help_search', 4),
('who', 18, 'en', 'help_search', 1),
('who', 20, 'en', 'help_search', 19),
('who', 34, 'en', 'help_search', 1),
('who', 42, 'en', 'help_search', 3),
('who', 46, 'en', 'help_search', 19),
('who', 50, 'en', 'help_search', 1),
('who', 55, 'en', 'help_search', 19),
('who', 56, 'en', 'help_search', 19),
('who', 57, 'en', 'help_search', 19),
('who', 58, 'en', 'help_search', 19),
('who', 65, 'en', 'help_search', 19),
('who', 66, 'en', 'help_search', 19),
('who', 67, 'en', 'help_search', 19),
('who', 71, 'en', 'help_search', 0.879565),
('who', 76, 'en', 'help_search', 19),
('who', 77, 'en', 'help_search', 19),
('who', 80, 'en', 'help_search', 19),
('who', 83, 'en', 'help_search', 20),
('whose', 8, 'en', 'help_search', 1),
('whose', 48, 'en', 'help_search', 1),
('whose', 78, 'en', 'help_search', 1),
('whose', 85, 'en', 'help_search', 1),
('why', 35, 'en', 'help_search', 1),
('widelyused', 54, 'en', 'help_search', 1),
('widget', 12, 'en', 'help_search', 17.5931),
('widget', 16, 'en', 'help_search', 4),
('widget', 63, 'en', 'help_search', 7),
('widgets', 63, 'en', 'help_search', 5),
('width', 16, 'en', 'help_search', 1),
('width', 53, 'en', 'help_search', 30),
('width', 70, 'en', 'help_search', 4),
('widths', 53, 'en', 'help_search', 2),
('will', 3, 'en', 'help_search', 2),
('will', 5, 'en', 'help_search', 1),
('will', 6, 'en', 'help_search', 1),
('will', 7, 'en', 'help_search', 1),
('will', 8, 'en', 'help_search', 1),
('will', 11, 'en', 'help_search', 1.67852),
('will', 12, 'en', 'help_search', 0.584241),
('will', 13, 'en', 'help_search', 2),
('will', 18, 'en', 'help_search', 1.86679),
('will', 19, 'en', 'help_search', 1),
('will', 20, 'en', 'help_search', 2),
('will', 24, 'en', 'help_search', 1),
('will', 27, 'en', 'help_search', 2.96109),
('will', 28, 'en', 'help_search', 2),
('will', 29, 'en', 'help_search', 3),
('will', 30, 'en', 'help_search', 5.57006),
('will', 31, 'en', 'help_search', 1),
('will', 33, 'en', 'help_search', 1),
('will', 34, 'en', 'help_search', 5),
('will', 37, 'en', 'help_search', 1),
('will', 40, 'en', 'help_search', 1),
('will', 42, 'en', 'help_search', 1),
('will', 46, 'en', 'help_search', 1),
('will', 47, 'en', 'help_search', 1),
('will', 49, 'en', 'help_search', 2),
('will', 50, 'en', 'help_search', 1.72016),
('will', 52, 'en', 'help_search', 1),
('will', 53, 'en', 'help_search', 1),
('will', 54, 'en', 'help_search', 2.68852),
('will', 55, 'en', 'help_search', 1.98087),
('will', 56, 'en', 'help_search', 2),
('will', 57, 'en', 'help_search', 3),
('will', 58, 'en', 'help_search', 1),
('will', 60, 'en', 'help_search', 2),
('will', 62, 'en', 'help_search', 1),
('will', 64, 'en', 'help_search', 2),
('will', 65, 'en', 'help_search', 2),
('will', 66, 'en', 'help_search', 4),
('will', 71, 'en', 'help_search', 1),
('will', 72, 'en', 'help_search', 1),
('will', 73, 'en', 'help_search', 3),
('will', 74, 'en', 'help_search', 1),
('will', 76, 'en', 'help_search', 1),
('will', 77, 'en', 'help_search', 2),
('will', 78, 'en', 'help_search', 1),
('will', 79, 'en', 'help_search', 1),
('will', 80, 'en', 'help_search', 6),
('will', 81, 'en', 'help_search', 0.989021),
('will', 82, 'en', 'help_search', 3),
('will', 83, 'en', 'help_search', 4.98224),
('will', 84, 'en', 'help_search', 2),
('wish', 30, 'en', 'help_search', 0.816452),
('wish', 62, 'en', 'help_search', 1),
('wish', 63, 'en', 'help_search', 1),
('with', 7, 'en', 'help_search', 1),
('with', 8, 'en', 'help_search', 1),
('with', 10, 'en', 'help_search', 1),
('with', 11, 'en', 'help_search', 0.757065),
('with', 12, 'en', 'help_search', 8.7836),
('with', 15, 'en', 'help_search', 1),
('with', 16, 'en', 'help_search', 2),
('with', 18, 'en', 'help_search', 1.88882),
('with', 19, 'en', 'help_search', 1),
('with', 20, 'en', 'help_search', 1),
('with', 22, 'en', 'help_search', 45),
('with', 23, 'en', 'help_search', 3),
('with', 24, 'en', 'help_search', 2),
('with', 25, 'en', 'help_search', 1),
('with', 27, 'en', 'help_search', 26.9729),
('with', 29, 'en', 'help_search', 1),
('with', 30, 'en', 'help_search', 3.83051),
('with', 34, 'en', 'help_search', 1),
('with', 35, 'en', 'help_search', 2),
('with', 36, 'en', 'help_search', 1),
('with', 42, 'en', 'help_search', 1),
('with', 43, 'en', 'help_search', 1),
('with', 44, 'en', 'help_search', 2),
('with', 46, 'en', 'help_search', 1),
('with', 50, 'en', 'help_search', 1),
('with', 53, 'en', 'help_search', 12.363),
('with', 55, 'en', 'help_search', 2.97286),
('with', 56, 'en', 'help_search', 1),
('with', 58, 'en', 'help_search', 1),
('with', 59, 'en', 'help_search', 1),
('with', 60, 'en', 'help_search', 3),
('with', 61, 'en', 'help_search', 1),
('with', 64, 'en', 'help_search', 1),
('with', 65, 'en', 'help_search', 2),
('with', 66, 'en', 'help_search', 1),
('with', 67, 'en', 'help_search', 2),
('with', 71, 'en', 'help_search', 10.3981),
('with', 76, 'en', 'help_search', 3),
('with', 77, 'en', 'help_search', 1),
('with', 78, 'en', 'help_search', 1),
('with', 79, 'en', 'help_search', 1),
('with', 80, 'en', 'help_search', 1),
('with', 81, 'en', 'help_search', 1.9381),
('with', 83, 'en', 'help_search', 3),
('with', 85, 'en', 'help_search', 10.6148),
('within', 11, 'en', 'help_search', 1),
('within', 12, 'en', 'help_search', 2),
('within', 27, 'en', 'help_search', 1),
('within', 47, 'en', 'help_search', 1),
('within', 50, 'en', 'help_search', 0.997306),
('within', 54, 'en', 'help_search', 0.896076),
('without', 8, 'en', 'help_search', 1),
('without', 44, 'en', 'help_search', 1),
('without', 60, 'en', 'help_search', 2),
('without', 73, 'en', 'help_search', 1),
('word', 29, 'en', 'help_search', 4),
('word', 30, 'en', 'help_search', 0.96498),
('word', 35, 'en', 'help_search', 1),
('word', 36, 'en', 'help_search', 1),
('word', 67, 'en', 'help_search', 1),
('words', 29, 'en', 'help_search', 2),
('words', 30, 'en', 'help_search', 0.945829),
('work', 59, 'en', 'help_search', 1),
('work', 67, 'en', 'help_search', 0.976851),
('work', 83, 'en', 'help_search', 1),
('workflow', 11, 'en', 'help_search', 7.45733),
('workflow', 59, 'en', 'help_search', 1),
('working', 11, 'en', 'help_search', 1),
('working', 22, 'en', 'help_search', 45),
('working', 27, 'en', 'help_search', 26),
('working', 53, 'en', 'help_search', 10.4041),
('would', 14, 'en', 'help_search', 1),
('would', 20, 'en', 'help_search', 1),
('would', 30, 'en', 'help_search', 0.957226),
('would', 31, 'en', 'help_search', 1),
('would', 33, 'en', 'help_search', 0.972861),
('would', 36, 'en', 'help_search', 2),
('would', 53, 'en', 'help_search', 1),
('would', 55, 'en', 'help_search', 1),
('would', 60, 'en', 'help_search', 3),
('would', 65, 'en', 'help_search', 1),
('would', 67, 'en', 'help_search', 1),
('would', 77, 'en', 'help_search', 1),
('would', 78, 'en', 'help_search', 1),
('would', 83, 'en', 'help_search', 1),
('wraps', 10, 'en', 'help_search', 1),
('write', 11, 'en', 'help_search', 0.707906),
('writing', 27, 'en', 'help_search', 1),
('written', 22, 'en', 'help_search', 1),
('written', 53, 'en', 'help_search', 1),
('wwwexamplecom', 78, 'en', 'help_search', 4),
('wysiwyg', 54, 'en', 'help_search', 4),
('xml', 25, 'en', 'help_search', 1),
('yaml', 1, 'en', 'help_search', 1),
('yaml', 4, 'en', 'help_search', 1),
('yaml', 11, 'en', 'help_search', 3.56669),
('yaml', 27, 'en', 'help_search', 1),
('yaml', 53, 'en', 'help_search', 0.968904),
('yamlformat', 4, 'en', 'help_search', 1),
('yet', 14, 'en', 'help_search', 1),
('yet', 21, 'en', 'help_search', 1),
('yet', 58, 'en', 'help_search', 1),
('yml', 11, 'en', 'help_search', 0.993146),
('you', 2, 'en', 'help_search', 1),
('you', 3, 'en', 'help_search', 2),
('you', 4, 'en', 'help_search', 2),
('you', 5, 'en', 'help_search', 4),
('you', 6, 'en', 'help_search', 1),
('you', 7, 'en', 'help_search', 2),
('you', 8, 'en', 'help_search', 1),
('you', 9, 'en', 'help_search', 1),
('you', 10, 'en', 'help_search', 1.97685),
('you', 12, 'en', 'help_search', 6.57496),
('you', 13, 'en', 'help_search', 10.9946),
('you', 14, 'en', 'help_search', 3),
('you', 15, 'en', 'help_search', 1),
('you', 16, 'en', 'help_search', 1),
('you', 18, 'en', 'help_search', 1.74636),
('you', 19, 'en', 'help_search', 1),
('you', 20, 'en', 'help_search', 5),
('you', 21, 'en', 'help_search', 1),
('you', 22, 'en', 'help_search', 5),
('you', 23, 'en', 'help_search', 1),
('you', 24, 'en', 'help_search', 3),
('you', 26, 'en', 'help_search', 1),
('you', 27, 'en', 'help_search', 1.98902),
('you', 28, 'en', 'help_search', 3),
('you', 29, 'en', 'help_search', 2.83423),
('you', 30, 'en', 'help_search', 6.3893),
('you', 31, 'en', 'help_search', 1),
('you', 32, 'en', 'help_search', 5),
('you', 33, 'en', 'help_search', 6.74314),
('you', 35, 'en', 'help_search', 8),
('you', 36, 'en', 'help_search', 6),
('you', 37, 'en', 'help_search', 5),
('you', 38, 'en', 'help_search', 7),
('you', 39, 'en', 'help_search', 1),
('you', 40, 'en', 'help_search', 3),
('you', 41, 'en', 'help_search', 1),
('you', 42, 'en', 'help_search', 2),
('you', 44, 'en', 'help_search', 7.96229),
('you', 45, 'en', 'help_search', 3),
('you', 46, 'en', 'help_search', 2),
('you', 47, 'en', 'help_search', 6),
('you', 48, 'en', 'help_search', 4),
('you', 49, 'en', 'help_search', 3),
('you', 50, 'en', 'help_search', 4.18461),
('you', 51, 'en', 'help_search', 2),
('you', 52, 'en', 'help_search', 1),
('you', 53, 'en', 'help_search', 0.972861),
('you', 54, 'en', 'help_search', 12.7711),
('you', 55, 'en', 'help_search', 6.91674),
('you', 56, 'en', 'help_search', 2),
('you', 57, 'en', 'help_search', 6),
('you', 58, 'en', 'help_search', 3),
('you', 59, 'en', 'help_search', 3.8894),
('you', 60, 'en', 'help_search', 4.91448),
('you', 61, 'en', 'help_search', 8),
('you', 62, 'en', 'help_search', 6),
('you', 63, 'en', 'help_search', 4),
('you', 64, 'en', 'help_search', 11),
('you', 65, 'en', 'help_search', 3),
('you', 66, 'en', 'help_search', 5),
('you', 67, 'en', 'help_search', 1),
('you', 68, 'en', 'help_search', 3),
('you', 69, 'en', 'help_search', 1),
('you', 71, 'en', 'help_search', 8.4838),
('you', 72, 'en', 'help_search', 2),
('you', 73, 'en', 'help_search', 3),
('you', 74, 'en', 'help_search', 1),
('you', 75, 'en', 'help_search', 1),
('you', 76, 'en', 'help_search', 2),
('you', 77, 'en', 'help_search', 3),
('you', 78, 'en', 'help_search', 5),
('you', 79, 'en', 'help_search', 2),
('you', 80, 'en', 'help_search', 10),
('you', 81, 'en', 'help_search', 6.9394),
('you', 82, 'en', 'help_search', 5),
('you', 83, 'en', 'help_search', 4),
('you', 85, 'en', 'help_search', 6.99731),
('your', 1, 'en', 'help_search', 27),
('your', 2, 'en', 'help_search', 6),
('your', 3, 'en', 'help_search', 30),
('your', 4, 'en', 'help_search', 5),
('your', 6, 'en', 'help_search', 1),
('your', 7, 'en', 'help_search', 1),
('your', 8, 'en', 'help_search', 1),
('your', 10, 'en', 'help_search', 42.1676),
('your', 11, 'en', 'help_search', 1),
('your', 12, 'en', 'help_search', 8.53008),
('your', 13, 'en', 'help_search', 9),
('your', 14, 'en', 'help_search', 39),
('your', 15, 'en', 'help_search', 32),
('your', 16, 'en', 'help_search', 2),
('your', 18, 'en', 'help_search', 1.98902),
('your', 19, 'en', 'help_search', 29),
('your', 20, 'en', 'help_search', 3),
('your', 21, 'en', 'help_search', 27),
('your', 22, 'en', 'help_search', 22),
('your', 24, 'en', 'help_search', 3),
('your', 25, 'en', 'help_search', 1),
('your', 26, 'en', 'help_search', 2),
('your', 27, 'en', 'help_search', 1),
('your', 28, 'en', 'help_search', 1),
('your', 29, 'en', 'help_search', 2),
('your', 30, 'en', 'help_search', 1.80822),
('your', 31, 'en', 'help_search', 4),
('your', 32, 'en', 'help_search', 4),
('your', 33, 'en', 'help_search', 5.96178),
('your', 34, 'en', 'help_search', 5),
('your', 35, 'en', 'help_search', 2),
('your', 36, 'en', 'help_search', 1),
('your', 37, 'en', 'help_search', 32),
('your', 38, 'en', 'help_search', 3),
('your', 41, 'en', 'help_search', 1),
('your', 42, 'en', 'help_search', 2),
('your', 44, 'en', 'help_search', 4.99731),
('your', 47, 'en', 'help_search', 1),
('your', 48, 'en', 'help_search', 2),
('your', 51, 'en', 'help_search', 3),
('your', 52, 'en', 'help_search', 3),
('your', 53, 'en', 'help_search', 1),
('your', 54, 'en', 'help_search', 2),
('your', 59, 'en', 'help_search', 2),
('your', 60, 'en', 'help_search', 4.95373),
('your', 61, 'en', 'help_search', 1),
('your', 62, 'en', 'help_search', 2),
('your', 63, 'en', 'help_search', 2),
('your', 64, 'en', 'help_search', 0.997306),
('your', 65, 'en', 'help_search', 2),
('your', 66, 'en', 'help_search', 1),
('your', 68, 'en', 'help_search', 1),
('your', 70, 'en', 'help_search', 1),
('your', 71, 'en', 'help_search', 1),
('your', 73, 'en', 'help_search', 1),
('your', 74, 'en', 'help_search', 1),
('your', 75, 'en', 'help_search', 1),
('your', 77, 'en', 'help_search', 1),
('your', 78, 'en', 'help_search', 4),
('your', 79, 'en', 'help_search', 5.99731),
('your', 80, 'en', 'help_search', 2),
('your', 81, 'en', 'help_search', 0.997306),
('your', 82, 'en', 'help_search', 2),
('your', 84, 'en', 'help_search', 3),
('your', 85, 'en', 'help_search', 4.98493),
('zone', 32, 'en', 'help_search', 2);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]search_total`
--

CREATE TABLE `[[dbprefix]]search_total` (
  `word` varchar(50) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique word in the search index.',
  `count` float DEFAULT NULL COMMENT 'The count of the word in the index using Zipf''s law to equalize the probability distribution.',
  PRIMARY KEY (`word`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Stores search totals for words.';

--
-- Dumping data for table `[[dbprefix]]search_total`
--

INSERT INTO `[[dbprefix]]search_total` VALUES
('1', 0.30103),
('15', 0.30103),
('2', 0.176091),
('200', 0.30103),
('255', 0.30103),
('3', 0.30103),
('403', 0.0184834),
('403404', 0.0157943),
('404', 0.0177455),
('40em', 0.0791812),
('5', 0.0319098),
('6', 0.30103),
('7', 0.0321847),
('9', 0.30103),
('abbreviation', 0.30103),
('ability', 0.0591189),
('able', 0.0977625),
('about', 0.0101432),
('aboutus', 0.0791812),
('above', 0.0862887),
('access', 0.0124533),
('accessed', 0.30103),
('accessibility', 0.00895484),
('accessible', 0.124939),
('accessing', 0.176091),
('accomplish', 0.30103),
('account', 0.00400315),
('accountname', 0.30103),
('accounts', 0.00509979),
('action', 0.0179663),
('actions', 0.0298577),
('active', 0.0188459),
('activity', 0.30103),
('acts', 0.30103),
('add', 0.00256055),
('added', 0.0331334),
('adding', 0.00211411),
('addition', 0.0818822),
('additional', 0.000785582),
('address', 0.0457575),
('addresses', 0.188552),
('adds', 0.30103),
('adjust', 0.13284),
('admin', 0.0222764),
('administer', 0.00706588),
('administering', 0.30103),
('administration', 0.0263289),
('administrative', 0.001819),
('administrator', 0.125187),
('administrators', 0.0347621),
('advanced', 0.0291605),
('advisories', 0.0211893),
('advisory', 0.0299632),
('affected', 0.30103),
('after', 0.0435474),
('afterwards', 0.30103),
('again', 0.124939),
('against', 0.176091),
('aggregation', 0.0203441),
('alias', 0.0050208),
('aliases', 0.00363428),
('aliasing', 0.30103),
('all', 0.0109269),
('allow', 0.0381864),
('allowed', 0.0187831),
('allows', 0.0175473),
('along', 0.176091),
('already', 0.0347621),
('alreadyconfigured', 0.30103),
('alreadyrendered', 0.30103),
('also', 0.00848959),
('alter', 0.30103),
('alternative', 0.30103),
('alternatively', 0.176091),
('always', 0.09691),
('american', 0.30103),
('anchor', 0.09691),
('and', 0.000403607),
('announcement', 0.0347621),
('announcements', 0.00464491),
('anonymous', 0.0224828),
('another', 0.0273551),
('any', 0.015937),
('anyone', 0.176091),
('apache', 0.0347621),
('api', 0.0122479),
('appear', 0.09691),
('appearance', 0.00686246),
('applications', 0.124939),
('applied', 0.124939),
('applies', 0.30103),
('apply', 0.0203789),
('appropriate', 0.176091),
('appropriately', 0.30103),
('approval', 0.30103),
('approved', 0.30103),
('archive', 0.0430226),
('are', 0.000504792),
('area', 0.0512188),
('areas', 0.30103),
('arrows', 0.176091),
('article', 0.0321847),
('articles', 0.176091),
('aspect', 0.30103),
('aspects', 0.30103),
('asset', 0.30103),
('assign', 0.179531),
('assigned', 0.124939),
('assistive', 0.30103),
('associate', 0.133055),
('associated', 0.30103),
('associates', 0.30103),
('association', 0.176091),
('assume', 0.30103),
('assuming', 0.30103),
('assumptions', 0.30103),
('attach', 0.102045),
('attached', 0.0669468),
('attention', 0.30103),
('attribute', 0.30103),
('audio', 0.30103),
('authenticated', 0.0378911),
('authenticating', 0.30103),
('authentication', 0.0125891),
('authoring', 0.0520117),
('authorized', 0.30103),
('automated', 0.0971766),
('automatic', 0.176091),
('automatically', 0.0795601),
('automaticallygenerated', 0.176091),
('available', 0.00299572),
('avoid', 0.30103),
('aware', 0.30103),
('away', 0.30103),
('back', 0.30103),
('background', 0.176091),
('bad', 0.30103),
('ban', 0.176091),
('bar', 0.30103),
('base', 0.0143783),
('basic', 0.00471913),
('because', 0.124939),
('become', 0.30103),
('becomes', 0.30103),
('been', 0.0313976),
('before', 0.0806055),
('behaves', 0.30103),
('behaving', 0.30103),
('behavior', 0.0687641),
('behind', 0.30103),
('being', 0.0477268),
('believe', 0.30103),
('belong', 0.30103),
('below', 0.0165796),
('besides', 0.207766),
('best', 0.09691),
('between', 0.0398561),
('big', 0.30103),
('bigpipe', 0.0446591),
('blank', 0.30103),
('block', 0.00149838),
('blocked', 0.30103),
('blocks', 0.00372822),
('blog', 0.0579919),
('body', 0.124939),
('boolean', 0.30103),
('both', 0.0415108),
('bottom', 0.0796915),
('box', 0.0377886),
('boxes', 0.09691),
('brackets', 0.30103),
('break', 0.30103),
('breakpoint', 0.00793195),
('breakpointenabled', 0.30103),
('breakpoints', 0.00497197),
('breaks', 0.09691),
('browse', 0.30103),
('browser', 0.0807971),
('bugs', 0.09691),
('builder', 0.142212),
('building', 0.30103),
('builtin', 0.176091),
('bulk', 0.00719509),
('but', 0.0303403),
('butter', 0.30103),
('button', 0.0273978),
('buttons', 0.0369925),
('bypass', 0.0511525),
('cache', 0.00512147),
('cacheable', 0.30103),
('cached', 0.0457575),
('caches', 0.0672286),
('caching', 0.0202034),
('calculated', 0.179818),
('calculation', 0.30103),
('calculations', 0.124939),
('calendar', 0.30103),
('called', 0.0518489),
('can', 0.000874947),
('cancel', 0.0324435),
('canceled', 0.0670605),
('cannot', 0.0669468),
('captcha', 0.30103),
('carefully', 0.30103),
('case', 0.30103),
('categorize', 0.30103),
('certain', 0.176091),
('challenge', 0.30103),
('change', 0.0142797),
('changed', 0.0460568),
('changes', 0.0349665),
('changing', 0.00599036),
('channel', 0.30103),
('character', 0.201523),
('characteristics', 0.232926),
('characters', 0.30103),
('check', 0.017203),
('checkbox', 0.176091),
('checked', 0.0579919),
('checking', 0.176091),
('child', 0.30103),
('children', 0.30103),
('chinese', 0.30103),
('choice', 0.176091),
('choices', 0.13934),
('choose', 0.0303115),
('choosing', 0.124939),
('chose', 0.176091),
('chosen', 0.107547),
('cjk', 0.097509),
('ckeditor', 0.0319098),
('claro', 0.125337),
('classified', 0.30103),
('classify', 0.0669747),
('clean', 0.30103),
('clear', 0.0321847),
('cleared', 0.30103),
('clearing', 0.01524),
('cli', 0.30103),
('click', 0.00278674),
('clicked', 0.30103),
('clicking', 0.0581091),
('clicks', 0.30103),
('clipboard', 0.124939),
('cloned', 0.30103),
('clones', 0.30103),
('cloning', 0.30103),
('closed', 0.0534271),
('code', 0.0829375),
('codebase', 0.30103),
('codes', 0.0304214),
('collected', 0.30103),
('collection', 0.178078),
('collectively', 0.30103),
('column', 0.0351189),
('combinations', 0.30103),
('come', 0.182608),
('comes', 0.30103),
('command', 0.176091),
('commandline', 0.30103),
('comment', 0.00238964),
('commentary', 0.30103),
('commented', 0.30103),
('commenters', 0.30103),
('commenting', 0.0418868),
('comments', 0.00161753),
('common', 0.124939),
('commonly', 0.176091),
('commonlyused', 0.176091),
('community', 0.30103),
('communitymembers', 0.30103),
('communityprovided', 0.176091),
('compares', 0.30103),
('comparison', 0.0377886),
('complete', 0.00744726),
('completely', 0.30103),
('complex', 0.128947),
('compliance', 0.30103),
('compliant', 0.30103),
('components', 0.0107239),
('composed', 0.30103),
('compressed', 0.30103),
('computer', 0.176091),
('concept', 0.00465218),
('concepts', 0.30103),
('conditions', 0.176091),
('config', 0.0511525),
('configurable', 0.30103),
('configuration', 0.000853108),
('configure', 0.00351659),
('configured', 0.0428044),
('configuring', 0.00108637),
('confirm', 0.30103),
('confirmation', 0.176091),
('confused', 0.30103),
('connect', 0.30103),
('connected', 0.30103),
('connecting', 0.0163904),
('consist', 0.30103),
('consume', 0.30103),
('contact', 0.00155045),
('contain', 0.0881532),
('containing', 0.0799177),
('contains', 0.100868),
('content', 0.000462597),
('context', 0.0850083),
('contextual', 0.00541456),
('continue', 0.0413927),
('contributed', 0.0124617),
('control', 0.0511525),
('convert', 0.176091),
('converted', 0.30103),
('converting', 0.176091),
('converts', 0.30103),
('cookies', 0.30103),
('cooking', 0.30103),
('copied', 0.187562),
('copy', 0.124939),
('core', 0.00309549),
('corner', 0.176091),
('correct', 0.0352981),
('corresponding', 0.186677),
('corresponds', 0.30103),
('corrupted', 0.30103),
('could', 0.052231),
('counterparts', 0.30103),
('country', 0.176091),
('covered', 0.176091),
('create', 0.00353208),
('created', 0.0100152),
('creates', 0.176091),
('creating', 0.00138972),
('creation', 0.0222764),
('criteria', 0.0224299),
('critical', 0.176091),
('cron', 0.00295015),
('crop', 0.0791812),
('cropping', 0.30103),
('css', 0.10025),
('curated', 0.30103),
('current', 0.0381109),
('currently', 0.0855755),
('custom', 0.0850895),
('customize', 0.30103),
('customizing', 0.0199788),
('data', 0.00429412),
('database', 0.0477659),
('date', 0.0173936),
('dates', 0.187061),
('datetime', 0.199796),
('death', 0.09691),
('decide', 0.30103),
('default', 0.00339584),
('defaults', 0.30103),
('defend', 0.30103),
('define', 0.0348417),
('defined', 0.0791812),
('defines', 0.124939),
('defining', 0.014864),
('delete', 0.0284002),
('deleted', 0.0142404),
('deleting', 0.0153447),
('deletion', 0.0222764),
('demonstrate', 0.0511525),
('dependencies', 0.30103),
('dependent', 0.30103),
('depending', 0.07144),
('depends', 0.30103),
('deploying', 0.013364),
('derived', 0.30103),
('described', 0.194576),
('describes', 0.124939),
('description', 0.011281),
('descriptive', 0.30103),
('deserialization', 0.09691),
('design', 0.30103),
('desired', 0.0172676),
('destination', 0.212504),
('details', 0.0695619),
('determine', 0.30103),
('determines', 0.30103),
('dev', 0.188552),
('development', 0.00801466),
('device', 0.09691),
('deviceindependent', 0.0377886),
('devices', 0.30103),
('diagnose', 0.176091),
('dialog', 0.176091),
('did', 0.176091),
('differences', 0.30103),
('different', 0.0275807),
('differentsized', 0.30103),
('difficult', 0.30103),
('direct', 0.30103),
('directly', 0.0979327),
('directories', 0.30103),
('directory', 0.0721144),
('disable', 0.0170333),
('disabled', 0.0303538),
('disabling', 0.00526424),
('discard', 0.30103),
('discovery', 0.177487),
('discussed', 0.30103),
('discussion', 0.30103),
('display', 0.00247898),
('displayed', 0.00929925),
('displaying', 0.30103),
('displayname', 0.30103),
('displays', 0.0193052),
('distributed', 0.30103),
('divided', 0.0791812),
('divisions', 0.30103),
('documentation', 0.00546188),
('documented', 0.30103),
('documents', 0.30103),
('does', 0.0178018),
('don', 0.30103),
('done', 0.0601132),
('down', 0.30103),
('download', 0.0109954),
('downloaded', 0.0579919),
('downloads', 0.30103),
('drag', 0.0360685),
('draganddrop', 0.124939),
('dragging', 0.185009),
('drastic', 0.30103),
('dropdown', 0.0791812),
('dropped', 0.30103),
('drupal', 0.00112892),
('drupalorg', 0.012965),
('drush', 0.0547947),
('due', 0.30103),
('during', 0.176091),
('dynamic', 0.0405796),
('each', 0.00994036),
('easier', 0.09691),
('easy', 0.30103),
('edit', 0.00181144),
('edited', 0.30103),
('editing', 0.00246179),
('editor', 0.0105939),
('editors', 0.00955747),
('edits', 0.176091),
('effect', 0.0377886),
('effects', 0.0511525),
('efficiently', 0.30103),
('either', 0.0555492),
('element', 0.30103),
('else', 0.30103),
('email', 0.0116858),
('embed', 0.30103),
('enable', 0.09691),
('enabled', 0.0247114),
('enables', 0.176091),
('enabling', 0.00796893),
('enclosed', 0.30103),
('encode', 0.30103),
('end', 0.0690913),
('enforces', 0.30103),
('enforcing', 0.30103),
('engines', 0.30103),
('english', 0.0975029),
('enhances', 0.30103),
('ensure', 0.184484),
('enter', 0.0107552),
('entered', 0.176091),
('entering', 0.30103),
('enters', 0.30103),
('entities', 0.0140013),
('entity', 0.00200787),
('entries', 0.176091),
('error', 0.010809),
('errors', 0.0123697),
('etc', 0.0588093),
('events', 0.30103),
('every', 0.0982369),
('exact', 0.176091),
('example', 0.0101561),
('examplecom', 0.017852),
('examples', 0.0841362),
('exceed', 0.30103),
('except', 0.30103),
('exchanged', 0.176091),
('exist', 0.202653),
('existing', 0.00635326),
('exists', 0.176091),
('expand', 0.30103),
('expanded', 0.09691),
('expect', 0.30103),
('expected', 0.30103),
('experience', 0.30103),
('experimental', 0.0170333),
('expiring', 0.30103),
('explaining', 0.30103),
('export', 0.0255328),
('exported', 0.0398026),
('exporting', 0.00773452),
('expose', 0.30103),
('exposed', 0.0440728),
('exposes', 0.176091),
('extend', 0.00815772),
('extending', 0.00640737),
('extends', 0.30103),
('extension', 0.0836586),
('external', 0.30103),
('facilitate', 0.30103),
('factors', 0.176091),
('false', 0.30103),
('far', 0.30103),
('faster', 0.124939),
('faulty', 0.30103),
('feature', 0.30103),
('features', 0.09691),
('feed', 0.0669468),
('feel', 0.30103),
('few', 0.30103),
('fewer', 0.30103),
('field', 0.00145042),
('fields', 0.00224589),
('file', 0.0142686),
('files', 0.0309399),
('fill', 0.0806641),
('filling', 0.30103),
('filter', 0.009974),
('filtering', 0.129075),
('filters', 0.0049671),
('finally', 0.30103),
('find', 0.00978914),
('finish', 0.30103),
('finished', 0.176091),
('first', 0.0362397),
('fix', 0.30103),
('fixed', 0.176091),
('fixing', 0.0377886),
('flag', 0.30103),
('flat', 0.176091),
('flexible', 0.30103),
('focusing', 0.30103),
('follow', 0.0281802),
('following', 0.0389632),
('footer', 0.0993263),
('for', 0.000643538),
('force', 0.30103),
('forcing', 0.30103),
('form', 0.001733),
('formal', 0.30103),
('format', 0.00533348),
('formats', 0.00399671),
('formatted', 0.0266232),
('formatter', 0.0228134),
('formatters', 0.0636519),
('formatting', 0.30103),
('forms', 0.00299436),
('found', 0.30103),
('four', 0.30103),
('framework', 0.176091),
('free', 0.30103),
('from', 0.0110468),
('front', 0.0669468),
('full', 0.0791812),
('fullexport', 0.30103),
('fully', 0.0834463),
('function', 0.124939),
('functionality', 0.0107813),
('functions', 0.30103),
('further', 0.0908076),
('future', 0.181508),
('gear', 0.176091),
('generally', 0.30103),
('generate', 0.176091),
('generated', 0.09691),
('generating', 0.30103),
('generic', 0.176091),
('get', 0.0808654),
('give', 0.0595632),
('given', 0.30103),
('goal', 0.000393918),
('goals', 0.30103),
('goes', 0.176091),
('good', 0.30103),
('governance', 0.30103),
('granting', 0.30103),
('green', 0.30103),
('grid', 0.0669468),
('group', 0.0151048),
('grouped', 0.176091),
('groups', 0.0181544),
('guide', 0.00145328),
('handles', 0.30103),
('handling', 0.0978732),
('happen', 0.30103),
('happens', 0.097149),
('has', 0.00616605),
('have', 0.00443235),
('haven', 0.30103),
('having', 0.30103),
('header', 0.0805449),
('heading', 0.124939),
('health', 0.176091),
('height', 0.013364),
('help', 0.00187366),
('helps', 0.30103),
('helptopics', 0.0511525),
('here', 0.0129959),
('hidden', 0.0241645),
('hide', 0.138466),
('hiding', 0.30103),
('hierarchical', 0.30103),
('hierarchy', 0.176091),
('highly', 0.176091),
('hints', 0.30103),
('history', 0.176091),
('holds', 0.30103),
('home', 0.0970591),
('horizontal', 0.30103),
('hour', 0.30103),
('hourly', 0.30103),
('hovering', 0.127893),
('hovers', 0.30103),
('how', 0.00351528),
('however', 0.176091),
('html', 0.0164933),
('http', 0.00975984),
('https', 0.0178401),
('human', 0.30103),
('humanreadable', 0.30103),
('icon', 0.124939),
('identification', 0.30103),
('identifier', 0.0892115),
('identifiers', 0.30103),
('identifies', 0.18527),
('image', 0.00581477),
('images', 0.0280683),
('immediately', 0.30103),
('impact', 0.30103),
('implementation', 0.176091),
('implemented', 0.30103),
('implications', 0.0791812),
('import', 0.0193052),
('imported', 0.0679688),
('importing', 0.00802071),
('improper', 0.11041),
('improve', 0.0202034),
('improved', 0.30103),
('include', 0.061714),
('includes', 0.176091),
('including', 0.0116291),
('incorrect', 0.30103),
('increasing', 0.30103),
('index', 0.00655471),
('indexed', 0.0834923),
('indexing', 0.0171016),
('indicating', 0.0689701),
('individual', 0.0584738),
('influence', 0.30103),
('information', 0.00781308),
('informational', 0.30103),
('ingredients', 0.0791812),
('inline', 0.0142475),
('inplace', 0.176091),
('input', 0.206239),
('insert', 0.30103),
('install', 0.0148461),
('installation', 0.176091),
('installed', 0.00844105),
('installing', 0.00568143),
('instance', 0.0430167),
('instances', 0.107823),
('instead', 0.0515494),
('instructions', 0.0981008),
('integer', 0.125963),
('integers', 0.30103),
('interactions', 0.30103),
('interest', 0.09691),
('interests', 0.30103),
('interface', 0.0036333),
('interfaces', 0.30103),
('internal', 0.018932),
('into', 0.0103325),
('invalid', 0.30103),
('item', 0.00182117),
('items', 0.00539173),
('its', 0.0195548),
('itself', 0.30103),
('japanese', 0.30103),
('javascript', 0.0813935),
('jobs', 0.30103),
('json', 0.0115819),
('just', 0.124939),
('keep', 0.128426),
('keeping', 0.176091),
('kept', 0.30103),
('key', 0.19672),
('keyboardonly', 0.30103),
('keys', 0.0997059),
('keyword', 0.176091),
('keywords', 0.124939),
('kinds', 0.0222764),
('knowing', 0.30103),
('known', 0.09691),
('korean', 0.30103),
('label', 0.0100639),
('labeled', 0.124939),
('labels', 0.081504),
('language', 0.0177337),
('languages', 0.00730688),
('languagespecific', 0.30103),
('large', 0.137029),
('larger', 0.30103),
('last', 0.0377886),
('later', 0.0687802),
('layout', 0.0114104),
('layouts', 0.0673016),
('leading', 0.30103),
('leads', 0.30103),
('learn', 0.124939),
('learning', 0.30103),
('least', 0.176091),
('leave', 0.176091),
('left', 0.0512925),
('length', 0.0791812),
('less', 0.30103),
('let', 0.09691),
('lets', 0.30103),
('letting', 0.30103),
('level', 0.30103),
('library', 0.0157943),
('lifetime', 0.081253),
('like', 0.0349754),
('limit', 0.0550801),
('limitations', 0.0211893),
('limited', 0.30103),
('limits', 0.176091),
('line', 0.0791812),
('link', 0.00452883),
('links', 0.00268144),
('linuxlike', 0.30103),
('list', 0.00541726),
('listed', 0.00977448),
('listing', 0.125782),
('listings', 0.00911297),
('lists', 0.101808),
('live', 0.1031),
('load', 0.30103),
('loads', 0.30103),
('locate', 0.0347621),
('located', 0.09691),
('location', 0.144709),
('locations', 0.30103),
('locator', 0.30103),
('log', 0.0457575),
('logged', 0.0792203),
('loggedin', 0.30103),
('logging', 0.060091),
('loginurl', 0.30103),
('long', 0.0454152),
('longer', 0.176091),
('look', 0.124939),
('looks', 0.124939),
('machine', 0.0669468),
('machinereadable', 0.30103),
('made', 0.30103),
('mail', 0.30103),
('main', 0.0443459),
('maintaining', 0.00934003),
('maintenance', 0.00344715),
('make', 0.0126852),
('makes', 0.30103),
('making', 0.0121207),
('malicious', 0.30103),
('manage', 0.00128373),
('managed', 0.0791812),
('management', 0.0086537),
('manager', 0.135476),
('managers', 0.30103),
('manages', 0.30103),
('managing', 0.000695884),
('manner', 0.30103),
('manually', 0.0669468),
('many', 0.0727736),
('mark', 0.30103),
('marked', 0.09691),
('marker', 0.30103),
('markup', 0.09691),
('match', 0.103025),
('matched', 0.30103),
('matches', 0.30103),
('matching', 0.30103),
('matter', 0.30103),
('maximum', 0.1302),
('may', 0.0251936),
('meaning', 0.176091),
('means', 0.127485),
('meant', 0.124939),
('measure', 0.30103),
('mechanisms', 0.09691),
('media', 0.00276975),
('mediarelated', 0.30103),
('medium', 0.30103),
('members', 0.30103),
('mentioned', 0.30103),
('menu', 0.00153637),
('menus', 0.00695232),
('merged', 0.30103),
('message', 0.00899005),
('messages', 0.0286464),
('metadata', 0.0234811),
('method', 0.124939),
('might', 0.0693384),
('minimum', 0.09691),
('minwidth', 0.30103),
('misbehaving', 0.30103),
('mistakes', 0.30103),
('modal', 0.176091),
('mode', 0.00532883),
('moderate', 0.0211893),
('moderating', 0.0113174),
('moderation', 0.0170568),
('modify', 0.0791812),
('modifying', 0.00553249),
('module', 0.00121785),
('modules', 0.0031779),
('month', 0.176091),
('more', 0.00611059),
('most', 0.026264),
('mostcommonlyused', 0.30103),
('mouse', 0.30103),
('move', 0.30103),
('much', 0.30103),
('multiple', 0.09691),
('multiplevalued', 0.30103),
('multiplier', 0.30103),
('multipliers', 0.0185231),
('must', 0.0512436),
('name', 0.00578103),
('names', 0.30103),
('navigate', 0.00576825),
('navigating', 0.176091),
('navigation', 0.30103),
('near', 0.30103),
('necessary', 0.128817),
('need', 0.0131348),
('needed', 0.0690178),
('needing', 0.30103),
('needs', 0.30103),
('never', 0.30103),
('new', 0.00216812),
('newly', 0.30103),
('news', 0.176091),
('next', 0.0299632),
('node', 0.0180067),
('nolink', 0.09691),
('nonadministration', 0.30103),
('nonadministrative', 0.09691),
('noncacheable', 0.30103),
('nondefault', 0.30103),
('none', 0.104012),
('nonenglish', 0.30103),
('nonerror', 0.30103),
('nontoplevel', 0.30103),
('normal', 0.124939),
('normally', 0.124939),
('not', 0.00819287),
('note', 0.0511525),
('notfound', 0.0524957),
('notice', 0.30103),
('notify', 0.09691),
('notifying', 0.30103),
('now', 0.0691678),
('number', 0.0185655),
('numbers', 0.109372),
('numerical', 0.30103),
('occasionally', 0.30103),
('occur', 0.0211893),
('off', 0.09691),
('offer', 0.155997),
('official', 0.09691),
('often', 0.176091),
('older', 0.30103),
('once', 0.0702755),
('one', 0.0105604),
('onetimeloginurl', 0.30103),
('online', 0.00545524),
('only', 0.0245256),
('open', 0.0358537),
('operation', 0.30103),
('operations', 0.00478587),
('optimizing', 0.0163904),
('option', 0.205335),
('optional', 0.0522058),
('optionally', 0.0147342),
('options', 0.00995658),
('order', 0.0107952),
('ordered', 0.30103),
('ordering', 0.176091),
('organize', 0.30103),
('organized', 0.30103),
('organizes', 0.30103),
('original', 0.30103),
('other', 0.00549379),
('out', 0.080246),
('outline', 0.30103),
('output', 0.0458695),
('outreach', 0.30103),
('outside', 0.0511688),
('over', 0.0987526),
('overall', 0.184765),
('override', 0.0803525),
('overview', 0.00112655),
('own', 0.0301141),
('owned', 0.30103),
('owners', 0.176091),
('page', 0.00163557),
('pagelevel', 0.176091),
('pager', 0.0824479),
('pages', 0.00288986),
('paginate', 0.30103),
('paragraph', 0.30103),
('parent', 0.0511525),
('part', 0.0579919),
('particular', 0.0250746),
('parts', 0.187855),
('pass', 0.30103),
('password', 0.0579919),
('past', 0.0822022),
('paste', 0.0669468),
('path', 0.012476),
('pathauto', 0.0377886),
('paths', 0.0137883),
('patterns', 0.09691),
('paying', 0.30103),
('pencil', 0.176091),
('pending', 0.30103),
('people', 0.0123866),
('per', 0.0413927),
('perform', 0.0669468),
('performance', 0.00580152),
('performing', 0.129203),
('periodically', 0.09691),
('periods', 0.30103),
('permanent', 0.30103),
('permission', 0.00557694),
('permissions', 0.00483939),
('personal', 0.00742402),
('personalized', 0.30103),
('php', 0.0299632),
('physical', 0.30103),
('piece', 0.176091),
('pieces', 0.30103),
('pipe', 0.30103),
('pixel', 0.0347621),
('place', 0.0116406),
('placed', 0.0511525),
('placeholders', 0.185457),
('placing', 0.01524),
('plain', 0.0382693),
('plaintext', 0.30103),
('planning', 0.063656),
('plugin', 0.0732599),
('pluginbased', 0.30103),
('plugins', 0.176091),
('point', 0.176091),
('policy', 0.0299632),
('pop', 0.176091),
('popup', 0.30103),
('porter', 0.0383419),
('position', 0.30103),
('positions', 0.30103),
('possibility', 0.30103),
('possible', 0.0754469),
('post', 0.176091),
('posted', 0.124939),
('posting', 0.30103),
('posts', 0.124939),
('potentiallydangerous', 0.30103),
('practice', 0.176091),
('practices', 0.30103),
('predefined', 0.141044),
('prefer', 0.30103),
('preferred', 0.176091),
('preindex', 0.30103),
('presents', 0.30103),
('prevent', 0.30103),
('preventing', 0.0377886),
('preview', 0.0324458),
('previewing', 0.30103),
('previous', 0.140099),
('previously', 0.09691),
('previouslyplaced', 0.0157943),
('printers', 0.30103),
('problem', 0.124939),
('problems', 0.0299774),
('process', 0.0249474),
('processed', 0.198979),
('processing', 0.0743237),
('production', 0.18123),
('profile', 0.0579919),
('profiles', 0.09691),
('programs', 0.30103),
('progress', 0.057808),
('project', 0.0669468),
('projects', 0.30103),
('promote', 0.30103),
('provide', 0.00725098),
('provided', 0.00895819),
('provides', 0.0152187),
('providing', 0.176091),
('public', 0.30103),
('publish', 0.0348386),
('published', 0.030789),
('publishes', 0.30103),
('publishing', 0.30103),
('pull', 0.30103),
('purpose', 0.30103),
('purposes', 0.0979142),
('put', 0.0347621),
('putting', 0.30103),
('queries', 0.0132653),
('query', 0.30103),
('quick', 0.00768683),
('quickly', 0.128688),
('radio', 0.143522),
('ran', 0.30103),
('range', 0.200374),
('ranging', 0.30103),
('ranking', 0.0791812),
('rather', 0.30103),
('ratio', 0.30103),
('reach', 0.30103),
('read', 0.199973),
('readers', 0.176091),
('ready', 0.30103),
('really', 0.30103),
('rearrange', 0.0791812),
('reasons', 0.176091),
('rebuild', 0.09691),
('recalculated', 0.30103),
('recalculation', 0.30103),
('receive', 0.176091),
('recent', 0.0791812),
('recently', 0.176091),
('recipe', 0.124939),
('recipes', 0.124939),
('recipient', 0.30103),
('recipients', 0.0791812),
('recommended', 0.124939),
('records', 0.30103),
('red', 0.30103),
('redirected', 0.30103),
('reduce', 0.176091),
('reference', 0.00411292),
('referenced', 0.176091),
('references', 0.30103),
('refers', 0.30103),
('refine', 0.176091),
('region', 0.0170333),
('regional', 0.09691),
('regions', 0.0377886),
('register', 0.09691),
('registered', 0.124939),
('regular', 0.127995),
('regularlength', 0.30103),
('reindex', 0.101856),
('reindexed', 0.30103),
('related', 0.00615572),
('relationship', 0.187564),
('relationships', 0.106869),
('released', 0.30103),
('releases', 0.176091),
('relevant', 0.30103),
('remain', 0.183419),
('remote', 0.30103),
('remove', 0.0976765),
('removing', 0.30103),
('render', 0.30103),
('rendered', 0.30103),
('rendering', 0.30103),
('renders', 0.30103),
('reordering', 0.0157943),
('repeat', 0.082512),
('replacement', 0.09691),
('replacements', 0.30103),
('reply', 0.0382057),
('report', 0.0413927),
('reported', 0.30103),
('reports', 0.00983967),
('reproduced', 0.30103),
('request', 0.176091),
('requested', 0.179818),
('requests', 0.30103),
('require', 0.130078),
('required', 0.0267297),
('requires', 0.0835812),
('requiring', 0.30103),
('reset', 0.176091),
('resides', 0.30103),
('resized', 0.30103),
('resolution', 0.00896416),
('resource', 0.30103),
('resources', 0.000809978),
('respective', 0.30103),
('respectively', 0.30103),
('respond', 0.124939),
('response', 0.0669468),
('responses', 0.00895484),
('responsive', 0.0716471),
('rest', 0.0348708),
('restful', 0.0184834),
('restrict', 0.186044),
('restrictions', 0.30103),
('restrictive', 0.30103),
('restricts', 0.191184),
('result', 0.179531),
('results', 0.0473965),
('retrieved', 0.30103),
('return', 0.0612521),
('returned', 0.0350127),
('reusing', 0.30103),
('reverse', 0.176091),
('review', 0.176091),
('reviews', 0.30103),
('right', 0.0458303),
('righttoleft', 0.0513167),
('risk', 0.110762),
('role', 0.00459601),
('roles', 0.0136974),
('row', 0.0377886),
('rows', 0.30103),
('rss', 0.30103),
('run', 0.0131008),
('running', 0.00540085),
('runs', 0.0970591),
('runtime', 0.30103),
('safe', 0.30103),
('same', 0.033335),
('save', 0.00204354),
('saved', 0.0691786),
('saves', 0.30103),
('saving', 0.30103),
('say', 0.30103),
('saying', 0.176091),
('says', 0.30103),
('scaffolding', 0.30103),
('scaling', 0.30103),
('scan', 0.176091),
('scenes', 0.30103),
('schedule', 0.0792806),
('screen', 0.0347621),
('screens', 0.124939),
('scripts', 0.30103),
('scroll', 0.176091),
('search', 0.00103629),
('searchable', 0.30103),
('searches', 0.185009),
('searching', 0.047278),
('second', 0.176091),
('section', 0.0204413),
('sections', 0.0193052),
('secure', 0.01524),
('security', 0.00317636),
('see', 0.00307463),
('seen', 0.30103),
('sees', 0.30103),
('select', 0.00873573),
('selected', 0.022374),
('selecting', 0.176091),
('selects', 0.30103),
('send', 0.30103),
('sending', 0.30103),
('sends', 0.30103),
('sent', 0.129993),
('seofriendly', 0.30103),
('separate', 0.30103),
('separately', 0.176091),
('separates', 0.30103),
('sequence', 0.30103),
('serialization', 0.0170434),
('serialized', 0.30103),
('serve', 0.177189),
('server', 0.124939),
('servers', 0.30103),
('service', 0.0211893),
('services', 0.00599036),
('serving', 0.30103),
('session', 0.09691),
('set', 0.00740959),
('sets', 0.0791812),
('setting', 0.00542214),
('settings', 0.00136381),
('settingsphp', 0.0679777),
('several', 0.0509907),
('severity', 0.09691),
('share', 0.30103),
('shared', 0.176091),
('shield', 0.30103),
('shift', 0.30103),
('short', 0.124939),
('shortcut', 0.00783464),
('shortcuts', 0.0087851),
('should', 0.0117584),
('show', 0.0211893),
('showing', 0.204837),
('shown', 0.018654),
('shows', 0.102136),
('side', 0.0669468),
('similar', 0.0795761),
('simple', 0.0458095),
('since', 0.30103),
('single', 0.00663058),
('singleitem', 0.30103),
('singleline', 0.248161),
('singlevalued', 0.210151),
('site', 0.000609238),
('sites', 0.036723),
('sitewide', 0.0579919),
('situations', 0.30103),
('size', 0.124939),
('sized', 0.177487),
('sizes', 0.30103),
('sizing', 0.30103),
('slogan', 0.176091),
('smaller', 0.0669468),
('social', 0.30103),
('software', 0.0193319),
('solr', 0.0347621),
('some', 0.0137214),
('someone', 0.30103),
('sometimes', 0.176091),
('soon', 0.30103),
('sort', 0.0669468),
('sorting', 0.176091),
('sorts', 0.30103),
('source', 0.192339),
('sources', 0.30103),
('spaces', 0.30103),
('spam', 0.182335),
('spamreduction', 0.30103),
('special', 0.30103),
('specific', 0.021454),
('specifically', 0.30103),
('specification', 0.0377886),
('specify', 0.176091),
('specifying', 0.180387),
('speed', 0.30103),
('sphinx', 0.0377886),
('square', 0.30103),
('stable', 0.124939),
('staging', 0.30103),
('standard', 0.30103),
('standards', 0.0196872),
('star', 0.30103),
('start', 0.130682),
('started', 0.30103),
('starting', 0.30103),
('starts', 0.176091),
('state', 0.0579919),
('status', 0.0237782),
('stemmer', 0.0384937),
('stemming', 0.30103),
('step', 0.125487),
('stepbystep', 0.30103),
('steps', 0.000385009),
('still', 0.30103),
('storage', 0.176091),
('store', 0.124939),
('stored', 0.0643431),
('stores', 0.0352647),
('strategic', 0.30103),
('streamed', 0.30103),
('string', 0.0791812),
('strings', 0.102946),
('structure', 0.00255912),
('structures', 0.30103),
('style', 0.00683942),
('styles', 0.0512762),
('styling', 0.30103),
('subdirectory', 0.30103),
('subject', 0.0347621),
('submission', 0.30103),
('submit', 0.176091),
('submitting', 0.30103),
('subset', 0.30103),
('substituted', 0.30103),
('subterm', 0.30103),
('subtype', 0.00330539),
('subtypes', 0.0299859),
('such', 0.0106934),
('sufficient', 0.30103),
('suggested', 0.30103),
('summarizes', 0.30103),
('summary', 0.0545088),
('supplied', 0.30103),
('support', 0.13267),
('supports', 0.30103),
('sure', 0.033211),
('sustainability', 0.30103),
('switch', 0.127058),
('switcher', 0.09691),
('sync', 0.0864771),
('synchronization', 0.0108913),
('synchronize', 0.0791812),
('synchronized', 0.30103),
('synchronizing', 0.30103),
('syslog', 0.30103),
('system', 0.00974223),
('systems', 0.30103),
('tab', 0.09691),
('table', 0.0282891),
('tables', 0.176091),
('tablestyle', 0.30103),
('tabs', 0.30103),
('tag', 0.190003),
('tagging', 0.30103),
('tags', 0.0365968),
('take', 0.176091),
('taken', 0.30103),
('takes', 0.176091),
('target', 0.09691),
('task', 0.0588466),
('tasks', 0.00451582),
('taste', 0.30103),
('taxonomy', 0.00273808),
('team', 0.0377886),
('technically', 0.30103),
('technologies', 0.30103),
('technology', 0.176091),
('telephone', 0.151968),
('template', 0.30103),
('temporarily', 0.30103),
('temporary', 0.176091),
('term', 0.0323619),
('terms', 0.0204346),
('test', 0.127071),
('text', 0.00113543),
('than', 0.0396293),
('that', 0.0021957),
('the', 0.000219751),
('their', 0.0221045),
('them', 0.0229295),
('theme', 0.00284869),
('themes', 0.00612104),
('theming', 0.0410633),
('themselves', 0.30103),
('then', 0.0525345),
('there', 0.00948548),
('thereby', 0.30103),
('these', 0.0146964),
('they', 0.0226736),
('thirdparty', 0.176091),
('this', 0.00547482),
('threading', 0.09691),
('threads', 0.30103),
('three', 0.176091),
('throttle', 0.09691),
('through', 0.0738368),
('time', 0.0224476),
('timeout', 0.30103),
('times', 0.195673),
('timestamp', 0.30103),
('title', 0.00643964),
('together', 0.30103),
('toggle', 0.30103),
('tomatoes', 0.124939),
('tool', 0.30103),
('toolbar', 0.0103021),
('tooltip', 0.30103),
('top', 0.09759),
('topic', 0.0128508),
('topics', 0.00289902),
('topleft', 0.30103),
('toplevel', 0.30103),
('topright', 0.30103),
('totally', 0.30103),
('track', 0.30103),
('tracked', 0.0222764),
('tracking', 0.00474644),
('tracks', 0.176091),
('traditional', 0.30103),
('transferred', 0.30103),
('transform', 0.30103),
('translatable', 0.124939),
('translate', 0.30103),
('translated', 0.0102192),
('translation', 0.0579919),
('translations', 0.0142404),
('transmission', 0.30103),
('transported', 0.30103),
('tray', 0.124939),
('triggers', 0.30103),
('troubleshooting', 0.00934003),
('true', 0.30103),
('trusted', 0.09691),
('try', 0.30103),
('trying', 0.176091),
('turn', 0.100179),
('turning', 0.176091),
('turns', 0.30103),
('twice', 0.30103),
('twig', 0.30103),
('twigfilebased', 0.30103),
('two', 0.0426965),
('type', 0.00129911),
('types', 0.00230767),
('typically', 0.0669468),
('typing', 0.30103),
('unapproved', 0.09691),
('uncacheable', 0.30103),
('uncheck', 0.0669468),
('under', 0.0209812),
('underlying', 0.30103),
('understand', 0.176091),
('understandable', 0.30103),
('unformatted', 0.0467698),
('uniform', 0.30103),
('uninstall', 0.0113013),
('uninstalled', 0.0377886),
('uninstalling', 0.00590886),
('unique', 0.0992971),
('unlimited', 0.176091),
('unpacked', 0.30103),
('unpublish', 0.0791812),
('unpublished', 0.09691),
('unpublishing', 0.30103),
('until', 0.0511525),
('untrusted', 0.188816),
('unused', 0.0163904),
('unwanted', 0.30103),
('upcoming', 0.30103),
('update', 0.0194147),
('updated', 0.0299632),
('updates', 0.0143266),
('updating', 0.0875392),
('upload', 0.09691),
('uploaded', 0.176091),
('upper', 0.176091),
('url', 0.00282977),
('urls', 0.00654752),
('use', 0.00506609),
('used', 0.0164064),
('useful', 0.30103),
('user', 0.000718935),
('userdefined', 0.30103),
('userinterface', 0.30103),
('username', 0.09691),
('users', 0.00404986),
('uses', 0.176091),
('using', 0.00249082),
('usually', 0.30103),
('uuid', 0.0762928),
('valid', 0.176091),
('value', 0.0258864),
('values', 0.0150876),
('variables', 0.0170333),
('variations', 0.30103),
('various', 0.181508),
('vary', 0.124939),
('vegetables', 0.30103),
('verification', 0.176091),
('verified', 0.176091),
('verify', 0.0216799),
('versatile', 0.30103),
('versions', 0.30103),
('vertical', 0.30103),
('very', 0.137029),
('via', 0.176091),
('videos', 0.30103),
('view', 0.00201134),
('viewed', 0.124939),
('viewer', 0.30103),
('viewing', 0.0137883),
('viewport', 0.176091),
('viewports', 0.30103),
('views', 0.0039232),
('visibility', 0.0413927),
('visible', 0.0327972),
('visit', 0.0378247),
('visited', 0.0147233),
('visiting', 0.30103),
('visitor', 0.30103),
('visitors', 0.00800483),
('visits', 0.0211893),
('visual', 0.0511525),
('visually', 0.09691),
('vocabularies', 0.0676289),
('vocabulary', 0.0104654),
('w3c', 0.0401585),
('wait', 0.09691),
('waiting', 0.30103),
('walk', 0.183394),
('walked', 0.30103),
('walking', 0.30103),
('want', 0.00645048),
('warning', 0.09691),
('warnings', 0.30103),
('was', 0.0579919),
('way', 0.0450238),
('ways', 0.124939),
('web', 0.00415596),
('website', 0.0115819),
('week', 0.30103),
('weekly', 0.30103),
('weights', 0.0791812),
('well', 0.0684206),
('went', 0.30103),
('were', 0.0595965),
('wget', 0.09691),
('what', 0.000273766),
('when', 0.00669569),
('whenever', 0.30103),
('where', 0.0153403),
('whether', 0.0583201),
('which', 0.00460039),
('while', 0.0647376),
('white', 0.09691),
('who', 0.00170059),
('whose', 0.09691),
('why', 0.30103),
('widelyused', 0.30103),
('widget', 0.0149292),
('widgets', 0.0791812),
('width', 0.0122345),
('widths', 0.176091),
('will', 0.00445336),
('wish', 0.131957),
('with', 0.00249567),
('within', 0.0588308),
('without', 0.0791812),
('word', 0.0513646),
('words', 0.126931),
('work', 0.125782),
('workflow', 0.0485353),
('working', 0.00523858),
('would', 0.0249232),
('wraps', 0.30103),
('write', 0.30103),
('writing', 0.30103),
('written', 0.176091),
('wwwexamplecom', 0.09691),
('wysiwyg', 0.09691),
('xml', 0.30103),
('yaml', 0.0541162),
('yamlformat', 0.30103),
('yet', 0.124939),
('yml', 0.30103),
('you', 0.0014783),
('your', 0.00102698),
('zone', 0.176091);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]semaphore`
--

CREATE TABLE `[[dbprefix]]semaphore` (
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique name.',
  `value` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A value for the semaphore.',
  `expire` double NOT NULL COMMENT 'A Unix timestamp with microseconds indicating when the semaphore should expire.',
  PRIMARY KEY (`name`),
  KEY `value` (`value`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Table for holding semaphores, locks, flags, etc. that…';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sequences`
--

CREATE TABLE `[[dbprefix]]sequences` (
  `value` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'The value of the sequence.',
  PRIMARY KEY (`value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Stores IDs.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sessions`
--

CREATE TABLE `[[dbprefix]]sessions` (
  `uid` int unsigned NOT NULL COMMENT 'The "[[dbprefix]]users".uid corresponding to a session, or 0 for anonymous user.',
  `sid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'A session ID (hashed). The value is generated by Drupal''s session handlers.',
  `hostname` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The IP address that last used this session ID (sid).',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when this session last requested a page. Old records are purged by PHP automatically.',
  `session` longblob COMMENT 'The serialized contents of the user''s session, an array of name/value pairs that persists across page requests by this session ID. Drupal loads the user''s session from here   at the start of each request and saves it at the end.',
  PRIMARY KEY (`sid`),
  KEY `timestamp` (`timestamp`),
  KEY `uid` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Drupal''s session handlers read and write into the sessions…';

--
-- Dumping data for table `[[dbprefix]]sessions`
--

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shortcut`
--

CREATE TABLE `[[dbprefix]]shortcut` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `shortcut_set` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `shortcut_field__uuid__value` (`uuid`),
  KEY `shortcut_field__shortcut_set__target_id` (`shortcut_set`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COMMENT='The base table for shortcut entities.' AUTO_INCREMENT=3 ;

--
-- Dumping data for table `[[dbprefix]]shortcut`
--

INSERT INTO `[[dbprefix]]shortcut` VALUES
(1, 'default', 'a43ee85a-31ef-4c52-a53a-31d1a3abe575', 'en'),
(2, 'default', '0a0aa974-6ac0-4b85-9851-f0be49e7d997', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shortcut_field_data`
--

CREATE TABLE `[[dbprefix]]shortcut_field_data` (
  `id` int unsigned NOT NULL,
  `shortcut_set` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `weight` int DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `shortcut__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `shortcut_field__shortcut_set__target_id` (`shortcut_set`),
  KEY `shortcut_field__link__uri` (`link__uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The data table for shortcut entities.';

--
-- Dumping data for table `[[dbprefix]]shortcut_field_data`
--

INSERT INTO `[[dbprefix]]shortcut_field_data` VALUES
(1, 'default', 'en', 'Add content', -20, 'internal:/node/add', NULL, 'a:0:{}', 1),
(2, 'default', 'en', 'All content', -19, 'internal:/admin/content', NULL, 'a:0:{}', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shortcut_set_users`
--

CREATE TABLE `[[dbprefix]]shortcut_set_users` (
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "[[dbprefix]]users".uid for this set.',
  `set_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "[[dbprefix]]shortcut_set".set_name that will be displayed for this user.',
  PRIMARY KEY (`uid`),
  KEY `set_name` (`set_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Maps users to shortcut sets.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]taxonomy_index`
--

CREATE TABLE `[[dbprefix]]taxonomy_index` (
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "[[dbprefix]]node".nid this record tracks.',
  `tid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The term ID.',
  `status` int NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether the node is published (visible to non-administrators).',
  `sticky` tinyint DEFAULT '0' COMMENT 'Boolean indicating whether the node is sticky.',
  `created` int NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was created.',
  PRIMARY KEY (`nid`,`tid`),
  KEY `term_node` (`tid`,`status`,`sticky`,`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Maintains denormalized information about node/term…';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]taxonomy_term_data`
--

CREATE TABLE `[[dbprefix]]taxonomy_term_data` (
  `tid` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `vid` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`tid`),
  UNIQUE KEY `taxonomy_term_field__uuid__value` (`uuid`),
  UNIQUE KEY `taxonomy_term__revision_id` (`revision_id`),
  KEY `taxonomy_term_field__vid__target_id` (`vid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The base table for taxonomy_term entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]taxonomy_term_field_data`
--

CREATE TABLE `[[dbprefix]]taxonomy_term_field_data` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `vid` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `name` varchar(255) NOT NULL,
  `description__value` longtext,
  `description__format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `weight` int NOT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`tid`,`langcode`),
  KEY `taxonomy_term__id__default_langcode__langcode` (`tid`,`default_langcode`,`langcode`),
  KEY `taxonomy_term__revision_id` (`revision_id`),
  KEY `taxonomy_term_field__name` (`name`(191)),
  KEY `taxonomy_term__status_vid` (`status`,`vid`,`tid`),
  KEY `taxonomy_term__tree` (`vid`,`weight`,`name`(191)),
  KEY `taxonomy_term__vid_name` (`vid`,`name`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The data table for taxonomy_term entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]taxonomy_term_field_revision`
--

CREATE TABLE `[[dbprefix]]taxonomy_term_field_revision` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `name` varchar(255) DEFAULT NULL,
  `description__value` longtext,
  `description__format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `taxonomy_term__id__default_langcode__langcode` (`tid`,`default_langcode`,`langcode`),
  KEY `taxonomy_term_field__description__format` (`description__format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The revision data table for taxonomy_term entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]taxonomy_term_revision`
--

CREATE TABLE `[[dbprefix]]taxonomy_term_revision` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `taxonomy_term__tid` (`tid`),
  KEY `taxonomy_term_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The revision table for taxonomy_term entities.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]taxonomy_term_revision__parent`
--

CREATE TABLE `[[dbprefix]]taxonomy_term_revision__parent` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `parent_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `parent_target_id` (`parent_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Revision archive storage for taxonomy_term field parent.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]taxonomy_term__parent`
--

CREATE TABLE `[[dbprefix]]taxonomy_term__parent` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `parent_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `revision_id` (`revision_id`),
  KEY `parent_target_id` (`parent_target_id`),
  KEY `bundle_delta_target_id` (`bundle`,`delta`,`parent_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Data storage for taxonomy_term field parent.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]users`
--

CREATE TABLE `[[dbprefix]]users` (
  `uid` int unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`uid`),
  UNIQUE KEY `user_field__uuid__value` (`uuid`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COMMENT='The base table for user entities.' AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]users`
--

INSERT INTO `[[dbprefix]]users` VALUES
(0, '22eaa505-8d11-4c47-8ff8-1cb70eb2fe3a', 'en'),
(1, '98ccc8d3-2fb1-4e86-a506-a0aee94c87a7', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]users_data`
--

CREATE TABLE `[[dbprefix]]users_data` (
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "[[dbprefix]]users".uid this record affects.',
  `module` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the module declaring the variable.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The identifier of the data.',
  `value` longblob COMMENT 'The value.',
  `serialized` tinyint unsigned DEFAULT '0' COMMENT 'Whether value is serialized.',
  PRIMARY KEY (`uid`,`module`,`name`),
  KEY `module` (`module`),
  KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Stores module data as key/value pairs per user.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]users_field_data`
--

CREATE TABLE `[[dbprefix]]users_field_data` (
  `uid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `preferred_langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `preferred_admin_langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `name` varchar(60) NOT NULL,
  `pass` varchar(255) DEFAULT NULL,
  `mail` varchar(254) DEFAULT NULL,
  `timezone` varchar(32) DEFAULT NULL,
  `status` tinyint DEFAULT NULL,
  `created` int NOT NULL,
  `changed` int DEFAULT NULL,
  `access` int NOT NULL,
  `login` int DEFAULT NULL,
  `init` varchar(254) DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`uid`,`langcode`),
  UNIQUE KEY `user__name` (`name`,`langcode`),
  KEY `user__id__default_langcode__langcode` (`uid`,`default_langcode`,`langcode`),
  KEY `user_field__mail` (`mail`(191)),
  KEY `user_field__created` (`created`),
  KEY `user_field__access` (`access`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='The data table for user entities.';

--
-- Dumping data for table `[[dbprefix]]users_field_data`
--

INSERT INTO `[[dbprefix]]users_field_data` VALUES
(0, 'en', 'en', NULL, '', NULL, NULL, NULL, 0, [[timestamp]], [[timestamp]], 0, 0, NULL, 1),
(1, 'en', 'en', NULL, '[[admin_username]]', '[[admin_pass]]', '[[admin_email]]', 'UTC', 1, [[timestamp]], [[timestamp]], [[timestamp]], [[timestamp]], '[[admin_email]]', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]user__roles`
--

CREATE TABLE `[[dbprefix]]user__roles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `roles_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `roles_target_id` (`roles_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Data storage for user field roles.';

--
-- Dumping data for table `[[dbprefix]]user__roles`
--

INSERT INTO `[[dbprefix]]user__roles` VALUES
('user', 0, 1, 1, 'en', 0, 'administrator');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]user__user_picture`
--

CREATE TABLE `[[dbprefix]]user__user_picture` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `user_picture_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `user_picture_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `user_picture_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `user_picture_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `user_picture_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `user_picture_target_id` (`user_picture_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='Data storage for user field user_picture.';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]watchdog`
--

CREATE TABLE `[[dbprefix]]watchdog` (
  `wid` bigint NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique watchdog event ID.',
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "[[dbprefix]]users".uid of the user who triggered the event.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Type of log message, for example "user" or "page not found."',
  `message` longtext NOT NULL COMMENT 'Text of log message to be passed into the t() function.',
  `variables` longblob NOT NULL COMMENT 'Serialized array of variables that match the message string and that is passed into the t() function.',
  `severity` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'The severity level of the event. ranges from 0 (Emergency) to 7 (Debug)',
  `link` text COMMENT 'Link to view the result of the event.',
  `location` text NOT NULL COMMENT 'URL of the origin of the event.',
  `referer` text COMMENT 'URL of referring page.',
  `hostname` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Hostname of the user who triggered the event.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'Unix timestamp of when event occurred.',
  PRIMARY KEY (`wid`),
  KEY `type` (`type`),
  KEY `uid` (`uid`),
  KEY `severity` (`severity`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COMMENT='Table that contains logs of all system events.' AUTO_INCREMENT=1 ;

--
-- Dumping data for table `[[dbprefix]]watchdog`
--


/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
